# 使用 style 来配置 pyplot 风格

In [1]:

```py
import matplotlib.pyplot as plt
import numpy as np

%matplotlib inline

```

`style` 是 `pyplot` 的一个子模块，方便进行风格转换， `pyplot` 有很多的预设风格，可以使用 `plt.style.available` 来查看：

In [2]:

```py
plt.style.available

```

Out[2]:

```py
[u'dark_background', u'bmh', u'grayscale', u'ggplot', u'fivethirtyeight']
```

In [3]:

```py
x = np.linspace(0, 2 * np.pi)
y = np.sin(x)

plt.plot(x, y)

plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXoAAAEACAYAAAC9Gb03AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

例如，我们可以模仿 `R` 语言中常用的 `ggplot` 风格：

In [4]:

```py
plt.style.use('ggplot')

plt.plot(x, y)

plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEECAYAAAAvY19bAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

有时候，我们不希望改变全局的风格，只是想暂时改变一下分隔，则可以使用 `context` 将风格改变限制在某一个代码块内：

In [5]:

```py
with plt.style.context(('dark_background')):
    plt.plot(x, y, 'r-o')
    plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEECAYAAAAvY19bAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

在代码块外绘图则仍然是全局的风格。

In [6]:

```py
with plt.style.context(('dark_background')):
    pass
plt.plot(x, y, 'r-o')
plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEECAYAAAAvY19bAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

还可以混搭使用多种风格，不过最右边的一种风格会将最左边的覆盖：

In [7]:

```py
plt.style.use(['dark_background', 'ggplot'])

plt.plot(x, y, 'r-o')
plt.show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEECAYAAAAvY19bAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

事实上，我们还可以自定义风格文件。

自定义文件需要放在 `matplotlib` 的配置文件夹 `mpl_configdir` 的子文件夹 `mpl_configdir/stylelib/` 下，以 `.mplstyle` 结尾。

`mpl_configdir` 的位置可以这样查看：

In [8]:

```py
import matplotlib
matplotlib.get_configdir()

```

Out[8]:

```py
u'c:/Users/Jin\\.matplotlib'
```

里面的内容以 `属性：值` 的形式保存：

```py
axes.titlesize : 24
axes.labelsize : 20
lines.linewidth : 3
lines.markersize : 10
xtick.labelsize : 16
ytick.labelsize : 16
```

假设我们将其保存为 `mpl_configdir/stylelib/presentation.mplstyle`，那么使用这个风格的时候只需要调用：

```py
plt.style.use('presentation')
```