# figures, subplots, axes 和 ticks 对象

## figures, axes 和 ticks 的关系

这些对象的关系可以用下面的图来表示：

示例图像：

![图1](./artists_figure.png)

具体结构：

![图2](./artists_tree.png)

## figure 对象

`figure` 对象是最外层的绘图单位，默认是以 `1` 开始编号（**MATLAB** 风格，`Figure 1, Figure 2, ...`），可以用 `plt.figure()` 产生一幅图像，除了默认参数外，可以指定的参数有：

*   `num` - 编号
*   `figsize` - 图像大小
*   `dpi` - 分辨率
*   `facecolor` - 背景色
*   `edgecolor` - 边界颜色
*   `frameon` - 边框

这些属性也可以通过 `Figure` 对象的 `set_xxx` 方法来改变。

## subplot 和 axes 对象

### subplot

`subplot` 主要是使用网格排列子图：

In [1]:

```py
%pylab inline

subplot(2,1,1)
xticks([]), yticks([])
text(0.5,0.5, 'subplot(2,1,1)',ha='center',va='center',size=24,alpha=.5)

subplot(2,1,2)
xticks([]), yticks([])
text(0.5,0.5, 'subplot(2,1,2)',ha='center',va='center',size=24,alpha=.5)

show()

```

```py
Populating the interactive namespace from numpy and matplotlib

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

更高级的可以用 `gridspec` 来绘图：

In [2]:

```py
import matplotlib.gridspec as gridspec

G = gridspec.GridSpec(3, 3)

axes_1 = subplot(G[0, :])
xticks([]), yticks([])
text(0.5,0.5, 'Axes 1',ha='center',va='center',size=24,alpha=.5)

axes_2 = subplot(G[1,:-1])
xticks([]), yticks([])
text(0.5,0.5, 'Axes 2',ha='center',va='center',size=24,alpha=.5)

axes_3 = subplot(G[1:, -1])
xticks([]), yticks([])
text(0.5,0.5, 'Axes 3',ha='center',va='center',size=24,alpha=.5)

axes_4 = subplot(G[-1,0])
xticks([]), yticks([])
text(0.5,0.5, 'Axes 4',ha='center',va='center',size=24,alpha=.5)

axes_5 = subplot(G[-1,-2])
xticks([]), yticks([])
text(0.5,0.5, 'Axes 5',ha='center',va='center',size=24,alpha=.5)

show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAV0AAADtCAYAAAAcNaZ2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

## axes 对象

`subplot` 返回的是 `Axes` 对象，但是 `Axes` 对象相对于 `subplot` 返回的对象来说要更自由一点。`Axes` 对象可以放置在图像中的任意位置：

In [3]:

```py
axes([0.1,0.1,.8,.8])
xticks([]), yticks([])
text(0.6,0.6, 'axes([0.1,0.1,.8,.8])',ha='center',va='center',size=20,alpha=.5)

axes([0.2,0.2,.3,.3])
xticks([]), yticks([])
text(0.5,0.5, 'axes([0.2,0.2,.3,.3])',ha='center',va='center',size=16,alpha=.5)

show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAWcAAAD0CAYAAABHPefUAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)In [4]:

```py
axes([0.1,0.1,.5,.5])
xticks([]), yticks([])
text(0.1,0.1, 'axes([0.1,0.1,.8,.8])',ha='left',va='center',size=16,alpha=.5)

axes([0.2,0.2,.5,.5])
xticks([]), yticks([])
text(0.1,0.1, 'axes([0.2,0.2,.5,.5])',ha='left',va='center',size=16,alpha=.5)

axes([0.3,0.3,.5,.5])
xticks([]), yticks([])
text(0.1,0.1, 'axes([0.3,0.3,.5,.5])',ha='left',va='center',size=16,alpha=.5)

axes([0.4,0.4,.5,.5])
xticks([]), yticks([])
text(0.1,0.1, 'axes([0.4,0.4,.5,.5])',ha='left',va='center',size=16,alpha=.5)

show()

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAWcAAAD0CAYAAABHPefUAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

后面的 `Axes` 对象会覆盖前面的内容。

## ticks 对象

ticks 用来注释轴的内容，我们可以通过控制它的属性来决定在哪里显示轴、轴的内容是什么等等。