# 探索 NBA 数据

我们首先安装 `Goldsberry` 包，项目源地址：

[https://github.com/bradleyfay/py-Goldsberry](https://github.com/bradleyfay/py-Goldsberry)

使用 `pip` 安装：

```py
pip install py-goldsberry 
```

该包的接口与 `pandas` 兼容，可以与 `pandas` 的 `DataFrame` 一起使用。

In [1]:

```py
import goldsberry as gb
import pandas as pd

```

当前使用的版本号为：

In [2]:

```py
gb.__version__

```

Out[2]:

```py
'0.8.0.1'
```

## 球员信息

获得 `2015-2016` 赛季运动员的名单：

In [3]:

```py
players = gb.PlayerList().players()
players = pd.DataFrame(players)

players.head()

```

Out[3]:

|  | DISPLAY_LAST_COMMA_FIRST | FROM_YEAR | GAMES_PLAYED_FLAG | PERSON_ID | PLAYERCODE | ROSTERSTATUS | TEAM_ABBREVIATION | TEAM_CITY | TEAM_CODE | TEAM_ID | TEAM_NAME | TO_YEAR |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| 0 | Acy, Quincy | 2012 | Y | 203112 | quincy_acy | 1 | SAC | Sacramento | kings | 1610612758 | Kings | 2015 |
| 1 | Adams, Jordan | 2014 | Y | 203919 | jordan_adams | 1 | MEM | Memphis | grizzlies | 1610612763 | Grizzlies | 2015 |
| 2 | Adams, Steven | 2013 | Y | 203500 | steven_adams | 1 | OKC | Oklahoma City | thunder | 1610612760 | Thunder | 2015 |
| 3 | Afflalo, Arron | 2007 | Y | 201167 | arron_afflalo | 1 | NYK | New York | knicks | 1610612752 | Knicks | 2015 |
| 4 | Ajinca, Alexis | 2008 | Y | 201582 | alexis_ajinca | 1 | NOP | New Orleans | pelicans | 1610612740 | Pelicans | 2015 |

球员总数为：

In [4]:

```py
print len(players)

```

```py
464

```

通过查询特定的 `TEAM_ABBREVIATION`，我们可以查看某个球队本赛季的球员，比如 `2014-2015` 赛季的总冠军金州勇士 `GSW`：

In [5]:

```py
gsw_players = players.ix[players["TEAM_ABBREVIATION"] == "GSW"]

gsw_players[["DISPLAY_LAST_COMMA_FIRST", "FROM_YEAR", "TEAM_ABBREVIATION", "TEAM_CITY", "TEAM_NAME", "PERSON_ID"]]

```

Out[5]:

|  | DISPLAY_LAST_COMMA_FIRST | FROM_YEAR | TEAM_ABBREVIATION | TEAM_CITY | TEAM_NAME | PERSON_ID |
| --- | --- | --- | --- | --- | --- | --- |
| 30 | Barbosa, Leandro | 2003 | GSW | Golden State | Warriors | 2571 |
| 33 | Barnes, Harrison | 2012 | GSW | Golden State | Warriors | 203084 |
| 52 | Bogut, Andrew | 2005 | GSW | Golden State | Warriors | 101106 |
| 86 | Clark, Ian | 2013 | GSW | Golden State | Warriors | 203546 |
| 103 | Curry, Stephen | 2009 | GSW | Golden State | Warriors | 201939 |
| 135 | Ezeli, Festus | 2012 | GSW | Golden State | Warriors | 203105 |
| 164 | Green, Draymond | 2012 | GSW | Golden State | Warriors | 203110 |
| 209 | Iguodala, Andre | 2004 | GSW | Golden State | Warriors | 2738 |
| 262 | Livingston, Shaun | 2004 | GSW | Golden State | Warriors | 2733 |
| 263 | Looney, Kevon | 2015 | GSW | Golden State | Warriors | 1626172 |
| 279 | McAdoo, James Michael | 2014 | GSW | Golden State | Warriors | 203949 |
| 377 | Rush, Brandon | 2008 | GSW | Golden State | Warriors | 201575 |
| 398 | Speights, Marreese | 2008 | GSW | Golden State | Warriors | 201578 |
| 414 | Thompson, Jason | 2008 | GSW | Golden State | Warriors | 201574 |
| 415 | Thompson, Klay | 2011 | GSW | Golden State | Warriors | 202691 |

## 球员比赛数据

通过 `DISPLAY_LAST_COMMA_FIRST`，我们来查询宣布本赛季之后退役的科比布莱恩特（`Kobe, Bryant`）的信息：

In [6]:

```py
kobe = players.ix[players["DISPLAY_LAST_COMMA_FIRST"].str.contains("Kobe")]

kobe

```

Out[6]:

|  | DISPLAY_LAST_COMMA_FIRST | FROM_YEAR | GAMES_PLAYED_FLAG | PERSON_ID | PLAYERCODE | ROSTERSTATUS | TEAM_ABBREVIATION | TEAM_CITY | TEAM_CODE | TEAM_ID | TEAM_NAME | TO_YEAR |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| 64 | Bryant, Kobe | 1996 | Y | 977 | kobe_bryant | 1 | LAL | Los Angeles | lakers | 1610612747 | Lakers | 2015 |

为了方便，我们将 `Kobe` 的 `ID` 放到变量中去：

In [7]:

```py
kobe_id = 977

```

我们来看本赛季 `Kobe` 的比赛记录：

In [8]:

```py
kobe_logs = gb.player.game_logs(kobe_id)

kobe_logs = pd.DataFrame(kobe_logs.logs())

# 最近五场比赛
kobe_logs.head()

```

Out[8]:

|  | AST | BLK | DREB | FG3A | FG3M | FG3_PCT | FGA | FGM | FG_PCT | FTA | ... | PF | PLUS_MINUS | PTS | Player_ID | REB | SEASON_ID | STL | TOV | VIDEO_AVAILABLE | WL |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| 0 | 3 | 0 | 6 | 7 | 3 | 0.429 | 16 | 5 | 0.313 | 4 | ... | 2 | -19 | 17 | 977 | 6 | 22015 | 1 | 3 | 1 | L |
| 1 | 0 | 0 | 4 | 14 | 4 | 0.286 | 25 | 6 | 0.240 | 4 | ... | 0 | -6 | 19 | 977 | 5 | 22015 | 0 | 0 | 1 | L |
| 2 | 4 | 1 | 1 | 14 | 4 | 0.286 | 28 | 9 | 0.321 | 3 | ... | 4 | -2 | 25 | 977 | 2 | 22015 | 0 | 2 | 1 | L |
| 3 | 2 | 0 | 9 | 11 | 4 | 0.364 | 24 | 10 | 0.417 | 4 | ... | 0 | 16 | 27 | 977 | 12 | 22015 | 2 | 1 | 1 | W |
| 4 | 5 | 0 | 3 | 11 | 7 | 0.636 | 21 | 10 | 0.476 | 12 | ... | 3 | 6 | 38 | 977 | 5 | 22015 | 2 | 2 | 1 | W |

5 rows × 27 columns

截至到全明星赛前，本赛季 `Kobe` 一共参加了 44 场比赛，其场均数据为：

In [9]:

```py
kobe_logs.Game_ID

```

Out[9]:

```py
0     0021500795
1     0021500776
2     0021500767
3     0021500747
4     0021500734
5     0021500720
6     0021500697
7     0021500662
8     0021500653
9     0021500638
10    0021500614
11    0021500608
12    0021500592
13    0021500576
14    0021500549
15    0021500539
16    0021500476
17    0021500458
18    0021500455
19    0021500440
20    0021500435
21    0021500422
22    0021500385
23    0021500370
24    0021500349
25    0021500342
26    0021500325
27    0021500308
28    0021500301
29    0021500286
30    0021500269
31    0021500263
32    0021500253
33    0021500244
34    0021500214
35    0021500201
36    0021500188
37    0021500151
38    0021500135
39    0021500095
40    0021500077
41    0021500059
42    0021500045
43    0021500031
44    0021500017
Name: Game_ID, dtype: object
```

In [10]:

```py
def show_avg_info(avg):
    print "得分：{:.1f}".format(avg.ix["PTS"])
    print "篮板：{:.1f}".format(avg.ix["REB"])
    print "助攻：{:.1f}".format(avg.ix["AST"])
    print "盖帽：{:.1f}".format(avg.ix["BLK"])
    print "时间：{:.1f}".format(avg.ix["MIN"])
    print "抢断：{:.1f}".format(avg.ix["STL"])
    print "失误：{:.1f}".format(avg.ix["TOV"])
    print "犯规：{:.1f}".format(avg.ix["PF"])
    print "投篮：{:.1f}%".format(avg.ix["FGM"] * 100 / avg.ix["FGA"])
    print "三分：{:.1f}%".format(avg.ix["FG3M"] * 100 / avg.ix["FG3A"])
    print "罚篮：{:.1f}%".format(avg.ix["FTM"] * 100 / avg.ix["FTA"])
    print "后篮板：{:.1f}".format(avg.ix["DREB"])
    print "前篮板：{:.1f}".format(avg.ix["OREB"])
    print "正负值：{:.1f}".format(avg.ix["PLUS_MINUS"])

show_avg_info(kobe_logs.mean())

```

```py
得分：16.9
篮板：4.2
助攻：3.4
盖帽：0.2
时间：29.3
抢断：1.0
失误：2.2
犯规：1.9
投篮：34.9%
三分：28.0%
罚篮：80.3%
后篮板：3.5
前篮板：0.7
正负值：-7.9

```

再看一下史提芬库里的场均数据（不要问我为什么跪着看球）：

In [11]:

```py
curry_id = 201939
curry_logs = gb.player.game_logs(curry_id)
curry_logs = pd.DataFrame(curry_logs.logs())

show_avg_info(curry_logs.mean())

```

```py
得分：29.8
篮板：5.3
助攻：6.6
盖帽：0.2
时间：33.9
抢断：2.1
失误：3.3
犯规：2.0
投篮：50.8%
三分：45.4%
罚篮：91.2%
后篮板：4.5
前篮板：0.9
正负值：15.5

```

当然我们也可以对比一下职业生涯的数据：

In [12]:

```py
kobe_career = gb.player.career_stats(kobe_id)
curry_career = gb.player.career_stats(curry_id)

```

职业生涯最高：

In [13]:

```py
def show_career_high(career):
    career_high = pd.DataFrame(career.career_high()).ix[[0,1,5]]
    print career_high[["GAME_DATE", "STAT", "STAT_VALUE", "VS_TEAM_CITY", "VS_TEAM_NAME"]]

print "Kobe"
show_career_high(kobe_career)

print "Curry"
show_career_high(curry_career)

```

```py
Kobe
     GAME_DATE STAT  STAT_VALUE VS_TEAM_CITY VS_TEAM_NAME
0  JAN 22 2006  PTS          81      Toronto      Raptors
1  JAN 24 2010  REB          16      Toronto      Raptors
5  JAN 15 2015  AST          17    Cleveland    Cavaliers
Curry
     GAME_DATE STAT  STAT_VALUE VS_TEAM_CITY VS_TEAM_NAME
0  FEB 27 2013  PTS          54     New York       Knicks
1  DEC 28 2015  REB          14   Sacramento        Kings
5  DEC 27 2013  AST          16      Phoenix         Suns

```

本赛季最高：

In [14]:

```py
def show_season_high(career):
    career_high = pd.DataFrame(career.season_high()).ix[[0,1,5]]
    print career_high[["GAME_DATE", "STAT", "STAT_VALUE", "VS_TEAM_CITY", "VS_TEAM_NAME"]]

print "Kobe"
show_season_high(kobe_career)

print "Curry"
show_season_high(curry_career)

```

```py
Kobe
     GAME_DATE STAT  STAT_VALUE VS_TEAM_CITY  VS_TEAM_NAME
0  FEB 02 2016  PTS          38    Minnesota  Timberwolves
1  FEB 04 2016  REB          12  New Orleans      Pelicans
5  NOV 15 2015  AST           9      Detroit       Pistons
Curry
     GAME_DATE STAT  STAT_VALUE VS_TEAM_CITY VS_TEAM_NAME
0  OCT 31 2015  PTS          53  New Orleans     Pelicans
1  DEC 28 2015  REB          14   Sacramento        Kings
5  JAN 25 2016  STL           5  San Antonio        Spurs

```

## 比赛信息

In [15]:

```py
game_ids = gb.GameIDs()
game_ids = pd.DataFrame(game_ids.game_list())

game_ids.head()

```

Out[15]:

|  | AST | BLK | DREB | FG3A | FG3M | FG3_PCT | FGA | FGM | FG_PCT | FTA | ... | PTS | REB | SEASON_ID | STL | TEAM_ABBREVIATION | TEAM_ID | TEAM_NAME | TOV | VIDEO_AVAILABLE | WL |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| 0 | 28 | 4 | 45 | 29 | 8 | 0.276 | 124 | 56 | 0.452 | 46 | ... | 147 | 64 | 22015 | 7 | DET | 1610612765 | Detroit Pistons | 11 | 1 | W |
| 1 | 30 | 2 | 36 | 23 | 9 | 0.391 | 87 | 53 | 0.609 | 34 | ... | 142 | 46 | 22015 | 9 | SAC | 1610612758 | Sacramento Kings | 15 | 1 | W |
| 2 | 34 | 2 | 30 | 21 | 9 | 0.429 | 86 | 52 | 0.605 | 13 | ... | 123 | 38 | 22015 | 10 | SAS | 1610612759 | San Antonio Spurs | 13 | 1 | W |
| 3 | 29 | 6 | 36 | 35 | 16 | 0.457 | 95 | 52 | 0.547 | 15 | ... | 131 | 46 | 22015 | 10 | GSW | 1610612744 | Golden State Warriors | 15 | 1 | W |
| 4 | 34 | 8 | 38 | 31 | 8 | 0.258 | 104 | 52 | 0.500 | 16 | ... | 122 | 46 | 22015 | 10 | SAC | 1610612758 | Sacramento Kings | 20 | 1 | L |

5 rows × 29 columns

## 获得运动员的头像

In [16]:

```py
from IPython.display import Image

Image("http://stats.nba.com/media/players/230x185/"+str(kobe_id)+".png")

```

Out[16]:![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOYAAAC5CAMAAAALbLOrAAAC91BMVEUAAAD9uzT/wzlMTlBaYGNc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)In [17]:

```py
Image("http://stats.nba.com/media/players/230x185/"+str(curry_id)+".png")

```

Out[17]:![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOYAAAC5CAMAAAALbLOrAAADAFBMVEUAAADrsIz4wJs7ccLRmHz7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)

## More

修改了 `goldsberry\player\_Player.py` 代码中的错误，使之能够查询退役球员的信息，修改后的代码在本文件夹下，放到安装目录之后下面的代码均可以运行：

In [18]:

```py
from goldsberry.player import _Player as pl_old

```

1997 年的球员列表：

In [19]:

```py
players_1997 = pl_old.PlayerList(1997)

players_1997 = pd.DataFrame(players_1997)

```

乔丹的球员 ID：

In [20]:

```py
jordan_id = players_1997["PERSON_ID"].ix[players_1997["DISPLAY_LAST_COMMA_FIRST"].str.contains("Jordan, Michael")]
jordan_id = jordan_id[jordan_id.index[0]]
jordan_id

```

Out[20]:

```py
893
```

乔丹在 1997-1998 赛季常规赛表现：

In [21]:

```py
jordan_logs_1997 = pl_old.game_logs(jordan_id, season="1997")
jordan_logs_1997 = pd.DataFrame(jordan_logs_1997.logs())

show_avg_info(jordan_logs_1997.mean())

```

```py
得分：28.7
篮板：5.8
助攻：3.5
盖帽：0.5
时间：38.9
抢断：1.7
失误：2.3
犯规：1.8
投篮：46.5%
三分：23.8%
罚篮：78.4%
后篮板：4.2
前篮板：1.6
正负值：7.3

```

乔丹在 1997-1998 赛季季后赛表现：

In [22]:

```py
jordan_logs_1997 = pl_old.game_logs(jordan_id, season="1997", seasontype=2)
jordan_logs_1997 = pd.DataFrame(jordan_logs_1997.logs())

show_avg_info(jordan_logs_1997.mean())

```

```py
得分：32.4
篮板：5.1
助攻：3.5
盖帽：0.6
时间：41.0
抢断：1.5
失误：2.1
犯规：2.2
投篮：46.2%
三分：30.2%
罚篮：81.2%
后篮板：3.5
前篮板：1.6
正负值：7.5

```

头像：

In [23]:

```py
Image("http://stats.nba.com/media/players/230x185/"+str(jordan_id)+".png")

```

Out[23]:![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAOYAAAC5CAMAAAALbLOrAAAABGdBTUEAALGOfPtRkwAAAwBQTFRF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)