# 插值

In [1]:

```py
import numpy as np
import matplotlib.pyplot as plt
%matplotlib inline

```

设置 **`Numpy`** 浮点数显示格式：

In [2]:

```py
np.set_printoptions(precision=2, suppress=True)

```

从文本中读入数据，数据来自 [http://kinetics.nist.gov/janaf/html/C-067.txt](http://kinetics.nist.gov/janaf/html/C-067.txt) ，保存为结构体数组：

In [3]:

```py
data = np.genfromtxt("JANAF_CH4.txt", 
                  delimiter="\t", # TAB 分隔
                  skiprows=1,     # 忽略首行
                  names=True,     # 读入属性
                  missing_values="INFINITE",  # 缺失值
                  filling_values=np.inf)      # 填充缺失值

```

显示部分数据：

In [4]:

```py
for row in data[:7]:
    print "{}\t{}".format(row['TK'], row['Cp'])
print "...\t..."

```

```py
0.0	0.0
100.0	33.258
200.0	33.473
250.0	34.216
298.15	35.639
300.0	35.708
350.0	37.874
...	...

```

绘图：

In [5]:

```py
p = plt.plot(data['TK'], data['Cp'], 'kx')
t = plt.title("JANAF data for Methane $CH_4$")
a = plt.axis([0, 6000, 30, 120])
x = plt.xlabel("Temperature (K)")
y = plt.ylabel(r"$C_p$ ($\frac{kJ}{kg K}$)")

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAZYAAAEbCAYAAAD51qKQAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

## 插值

假设我们要对这组数据进行插值。

先导入一维插值函数 `interp1d`：

```py
interp1d(x, y)
```

In [6]:

```py
from scipy.interpolate import interp1d

```

In [7]:

```py
ch4_cp = interp1d(data['TK'], data['Cp'])

```

`interp1d` 的返回值可以像函数一样接受输入，并返回插值的结果。

单个输入值，注意返回的是数组：

In [8]:

```py
ch4_cp(382.2)

```

Out[8]:

```py
array(39.565144000000004)
```

输入数组，返回的是对应的数组：

In [9]:

```py
ch4_cp([32.2,323.2])

```

Out[9]:

```py
array([ 10.71,  36.71])
```

默认情况下，输入值要在插值允许的范围内，否则插值会报错：

In [10]:

```py
ch4_cp(8752)

```

```py
---------------------------------------------------------------------------
ValueError                                Traceback (most recent call last)
<ipython-input-10-5d727af9aa33> in <module>()
----> 1  ch4_cp(8752)

d:\Miniconda\lib\site-packages\scipy\interpolate\polyint.pyc in __call__(self, x)
 77         """
 78         x, x_shape = self._prepare_x(x)
---> 79  y = self._evaluate(x)
 80         return self._finish_y(y, x_shape)
 81 

d:\Miniconda\lib\site-packages\scipy\interpolate\interpolate.pyc in _evaluate(self, x_new)
 496         #    The behavior is set by the bounds_error variable.
 497         x_new = asarray(x_new)
--> 498  out_of_bounds = self._check_bounds(x_new)
 499         y_new = self._call(self, x_new)
 500         if len(y_new) > 0:

d:\Miniconda\lib\site-packages\scipy\interpolate\interpolate.pyc in _check_bounds(self, x_new)
 526                 "range.")
 527         if self.bounds_error and above_bounds.any():
--> 528 raise ValueError("A value in x_new is above the interpolation " 529                 "range.")
 530 

ValueError: A value in x_new is above the interpolation range.
```

但我们可以通过参数设置允许超出范围的值存在：

In [11]:

```py
ch4_cp = interp1d(data['TK'], data['Cp'], 
                  bounds_error=False)

```

不过由于超出范围，所以插值的输出是非法值：

In [12]:

```py
ch4_cp(8752)

```

Out[12]:

```py
array(nan)
```

可以使用指定值替代这些非法值：

In [13]:

```py
ch4_cp = interp1d(data['TK'], data['Cp'], 
                  bounds_error=False, fill_value=-999.25)

```

In [14]:

```py
ch4_cp(8752)

```

Out[14]:

```py
array(-999.25)
```

### 线性插值

`interp1d` 默认的插值方法是线性，关于线性插值的定义，请参见：

*   维基百科-线性插值： [https://zh.wikipedia.org/wiki/%E7%BA%BF%E6%80%A7%E6%8F%92%E5%80%BC](https://zh.wikipedia.org/wiki/%E7%BA%BF%E6%80%A7%E6%8F%92%E5%80%BC)
*   百度百科-线性插值： [http://baike.baidu.com/view/4685624.htm](http://baike.baidu.com/view/4685624.htm)

其基本思想是，已知相邻两点 $x_1,x_2$ 对应的值 $y_1,y_2$ ，那么对于 $(x_1,x_2)$ 之间的某一点 $x$ ，线性插值对应的值 $y$ 满足：点 $(x,y)$ 在 $(x_1,y_1),(x_2,y_2)$ 所形成的线段上。

应用线性插值：

In [15]:

```py
T = np.arange(100,355,5)
plt.plot(T, ch4_cp(T), "+k")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

其中红色的圆点为原来的数据点，黑色的十字点为对应的插值点，可以明显看到，相邻的数据点的插值在一条直线上。

### 多项式插值

我们可以通过 `kind` 参数来调节使用的插值方法，来得到不同的结果：

*   `nearest` 最近邻插值
*   `zero` 0阶插值
*   `linear` 线性插值
*   `quadratic` 二次插值
*   `cubic` 三次插值
*   `4,5,6,7` 更高阶插值

最近邻插值：

In [16]:

```py
cp_ch4 = interp1d(data['TK'], data['Cp'], kind="nearest")
p = plt.plot(T, cp_ch4(T), "k+")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

0阶插值：

In [17]:

```py
cp_ch4 = interp1d(data['TK'], data['Cp'], kind="zero")
p = plt.plot(T, cp_ch4(T), "k+")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

二次插值：

In [18]:

```py
cp_ch4 = interp1d(data['TK'], data['Cp'], kind="quadratic")
p = plt.plot(T, cp_ch4(T), "k+")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

三次插值：

In [19]:

```py
cp_ch4 = interp1d(data['TK'], data['Cp'], kind="cubic")
p = plt.plot(T, cp_ch4(T), "k+")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

事实上，我们可以使用更高阶的多项式插值，只要将 `kind` 设为对应的数字即可：

四次多项式插值：

In [20]:

```py
cp_ch4 = interp1d(data['TK'], data['Cp'], kind=4)
p = plt.plot(T, cp_ch4(T), "k+")
p = plt.plot(data['TK'][1:7], data['Cp'][1:7], 'ro', markersize=8)

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXUAAAEACAYAAABMEua6AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAE7ZJREFUeJzt3W+MHHd9x/H313Z8uShqXLgqhAaTAKV/ROk5DZSTArWL
40IfQHlC/0gUtZUc9UEotElMCuEuBhScGkofVCgKQQ1pG1FRCkVUisuRSxrJBCh3EGIoBZUYQzFc
SRBknWscf/vg5s6b893u3t7u3uzM+yWdMp6Z3f3ld7Ofm/3O7zcbmYkkqRq2bHYDJEm9Y6hLUoUY
6pJUIYa6JFWIoS5JFWKoS1KFtAz1iDg/Ih6MiLmIOBYRtxTrXxoRn4uI2Yj4fES8ZDDNlSS1Eu3G
qUfEBZnZiIhtwAPAdcA7gfdk5j0R8Wrghszc0//mSpJaaVt+ycxGsbgd2Ao8CnwPuKhYvwP4Tl9a
J0lal07O1LcAXwSeD3wgM2+IiOeyeNaeLP5hmMjMb/e7sZKk1jo5Uz+TmePApcArImI3cAfwpszc
CbwF+FBfWylJ6kjbM/Wn7RxxE3AKeEdm/lSxLoDHMvOiVfb3xjKStE6ZGd0+tt3ol7GI2FEsjwJX
A3PANyLi14vdfgP4eovG+ZPJ5OTkprehLD/2hf1gXzz95/HHH+f9Bw7w9n37us3yZdvabL8EuLOo
q28B7srMT0fEfuBvImKExTP3/RtuiSTVUKPR4Pq9ezlw9Cg7gXdt8PlahnpmPgRcscr6LwC/tsHX
lqTau/3gweVA7wVnlA7I7t27N7sJpWFfLLIfzqpzX8zPzvYs0GGdF0rX/eQR2c/nl6RhN7V7N1P3
3bf876CPF0olSf311MhIT5/PUJekTTS2axfHe/h8ll8kaROdOnWK6175yuWLpRstvxjqkrTJTp06
xW1TU8zPzfHuI0cMdUmqiojwQqkkaZGhLkkVYqhL0iaYmZnpy/Ma6pK0CQx1SVJb7e7SKEnqkZmZ
meUz9Jtvvnl5/e7du3t2/xtDXZIGZGV4T01N9fw1LL9IUoUY6pK0Cfp1u2FnlEpSiTijVJK0zFCX
pAox1CWpT/o1wagVQ12S+sRQlyRtiJOPJKmHBjFrtBVDXZJ6aBCzRlux/CJJFWKoS1KfDKLcspIz
SiWpRJxRKklaZqhLUoUY6pJUIYa6JG3AZswabcVQl6QNMNQlSX3jjFJJWqfNvhVAK4a6JK3TZt8K
oBXLL5JUIS3P1CPifOA+YATYDnwiM2+MiI8ALyx22wE8lpm7+tpSSSqhzS63rNT2NgERcUFmNiJi
G/AAcF1mPtC0/TCLof6uVR7rbQIkaR02epuAtjX1zGwUi9uBrcAPm148gNcDe7ptgCSpd9rW1CNi
S0TMASeBezPzWNPmlwMnM/Ob/WqgJKlznZypnwHGI+Ii4J6I2J2ZM8Xm3wP+odXjm68Kl2G4jyR1
Y2Zmpi/51Tw8shfWdevdiLgJOJWZh4sa+wngisz87hr7W1OXVAlTU1MDGbrY11vvRsRYROwolkeB
q4HZYvNe4KtrBbokafDalV8uAe6MiC0s/gG4KzOni22/A9zdz8ZJ0mYq88zRtfjNR5LUgUqUXyRJ
w8VQl6QOlLXcspLlF0kqEcsvkqRlhrokVYihLkmFsn01XTcMdUkqGOqSpFLx6+wk1dowzhptxVCX
VGtl/r7Rblh+kaQKMdQlqTCM5ZaVnFEqSSXijFJJ0jJDXVKtVGEseiuGuqRaMdQlSUPDceqSKq9q
E4xaMdQlVV7VJhi1YvlFkirEUJdUK1Urt6zk5CNJKhEnH0mSlhnqkiqp6uPR12KoS6okQ12SNPQc
py6pMuo0yWgthrqkyqjTJKO1WH6RpAox1CVVUl3KLSs5+UiSSsTJR5KkZYa6JFWIoS5paNV1glEr
hrqkoWWon6tlqEfE+RHxYETMRcSxiLiladu1EfHViPhKRBzqf1MlSe20nHyUmU9ExJ7MbETENuCB
iLgKOA94DfDizHwyIn5mEI2VJGeNttZ2RmlmNorF7cBW4FHgHcAtmflksc8P+tZCSWrirNHW2tbU
I2JLRMwBJ4F7M/Nh4IXAKyLisxExExFX9ruhkqT2OjlTPwOMR8RFwD0Rsbt43E9n5ssi4iXAPwLP
62tLJWkFyy3n6viGXpn5o4j4FHAlcAL4WLH+8xFxJiKemZn/u/JxzR+NrHlJ6qUq5EnzNYJeaHmb
gIgYA05n5mMRMQrcA9wMvAB4dmZORsQLgU9n5s5VHu9tAiRtyMzMTCXCu1P9vk3AJcBnipr6g8An
M3Ma+BDwvIh4CLgb+INuGyBJrTgWfX3aDWl8CLhilfVPAm/oV6MkSd3xSzIklY5j0btnqEsqHcei
d897v0hShRjqkkrNcsv6+M1HklQiGx3SaE1d0qZoNBrcfvAg87OzbF1Y4KmREcZ27WL/5CSjo6Ob
3byh5Zm6pIFrNBpcv3cvB44epXnW4nHg0MQEh6enaxvsfkeppKFz+8GD5wQ6wE7gwNGj3OZol64Z
6pIGqtFo8B8f+cg5gb5kJzA/NzfIJlWKoS5pYJbKLs/+1rda7rdtYWEwDaogQ13SwCyVXc5rs9/p
kZGBtKeKDHVJAzM/O8tOYIzFi6KreQQYGx8fXKMqxlCXNDBbi7LKfuAQ5wb7I8CtExNc44XSrjlO
XdLAPFWUVUaBw8BtwDyLQXQaOHbZZfx9jYcz9oKhLmlgGs98JsdZHOEyCry5adsjwD+//vUG+gZZ
fpE0MOdffjmHJibOKbscx7JLr3imLmlgzjvvPA5PT3Pb1BTzc3NsW1jg9MgIY+PjHJ6a8iy9Bwx1
SX216hdejI6y98YbvQNjHxjqkvrKL7wYLGvqklQhhrqkgbHc0n/eeleSSsRb70oqlaWLotochrqk
njLUN5ehLkkV4pBGSRu26lh0zh3OqP4z1CVtmGPRy8PyiyRViKEuqacst2wux6lLUok4Tl3SwDls
sbwMdUnrZqiXl6EuSRXikEZJHXEs+nAw1CV1xLHow8HyiyRVSMtQj4jzI+LBiJiLiGMRcUuxfioi
TkTEbPHzqsE0V1IZWG4pr7bj1CPigsxsRMQ24AHgOuCVwI8z831tHus4dWmIzczMGOAD1vdx6pnZ
KBa3A1uBR5deu9sXlTQcHLo4fNqGekRsiYg54CRwb2Y+XGy6NiK+FBF3RMSOvrZSktSRtqNfMvMM
MB4RFwH3RMRu4APAwWKXdwLvBf64X42UNDgOXRxuHQ9pzMwfRcSngCszc2ZpfUR8EPjkWo9rHvbk
QSGVn0MXB6v5j2gvtLxQGhFjwOnMfCwiRoF7gJuBhzPze8U+bwFekpm/v8rjvVAqDbGpqSlDfcA2
eqG03Zn6JcCdEbGFxfr7XZk5HREfjohxIIH/Bq7ptgGSystP1sPHW+9KNeewxXLx1ruSNsRhi9Vi
qEtShXhDL6mGHLZYXYa6VEMOW6wuyy+SVCGGulQDrS6GWm6pFkNdqgFDvT4MdUmqEC+UShXlCJd6
MtSlinKESz1ZfpGkCjHUpQpZ64Ko5Zb6MNSlCjHUZahLUoV4oVQaco5yUTNDXRpyjnJRM8svklQh
hro0ZJzyr1YMdWnIGOpqxVCXpArxQqk0BBzhok4Z6tIQcISLOmX5RSqhVnVzqRVDXSohL4aqW4a6
NGQMdbViTV0qCS+GqhcMdakkvBiqXjDUpQFqNBrcfvAg87OzbF1Y4KmREcZ27WL/5CSjo6Ob3TxV
gKEuDUij0eD6vXs5cPQoO5vWHz9yhOvuv5/D09PLwW65Rd2KzOzfk0dkP59fGiZ//da38rpDh54W
6EuOAx+74QbefOjQoJulkokIMjO6fbyjX6QBmZ+dXTXQAXYC83Nzg2yOKspQlwZk68JCy+3b2myX
OmGoS322NEzxqZGRlvudbrNd6oShLvXZUqiP7drF8TX2eQQYGx8fVJNUYYa6NCD7Jyc5NDFxTrAf
B26dmOAax6WrBxzSKPXBWrNDXzM5ycc+8xnm5+bYtrDA6ZERxsbHOTw15Th19UTLIY0RcT5wHzAC
bAc+kZk3Nm3/c+AvgbHM/OEqj3dIo2pvamrK2aHqWF+HNGbmE8CezBwHXgzsiYirihd+DnA1i+VA
qda8Va7Kom1NPTMbxeJ2YCuwdEb+PuCGPrVLGireKldl0TbUI2JLRMwBJ4F7M/NYRLwWOJGZX+57
C6UhZ6hrkNpeKM3MM8B4RFwE3BMRvwXcCOxr2m3N+k9zLdFbiKpKvFWueqH5OOqFdd37JSJuAhK4
Flgqy1wKfAd4aWZ+f8X+XihVZczMzKwZ1l4MVa/09UJpRIxFxI5ieZTFC6NHM/PizLw8My8HTgBX
rAx0qWq8GKph0K78cglwZ0RsYfEPwF2ZOb1iH0/FVXuWW1QWLUM9Mx8Crmizz/N62iKpRDqtmxvq
KovKzyhtVQdttU311Xxc+BVzGjaVuPdLq1pnN9usndabv38Ns8qHeq+fzzd8ffmpTsOgkuWXVnXQ
pe2rbevkTWvJphpW/h47qZ37e9cwGKpQb34jtnsTtqqDrrZtZmZmebnbiSQG/vBY+buydq6qGNpQ
7/WbsNXzdToCwlCXtNmGKtS70SpkOw3gXvwBMfAHr5sSy9K/pWFV+lDfaK2zm23reVN7Fl9e3ZZY
/D1pmJU+1Dt5I/b6TbiePwTWYiWVSelCvexntL0+iy/7/+8wWM8F9OZ/S1U0VKFe9jdiN2fxhvrG
dXMB3T5XVQ3V5KOyvxF73T4nOklar1Kcqdfhywa6GYXhWfxZThaSOlOKUK/DxcZuRmG0UrfA72Yk
S536R1pSilDXWXU+i6/i/5M0aKUL9bq9qXs9RLKswdhoNLj94EHmZ2fZurDAUyMjjO3axf7JSUZH
RwEnC0m9sCmhPswjXHptkEMkNyvwG40G1+/dy4GjR9nZtP74kSNcd//9HJ6eXg72Zo5kkdavdKGu
swZ5Ft/r30nz891+8OA5gQ6wE7jh6FHesHcvL7r66speJJcGqXTlF53Vaaj1YvTQWqHe7R+C5m3z
s7PnBPqS5wK/cOGFy3+gPBuXNmZgoV6HYYuD1OlIkI32ey/O7rcuLLTcvq3NdjDUpU4NLNTrMGxx
kDoNuX4G/kprPd8PHn+85eNOj4wsv66kjbH8UjHrCca1An+mxReGLG1fbdtaz/fXTzzB8S98YdUS
zCPA2Pj4utsuaXWbEuq+efunVd/24ux+5fN08olr/+Qk191//7mjX4BbJyY47Kc2qWcM9RrpReB3
81qjo6Mcnp7mtqkp5ufm2LawwOmREcbGxzk8NbXqcEZJ3YnM7N+TR+Tb9+07Z5KJhkcZx71LVRYR
ZGZ0/fh+h3qy+DH70MTEmpNMJEmLNhrqA7n17k7gwNGj3GbtVJL6amD3U98JzM/NDerlJKmWBvol
GZ1MMpEkdW+gob40yUSS1B8DC/XmSSaSpP5w9IsklUjphzS+bd8+xsbHucZJJpLUVulDvZ/PL0lV
MxTj1CVJg9Ey1CPi/Ih4MCLmIuJYRNxSrH9nRHypWD8dEc8ZTHMlSa20DPXMfALYk5njwIuBPRFx
FXBrZv5Ksf7jwGT/mzrclm5XK/tiif1wln3RO23LL5nZKBa3A1uBH2bmj5t2uRCY70PbKsWD9iz7
YpH9cJZ90Tttb70bEVuALwLPBz6QmceK9e8G3gA0gJf1s5GSpM50cqZ+piizXAq8IiJ2F+vflpk7
gb8F/qqfjZQkdWZdQxoj4ibgVGYeblq3E/jXzHzRKvs7nlGS1mkjQxpbll8iYgw4nZmPRcQocDVw
c0S8IDO/Uez2WmC21w2TJK1fu5r6JcCdRV19C3BXZk5HxEcj4ueBp4BvAn/S53ZKkjrQ1xmlkqTB
6npGaUR8KCJORsRDTeueERH/FhFfj4gjEbGjaduNEfFfEfG1iNi30YaXyRp9MRURJyJitvh5ddO2
KvfFcyLi3oh4OCK+EhFvKtbX7tho0Re1OzZaTGSs43GxVl/05rjIzK5+gJcDu4CHmtbdCtxQLB8A
3lMs/xIwB5wHXAZ8A9jS7WuX7WeNvpgE/myVfaveF88CxovlC4H/BH6xjsdGi76o67FxQfHfbcBn
gavqeFy06IueHBddn6ln5r8Dj65Y/RrgzmL5TuC3i+XXAndn5pOZ+a2iUS/t9rXLZo2+AFjtQnHV
++J7mTlXLP8E+Crws9Tw2GjRF1DPY2PlRMZHqeFxAWv2BfTguOj1Db0uzsyTxfJJ4OJi+dnAiab9
TnD24K6ya4t75NzR9LGyNn0REZex+AnmQWp+bDT1xWeLVbU7NiJiS0TMsfj7vzczH6amx8UafQE9
OC76dpfGXPzc0OoqbNWv0H4AuBwYB/4HeG+LfSvXFxFxIfBPwJ/m028rUbtjo+iLj7LYFz+hpsdG
njuRcc+K7bU5Llbpi9306LjodaifjIhnAUTEJcD3i/XfAZrv5Hhpsa6yMvP7WQA+yNmPS5Xvi4g4
j8VAvyszP16sruWx0dQXf7fUF3U+NgAy80fAp4BfpabHxZKmvriyV8dFr0P9X4A3FstvZPEOjkvr
fzcitkfE5cDPAZ/r8WuXSnGALnkdsDQyptJ9EREB3AEcy8z3N22q3bGxVl/U8diIiLGlckKcncg4
Sz2Pi1X7YumPW6H742IDV2/vBr4L/B/wbeAPgWcAnwa+DhwBdjTt/xcsFvi/BvzmZl997uXPKn3x
R8CHgS8DX2LxQL24Jn1xFXCGxav1s8XPq+p4bKzRF6+u47EB/DKLNwacK/7fry/W1/G4WKsvenJc
OPlIkirEr7OTpAox1CWpQgx1SaoQQ12SKsRQl6QKMdQlqUIMdUmqEENdkirk/wFRMdOvMWDKNgAA
AABJRU5ErkJggg==
)

可以参见：

*   维基百科-多项式插值：[https://zh.wikipedia.org/wiki/%E5%A4%9A%E9%A1%B9%E5%BC%8F%E6%8F%92%E5%80%BC](https://zh.wikipedia.org/wiki/%E5%A4%9A%E9%A1%B9%E5%BC%8F%E6%8F%92%E5%80%BC)
*   百度百科-插值法：[http://baike.baidu.com/view/754506.htm](http://baike.baidu.com/view/754506.htm)

对于二维乃至更高维度的多项式插值：

In [21]:

```py
from scipy.interpolate import interp2d, interpnd

```

其使用方法与一维类似。

### 径向基函数

关于径向基函数，可以参阅：

*   维基百科-Radial basis fucntion：[https://en.wikipedia.org/wiki/Radial_basis_function](https://en.wikipedia.org/wiki/Radial_basis_function)

径向基函数，简单来说就是点 $x$ 处的函数值只依赖于 $x$ 与某点 $c$ 的距离：

$$\Phi(x,c) = \Phi(\|x-c\|)$$In [22]:

```py
x = np.linspace(-3,3,100)

```

常用的径向基（`RBF`）函数有：

高斯函数：

In [23]:

```py
plt.plot(x, np.exp(-1 * x **2))
t = plt.title("Gaussian")

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEKCAYAAAAPVd6lAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

`Multiquadric` 函数：

In [24]:

```py
plt.plot(x, np.sqrt(1 + x **2))
t = plt.title("Multiquadric")

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEKCAYAAAAPVd6lAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

`Inverse Multiquadric` 函数：

In [25]:

```py
plt.plot(x, 1. / np.sqrt(1 + x **2))
t = plt.title("Inverse Multiquadric")

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAXIAAAEKCAYAAAAPVd6lAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

### 径向基函数插值

对于径向基函数，其插值的公式为：

$$ f(x) = \sum_j n_j \Phi(\|x-x_j\|) $$

我们通过数据点 $x_j$ 来计算出 $n_j$ 的值，来计算 $x$ 处的插值结果。

In [26]:

```py
from scipy.interpolate.rbf import Rbf

```

使用 `multiquadric` 核的：

In [27]:

```py
cp_rbf = Rbf(data['TK'], data['Cp'], function = "multiquadric")
plt.plot(data['TK'], data['Cp'], 'k+')
p = plt.plot(data['TK'], cp_rbf(data['TK']), 'r-')

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEACAYAAAC08h1NAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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==
)

使用 `gaussian` 核：

In [28]:

```py
cp_rbf = Rbf(data['TK'], data['Cp'], function = "gaussian")
plt.plot(data['TK'], data['Cp'], 'k+')
p = plt.plot(data['TK'], cp_rbf(data['TK']), 'r-')

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAYAAAAEACAYAAAC6d6FnAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

使用 `nverse_multiquadric` 核：

In [29]:

```py
cp_rbf = Rbf(data['TK'], data['Cp'], function = "inverse_multiquadric")
plt.plot(data['TK'], data['Cp'], 'k+')
p = plt.plot(data['TK'], cp_rbf(data['TK']), 'r-')

```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAX4AAAEACAYAAAC08h1NAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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)

不同的 `RBF` 核的结果也不同。

### 高维 `RBF` 插值

In [30]:

```py
from mpl_toolkits.mplot3d import Axes3D

```

三维数据点：

In [31]:

```py
x, y = np.mgrid[-np.pi/2:np.pi/2:5j, -np.pi/2:np.pi/2:5j]
z = np.cos(np.sqrt(x**2 + y**2))

```

In [32]:

```py
fig = plt.figure(figsize=(12,6))
ax = fig.gca(projection="3d")
ax.scatter(x,y,z)

```

Out[32]:

```py
<mpl_toolkits.mplot3d.art3d.Path3DCollection at 0x176b4da0>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAqsAAAFdCAYAAAAkOCRoAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAIABJREFUeJzsvXuYHVWZ7/+tfb90p0MuHUgn0ECDXAQhgohyl6hBDaAI
KCMoolGCmKNzxDOH+SEzj8qMeA4qDoOOo+jMACM+I5whgDAKyiAE5SKCmIQkGiKBdDdJOr17X6r2
/v0R32L16qraVXvXqlq1+/08T56kO9211q7LWt961/d9l9FqtcAwDMMwDMMwOpKKuwMMwzAMwzAM
4waLVYZhGIZhGEZbWKwyDMMwDMMw2sJilWEYhmEYhtEWFqsMwzAMwzCMtrBYZRiGYRiGYbQl0+b/
ua4VwzAMwzAMEwWG0zc5ssowDMMwDMNoC4tVhmEYhmEYRltYrDIMwzAMwzDawmKVYRiGYRiG0RYW
qwzDMAzDMIy2sFhlGIZhGIZhtIXFKsMwDMMwDKMtLFYZhmEYhmEYbWGxyjAMwzAMw2gLi1WGYRiG
YRhGW1isMgzDMAzDMNrCYpVhGIZhGIbRFharDMMwDMMwjLawWGUYhmEYhmG0hcUqwzAMwzAMoy0s
VhmGYRiGYRhtYbHKMAzDMAzDaAuLVYZhGIZhGEZbWKwyDMMwDMMw2sJilWEYhmEYhtGWTNwdYBim
92m1Wmg2m6jVakin00ilUkilUjAMw/7DMAzDME4YrVbL6/89/5NhGMaNVquFVqsFy7JgWRZarRbq
9TqazeYMcdpsNpHNZpFOp1nMMgzDzF4cB3uOrDIMEyqtVgumacKyLExOTiKfzyOTycAwDFuEyj9f
q9VgGIYtamVxSr9HYpaOxWKWYRim92GxyjBM19Ayv2maaDabAGCLTxKTzWYTjUZjmmAVhaZhGEin
047HBgDLsmCapquYpYgsi1mGYZjegsUqwzAdQQKVlvkBzBCHFGWtVqtoNBr290nQkqAkIUtClL5P
xxT/duoHteNma3ITs6JoZhiGYfSEPasMw/jGyYcKYEb00jRN1Ot1VKtVpFIpFAoF5HK5aZFRErtk
AyDhSN8HXhOzbn8H6TP92wnRYiC2wWKWYRgmUhwHWxarDMO0hQSqGL2UBWqz2US9XketVkOz2UQ+
n0ej0UCpVEI2mwUA1Ot1x2X8qakpZLNZZDIZuz06pihqxb8BtWK21Wqh0Wggn89P88yKyV9B2mEY
hmHawglWDMP4x82HKi/z1+t11Ot1mKaJbDaLUqlkJ1RNTEy4RjO9oOM7eVipXfojCljLsuyvqZ9u
Qla0FzgJzlarhWq1atsUyKrg1FcWswzDMOpgscowjI24zG+aJgBngdpoNGyRmk6nkc/n0dfXF5kw
E/vjlpQli1myLfgVs05tObUDgMUswzCMQlisMswsx68P1bIs1Go11Ot1GIaBXC6HgYGBGaWodCAs
MQvAjq46RWb9JH8BsKO+LGYZhmGCw2KVYWYpJNCq1Sparda0WqiE7EPN5XLo6+uzM+rbQYlUfvsT
FX7EbLPZxNTUFNLp9AyLgVtkVhayYYpZUcjKbTEMw/QyLFYZZhbh5EMlgZTL5eyfaTQaqNVqtg+1
WCwim812LYzcxKtugksU7ZQcJuLml6XyW3IJLreobFAxS9RqNeRyuWmC2avOLMMwTJJhscowPY5f
H6ppmvYyP/lQy+VyV8v8QSKrSUIUiU44iVmxlmy3YrbZbE6LCItiVq62wGKWYZikw2KVYXqQID5U
2hqVyjTNmTPHNQuf8YdqMSu2I/7t1A7gLWZlawGLWYZhdIPFKsP0EKJAFctNOflQ6/U6LMtCOp1G
JpOJNJt/tuNHzMq1ZcUEMACoVCqOyVhuW9m6tQO038qWxSzDMHHCYpVhEo7feqhUbqrRaCCTyaBQ
KCCbzaJWq8GyLCWiw68NoFftAp1iGIZndHvPnj0oFArTxCxFZYNsmBC2mJV3AGMxyzBMGLBYZZgE
4uRDBTBDoMo+1Fwuh1KpNC2ix0IxmXiVtXKKzEYhZumFiZL1qB230lwsZhmG8QOLVYZJEOQ99PKh
NptNW6C2Wi3kcrlYfagshKPHKzLrtpWtHzHrtPuX+Dcdi9oOEplNp9OOFgMWswzDsFhlGM2hCKks
UMXoKG17Skv6FEGl2qleqIysysdOkvAQI9RJ6nc7vOrLAt1tZUtCV26rW5uBVyWDXro2DMM4w2KV
YTRE9qFOTk4il8vZtTXpZ2iZn3yo+Xx+2s8kCY7A6oEoAIPu/kUVByYnJ9uW5qK2xL+d2gJgC9kg
YlZMNGMYJtmwWGUYTfDjQzUMA6Zp2lHUVCqFfD4/w4caBNWRVTna5iQ42DebHLzEbL1etz2r7bay
DUvM0kub2/3DYpZhkg+LVYaJGT8+VGCvEKhWq2g2m8jn8+jv70cmw48woxeiRcUrMutmMZDFrNuG
CdSWl9gUxWyj0ZiW/NVqtTwrGXglsDEMEy080zFMDPiph0o+VCo3lU6nfftQg8BRTSZK/NSYDWP3
L7Et+jeJUrEt8fhyP7wqGbCYZZjoYLHKMBEhRpHI2+dUD5WW+cVtT2mSdNqnXmdYCM8uwrjWqsQs
vRSKNhSvyKxYNcFJzNLvs5hlGPWwWGUYhQTZ9pTKTRmGgVwuh4GBAXvCFn83bKIUlG6Tt5O3lUkm
qgVap2KWniHTNF0js53s/kXHZjHLMOpgscowCnDzoTpte1qr1WwvXV9fn50EIpLUCGVS+80kFzcx
W6vVYBgGstls261svTZMENugfzsRVMy6bZrAMAyLVYYJDb8+1EajgVqtBtM0kc1mUSwWkc1mPScm
lZFHFpTJQnz5YYJjGN5b2Ua9+xeVqKtWqygWizP62q7OLMPMBlisMkwX0ARGHlOqcSr7UMVlfvKh
lsvlQOWmWFAyTOdQwlQ7vMRsN7t/+RGzcvIXtUUed6e+sphlZgMsVhkmIE4+VCrOXygU7J+zLMte
5geAfD7f8banKicd1XVW/R6bxTijO271ZQkvMUv/BqaLWXnlpZPILIlZuYYxtcNilkk6LFYZxide
PlSacMQoK2176uZDDUIUS/VRbCvqlWDFJB+/0ctexY+Yddr9iyKytPNXu9JcYlt+xayTfUT0y7KY
ZXSGxSrDeODXh2qaJizLwq5du5DJZFAoFNr6UHVBdR+THDGll4QkXEfGGx2uoygARUFLNqFisei6
la2K3b+obdoBTP5ZMdkrnU6zmGVig8Uqw0j4rYcq+lBJvIrlpsIkqUlQPJkxTHucStp57f4Vh5ht
NBrTbE4AZkRl5UoG/PwzYcFilWHgvx5qs9m0BWqr1UIul8OcOXNgGAZ27typbAlUtVjlCCLDxIuf
Z8+vmG23la3f3b/ob1GQim0B/iKzopBlMct0AotVZlYjLuG71UOlbU9rtZrtQ5W3PaXfZcE3Hb8i
O6mRY2Y6Ol/D2fBsilFVJ8Le/Uv826ktoL2Y9Ur+6vXrxfiHxSoz63DzocrL/JTh32g0kMlkkM/n
7dJUMlEkJkURWVUNTYhM78ICIzhRCelOxSy9zFMCWNDIrFtbAGwhy2KW8YLFKjMr8ONDBfYOnBRF
TaVSyOfzKJVKvuszqpp0kh55FMt4NZvNaZNmKpWaNknyJMQw8eAmZkXbk5PNQKwxK4tYp92/nP6W
oTGBxKwTJGJJ0Ipteh2bSR4sVpmeRfShks+0WCw6+lBFIZXP59Hf349MJtjjkWRBqaLvYn3J3bt3
2/YJmtTk6E2r1cLU1NS0pUivouoMEwSdbQA69w14rX9+IrPdbJgATBexXudEFLP1eh3VahWFQmHG
77uJWZ3PNzMTFqtMz+HkQwX2Rk1pQCQfar1et7c9lX2oOpEUISy/HFBCxty5c23vW6PRmDHh0e+U
SiXfE167bGeGYaKFxKEb3YpZ8dl2shyIAQZRzDYajRn98KpkwGJWP1isMj1BOx+qODCSSKVtT/v6
+kIZmKIQlLraDOQqCbRbVyqVwquvvtp2yU9s32vC81u6x4+njgmfJLxQ6UgSIqthVDpp92wDnW1l
69ZWO7+smGDm9PssZvWBxSqTWPz6UClq12w2UalUkMvllNRDVSlWdRwYaSKp1Wqu0emwz4d4bf2W
7qHJKGjkhukMXc+h7oJwtuP1XAPOYlYszQUAe/bs8bXq4jf5i8WsPrBYZRJFkHqoog81l8sBgF0T
VQWqI6u6JHBRlYQg0Wmx3ypFQ6eeOreC6nSvicdmmLAJK3KpCh2EvpeYJd9qoVBou+rSbuVFbMuP
mLUsy1PMOtWYZTEbHBarTCKggUfMDJVFiVOkr1gsIpvNAgBqtVok/Uzy8d0QxT9lBc+ZM8fTnwY4
D/ZxDtJBLQYAbOuIl8WAs4/1hu0J3aGDWG2HOB/osvsXiVkAdoCFAieimN22bRssy8Jhhx0W7knp
IVisMtpCg4hpmp71UOWEnnw+j3K5HHmkQvVgrvL4TpFVP8v8KtuPGieLgWmayOfzSKfTjhYDuWwP
Wwz0RtdrkAQxqDN+zp9fC5EsZuXdvzoVs1SWj8YS+p5lWfjJT36CbDbLYtUDFquMVogZnO18qBTp
A2An9HhF+lQuo4vHV4Xq49OxSfyLtWa7Ff+9MBmHbTHotIpB3KKemX3o/vyG0b9O/PBBtrIlsUpt
iX+Pj4/jyCOP7Kr/vQ6LVSZ2gvpQ6/W6vZzS19dn72zSjqSLSdWYpoldu3bZtWb9LPP7QedJLkyC
Wgz8TnROFgNdz6nuokZXdD9v3L9wtrIFXouwPvvss1i/fj2Gh4fxyiuv4NRTTw29z5deeinuvvtu
DA4O4plnnpnx/w8++CDOPvtsHHTQQQCA973vfbj66qtD70cYsFhlYkP0oVYqFWSzWWSzWUcfar1e
t7c9LRQKyGazgQenKMRkksQwRbDJQpFKpVAqlTo6t4w3nUZtnCwGdB9Q3WBO/GqP7mJLZ5LwAq7D
9W0nZqempmyPaqvVwiuvvIK1a9fij3/8IzZv3oxvf/vbGB4etv8ceOCBOPbYY/H2t7+94z595CMf
wac+9SlcfPHFrj9z6qmn4q677uq4jahgscpEipsPVfy3kw+Vdj/qZik66ZHVsI4vnlvDMJDP5+1B
lsz/YRKk3zpMOnEQxGJA9ph2FgOuLZscknDfc/+6J51O2xsXrFixAitWrAAAnH/++fjWt76FiYkJ
bNmyBZs3b8aWLVvw1FNPdSVWTz75ZGzZssXzZ5LwMgKwWGUiQFzmN00TwEwfqmEYsCwLU1NT0/ah
DmspmtpQLSZJdOtGq9WyPb6ihYIGzkqlEuuglYSJJk5Ei0EqlYJpmigWiwBmWgzEcjpuFoPZlviV
lAlZR5IgpJPex4mJCSxevBjpdBpHHHFEZH0yDAOPPPII3vCGN2BoaAjXX399pO0HgcUqowS/PlQS
UbTUn8/nlW57moTIZ1jHF5f521koku63nc0EsRj42RWoV7ev1flzJEFs6UwSzp9bH2ncjaPO7rJl
y7B161aUSiXcc889OOecc7B+/frI++EHFqtMqIgCVVzal32osojKZDJIp9MolUrK+haFAV8HsUpb
n4qVEvxYKFT1nYVwvHhZDMSkDz+1J9ttX5sE0cAEIwnXNOl9jKv//f399r9XrFiByy+/HOPj45g3
b17kfWkHi1Wma9x8qPJERruMiCWRSERNTU0pX0JPeoJVu3adlvmDVEqICt0nldmEGJENun2tbDEg
MUyJXzpZDHR+WRJXnZjO0Pn6At79azQa9sY1UfPyyy9jcHAQhmFg3bp1aLVaWgpVgMUq0yF+fKjA
zG1P8/k8+vv7ba8kEYWQjCLyqRK5/06JaPl8HrlcTqtKCX6PTT/Hk7Y+BEn8opdN2mVOtBh0W1s2
rM/CBEf3ZzIJYl9coZAZHR3F/PnzlbT7gQ98AA899BBGR0exdOlSXHvttfbWsKtWrcIdd9yBm266
CZlMBqVSCbfddpuSfoQBi1XGN0F9qPV63ffOR6lUqifEahSRW1rmp0S0MGuiRoHukx/jHzHxC4C9
Pzs9C061ZWWLgZeQnQ33ie7Pg+79I3Tuo9c5HBsbw4IFC5S0e+utt3r+/+rVq7F69WolbYcNi1Wm
LUF8qCRSKcrX19fnexk6CrGq0mqg8jOIVotarRb61qfsK2W6Rb5/giR+yRaDsLevTYrgYoKThGvr
NbaOjo5i4cKFEfYmmbBYZRwRxVGlUkEmk7GzyMWBQa7ZmcvlMDAwEDizsVdsAGEfXyzaT5N0f3+/
9oOziHxekrbczyI+GH6va1CLgVsVAx0sBt2g+7PA/QsHr8gqi9X2sFhlbJx8qACmLdnR16IPNWgy
jxO9IFbDQjy/Yr3ZRqMB0zSVDMxRnZskTCoiSetvLyFbDETcLAZu29eKY9tsshiEQVLEoM54ncPR
0VEMDQ1F3KPkwWKVsYuIu/lQDWNvwX4SUORDLRaLoW3N2QtitZvjU9SIas46LfOLLxBJImiCFcO0
I6jFgCKy9IINhGcx6BYWg92RhPPXTqwec8wxEfcoebBYnaX49aFSlNWyLGQyGeTzeZTL5dALGPeK
WAWCDZ5ko3Aq5+V0/Lgz9hkmCcgWAxKv+Xze/trJYuC1fW0SLQZh0Gq1YilY75eki9Xx8XFlCVa9
BIvVWYTfeqhiFBV4rQZjX19fJH1UNfBEKYi9PgNFeOr1OizLci3nxTCMGsK0GMi7f9Hx/aK72OL+
dY+X4B8bG8Pg4GDEPUoePDv2OG4+VFmgkk+SBJToQ6WlaZVQf1QPPHFFD6lagp+tT91IamSVo7az
A51FQ5C+dVLFQCzJBThbDGZjVDYKkjC2cGS1e1is9ijtfKjATJ+km4CKMvkmimV6lcifQa6W4Hfr
Uz/H7jV6/fOFBZ+jeAlaxYDGYjeLAQncZrOppZjV+SWE0L1/XufQNE3kcrmIe5Q8WKz2EEF8qOKu
R7lczlNAiQOqSqJKgFJtNRDroXay9WkcqD73TqWrmM7R9T5iglkMRGvB1NSUo8UgrsSvpKC7pxZw
F6t07Zn2sFhNOOIylGVZANy3PRV3PaJySH52PYpidykg2ZFVWuZvNpuYmJhANpsNvMzfjqSKPJ5g
mbjRRdA4WQxqtRoMY2+Naich61Rb1k3IqnjWdI+s6t4/wFus6hhN1xEWqwmEBjTTNDE1NWUvITgt
81OiFEX4Otn1qFdsAGIbYQ0O9BJAyWiGYaBYLKJQKIRyfBH2lTJMb+NlMaDnUxSyTtvXegnZTsY9
3cVgEvrnxs6dOzEwMBBhb5ILi9UEIftQW60WKpXKNGHklMiTz+eRy+U6fqCjWD4X21FJGG3QS0C9
Xrf9RuVyGZlMBnv27NEigqMTLIRnB7qLBl3xG/UVI7JBt6+Vqxj4rS2bhOdW9z56RU/Hx8cxf/78
GHqVPFisao6XD5UeUvoZiqK2q9cZlKgmIJ3FqpPXN5/Po6+vL7JkNNXHBtQLDtEuQR5eao9FLaOK
2SCkgyZ++bEYJAWdr63Xvbdjxw7eatUnLFY1xK8PlSb23bt3o9lsKq3XSYlDfjyu3bShm1iVtz7N
5/OeXt8oPkMSJ95ms4lKpWK/TAGw/dN0X4vJBp3WrAwbFtCMaqJ6ntslfgEzLQYkYicnJ5VYDMJA
9/HQq39jY2MsVn3CYlUTaKL2U25KXIKmckj5fF7pAxtFkpUuYpUiDuLWsn69vlFEP1URtp9X9Ew3
m00UCgXMmTPHvs9FgUovBcDecl+0mxAQfUIJw8w23CwGzWYTU1NTKJVKoVsMwiAJL5JeY+ro6CjX
WPUJi9WYcauHKpebMk3TFqniEvTExEQkJZGiEpKqS2R5fQ46x7VazXWZP27CFpRhI9slMpmMHekv
lUoA4Lg5RSqVgmmaSKfTyGaz047XLqGEy/ww7dD9mdG9b2FZDMLevjYJ2fTtIqvHHntsxD1KJixW
Y8DLhyoiF5TP5XIYGBiY9nO9mKkfZRviMj9ZKfyW9PJzfBXo6Il1skvQvUrJfiJOA7hT+7R02S6h
xGmCFCdYWczqPsElEZ1FF9MZfq9pO4uBnPzV7qVTF4tBGHiNqWwD8A+L1Yjw60OVxVO7gvKpVKon
CvZH1QYwfWvZRqOBbDaLYrEYSk1U1dFhnQZtufJEELtEGHhFe+QJkp69dsuWbC9goqbXRb74PAWt
YuC1fa3uq0wi7FntHharCgniQ5U9kn7FU69FVlUKPcuyYJomLMuyl/nDqphAqD5Pqj2xfo4t1pYl
z3TY57Fb/EyQTsuWcr1KHZO+mOAkRdToRhTnrVOLAf0bACqVSugWg7BotdxLk7FY9Q+LVQVQxKmd
D9WpFFK5XA406UclVqOI4Kr4LGKSD4lUilarIgmm/6DIL1RBtpCN6h4Ngp9lS076YqKAhbQ3Xs9q
vV63N7yRqxjIKyhOliA6vkq8ru/k5CT6+/uVtt8rsFgNCTGCalkWdu3ahblz586YvMR6qAC69kim
UqkZfkAVRJH8FFbFAXl5OpPJ2FufkmhVRZIT3ZyOLfumw0g6031i5qQvhtlLEoR0KpUKtFGC+LzS
73t527vF7RxS33RakdIZFqsh0Gq17MQSeVIikUceSXoL9BuVakev2QC6aUN8EXBbnk7yMn0Uxwec
t+nt6+vrqn6vnz7rGIF1opukL2BmVnQvJZLo2n9d+6b7/a7refNLUIsBiVmn7Ws7fV7bncMkn98o
YbEaAm43LtVClaN7Yd6cvSRWiSADpJuwcnsR6AUxqZJqtWpHE7vdppeYTYMxJ30xncDXtjO6FdN+
7EB+nlen57ZdH2u1GvL5fMd9n22wWA2JVCplWwAoylqtVlEoFJQmn/RaNQA/GZ60zE/R6kwm41tY
JV2shn18UexTcl83thTGnbCSvugeaDQanPTlgyS/PMaN7svUKvvn53n1s4oC7A1ckZDdtGkTli5d
irGxMcyfPz/0fl966aW4++67MTg4iGeeecbxZ6688krcc889KJVK+N73vpeIWq8sVkOiWq1iamoK
rVYLuVzOjqTmcjml7fZSghXg/XnELHQA02p5hnH8JBBG/+XkPrpXa7Uacrlc6EI16ec8KvwmfZmm
aV9DTvryj47nQPdldu6fO+1WUQDYuROGYcCyLExNTeH9738/tm3bhnnz5iGbzeKSSy7BgQceiIMO
Osj+e7/99utYhH/kIx/Bpz71KVx88cWO/7927Vps3LgRGzZswGOPPYZPfvKTePTRRztqK0pYrIZE
KpWaVmNycnIyUnGn+qGNy27glIVeLpc7ruWZtMhnmHgV7gdgZ77HRRRJfEHR5XrKEyNtX0tw0hcz
G9Hh2XSCnil61ihoVSgU8PTTT8M0Tdx555148MEHccopp2Dz5s247777sHnzZmzatAnPPvtsx1HX
k08+GVu2bHH9/7vuuguXXHIJAOCEE07Azp078fLLL2PRokUdtRcVLFZDIp/PT8syj1Lc+Vk6D6Od
KEUxvZHK28vqnpCm2/HlyghehfujvGeZ7nC6dnEnfekehdMR3c+Z7v0D9B5P3M5fJpOBaZp44xvf
iEsvvTTSPm3btg1Lly61v16yZAlefPFFFquzBfmGJA9rVG1H4SdVDU2mk5OTAIBcLhe6fzIqQaZy
kPfT/04L96s4N7pEJ2crsz3pKwmCS1d0P3dJ7t/Y2BiGh4ej7dCfkcdjnc8hwWJVEVFO0FEv0Yd5
Y8vL/IZhIJfLoVgsKn2AVA1ydEyVx3e71k6WiSAl0pIwYDHhElbSl1gj2bIsTvryie5iS3d0P3/t
xOpxxx0XcY+AoaEhbN261f76xRdfxNDQUOT9CAqL1ZBwiqxG5b+Lqi1qJ4zsS0rwqdVq9q5S5XIZ
U1NTSn10UQxsqm0S8rWWz2U3lgmOrDIifpO+RGtBrVbTKumL773O0VkMJuG6ep2/0dHRWLZaXbly
JW688UZceOGFePTRRzF37lztLQAAi1Vl9HJktVPEBJ9ms+m4e1dUlgaVg7Dqz0AiQa4v29/f31Xh
/rhFZdztM8GQ7QV0X1LtSJ2SvnQWXDr3LQnoev4A79Ja4+PjSsTqBz7wATz00EMYHR3F0qVLce21
19q7XK5atQpnnXUW1q5di5GREZTLZXz3u98NvQ8qYLEaEnFGVnUWq04JPsVi0XVzhCjFahKPT+dz
586doRbuF48fBTpPMExnyMJLh6Qvpnt0Pdc6C33Cq4/j4+NYsGBB6G3eeuutbX/mxhtvDL1d1bBY
VURU2fOAHjVQZZz2lPeT4BNF+aIoBHGYx6coarVaRbPZhGEYSgr3JzXSzCSPIElfYk3ZTpK+dL73
dBZcOvcN0L9/gPe912w2u1oJm23wmQoJGiTp5hS/Vv1ARSHwqB2vh89paTronvK9ElntFpqgxcL9
xWLRPseqdpiKamJPwkTDxEOYSV9i4pc4NjPJJyljiFMfdX6B0hUWqwrReXm+03ZkUSwv89NuSG7L
/H7a6AWx2unx2xXup+iSClQP/KKQcGuLB3GmHUGSvqgUl1gST4ekL7G/ugounfsG6N8/wL2PlKis
e/91gsVqiMgihZbnVe+zHmU1AKoda1mWLaqo3JSfZf52zEax6uTrjaNwv6pj+x2QeeBmusXJXtBo
NGBZFgqFglZJX7qTBDGoM142wJ07d2JgYCCGXiUXFqsK6bXIKrB3r+Pdu3dPW+b3W8fTD7NJrHZa
uL8X4Imw9/DKfNYFv0lf9LfqpK8knDNdScoY4tTH0dFRJclVvQyL1RCJqyKA6uxzsY6nYRgolUqh
ZqCL9IJYBdyXs8lf103h/qRFVsVj02dMwiRDsDVhdhBl0lcS0F0MJrl/cdVYTTIsVhUSVcRThSgW
o34AkM/nUS6XUavV7DqKKuiFagBOA1RYhfs5sz5aVJzvzZs34447fgzLsnD22e/C4YcfHurxmemE
IWrCTvqif0dhE+uUJIhBnaPSXudvbGyMI6sBYbEaIk6RVfJ4RkG3g4sc9ctmsyiXy7Z30jTNSKKe
1BeVA2UUNgC5OoLTJgg6EbcQjrv9KNi4cSPOPvsj2LPnQrRaeXz3ux/Hrbd+DcuWLYu7a0wXBE36
IosBBQURRVFEAAAgAElEQVQajYY2SV9JQfexwmsO27FjB0dWA8JiVSFRela7KZNFyT1UEskt6heF
rSEKsar6uoiiP51Od1UdQSapgi6p/Q6bf/zH72Ny8jL09V0OAKhUFuOrX/0O/vVfWaz2Kl72gkql
YluqxOoFOiR96R5ZBfS2E3mdv/HxcRx88MER9yjZsFgNkbg8q2JbfpdF5BJJuVyubdQvSluD7nVQ
ZVqtlr3Mr7Jwv9he2J+DBaV6JidrMIzXlv9SqYWoVKox9ig8dBU3uvaLCBqV5Z2+9qL7dW1nAxgc
HIy4R8mGxapCopz8/bTltMzvViKp3XFUDhK6ZOu3Q0w+Ewv3N5tNmKapRKjqPDh7IZ5zOm+zcZnz
ve89E/ff/1XUavvDMPIwjC/jfe97f2z9qVQquOOOH2Pr1h14wxsOxVlnvUNrH2Cv0W4sVZH05Tcq
m2RPqA6wZzVcWKyGSJyRVS8BJib3pFIpO1kq6EDUrd0gSDs6i9V2hfvr9Xok/U9aZFXegleeUOl7
pmn2rJBdvnw5vvKVSXz969fCNE18+MPn4qKLLgx0jLCufaPRwKc/fQ2effZAZDJvxN13/wQbN/4B
a9Z8outjM+pRlfQV1TjfLUnon9scOzo6ypHVgLBYVYg8IatEFsaioGo2m6El9/RCaalOjk8iKu7C
/UmDkswsy0KlUrHvQ9M0pz0flHQCYMaE2mtF2s899xyce+45cXcDzzzzDJ5/PovBwc/AMAxY1ltx
xx0X4eMfvxilUinu7oWGzhFC1d78TpO+xJ8TV0F0eYlMwvjqdW2r1SrK5XLEPUo2LFZDRHwjpa+B
aN4ADcOwBxtx69NisRhacg8Qza5cOonVTgr369T/uI5rWRaq1aptj0ilUnZ9XrENMbpDwrZYLAJo
79dziwzRtYl7QtWdvS8MRfs8GUYOrVa0FUyYePCyFwB7n71KpYJMZq9E0CXpy+lz6IrbvC/rA8Yf
LFYVozpZCNg7kJimCdM00Wg0lO6ENBsiq7K3V8VOXd2ga+TWq1TX7t27p507P+cxiF/PKTI0WxNP
/HLkkUdi4cJ/xiuv3I5C4fWYnFyLU045HP39/R0dT/dlWd3Q8Rkm6DrSi6ZIJ0lfYUdlk3CvefUx
Cf3XDRarISMLCYp4hh2JlIVBOp1GJpPBnDlzQm1HppfFKhfu30vQgVQ+b06luoKcEz/te/n1qB15
D3gx8cQrKjRbJpFyuYybbvobfPOb38cf//jfOPbYEXzsY5+Ju1uho7sw0LlvTnSS9EX/7jbpS2xH
9/Pm1sdKpWKvHjH+YbGqmDAjq7JvMpPJ2MKAIoGq6QWxSlAbYRfujzsy3M1x/eIVRfX7+4Zh4Omn
n8a2bdswPDyMI444otOuT0MUsX4ST7wmU4oUibaDXmJwcBDXXvuXcXdjVqK74Oqkf6qTvqK01nWD
1/g8OjrKlQA6gMVqyDgl23RbEcBp61N5mT8qgReVWFVZRYGu0eTk5AzRH8YAmFSxKh7b7Tw4RZ+p
qHlQbrzxn3DLLb+EYRyNVus2fPrT78I557yr24/QlnaJJ/Jk2mq1MDU1pZVXj2FUonJ86SbpS3zO
qESgzisiTn0aGxvj3as6gMWqYjqNrMqRq3a+yajKZKkWktSGisGy1WpNE/2GkbzC/XFA0Y9qtdpx
9Fm+plu3bsUtt/wUc+Z8H+l0PxqNMXz96x/Caae9NbYs2WaziUceeQSbN/8JS5YM4pRTToZhGLAs
C4VCYYZH1m9UiIVsvOj6HOraL5Gok6XaJX2Jzx2gb+UQr2vLkdXOYLEaMt1EVsnfI2996idyFVVk
NZVSny0c5mdxsk4Ui0VMTk4in88nsnB/FJFVINwoqtzGzp07kU7vh3R6bzJPNjsfhrEPdu/ejaGh
oa4/R1BarRa+/e1/wX/+505kMsfCNH+LJ59cjyuu+PC0frfz6sn2Aq+kk15L+EqC+GL8oeO1FKOy
tFtjPp8HoEfSl0g7scqR1eCwWFWMH3FHy/xUTL6byJXqQSYpntV21ompqamu++lFu+X0MI6tAopa
VCoVuxJCWNFnsc/Dw8PI51/ExMQj6Ot7M3bt+i/ss08V++67bywT5fj4ONau/R2Ghq5DOp1Ds3ka
fv7zv8Z73/sn7Lvvvm1/P0jSCQlZp+XN2ZzwNdvQURASuieIyudOh6Qvr/6JjI+PY2RkJPAxZzss
VkPGb2SVREG3W5+K7agUSGI7uopVOYqazWZRLpdjKdwfVaQ7LJrNJqrVqm2VKBQKHVVCcEM+zpw5
c/DNb/41Pve5r+Cll3bggAP2w/XXf8GOlERNvV5HKlVAKpUFAKRSGaRSZXu5sRv8Jp24TaSykJUn
WcYbPk+dofM5C3JNo0r68tu/0dFRnHjiiQE+LQOwWFWO7FklMSUu84clCnQWkirbmE2F+8M8tvzC
lMvlkEqlbIGvmiOPPBJr195iv1gAe5Pe4mBwcBAjIzls2PBj7LPPm7Br11MYGprC4sWLlbdNy5t+
KxeQvWByctLTI6uz2GD0FtE6940I80W6XdKX+ELplvQlPnte1r+xsTH2rHYAi9WQcYrg0W4+tJd8
mEurcltJz9SnNtp9Dieh1dfX51tkJS3yKdNN32VxL0ZRd+/ereS8eJ1vEqpxkk6ncfXVl+O7370D
69f/A444YhEuvXQ1crlcrDs6OU2kjUbDTnRrl/ClS8IJw4RJVGI6aFSWXiRpzJicnEQqlcIDDzyA
559/HsPDw9i5c6eSFaR7770Xa9asgWVZuOyyy3DVVVdN+/8HH3wQZ599Ng466CAAwPve9z5cffXV
ofdDFSxWFSGKKWDvBNPNMr8foqgIEMWOXF7+26QU7tctstqtuJ8NDAwMYM2aj077Xhg2AFUETfjy
u1Vtp+OTrtE47ldwdO4boE//3KKy1WoVqVQKmUwGzWYT5XIZ4+Pj+PWvf42nnnoKy5YtQzabxcEH
H4yDDjoIBx98MFauXIk3v/nNHfXDsixcccUVeOCBBzA0NITjjz8eK1euxOGHHz7t50499VTcdddd
HbURNzxTKWBqasq+WfP5PBqNRqj+PzeijBaqHCzk48plvGZz4X46tt+XEieLhNe9GNU95NZO0iPe
uhA04Yu3qmVEdBGDbiShf/TcpFIpnHHGGTjjjDPQarVw1lln4ec//znGxsbwwgsv4IUXXsCmTZuw
Z8+ejttbt24dRkZGMDw8DAC48MILceedd84Qq0keW1mshgwN7qKYqlarSrZcdWo7iqhnVIlcjUYD
jUYD9XqdC/cHwCnRzKtGbxSwCNUHr6VNukaiiPVbuUBHdL7ndBdcOqPzdQW8ry0J2YULF2LhwoUd
R1NFtm3bhqVLl9pfL1myBI899ti0nzEMA4888gje8IY3YGhoCNdff31ouwZGAYtVBRSLxWmRr6gm
6ig3BlD1eZrNpl3Ca3JyEoVCQZm/V/W5itoG0Emimd9jM7MDUcQGrVwA7N33XMeELxaFwdBZSNO9
pmv/APfzZ1lWbLW9ly1bhq1bt6JUKuGee+7BOeecg/Xr14feF1WwWI2AXtpdSmwnrIdOjgRmMhmk
UimUSiXkcrlQ2pCJIrKq8tjU9yDluuIkqntzNhDny4RX5YI9e/bYO32JUVlO+HKGImw6onPfCJ3v
GTexOj4+jnnz5oXe3tDQELZu3Wp/vXXrVixZsmTaz/T399v/XrFiBS6//HJl/VEBi1UFOFUEiNMH
GDZhJVl5Fe6fmJjo+vheJN0G0Gq1UK1WUa1WAQCFQiFwFNUJHSKrcbcvosP5cEK3iZrOkZ9933mr
WqYbdI76At7j19jYGObPnx96m8cddxw2bNiALVu2YPHixbj99ttx6623TvuZl19+GYODgzAMA+vW
rUOr1UqMUAVYrEZCVJHVJNgA5Kx0t0hgFCIhaWKVoqjVahWmaU6riarz4B2EXvkczHSCVi7ws1Ut
HcvrntFZ2HDfOkPnvgGY9vIls2PHDiVbrWYyGdx44414xzveAcuy8NGPfhSHH344br75ZgDAqlWr
cMcdd+Cmm25CJpNBqVTCbbfdFno/VMJiVQG9HlntpB3LsuyMfvJTlstl10hgkpfp6fhhvTiQj5fq
9GazWTSbTfT19YVyfBFV510+blQvVoz+BK1c4JTwpZtHNunouJqQFLzE9NjYmBKxCuxd2l+xYsW0
761atcr+9+rVq7F69WolbUcBi9UISKVSkdRr1E2sdlPbM+nL9N1CySvVatX2olKdXsuyYJqm0rZV
o/O5Z/TBq3IB4JzwRfVkSTS0Wnu3EHbaKjNOdH8G4j4/biQlsuqESrHa67BYVUBckVVdErnCKNyf
dLHa6fFpYqUoqlNGv+oarlFEVgH9Jx1Gf7wSvsg2U6/XYRjGNGuBmPAVZ1RW1/tf52dT574B7cXq
YYcdFnGPegMWqwqQb9SolzxVP8ypVGrGFpRhF+5XnT2um1iljH6qKVssFl1rykaRvBUXuke8GWf8
jDljY2NYvfrzeOyxddhnn/n46lf/GqeffrqyPolRVLmqiJ+EL65coCe6i1UvVCVYzQZYrEZAlMvz
1FZUpZNkkRVW4X7dxKSK45PAr1ardhR1YGAg1pIxSZ0EGP35+Mc/i8cfPxLZ7M0YG/stLrvs47jv
vn/ByMiIsjbdnsHt27dj3bp1yOVyeOtb34o5c+ZM+x054UvFVrU6iy7uW+d49W90dBSLFi2KuEe9
AYtVBbhFVqN4yKgt1YLHsizs2rXLFllhF+6PKsFK5TVx63+QKKoTSYyscsR0dmNZFtatewz5/L/B
MLLI5U6EZS3H448/rlSsAjPH4/Xr12PVqmtRqZwCYAKLF/8I//zPX8E+++xj/3zYlQvomDqLLIKf
0+7wmlPGx8fZs9ohLFYVIU7OUQ5QqkQB+b9IZBmGobRsUhTiRmUUWj5m2DYJOmbYfZ/tXj1GDalU
CsViHxqNjchkDker1QTwAubOfUvkffn613+AWm0VFi58BwBg27Yb8aMf3YXLLruk7e+GUbmAfl8U
uDoKWd36Q7Raem9Y4NW/Wq2GYrEYcY96AxarEUERTxVbrYmELfLkwv2FQgH5fB6Tk5PIZrOhtSMT
pVhVeWzK6A/TJhGVxSNs/B6XIzu9h2EYuO66v8Jf/uUHUa+vRDr9LI45JoMzzzxTabtOL3Tj4xMo
FPa3v06nD8DY2O+6bitI5QISqbS1tC4JX9RPXYUqkNz+0XVmOoPFqiLkST9JFQHkklNy4X4xIqCK
JItVMVlj9+7dSm0SOg/aIkEsDkzy8HMvvve95+Kggw7Er371KyxYcC7e9a532S+8r7zyCv74xz+i
WCzisMMOU/pSf9ppx+Lb3/4estnPw7L2oNm8A299618oa48QKxfQGFEqlQC8JmTlqGwcCV+6jytJ
7V8cK629BIvViEjC7lJUcoqW+duVnFI5aCRRrMoluwBg7ty5iRucVJ932oXLsqwZE6+Ke+qJJ57A
k08+iX333RcrVqzQegmx1znmmGNwzDHHTPvehg0b8LWvrYVlHQnL2oBjjnkSq1Z9QJlg/chHPoiJ
iW/hrrs+jFwui8997n046aSTlLTlFxKyTvipXCCK2F6vXKB7dNJtDNuzZ4+SjVxmCyxWFSHfrFFW
BAgiiuUoqp/C/VFUHaDjq36L7vaauHlRU6kUXn311ZB6ORNV95PKc02R5maziWw2a0/OYgSJrrco
ZLtJUPn+9/8Vf/VX16PVejdSqR/hlFPuxA9+8I+BBKvuk2PS+cEPHkCpdD4GBg5Aq9XCk0/+C557
7jkcddRRXR/bafzIZrP47GdX47OfjW83nyDjWtCEL7+VC+jY3fQtLnTun9v547JV3cFiNSKiiqw6
1UB1otvC/VFl66ukmzaczl8ul4s0QSkJWfvieWq1WrZnlyZVeQKuVqsAYC+VyjsSOe0P7yZkTdPE
5z9/DSzrYaRSI7CsOn7+85Pw8MMP45RTTvHV/7gmxbGxMfzyl0+jWjVx9NEH4tBDD4mlH1Gwc+ck
5s/fW85nb4RxEJVKJeZeJYOgCV/03HlVLiDhqys6i2mvpf7R0VGuBNAFLFYVEWdk1a2dMDPSk56t
Lx7fLxSFpiXsducvab7SsHCK1pfLZVQqFbs4u9s5ISuAU/KevBTaTshOTEyg2QQM4+A/t5lDKnUY
xsbG1H34EHj11Vdx8833wDSPRyZTwhNPPIoPfrCB17/+iLi7poRjjz0Ajz76MwwNnYmpqVEYxjNY
uvS8uLullCjGBa+ELxr3nJ4nErKVSsXVIxvXmKaziAba11hlsdo5LFYVId+wqVQKjUYjknbFCC4N
QmEX7g9qN+i0DdXRWz/H7zSKGkW1AZ2OK1aOMAwDhULBjtaHEa0RE1RknIRsoVDA8PAwNm36exjG
p9FsPoZM5uc4+ujPwrKsjq0Fqvn97zdgaupILF36egBALlfCL37xoNZitRvxdcEF70Kz+Z948sm/
R39/AatXvw2LFy+OvV+9jChi5eepXq/bVh2nWrJxVi4QPbo60q7G6oIFCyLuUe/AYjUioqwGQIMK
RVFbrfB3R6J2VBKnWHWKDvb393t6ed2Oo4Ko7ic/UMJUo9FANptFX18f0ul0pBOKm5C9447v4eKL
r8Bvf3sd5s1bhBtv/L8YGhpCrVbzVcQ9DvZGir3/v5colUr46EfPn1XCUvfP2m3C12zdqrZdZPXw
ww+PuEe9A4tVRThFVlVHIimi1Gw2sWvXLmSzWZRKJSWF+5OYre/n+F7RwU6OnzT8nnOylIhbxZZK
JdeXobjE9ZIlS/DTn/7Ys5yM11Io9btWq0W2G9HrXncIfvaztdi+vYRMpoQ9ex7FO995pJK2dCKJ
z0sv0k5I+034EoWsn4QvP9dfd5Hv1b+xsTG2AXQBi9WIUDlZy4X7AYRe11OmV8SqOKAGqYjg9/i9
FlkVLRGdbBXrhyirHLSzFpimiXq9DgCOuxE5JXx5teeHefPm4eMffyd++cunUatZOProY2YkWOk8
YesEeZl1Q2fR1c05C1q5IOhWtTqfN4DFqkpYrCpCdWTVTWCl02ns3LkzEvN+FGJVZTSaxMiuXbtg
GO3rygZFN7H6wgsv4P/9v7UwDANnn/1uDA8P+zruyy+/jOeeex5AE4ceeij22WefUF6GnM6zThOR
uHSZz+en/Z+cYR22kF2wYAHe8563hf+hGCYm/AhZ8blyeqboZxuNhhYJXzLtxOrg4GDEPeodWKwq
xGni7/bN0E/h/qiEpJ8SWd22EfbnIIFKHkvDMDryogZpTweeffZZvP/9qzE5eT4AC9/+9kfw4x9/
GyMjI66/02w2sXHjRnzjG2vRaBwDwzCxePHdWLMmeMF2uj91j4z4xS0iK2dZBxGyST4vvXJdo0Ln
8xVH30TB6ZVAKa5yyLWZdfCee0Wld+3ahblz50bWl16DxWpE0APUbDYDT/Ryyal2y9QUkVRpA4gi
wSrMNmQvaj6fRz6fR7VaVSZUVQ6SQYX8DTf8M6amPoW5cy8EAOzePYCbbroFX/3q3077OTrmnj17
0Gg0cM89j6JYPAvDw3sTA/7whwfxq189idNP91en1AudJ+xO8cqynq1CNk568R5TjY7nTHw5JI88
IVsL3LaqjVPIiuX1mM5gsaoQWVAEFRidlkzqhUx9aqMbGwBFUWu1mmOmummaWpTG6pQgx96zZwrp
9GtLUKnUIuza9ZtpxxJ9z+l0GqVSCaZpoFh8LRqQyfRjamq0677rtHQXFWEJWUpUoV2+Ztt57AV0
FIRJwOm86VS5wE9yGtMZLFYjxI/4kqOonRTu74Xkp27acIqiumWq6yZWJyYm8E//dBt++9utWLx4
H3ziE+djaGio62Ofc84ZWLfua6jVBtFqWTCMf8A556yCZVmoVqt2Dd5isYg9e/Ygn88jlUrh+OMP
xu23/wyZzDvRaEzBNH+Fww/vzEvpJ0EirsSxuGknZJ0mXafyW51kWDOMiM5COmh0MmjCl6qtahuN
hrIVvNkCnz2FOCVZOU3EVDInrML9qhOTqA2dxKpTFLVcLnuW7dItCa3VauHv//5b+M1vDsbChe/H
73+/Hldf/Q/4xjf+F/r6+mYcO8g1Pv/892Fqagr/9E+fRypl4GMfuwCnnHISdu/ePeOFSDwvJ598
IizLwi9+8UOUyxlccMFbcOCBB/putxeIWzzLfj6aSHO5nKOQddtSczYKWV2Fl85LwnHf716EeT2D
Jnz53arWifHxccyfPz+Ufs9WWKxGiCwwVBXuj8oGoIMgpnNIe8oXCgXPep9Bj98twZbq9+CZZ3Zg
yZLPwTAMFAoL8NJLv8aWLVvw+te/vqt+GIaBiy++CBdccJ5dM9TNViKeF8MwcPrpJ+P000/uqn35
uElBR6Ej4pWY4pZh7VQqqFshq6soZDpD12sZ1fjR7rkCnLeqBYCpqSl7/vnSl76E/fffH+VyGeVy
GZZlhZ5Lcu+992LNmjWwLAuXXXYZrrrqqhk/c+WVV+Kee+5BqVTC9773PRx77LGh9iEKWKwqxCmy
Sm9nYgQw7ML9UQlJQO0k5SZuOomieh1f1WcIesy9wrEB05xENtuHVqsJy9o5o2wSHdvPwC2fq7Bq
yDL6042Q9VoC1VXIJAldxX0SXibjPm9ulp1Wq4XJyUmUy2U7iDIwMIAnn3wSGzZswO9//3uUy2Uc
cMABGBkZwcjICA499FCsXr26475YloUrrrgCDzzwAIaGhnD88cdj5cqV03bKWrt2LTZu3IgNGzbg
sccewyc/+Uk8+uijnZ+AmOAZSyHiQ9VsNmGaJhqNBkzTbLvjT7ftRiFW/XgQu21DHDydItHdnEPd
bAD5fB5/8Ren4XvfuwGp1BvRbG7EW986gIMPPjjwscWEqVarpV3E2YskTJhJJ2whq3q86RRdRaHu
6HrOdL6e1DdK+CoWi/if//N/AgB+9KMf4dVXX8UnPvEJbN68GRs3bsQLL7yAbdu2ddXmunXrMDIy
guE/18y+8MILceedd04Tq3fddRcuueQSAMAJJ5yAnTt34uWXX8aiRYu6ajtqWKwqREyWMk3TfhOb
M2eO0gcuChsAEN0OUxQZrNfroUeiVQruTs7Pe9/7bhx00BJs3vxHLFhwJN7ylrcEEuNywpSq7XY7
wc/50KGfsx0/QlbehYi+npycnCZkZ9O+8EHQVXTp2i9C5/559W10dBT77bcfisUijjjiCBxxxBGh
tLlt2zYsXbrU/nrJkiV47LHH2v7Miy++yGKVeY1ms4mpqSl7f3nTNFGpVLSL6OnYDgl9AHZ2ehh+
XhnV5yrosQ3DwLHHHtvWUyT2m8qxVKtVu4JEN+cq7shqO7hmYXy4JaXU63U0m03kcjnf2dUsZPVD
dzGoM17nbmxsDEcddVTobfq9VvK50/Uae8FiVSGZTAYDAwP211FGPKNYllMhasQoKvkq58yZo0yY
qBRmKgcEusaVSiVwHd64CONcr1+/Eb/85SZYVguHHbYQb3rT0ey/1QB6eRBL+8j/H6RMUFhCVlfx
9fzzz+OZZzahVMrj9NNPxIIFC+LuUmLQ8XoC7cXqwoULQ29zaGgIW7dutb/eunUrlixZ4vkzL774
omM5RN3h0IRCnLKsoxCRUYlir1IdQSB/5a5du7Bnzx6kUikMDAygv78/0VFoFcemKGqlUrEn/v7+
fsyZMwf5fD5Ua4RuvPTSS3jwwe2YO/d0LFr0Tjz7bBa/+c3zcXeL8QEJz0wmg2w2i3w+j2KxiFKp
hHK5jGKxiFwuZ+9QREmok5OTmJycRKVSse0tpmnaHtok8utfP4Hrr/8v/OIXh+Cee/bB3/zNdzA+
Ph53twDoK+4BvfsGtBerg4ODjv/XDccddxw2bNiALVu2oF6v4/bbb8fKlSun/czKlSvx/e9/HwDw
6KOPYu7cuYmzAAAcWVWOXAYIUP/QRdlONxOGHEUtFoszastG4YtNglgVS3QZhoFsNgvLslAul0M5
vi54nbMdO15FLrc/crkCAGD+/IOxdesTWLYsyh4yYeNmLQDcI7J+diDSlTvvfBQDA+dj/vxDYBgG
/vCHKn796yewfPmZcXdNa0Goc98A7/6Nj48riZ5nMhnceOONeMc73gHLsvDRj34Uhx9+OG6++WYA
wKpVq3DWWWdh7dq1GBkZQblcxne/+93Q+xEFLFYjJIoMerGtZrMZek03uY2gYkxMOvOzQ9dsF6ty
chmV6KJotApUnZNuj1sq5VGv77S/npzchaGhbBhdYzSlWyELwK4rrItH1jQtpFI5++tUKgvTVPMs
9xJJEKtuL0n1et2xBGEYrFixAitWrJj2vVWrVk37+sYbb1TSdpSwWFWMPEHT0rnqN/+oNgbw24ac
pe53h64olqR1W06UBX2hUJiRMKVbnzsh6MQzPHwADjhgHbZufQyGkUOpNIrjjjtOUe/0RfdJOyra
CVlKcKVdv1TuCR+E5cvfgJtv/hEMYyXq9Qnkco/imGMuVtqmX3S+t3TuG+Dev14Yq3WAxWrE9EKm
vtiGl2c1aBTVrQ3VkVWVxw6y6QBtuUsJU16CXveIsAoymQzOPPME7NixA5ZlYf78Q1EoFOLuVizo
NmnrVp1BFLHZ7PTou1xDljyyXkKWvg7jvJ966kkwzQaeeOIBlMtZvOc9F2K//fbr+rhhoONznxTa
iVXdntmkwWJVMfINGlZSkp92o9gYwKmNIKLLTxtJtgG0o9Xau8NUtVqFaZrI5XKBBL3u0QYR+Vx3
EolIp9PYd999lfTPDZ7Ak4nb/eXXWqBSyL7lLW/G8uVv6+rzqULX8UT3sc6tf7t378acOXNi6FFv
wWJVMU4VAaLK1FfdjthGGFFUJ5IsVsXjy/eBnDCVz+fR19fnezDWOXGu27Z1Qrf+BGXz5s145JFH
MDAwgHe84x0zoozMdHQQsnGiW4RcJKlidWxsjEuThQCL1YiJMrIalQ1AZa1P1RHiKCLQ4nVwS5jq
JqWPmIoAACAASURBVOqs8wAu4nRPJqn/SePhhx/GBRd8FK3WmTCMzTjssG9h7dofKkv00I2wx78w
hKz4u2J9WaY9ugtpN0ZHR5XUWJ1tsFhVjFNkNek2ABqIq9WqPRiHEUV1IgqxGkVktVaroVqtotVq
KduNKyyietHR1RvbK6xe/XlUKt9CKvUutFpNPPfce3D77bfj4ov1SOaJgqiEYBAhSzVip6amZghZ
+d9RC1mdXx517hvh1L/R0VGOrIYAi9WISaVSaDQakbRjWVaox5S9qLlcDqZpKq31mWQbAE1KExMT
SKfTjnVku0Fl31Wec7KMkAUiiculSWBs7BUYxhsBAIaRQq22DNu3b1fSVhKERFzIQtY0TQBAsVgM
FJGN4lnh69gZXueNI6vhwGJVMXF5VsNqhwbPWq1mJwD19/fbtT4rlYrSAU619zbs6yGfLwAolUpK
ll5V3UsqJ6t6vW6XE6J7iM4ZTdoAUKlUpvn+WMwG54QTTsTPf/5lWNZXAfwB+fxtOPHEr8fdrchI
QtQ+LGvBbHjp01lIe/VtfHwcRx11VMQ96j1YrEZMUqoBNJtNO4pqGAYKhcKMBCBxKVfVIJKUyKrb
+ZqYmNB2gI2CVqs1rcZuOp22X3bq9fqMe6fVamFychLZbHaakHWaoOXamLP5PDvxrW/9H1x00So8
/vhcZDJ5XHvt/4eTTz457m5Fio73hN/xMoiQJXtBt0I2qYIwbtpFVlVstTrbYLGqmCRVA3CKovb1
9SGTcb9NkiImVR2fyk41Gg1ks1n09fUhnU7b1z2JWfthHFdc6iefLtVEpSLtlmXBsix7AhUnUqek
MyfvH03OlHzhlomt6ySnkvnz5+Pee++wk/lm4znoVVQJ2aQKwrhpF1llG0D3sFiNAHHyp3+rfvCC
CA45KhikjJLuYlLF8Z2EWKlUcpw4VPZfR89qs9lEtVq1fc2iT7dSqaDZbNr2CHGCpAgs+awbjYaj
iJUzqsX+isullmXZEVnx95wm6F4nl8u1/6EeRFdxE8XY36mQBYBqtaqdtUB3Swd7VtXDYjViolg6
p3a8RHGrNbMYfbsoqlc7qtDp+GKCWSaT8ZUwFVUkPUyC3pd0L9VqNTQajRkbG5B4NAwDpmmiXq/b
EyH9DAnVTCZjC38xakqiU0walIVsOp2eUZGCzr04OYtbb4oTu077xycNXYUhMx0vIUtlCLPZbNuI
bFwWHF3vMa/7f2JigjcFCAEWqxEgCxaaiFWWLnITxd1EUd3a0UVMdoOXqBetEUE3O+jlyKocYS4U
CrbQlCOdwN5tL3O5nP1/jUZjmm+VxCw9G/QnnU7bxyQvNolYJyErWgLaCVn6fbFP4uRMv1+v17WJ
MjHJRndh7xSwkJ8TqnQSlZDV/ZzRmOP0fQDalilMEixWYyAqASZGV8XIl5O3slOiShhTNVi5HdNP
gplfkiZW231GcalfjjBTFJXuOzoeHZMEYa1WQyqVQrFYnOZPdVqiFAWkKF7Ff9PvOolY8d6RhayX
rYA+S61W40SvBKK7wNERt/NlGIbrC7qTkBVfKMN4VnS/lu36p3PfkwKL1QiQb9SoBB4AO/mHoqhu
3spOiSKyqto2IX4GeTm7E2uE27GThNxnJ9uI01I/3dfyUiOJPnpZKpfLjpMfTYpO/ye2Qd5Xmhzl
CTGdTiObzdoRWXFCBeAYjRX7LE6otVpt2q5s7SZnJ28s2woYwi0KFzedjrHdCFknb6yTkE2qWK3X
67PWMx42LFYjQL6JVS/fkuCiwaGbLT3bEYUYU9lGs9nEli1bAACLFy+2s9bDEvW0bK2CKCKrTkv9
FGF2WuoXJxn5XqQavZ2eV8MwXJcoxb5YloV6vW5/LfpjaVLMZrP2McUJVYwIi+LbNM1pgrPd5OwU
GQZmd6IXM/sIS8iKz7iOqxduYnV0dBTz58+PoUe9B4vVGFARWW02m6jX6/aSZaFQQKvVQi6Xsydm
FagUY2IbKkRZrVbDtdd+FQ89tA3p9BwsXrwHN9zwvzF37tzQ2lAt5lWJVUq2CGOpn+5BlZFxt6QR
cTlfjMhS/+WNB8gaY5qmLTLFCG23/lhZVIsTsFfpLd3RMfKlY58A7hfRiZClLWr9RmSjwu3cjY2N
cSWAkGCxGgFOkdUwBB5NwmKdz1KpZEdRxciQKpIWWSXvYbVaxX33/QQ/+1kTixbdgGy2gO3b78LX
vvY9fPnLnw+lLbFNFYR97ikSShNCq9UKvNRfr9ftup50L8ZJOyErR0HpZY9+V/TEuvlj6fcJNyEr
Hkfuhzw5e+1URAlouooeJpnodD85CdlWa2+ZwKDWAtX1lr3G4NHRUSxYsCD0NmcjLFZjIJVKodFo
dPz7rVbLTv6hB9hp2ZomNJUkJbIqJkylUink83mMj08gm30j0uksgBbmzFmGTZvuD6fTf0bl4B/m
S498P5mmiXK5HPlSf5TQhEiRVNM0kU6nkc/n7dUPv/5Y+nc3/li/dTFpFYUqFEQ5MTPdk0QPe9yI
QtpPRFaut6xSyFLf3GwAHFkNBxarERCWZ5VEQb1et+tRenlRoxCSUQniTtoQhZRTwtQhhxyAZvNB
WNbpAIrYufMhHHfcAVr0PQrkurF0P7VaLVSrVc+lfvKyRrXUHzY0kdVqNViWZVfIEAWjH/EYpj+W
kCdPWchOTU0hm83aO4GJESYnf+xsTfTSNZEJ0DM7XKfIqozfa9kuQVOFkPU6b2NjY1i6dKn/D8q4
wmI1BoJ4Vp2iXgMDA74e3G4juH7Q0QYgnzO3hKnTTjsN5523AXfccTlSqSIOO6wPV175v2Ltu+pj
k4CnrH65bqwopiYmJmZED8lGIdtOkgL1n+q75nI5lEol35N02P5YcTlfFrJyRJbap/+jY7h9TrdE
L/EzOHn+mN5k06ZN2LBhA/bZZx8cd9xxM+5hncVqGHQiZMUXv0785GNjY1i2bJmSzzPbSM4sk2A6
iazKUVQ/uyU5taubkFTZRtDIcyqVwpo1q3Deee9Co9HA/vvv77vYf9h9V31sUcADmLYZhNNSf39/
/7SIXb1enyaaaKKj5XESXrpOdvLSeT6fD71CRlB/bND6sbT7lzihevlj/SZ6Ofljg07MvS50wiSO
c/Wznz2EL3zhX9BqnQDgQbztbT/HX//1Z7SNPMuoPmfdCFnqF60y7dq1C6ZpYnBwEGNjY0o9q+Pj
47jgggvwhz/8AcPDw/j3f/93xwTh4eFhOyiRzWaxbt06ZX1SBYvViBCFBf1bfgBpaVXcc95vFLVd
m6pw+ywq2nBCXI62LKujczZv3jwA7uWIkozbUj+d03ZL/ZQVbxiG/cIkCy/K/HdbBo9z+dlvfVfV
tJsMverHis9YNptFsVhEOp2eEYF1i8ZS+0ESvWhi9rsRgo6wgN5Ls9nEl770HZTL16NYPADNpokH
HvgfWLnyaRx77LH2z+lsm4jzWrZ7dulF3jD2JjXfc889uPrqq9FoNLBw4UK88sorOProo3HIIYfg
kEMOwcjICBYuXBjK57nuuuuwfPlyfO5zn8Pf/d3f4brrrsN1113n+BkefPBBe65LIixWY0CcgCi5
o9soqhMqSmTJiMJGpViVP0ez+douSul0GoVCoeNzptLbG0dk1c9Sv5+s/kajYd+P4lJ/GMvgopgN
OxlIjEJalqV90pdhzKwfK0bCDcOwfa9UvqcTf6ybrcDLHyv2R/bqiscG9m5AIr+gUBvMa0QtvBqN
BqamGujv3x8AkEplkE4vxc6dO2PtVxB07Rs9O+l02i7+/6EPfQgf+tCHMD4+jg9/+MM477zzsHnz
Ztx///246aabsGHDBlxzzTW48soru27/rrvuwkMPPQQAuOSSS3Daaac5ilUg+Yl9LFYjQhYWhmHY
YoIigkH2nA/SpuoHXXWSlfg55F2U+vv7u/ZMql5eikqsksCpVqswDKPtUr9TFFUUeHLCkZ/++FkG
tyzLjh5Sf+RIbCe2Aopy1Ot1ALCrZOg4yblBVSsajQbS6bS9oYdMVP5Yv0J2cnLSTs7jjRCciUss
5PN5HHnkAfjd727DggXnY3JyPVKpp/C6170vlv50gs5Cy21+nTdvHur1Oj70oQ/N+H955aNTXn75
ZSxatAgAsGjRIrz88suOP2cYBs4880yk02msWrUKH/vYx0JpP0pYrEYE3axUF5WWT8OKonq1qZoo
7AamaWLXrl0zRFgYRNF/lS8MdE9RZF7csczPUj8JPMMwAicc+UVcSpM3qZDLMgW1FcgCj5bJkySG
yK5gmqZjZQIZVf5YADOqFTiV3nKKiMseYLrf5L7QMcXPEDRxxQ+6RONeeuklXHHF/8bTTz+DhQsX
4otf/EucccYZkfbhi1/8S1xzzf/F00/finnz5uBv/3YVFi9ePO1ndDlfMuK4pSNu9gmvOSVIUGr5
8uXYvn37jO9/8YtfnPa113Pz3//939hvv/2wY8cOLF++HIcddhhOPvlk333QARarEVGv1zE5OWlH
UTOZDPL5vPJ9g8kKoNKnp0rskT2ClkKp7JQKIaUy+gmEPxFQJNSyLOzevTuUpf64BJ6fpWf6LGL0
UDy3ZAWh+0PXiU2EriEJ83w+j2Kx2HXf/SSLiOfTq36sGJF18seK3yNvs+yP9Ur0Eo/htRGCKsuI
alqtFi699DPYsOGdKJd/gFdf/RWuuGIN7r//dRgaGoqsHwsWLMA3v/lFu4pEEtH1uruN7fT9bvt9
//3utb8XLVqE7du3Y99998VLL72EwcFBx5/bb7/9AAALFy7Eueeei3Xr1rFYZZwxDGOar3JycjKS
pY0oooZhtiEmTNEE3tfXh0qlomzbWNXnKGyRKi71A8DcuXMjW+qPElHw0FI4Jf1QWbJMJmO/kInJ
iWHYClThZFeIqkatm5B18qR61Y8ln7cYzRbtOmH6Y2WPrFc0VofrK7J7925s3LgV5fIn/zwHnIha
7Xj89re/jVSsEl7Pus6RVR37Rbj1b+fOnaFu3e3EypUrccstt+Cqq67CLbfcgnPOOWfGz1QqFViW
hf7+fkxOTuInP/kJrrnmGqX9UgGL1YjI5XLTBgoa7FUTlVjt9rOIWetywpQovlQQhVjt9vjiUj9l
tadSKezevdv+fz9L/UByvZwkUlOp1LQoqoyTl1OHagVi+Szd7ArtbAV0TkURK/5/o9GIzB8rRmOd
CruLYpoiiXGd473VN1qwrK3IZPZHq9VAs7kJ++xzXiz98UJXUahrvwi3/qkuWwUAn//853H++efj
O9/5Dob/XLoKAP70pz/hYx/7GO6++25s374d733vewHsXa286KKL8Pa3v11pv1TAYjUi5Js5lUqF
ZrL2IoqKAJ0mWIlRMkqYckoyS4KYVHF8+fzIZblo0q5UKo7RQ52W+juFPoMo0ttZWgxjZnY94G4r
EEWNimoFYvmsXC4XW/msThGjqOSppS1p4/DH+t0IAYD9/ABwfDlRLWSz2Sy+8IX/gWuuuQiNxhkA
foPTTjsAxx9/vLI2O0HnBCbdcROrO3bsUC5W582bhwceeGDG9xcvXoy7774bAHDQQQfhqaeeUtqP
KGCxGhO9FlkN0gYlxJAX1W/ClKo3bN3EqrikTfYRt6z+fD4/TXTJXk5RpOq63C/jZFcIo/SUk61A
bFMUOnK1AqdorJfwV/UZokT+DE6eWpX+WCcRK9/fopCV/bGmaaJQKMywJ5DwFhO9ZG9smP7YCy44
D0cc8To888wzWLjwWJx44onavjCq6teOHTuwbds2DAwMYHh4OFA7OkdWvcb1sbExLFy4MMLe9DYs
ViPCKbLaS55VP8Kbyk6JBdr9JEzRpJFUsQr4i1w4LfW3y+ovFAr28cnrC2Cal5M2TBAnY1l46TAZ
iJFkIFq7QjvR5VQiShQ6onillw16EUua5SKs6+DXH0vny80fm0rtrR8rJ3rRc+AUjaW/xYg5EO5G
CEHOx1FHHYWjjjrK3mRDN1QKwqeeehrf+MZ9aLVGYFnbcNZZ++P881f6bk93sep2L4yOjiqPrM4m
WKzGRFSR1SjsBl5ij0SUuCtXqVQKHGGKSlCqEsNebTYaDVSrVccduEShRMdyy+pPp9MolUqOEb8g
S+CypWA2ezkBf7YCEiGyD5O+F/U57QTxhaedL7gb/PpjnaLcTvcp1XcVXxRM07Rf1uh4cvtBE73E
sltiVDcJiV5x0Ww2cfPN/4mBgctRLu8Ly6pj7dqv4YQT/oDh4WFfx0iCWHVibGzM92dk2sNiNSJm
W2RV3uaz23qyKj9HHJFb2QpRKBSQy+Ucl/rFPgKdZfUHWQKXfYeqMuvpM5APMsleToqGi1uhBvFy
trMVqITuRfI2x3kd2glZr3MqPsPZbNaOxhLt/LFi+36ErPiMum2EIItZXYWXqn5Vq1VMTRlYsGBf
AEA6nUM6vR8mJiZi71sYePVtfHycbQAhwmI1QkTRIvqoVD6IUYhVcXlOTggKa1cuXZbqO0Hsu7i1
LhV/F8syxZHV77UELooDMSPfbbmWBFc7L2fYtUWjhK4T2Suc/Khh2QpUWjWCbkQQN07nlIQ2ReXp
/5rNpr1aEcQfKyZnAe6JXrI/VsRLVBPi1rSitSAuVI19xWIRBxzQhz/96ZdYtOjNmJz8E9LpTVi8
ONpNEVThNX+Pjo6yWA0RFqsRIotVldE8IopqADQ40w5TYkJQWKgWqyqvAQm03bt3w7IsFAqFGUv9
4iQpR5bEyFfUy+TtlkhF0SVHDuUoLFkWUqmUvTFG0kRqWF7ObqsVdGorcBLauotUJ2Sh7Za81ok/
VoyC+vHHis+rl5Cll81mc+8mLfIzI4pq+d9R+bZVHPNTn/ogvvGNW7Fly93o709jzZpzMH/+fN/H
oPFER9qJVbci/UxwWKzGCC0jqnwQVYk8mvQoYarVaqG/v99xEg6DKMRq2McXRSawt+ZikKV+UVTo
Fvnys1xLdTkpiipCk7RuSV5OxOHlDGrVaGcrIKFdr9enecd1PeduUFS+E/uLTLf+WFHIiqshXrYC
6ou8wUlUiV5uqAyaLFiwANde+ynUajV7/NOlb93iNWdUKhWUy+UIe9PbsFiNkDh8q2GLMKeEqWKx
iF27diVyS1cVx5eX+mmAzufzsS31Rw1NtiQqZJEeZZ3TTtHNy9mprYB+RvRy6pTA1g4n60hY9pdO
/bHyfSqXhpOFrChAU6nUjK1pgWAbIYjHdvPH6nZ98/l8R7+ns1gFnCPSNLbrElzoBVisxkgUPsyw
vLFiWaUwEqaCortYpYmIfHLiUj99zyurP86l/rAgof3cc89hz549eP3rX29vBUv4iRxaljWjzmmU
26cGjd7FjZOtQPRyipG8ZrOJqamp2CtA+MHJdhH3trTUL6cXLid/LJ1PeoHIZDLTroVTopebP9YJ
v4leTtYC+Tg6XHMnVM+R3dDOoqDrOU0iLFYjxCmyqtpP2o03VhZgXglT9FlURZ50FatiVj95MeUo
YqvVsoWoHDUkgafjUr9fyAdYrVaxZs1f4d57f4FMZhDl8k7cffftGBkZaXsMURzIS6Ttkrzclr+D
3O9i9K7VaiGXyyUyoi3vltXX1xc4CciPrUAlUdkuOsVNyMpL+VTtQlxBoe97+WPpWE7VCug47RK9
RI+teI3puOLvp1Ipu7yarqJVxz4B7iK/Wq3aNbCZcGCxGiNRRFY7acdLgIXVRlBooFd5/CD9lzc4
cMrqbzab2LFjB8rlMvr7+6dNGrKPkyYbiqzqFOFyQ05yue+++3DffZtgmr+BZZVQqdyEj3/8s/jp
T+/sqp12y6OykHVbqnUSXLIwSmriV7vqBDLd2AqczmsYUW566aHM/lKppMwDrwLZykOWhVwuZ38/
LH+sk5B1shW0E9XyigbZE+JM9JLRVUAD7n3jDQHCJzkjQQ/gFFlVXbCf2mkX9RQjS2JUxu9koWvk
M8zji5Fm0TtHokAc+F955RVccsmV2LhxO4Aq1qz5KFav/hgajca0pX6KZviNcKlc/vaDk3+QSk9t
2rQZU1PLkc2WAACGcTY2bvyKsr4EXaqVBRf9TDqdRqFQiNTWEgaqosFOtgJqz6/nOIitQCdvcKfI
18LJshClPxYIVj+WrDYkkOX+iH1x8saqErI6WwAAFqtRwmI1RnSIrNISNQ2yhUJByx2m4jy+HGkW
hY3sGaNjfeYzX8D69WegXP40LGsMN9zwARxyyAE49dRTHSdjPxEuFcvffpEjkLlcbsZk/LrXHYpi
8R/QaHwahtGPVuuHeN3rXhd6X/zgJmQpI940Tdty0Gq1/ly8fEq7JC8nxCQ8wzAiiwaLS8dhVCsA
MG1TiCRaYERfbafXIkx/LG2zLNoASMR6+WPpZUMUx259EftElWBUJXqRGNTl2RPxygXhGqvhw2I1
QuLwrFK7shCTE6Zoya3TQaEXxKp8Lfws9YsDljioPv30sygUvvLnQXweTPOd2LRpE975zncG6pNb
hKvd8ndY0VhxO1fxPnHi3HPPxU9/+kv88IdHIZOZj7lzTXzrW7cGbjNsnKLBThHIIElespCNAnmZ
XKckvCCCizzaBO34RZ7uqM9rJ8gvb6quhV9/rNPLrNs4IP+uOHZQIqjYftBEL/llBZie6CUKWp2v
sV+cPsPY2BhHVkOGxWqMRBVZJVEcJGEqKLp5Sjs9vjgJtVvqp98ToxA0GS9aNIjNm3+Jcvk9AExk
s09g8eL3hNZXv37DTnaccvJA+ol6GYaBG2/8Cj73uU9h9+7dGBkZiTXJQI5AOkWDRfwmeZGAp69V
R7nlF4akLZPTfSdGBml1AsC08xr2JghhI44PcfpqRQHp1Md2/lhxVYi2CRY9t2H7Y2VxLCZ6eVkL
kuhXBfaK1YMOOijiHvU2LFYjJK7IKgBbpKbTaV8JU0ERl55UoFqsUvRt586dMzyMbkv94uAuF/C/
4YZrcNFFV6LR+DGaze045ZQlePe7362s/0Q7v2G7HaeA1yalTj2Q+++/f/cfpAtURCC7SfLqNKs+
aSW0nBCXyQHn8lOdnle3Fy8ViPeU7i8MXkKWVossy7JfyprNJiYnJz39sd0megEzrU6yiKV7hf4t
ClYx8UsXW0A7sfqmN70p4h71NixWI0YUXWI0L+yHT1z6pFqLqneYUh1ZVXF8Grwp+iaeo3ZL/fJE
LIq7o48+Gg8++CP85je/QX9/P5YtWxar0PCawMRyR/Qz5GWme6ddNFYH5OoEUQiKIFFuP1n1hmFM
qxaR5E0huik/FZaPs1u7hpj8FdU9pQLxxSefz6NcLrvaYFT7Y2Uh6xUdphUMsexWHIleTnjN2+xZ
DR8WqxEji9WwlzqcEqay2awdEVBFFMv0QDhlTGgQFHfh6uvrQ7VanZENS207LfVT5M5tIp4/fz5O
P/30rvqqknY1Of1EY+OqxSn2kepZ6haBbBflFoWBeF6BvZM4RSCpBqaOLwgy8rOhYpncr4+zG7uG
/OKjyz0VFFmker34qPTHOolYcSyXhazsaxV3v5KjsZ1uhNAtXnPR+Pg4BgcHQ21vtsNiNWbCEnli
FFVOmCKPkEqSIFYpSkJ2CHEXLhrsaJtTpygqTX5RRu7CRk428qrJ2c4XJ0dh5Kihymis0/JyUiKQ
4nlNp9P2tUin09M2lNAxycsNMQIZ1zK5n/u1na2AVnB0e/EJgviM08t4N89Gt/5Y+eWA5iVRvIrR
WQB2JNU0TfuFjfri5o+l/rhdZ/FzhJHo5TUXvfrqq5g3b17gYzLusFiNGDffaicDu7jUJm/xKbcZ
hVhV7b/t1BcrZvWTOJOX+oG9n2HPnj0zBjQSRgCm1RVNEkGTjdrRLgrTzhvbqddQhR81DvyIOzHJ
K2jUMKpkpKREINvZCuieEgUWJbWFaStQiZNIVV07OMgLQrv6sWQtEO9vWp2g+x8IbyME2R/rFo11
O39eYpW21mXCg89mzHQiJJvNJqrVqp2R2q6gOQlilXQqJIMQ5Fw5LfW3y+rv6+uzBzXTNKfVTxSP
STU641r6DoIsilSLuzCjsU4+zqR7BzsVd91GDcO2a8jJX/39/do+A27Iqwxy4mmYtoIoPke1WgUA
bbanDeo7pn8TmUzGMdELaO+PpfaD+GO9Er2corHNZtPV5sOED4vViHGLrLZDHJBM00Qul/Nddkpc
clEpUnQQq7KQF5f65QGJjum11C/6OOWJyykBQYdEJPocYnUCHSJeQaKxNHmJ15tezOQdfHTHSRSF
GZ1vJwraJXm5vSB4fY5WK7wds6JGFnduEcgwbAVO5zbMzyG+UOsiUv0g3rP0OcibXSgU7JW6bvyx
YjACcE/0EgWojByNFXfzEr9nGAYefvhhlMtlHHzwwUoDAj/84Q/xhS98Ac8//zwef/xxLFu2zPHn
7r33XqxZswaWZeGyyy7DVVddpaQ/UcFiNWbaCTBa9qxWq7bRvK+vL9CDEMXgFacgFidRWuoXhTxN
2GL/ZJFKOxvRJOwkJsQB1m2JVo4UOEW2uinS74Xs40yKmJBFgRjZAPZ+DnqpE6NbYsRDFgU6fGYn
X23UW7rSMqpT39rds+IfEg0AErU1bb1en/ayGpa4Cxo1lF9qu7EVJFmkisifo1gsei6du92zXv5Y
Oq/t/LF0fHEcEoWxE5OTk9PurQceeAAPP/wwNm3aBNM0ceKJJ+LQQw+1/xxyyCE4+uiju35hOeqo
o/Af//EfWLVqlevPWJaFK664Ag888ACGhoZw/PHHY+XKlTj88MO7ajtOWKxGjFNkVVy6IMSEKVr2
7GZA6sYb64coBTEhL/WLW8U6vV3Lb8+y/7HTbStFseW2DaU4uLpFCTr1GcqfI6mTV5DP4VdsxWHX
EL3kul4Pv/csvcSJ0MqDzh7OrVu34oMfXIXnnvsNyuV+3HDDl3DmmW9DKqVutymi3QpCp7YC8b6K
4nOoIqhIJfzcs0Ei3eSFFVfdxMgs4G0rkK/zl7/8ZQDA7373O9xwww24/PLLsX79eqxfvx63sllI
LQAAIABJREFU3XYbtmzZgscff7zr83fYYYe1/Zl169ZhZGQEw8PDAIALL7wQd955J4tVpnNEASYO
RrRc6JQw1W07qqClG5WCmAYVWuonH6bfpX4AdqkjisKq9D8GWfoOumVqL/k4g+7QFPQFwSmyFXY0
1k/SVBIQVxroc4hJLroleTnxgQ98HM8//x6k0/+FSuUprF59Hn7608Ninay7sRXQ2GYYBrLZLLLZ
rHYvCO2g+6pardpiO6wkpLAi3TSeiP5YWciKY7ZoqaE/o6OjWLp0KU466SScdNJJoXy+oGzbtg1L
ly61v16yZAkee+yxWPoSFixWI8YtslqpVHwnTHXarmqxKj7gYUMDRa1Ww9TUVFdL/Sp8g0FpN3F5
bZkqLmuJIjVpE1cnW7r6wU9ky2801o/PMCkZ8e0gsV2v1x1f4oKILafM7yisMMDe5dnnn38WqdRP
/2yDWIZU6m146qmntI0sOd2z4sqR+FJGL+sqNkFQgShSVdXe9cJvpLudP5bOJ22eQv55UcyOjY3h
5ptvRn9/v21N6ITly5dj+/btM77/pS99Ce95T/ttu3W59mHCYjUmxAeYylz4TZjqBL+JXN2gQhCL
AzZFbefOnTvDh+RnqT+VSnW81B8lTj5DEurkqyVx2mw2UalU7O/pPGkBzv7gqHy1fpcR3ZLnnHxw
4mYEScyIB6aLba+6u160i2zJSV5eCTOd3rcktk3TRKFQRK32LFKpo9Bq1QE8i8HBswMdLy7EZz2T
yczYrEP8uW5sBVF8jjhFajvavXyJL7amacI0zWm/+8wzz+Df/u3fMDIygiVLluAXv/gFfv3rX2PN
mjU499xzu3phvf/++zv+XQAYGhrC1q1b7a+3bt2KJUuWdHXMuNHnzplFTE1N2X6dXC4H0zRRLpeV
thmVDaBdG+vXr8cTTzyBcrmMt73tbSiVSo4/RxOouNQvljbRaalfJeLSMg34TlFUOaolTlpukZco
o3+y3063lwZRbLVLnqNzK/4eTcxxnNtOkCPbKlcanF6+qA9OQjZopFuObPf39+Mb3/g7rF59Lgzj
TPz/7Z17WFTl2v+/M5wPCmgIiBriATANNA9tfd1qhW2P2dZrq729+pYVaoq+tTNrV+r+7RTPmVi5
MyXNSMXtlleBnVmQSYiV7UogwCJBE0VERc4z8/vD91mtWaw1s4Y5rLXG+3NdXcnMgnnWmplnfZ/7
ue/vDXyPceP6qrqbHGC+sJaTRmJPWoGlVBh7PwPCnG21iVQ5CHfkTCaT2XkYjUaEhIQgPDwcubm5
KCsrw+XLl9Hc3IzVq1cjIyMD/fv3x9SpU3H//fc7bZxS99uhQ4eirKwMFRUV6N69O/bt24f09HSn
jcMVaOsT5AawLwF/tdzY2MhtXTvzdZUWq/n5+XjuuW1obR0Pna4CH36Yjffe28AJVpPJsj0Xi0Kz
qmTh5Cq21e/r66t64SBEKCTkbC1LCSRbI4aOjsYK8zi1duPip5Owz55er+cWDcLoiyuvbUdg3zFH
dTeyB7liS+rasp0Fo9HYLmf70UenITY2Bt988w3CwibhgQceUO084IxcZ0flcNqyQ+MOIhVo/x0R
K5BsampCZmYmjh49ivnz52POnDnw8vLCzZs3UV5ezhVWXb9+3eHjO3ToEJKTk1FTU4NJkyZh8ODB
yM7OxsWLF/H000/j6NGj8PT0RGpqKh5++GEYDAbMmzdPtSkwctFZETDkbusE+LY8wO3WbI4qpJKC
CT1nRnBv3brFJc6LMW1aEmprl6JTp3sBANXV/w8rVtyDyZMnc1FUNjn4+PiYiV9hPhE/D47dtFiF
shqrr+UgtkXONyl39GsJb1rs346opmeRbRbt8vHxUa1YsIQw2uXt7W31Bix1ba1Fup25PSuswFZb
ZFsufCFhMBjMvv/Ca6t0kZc1+CJVDd8RsbQC/udWKq0AAPfZ4ruqaBEWLGELOWHtSGNjI3bu3In9
+/fjySefxLx58+Dt7a3giN0S0S+qNj9RboYaop6OwFqB1Y0b9fDx6c79bDJ1R23tNdTV1ZlF3aSq
+j09PbktWr6w40cEjEYjGhsb29lBqfWGBSiTV2trNb0lI3m+iHWm+b0rEW4ty4l2HTlyBEuWvIyb
N+swbtxD2LFjCzp16mR2jNxIt6PyjoXRLi3bHQk/WwEBAWbnoaYiL0sIRapaCvLk5HAKCz/51k4s
kssPHKh1zhViTaQ2Nzfj/fffx969e/Ff//VfOHHiBHx9fRUc8Z0HiVUFEH55WWTAmTmV7DWcibXX
ePDBYfjHP95Bly5JaGy8AL0+GwkJy+2u6pdqo2ppi0sNW7Mst5TvpauGvFpr1bNSdlv832WVslrC
HoeCM2fO4L//ezEaG/cDiMGxYy/gyScX48CBNLPj5OTG2pJ3LCUGbM1/VCv81CDAcmMFW4q8rHVF
csa8ICxkU4tIlQNfyLIFEEtbEDbt4M+5AFRd+MmP0ou58LS0tGDv3r1IS0vDzJkzkZeXJ1lnQTgX
EqsqwFpEUiuvYSl6azKZ8Oyz/42mpreRlzcfISEBWLZsIeLj4x1a1S/HpkSObZGzoi7s5iusItfC
TUsYeeG/J0x8sQWLUAyoxX9TDGGOWkccCj777DO0ts4GMAYA0Ny8GZ9+2lf273ckf5MtEoQCgEUU
tVxYKExbsDe1x9lFXpYQc1tQw+feVqzlpFpbgPGLE63t0jj7+ghFqvD73tbWho8++gg7duzAo48+
ik8//bTdLgnhWkisKoDwi8hWpc5+TSXEqrCq/7XX/mxxq184UTnK+N7WbW9HCy020bNuQEoWttiL
Lb6i1qKxSkZd+O+JvXmcISEh8PIqQFubCbdTrsoQGBjkkHHKica2tbVx15WfksGislpIhwHau0a4
otuUtUVCRwuRDAYDVyvgTiJV7hxsa1qBVLtfR352+e+J2BxsMBiQkZGBd955BxMnTsSxY8cQFOSY
7zFhH1RgpQAsOsJoaGiATqeTLExyBEajEXV1dejSpYvTXqO1tRWNjY3o1KmTWVW/j48PfHx8zLb6
mVjhuyDwt/r5gpEVGrk6+iicUPkTq1yhJYw+suugtZuWWM6gvcVfwpsV/9/OLEISe0/sLQi5desW
Ro0aj6qqnmhpiYW39x688846zJgx3a6/awkx+yn2nojlb9r62XUlJtNv3qJqL9KRU4jEjmPb5K70
N3UUQpHqqtQeqWsrllYgdxdMKFKFc5fRaMThw4eRmpqKBx54AM8//7xT75WERUTfSBKrCsCiS4zG
xkYYjUanVuqbTCZcu3YNISEhTpswW1tbUV9fz03KTKTyI67CrX4pYeeqQqOOIiUEmNDiCwZPT09N
5nAC5tuxgOWcQUe+ptj1tTfvmN/W1cvLixMRjuLWrVtIT0/HtWvXMHbsWAwbNsxhf5uPmP2ULe+J
tc+ulBBwxnsuzK3lL2q1BlugM7s5tmPGXySopcjLEkqJVDnjsrQIE0srAMClXEmJ1KysLGzZsgWj
Ro3CsmXLcNdddyl1isRtSKyqBaFYZdvcgYGBTn1dZ1lksVUrs1zq1KmT2VY/P5IKWN/q1+oNi7+t
zEQqAMnJVG25m3zUGBG2FtESE7EeHh7tiqaUiNI7AmfbT7kyGms0qsu2qaOw6LalSnLhsXKFlquj
sWoVqXIQ2wVra2vj7jnss7VmzRr06dMHffr0wZUrV/Duu+9i6NChWL58OcLDw5U8BeI3SKyqBTYp
MFg70c6dOzv1devq6hAYGOiQ7TX+jZNt9Xt7e+PGjRsICQkBAE1s9TsCfkGRVERYLEeL/VtN27L8
hQN7T7RwwxITsfyOZ6zAhr9QUOMiQQyhiFBi4cAXsWJCS25etzDfWcsi1Z7otvBvWZobHFHkZe31
tSpShRiNRrOmMj4+PtzjjY2N2Lp1K7777jucO3cO586dg7e3N2JiYhATE4P+/fsjISEBU6ZMUfgs
7njIZ1WtuKJS31Gvw3LLmpqauCrdwMBAs61+YQ9lYVU/X9h5e3s7fVvZWdhiPWWt2IAvsKxZFjla
qGjZoYDBF0xsIcWvIudfYyVcIDqCcItcycp+KXEkFo0VK6BjLgW2WoKpDaGVliMakDiiyKsjVnx8
kar058tehCJVWMym1+vx7bffIj8/H9HR0XjzzTdx99134+rVqygtLcWPP/6I0tJSFBQUkFhVKRRZ
VQi2ZQ7cFj38iKSzuHnzJhcBtRX+Vj/LwRTb6m9oaEBbW1u7iRS4LWL5ERUtToxiws5ZEWFLhQaO
2DZUIh/VWXQkbUEoBPj/VnJbVphbq9XoI1uYssUXOwdbo7FqwNkpGB0Zj5yUGKncWL5I1epcDJin
k4jNxSaTCYWFhUhJSUF4eDhee+019OnTR8ERA5WVlZgzZw4uX74MnU6HZ555BsnJye2OS05ORnZ2
Nvz9/ZGWlobBgwcrMFpFoMiqWmHRIP52uTPQ6WxrDCC21W/NwJ8ZJrPn2O/zF0VsK1DpLW9bEBN2
zraekmNZxG5StnTqEQo7rbanBezrq86/vnys2W05q0hGy6bxfKxtkVuLxqqpCEkoUtXyXZETjZW6
vuz3vby8zOZypc/JFoQ5z8LvislkwpkzZ7BmzRoEBQXhzTffRP/+/VVxjl5eXti8eTMSEhJQX1+P
++67D4mJiYiLi+OOycrKQnl5OcrKynDq1CksWLAABQUFCo5aeUisKgR/25w/iTvzyyQ3DYCJGamt
fv5kyMYvnCj4W/38ziBCEeDqLW9bEQo7NbSr5N+oxDxjLXXqYcfwRaoWBRGLbjtD2MlN2RC7vrZG
C8Xsp7Taola4RS4VqZdaJLC/4cjra8+5uNLv1ZEIry/fFozfslrs+ipd5GUNOSL1hx9+wJo1a+Dl
5YW1a9finnvuUc34ASA8PJwr5goMDERcXBwuXrxoJlYzMzMxd+5cAMCIESNQV1eH6upqhIWFKTJm
NUBiVSW4Im+VL5DF4G/1sxxMWw38+Tmcwg4n7HekOsnwIwFiuVmurKLniyE1tUK1hvD68quVDQYD
J07ZzbixsVE0901tNylA3OvV1cJOzufXUu4m/9qyY1j0UatNIhwZfZR7fZ0V7RYWG4nNYVpBKFIt
zWFydhOkhKwr4AcNpERqcXEx1qxZA6PRiJUrVyI+Pl7136eKigqcOXMGI0aMMHv8woUL6NmzJ/dz
jx49UFVVRWKVcD1i0Qaj0ehUQcRukHzYjYZvmMy3t+JPYOxv8EWMWFV/R4pzrG15W+uA1JECAyFq
EEOOgr2vLDeatd4UnotYSoGwAEnpLVkt5NZaihYKRWxTU5PZ94nZawEw+wyrHaGwc2b00VHRWKmF
2J0qUhlKFXnZci5SIrW8vBwpKSmor6/Hq6++imHDhqlqbpCivr4eM2bMwJYtW0RtK4WBJS2ckzPR
5rfRDXFFZJX/GmJb/fzuN2Jb/VKTuzOr+i1NokIR0NEqb+G5KF08YQ+2nou1lAJhXqwrt2RdKYac
CbsurCUqOxf2fbS0m+AsEWAPfAGhBmFnKRorJ1rIjvH09FT8XOyhIyJVDtZyu8WErFRal9w5Qngu
Ymk+P//8M9auXYsrV67glVdewciRIxX/bsiltbUV06dPx+OPP45p06a1ez4yMhKVlZXcz1VVVYiM
jHTlEFWHNr+VboBYZNUVaQBGoxG3bt0yW6kyAeCorX5XIRWBEptAxUQWizSzrX4t36jsKTSSwtJN
SmrLG4DdIssZ56IUcs5FTgGdpYWYq7Zk+VuxWnhfLC10+X7C7PqxuVELuZt8nCVSrSFnocv+44tY
YVoM/1oDsHoulZWVWLduHc6fP4+//OUvGDNmjCrfFylMJhPmzZuHAQMGYOnSpaLHTJ06FampqZg1
axYKCgoQHBx8R6cAAGRdpRhMJDEaGhqg0+ng5+fn8Ndi26iNjY0wGAzw9fWFr6+v2Va/MIrK/78r
7ZqcCTvP1tZWTlwxka6VvE0hTIir4X2RstORK7LcxTAecN65KGG3JSxq0fL7Ilw8CG2bxKKxQoN+
qbQCVyMUqVqxoBLmHvOvNfBbpNxgMCA/Px8xMTHo2bMnLl++jA0bNqCkpAQvv/wyHnroIVXPzVJ8
8cUX+P3vf497772XG//q1atx/vx5AEBSUhIAYNGiRcjJyUFAQAB27dqFIUOGKDZmF0MdrNQEE02M
xsZGGI1GBAQEOPQ1mpubzbwBGxoa0KVLF7N0AGtb/S0tLdDpdJo28LeU9ygWyRKKLLHcWKWug1hu
rbDntdqwJrLYMZ6enlzXLLUvFMRQavFgq8iSk3vsTosHRwhuJRYKUuPQokgVQ5jqwzzAjUYjLl26
hGeeeQbl5eWoq6uDh4cHEhISMGbMGK7rVExMDIKDgxU+C8LBkFhVE0KxyiZSsURrW2E3TLZVz+/i
c+3aNQQFBXE3N0B6q59FH/jiQWvwty7ZZGhLPqqUAODnZLlqO9bdcmtZYR8AUWszsSp6pRcKYqh9
8WBNZAmvMfucqSFaby+uiArLWSg4Yp4QpmG4k0gVa/FaU1ODLVu2oKCgAMnJyejTpw/Ky8vx448/
cv9169YN2dnZCp0F4SRIrKoJ9mVlsC9up06dOvz3+FX9vr6+ZhMzu2HduHHD7AYlzN90l5uUs3vc
S213i0VZ7C0+Em5dMsGtRWwR3FJbhUosFKTORe0uBZYQiizWYY6hth0FWxA2WFBqLnNENFYoUvkp
XFpDjki9du0atm7dis8//xxLly7FjBkzFD/fJ598EkePHkW3bt3w/ffft3s+NzcXjzzyCKKjowEA
06dPxyuvvOLqYboLJFbVhFCstrW14datWwgKCrLp7/C3+tnNn1/Vz45hW/38n1mvbr6dlYeHB+fF
qYRNkT2IRbi8vLxcOtFZi7LYYrXlbtuw/BuuPYLbloWCM7Zj3S3CLdZtCoDVHYWOVHk7G7WIVGuI
zRNi+d3sGL4bhhbhB1M8PDy47wyfGzduYNu2bfj444+RnJyMWbNmqeZ8T5w4gcDAQMyZM0dSrG7a
tAmZmZkKjM7toHaraoJN7PyteFvcAIRb/YGBgdyX31pVv16v50Sq0WiEl5cXFxFiv8e3KVJDFMsS
rrLRkoM9Vlv8a8qqZ319fTXr9Qq0F9yO6DTFdynoiCdvRyOFarNssgcmUi11m5Jjzs+v8gbsd4Lo
KPzGF8zrWc3fGblOBSx4YDQaUV9fL7oYU3PEm7/7oNPpRL8z9fX12L59OzIzM7Fw4UKcPHlSdd+r
0aNHo6KiwuIxznbzudNR1yfiDkav13M3ValJR2yrX2jgL1YwZamq35p4EEaxmMCSyndj/3YFwtxa
tYsHqWvDBBaLPAK/OTEwoSd2g1Ir7Hz4hUau6HNvSQAIRay1Nr/8ayxMw1C7ZZMlhOLB1m5Tcjw3
+XOFs9M2+AVtWu4CBrTv0iRsrqJWSzMxhJ8zPz+/dnNzQ0MDduzYgYMHD+Kpp57CyZMnuQIrraHT
6ZCfn4/4+HhERkZiw4YNGDBggNLDcivUe2e/AxBGVqUQbvX7+vqKVrLLqeoHYNOkLjeKxbw2xdqj
OnIrVikh5CyEBWBMCAl9b/lRLGdf447CblCsa5aaxAOzwxEiJbDYNWbHsPw6LW/3O7PBgrWFgqVr
LBRZcj7H7iZSLfW7Z8jxNVWiy5RwHEKRKvycNTU1IS0tDenp6Zg7dy6++OIL+Pj4OHQcrmbIkCGo
rKyEv78/srOzMW3aNJSWlio9LLeCxKqKYNFVFrVg23T8SUzuVj/QPvLoyBuU1M1JbPXviK1YYTGL
t7e3pm9QwgIwsWidnCiW2DV2dWGMlnM4xRZj7HtnMBi4nGf+rkZHraCUQA2pC9YWvLZECtn5qG0x
1BHkilQ52DJXOCMay08rkYrYt7S0YPfu3dizZw9mz56Nzz//3Cm+4krAL4yeMGECFi5ciNraWnTp
0kXBUbkXJFYVRDghsJxRYZGQv7+/U7f6HX1Ollb//EgsG6Olmz8/KuwO0S3heyPc6pOD3Gsstd3t
qG1CYVRY7WkYlhArzgsICBC9NmJ5sWId0pQsPhIWtKkxdUFupJA/VzA8PDxE8721MC84UqRaQ841
lhvxFlv0CnOfxebn1tZWpKen47333sOMGTPw2WefOcSiUU1UV1ejW7du0Ol0KCwshMlkIqHqYLR5
Z3FDWFSsvr6eE2Wu2up3Fda2YvlRQhbB4v+elkWq0OLIWe+NLdvd1nKPpW7+/Ii9l5eXKoWQXDpi
PyXnGiu1FetKIeRM2PVi1xGAWd6jVBGdmiPeantv7I14A+AWEPz7FaOtrQ0HDhzA9u3bMWXKFBw/
fhydO3d27Uk6iNmzZyMvLw81NTXo2bMnVq1axfmkJyUlISMjA2+//TZXO/HRRx8pPGL3g6yrFIRV
sLKtfp3udpcptjXCnzTkbPUzSxA1VerbgjC65eXl1e7mpJbiLjkII49qfG/Eco/56SX8KCF7f1ie
oFptgeTgytQFsZu/mE2RmC+vXNzJ5kyY9yj3vZGyjOvIgsyRCEWqlt8b/s4f++yyz/bGjRtx4sQJ
9OvXDz4+Pvjiiy/w0EMPYeXKlQgNDVV66IR2IJ9VtdHQ0ICbN2/Cx8cHPj4+Zvk+wigq//9iRUbu
IBzktnWVElhqKTziV/azm5MWI4/8KGxra6uZNYuaI1iWEFtAKJm6ICVi5QosoWWTj4+P6t8DKToq
UuX8XX7EW2pB5ugcb3cSqcBvudx8P17+Pam6uhoHDhzAiRMn0NDQAA8PD/z000+4cOECoqKiEBsb
i2XLlmHkyJEKnwmhcshnVW2wyYtt9et0Oi7CKpUfpPatflsQWgLJLQBzdXGXHMQWEB3JR1UL/Mp+
VtXLhIPYNRZ68opVdyuJWu2nrBXGCN02+Nvd7BgvLy/4+/ur4jp3BGGU2xlOBWLXGGjvfWyLpZkU
atvutxdLIhW4fb4ff/wxNm/ejOHDh2Pnzp3o1q0b93xTUxPXJjU8PNwlY7bWcQoAkpOTkZ2dDX9/
f6SlpWHw4MEuGRvRMSiyqiD8yla2vcKfLPmilU2m/BZ1Wr0x8UWdqyIOUpFYe/PcOpLzqGbsSV0Q
5sXy/61UxNvdtsf5woEtHviCy9FFdM5EaKeldJSbj5zPslj6ET+XW8ufNcDcHkwsJ9VoNOKzzz7D
hg0bcO+99+Lll19GRESEgiP+DWsdp7KyspCamoqsrCycOnUKS5YsQUFBgQIjJUSgyKra+Pzzz/Hp
p58iNjYWsbGx6N27NxcpNRgMyM/PR2RkJLp27cpNiAaDAQ0NDZI5bmq8KQHtPThdbT1lS3GXnCgh
3xJIr9dr2qUAcEzk0ZaCDWdHvPk3Wi10NLKE3AWRVFEMf+GrhjlDKFLV6CJh62eZFRqx39PpdGbN
PLT02eOnlojt3plMJpw4cQLr1q1Dv379sGfPHvTq1UvBEbfHWsepzMxMzJ07FwAwYsQI1NXVobq6
GmFhYS4aIWEr6poh7jAGDBiAGzduoKioCDk5Ofj55585wXD9+nXo9XqsWLECEydO5HLR5N74bTHY
diZSOYJqmbwtbcNKVc8z9Ho91+NeC/maYrBoPuul7owtS1vtzDoaJeQX6CmxIHI0whxOawsiuSkF
rkyPEY6DLfDUlIphC/zPsl6v5xa2rG4AgKzFghrmZiFyRGpBQQHWrl2LHj164L333kPv3r0VHHHH
uXDhAnr27Mn93KNHD1RVVZFYVTEkVhUkNDQUU6ZMwZQpU/DLL79g27Zt2LlzJ4YMGYLHHnsMOp0O
ubm52LFjB1paWtCtWzfExMQgJiYGcXFx6N+/P3x9fbkJRbhtxbcbcdUNicE3vdeivRH/xu/p6cmd
D7sxsep4/gQvtj2othsSIO4p6ufnp8gY5Ua8LVltsTQZfmGOllMxhJFHe3M4pXK8AdtzNjsyDv6C
VasilY+1nFQ5xvxqstuSI1K//vprpKSkoGvXrti2bRv69evnkrE5E2EKpFbnizsFEqsq4YMPPoDB
YEBhYSGio6PbPW80GlFdXY2ioiKcPXsW77//PsrKytDU1ITg4GDExsZyIjYmJsbM0FyuGb+9ItZR
pvdqwZbUBSWLu2w9Hy3k18qJEvJb/DL0ej3a2to0aRbPjzy6antcqmBIjmG8tSihWovaOkpHC6es
7SwIF2ViDSackbrBz+eWEqnfffcd1qxZAz8/P2zYsAFxcXGa+C5ZIzIyEpWVldzPVVVViIyMVHBE
hDWowErjmEwmXL16FWfPnkVRURGKiopQUlKChoYGBAYGIiYmhsuJjY2NRVBQkJmIFRYcSW3BWlrt
i7kUqFUEycHRHpzOKu6y5fX5IkiNfq+2IFUEZs3LVK1WW8LIo5qtzsQWZez/fM9Y9pn39PTkCkK1
Cl+kusomUCx1g3+d7Vn88kWqmN2ZyWRCcXExVq9eDb1ej9deew2DBg1SxXfFFioqKjBlyhSrBVYF
BQVYunQpFVipB/JZvZMwmUy4fv06zp49i+LiYhQVFaG4uBg3btyAr68vF4ll0diuXbvaLGJZEUFb
W5vZTVZrkxpDGAli+ajOQs51tmcLVng+ahZBcujo+Tj7OjvifLRePW4ymZCRkYG8vC/Ro0c3PPHE
EwgMDLTbBkpJjEYjmpqaOFGnFi9rS80PpK4zq3fgn4+YSC0tLUVKSgqamprw6quv4r777tPkfM7v
OBUWFtau4xQALFq0CDk5OQgICMCuXbswZMgQJYdM/AaJVeL2hFRfX88JWCZia2tr4e3tjX79+nEC
NjY2Ft26deMmaLbN//PPPyMiIoLbqmIesVLFXWqHX2SkBtEgZptjq1G8u9g1Ac47H6WstoSRLbWI
oI5iMBjw6qv/D+++exQNDU/Ax+ck+ve/hM8/z4a3t7fNNlBKp26oVaRaQ6r5gTBNxsvLCzU1Naiv
r0d0dDS8vb1x7tw5pKSk4Nq1a3j11Vdx//33a2LuJtwSEquENCaTCY2NjSgtLeVSCoqV1SZ5AAAg
AElEQVSLi1FdXQ1PT09ERUUBAL799ltcv34dn376KcLCwsxM4sUmSSlxpfTkL1Zk5O3treoJ2lrn
Lr5bBF/UqfmcpBBrsuCq7kzO2oJ1p25TwG+iu6GhAdHR/WEw/AIgDIAJgYG/Q1raC5gwYYLk74ul
FCiZuqFVkSoFi9y3tLRwRaHA7fftn//8J/72t7/h119/RWhoKJqbm5GYmIiHHnqISxkLCQlR+AyI
OxQSq4Tt1NTU4O2338a2bdvQtWtXjBs3DtXV1bh48SL0ej2i/q+NHsuNvfvuu822nSyJK6mcWGfe
wPn5tTqd9dauaoefXwuAS1tgN361FHfJRWg/pbb8Z7HPs6U8b51Ox4kGVm2t9kWRNYSiu7W1FZGR
UTAYboLV7AYGTsO2bX/EjBkzOvQallI3HF145G6RbjnpJRcuXMD69etx7tw5PP744wgMDERpaSlK
Skq4/xYsWIB169YpdBbEHQyJVcI2TCYThg0bhkGDBmHJkiVISEgwe85gMODcuXNmxV2VlZUwGo3o
2bOnWWFX7969zdp1WirScIZXrFRRjlZFg9wiMGvFXXKL6FxxPs7oC+8qxD7P7DoD4CrBXbkwczT8
RgtC0f3gg4/gm2/uRkvLnwGcROfOf8GZM/kOb68ptYtjNN72P5bKixW7ztYKjbSGHJF66dIlbNy4
ET/88ANeeukljB8/XtINorm5Gb6+vi4Ze05ODpYuXQqDwYCnnnoKL774otnzubm5eOSRRzinnOnT
p+OVV15xydgIl0NilbAdNvHJhd1MfvnlF85mq6ioCD///DPa2trQvXt3LgobFxeHPn36mN30pHLb
xESsnAihMN+Rvx2mRRxVNKWWoiOhp6g7LCL49mCsSE8qRUZt+ZpiWBKpjLq6Ojz77DLk5xcgMjIS
b721Fvfee6/LxshfAFtbmAHg7Lh8fHzcQqSyhbiUSL1y5QreeOMNnD59Gi+++CImTZqkmuixwWBA
TEwMPvnkE0RGRmLYsGFIT09HXFwcd0xubi42bdqEzMxMBUdKuAhqt0rYji1CFfjNHzM6OhrR0dGY
PHky95zRaERVVRWKi4tx9uxZ5OXloby83KzhAYvEChseCCOE/IYHUluvzOBcSdN7RyEU3fZ2mrLk
Y8q/4TurZafQrknrHpzWuk3JMYq39Jl2deoGv+EFS8ew1A0sODgYe/f+3SVjE8NS4wN2nVtbWznv
Y3YezBPaUSkFrkTYEUxsTqitrcWWLVtw8uRJPPfcc9i4caNqRCqjsLAQffv25eoiZs2ahcOHD5uJ
VaC9iT9xZ0FilXAZer0evXr1Qq9evfDwww9zjxuN9jU8YDf8lpYW7mYE/CbImJBQk7emHMSKjJzd
454vYsV6ovMXDPxrLTdCKNyqdAeR2pFuU9aM4vmRbmd0lbJ0PmrOGe4I7DMn3O639JlWc663HJF6
/fp1pKam4vjx41iyZAlSUlJU+z0Ta3166tQps2N0Oh3y8/MRHx+PyMhIbNiwAQMGDHD1UAkFIbFK
KI5er0dERAQiIiLw4IMPco8LGx7s379ftOFBeHg4vvjiC+zZswdHjhxBXFwc9Hq92Y2IRb2kCmHU
cBNiiHWaUrrHvVTkSm7nLp1Ox+Vxent72x0ZVhphowVHim6dznILWn7U21EFi0ykNjU1AdB+Yw+g
fU6qcKFnKRorzIsVWzCI2Zo5E6FIFfvM3bx5E++88w6OHj2KRYsWYdWqVU7vgmYvcq7bkCFDUFlZ
CX9/f2RnZ2PatGkoLS11wegItUA5q4TmYA0Pjhw5gu3bt+P06dMYMWIEfH190dbWJqvhgTUPUyW8
Yh3dOUtpmHBlN3q2gFBbcZctCNMX1NBoQa7Vlliut9YL28RwZuGUtflDSsTa8/r8eUHqM3fr1i28
++67OHToEJKSkjB37lybU7iUoqCgACtXrkROTg4AYM2aNdDr9e2KrPj07t0bX3/9Nbp06eKqYRKu
g3JWCfdAp9Phtddew/79+7Fw4UL84x//QGhoaLuGB8ePH0dqaqrshgf8aIowauVMr1ihU4EresI7
E2tbyWKRWGHUW6kFgxTC9AU1RYZtiRDy82L5DT28vLzg5eWlimvdUaxFUh2B3DQZqR0GW1IKhCkm
YpHUxsZG7Nq1C/v27cMTTzyBkydPwtvb26Hn7GyGDh2KsrIyVFRUoHv37ti3bx/S09PNjqmurka3
bt2g0+lQWFgIk8lEQvUOgyKrTuSFF17AkSNH4O3tjT59+mDXrl0ICgpqd5w12w6iPaWlpejVq5cs
axVrDQ+io6PNbLYiIyPNRKyzvGLdzanA3iidLR2lXFUI424enOw9amxshF5/u5uR8DMutsPgyMWZ
o1G7BVVH2qOy75GHhwd8fX3bzQvNzc3YvXs3PvjgAzz++ONISkpymc2UM8jOzubugfPmzcNLL72E
7du3A7jdHnXbtm14++234enpCX9/f2zatAn333+/wqMmnARZV7maY8eO4cEHH4Rer8fy5csBACkp
KWbHyLHtIJwDi1yUlZVxPrFFRUW4cOEC9PrfGh6wtAKxhge2esUCv91cWf6mOwggZ9pPSS0YbC3u
sgW+XZMaBZCtiL1H1vJi1W61xRepWmy2ILY4a2tra+fNm5+fj5aWFsTGxiIiIgIfffQRdu3ahT/9
6U9YuHAhAgICFD4TgnAolAbgahITE7l/jxgxAgcPHmx3jFzbDsLxsOjfwIEDMXDgQO5xsYYHBw8e
lGx4wPprS3nF8rdeGZ6enlzEREs3WD6usp/qaHGXrfZPQvcFNRS22YtQpFpLMbFkaaYWqy1+By0t
29LxI9jsffLw8OB2WNi1LikpwZEjR1BaWora2lp07doVI0eORENDA44ePWpm9UcQ7gqJVRexc+dO
zJ49u93jcmw7CNfCqrFZkdYf//hHAOIND7Kzs/Hzzz/DYDAgIiKiXcMDg8GAPXv24MqVK/if//kf
LneTCSvmY6m0r6Yt8G3ClMzflGv/JKeamwlvOZ6iWkBO5bgt2Gu15YjKeaFIdYf3iJ82I1xIsO9/
aGgompqakJSUhCeffBKXL19GcXExSkpKsG/fPhQXF+OVV17BY489puDZEIRzIbFqJ4mJibh06VK7
x1evXo0pU6YAAF5//XV4e3uLTiZanmzvNGxpeJCTk4OTJ0+ipqYGgwYNwvDhw5GVlSXZ8IAfsbJ0
s1eyal6YG6imIiMh1uyfmI0WK+xiv+Ph4QGDwQAAqinusgUlmi3YYrXVkQYT7i5S/fz82l0/o9GI
zMxMbN26FePGjUN2djZXUNSrVy8MHTpUiaFzyKmzSE5ORnZ2Nvz9/ZGWlobBgwcrMFLCXSCxaifH
jh2z+HxaWhqysrJw/Phx0ecjIyNRWVnJ/VxZWYkePXo4dIyE89Hrbzc8CAgIwOHDh5GVlYUZM2Zg
6dKl6NKli1nDg9LSUjQ3N9vU8EApr1ixrXGtbrsC4EQSE08sosWaRzjDw9QV8N0K1NIRzN7KeZ1O
x70P7iJSmZetTte+yxlw+33Mzs7GG2+8gZEjRyIzMxOhoaEKjro9BoMBixYtMquzmDp1qlnqWlZW
FsrLy1FWVoZTp05hwYIFKCgoUHDUhNYhsepEcnJysH79euTl5UnmE8mx7XA0Bw4cwMqVK1FSUoLT
p09jyJAhosdFRUWhc+fO3M2msLDQqeNyB/z8/BAWFobi4mKEh4dzj3e04QH7LygoSNIrlhUDOdIr
Vsx+yh3EgrVuU87q3OUs1GypJYU1qy3+55mJVnaOatllsAW5IvX48ePYuHEjhgwZgoMHD5rNH2pC
Tp1FZmYm5s6dC+B2vUZdXR2qq6sRFhamxJAJN4DEqhNZvHgxWlpauEKr3/3ud3jrrbdw8eJFPP30
0zh69Cg8PT2RmpqKhx9+mLPtcHZx1aBBgzjzaEvodDrk5uaSn50N+Pv7Y8WKFVaP0+l0uOuuuzBm
zBiMGTOGe5w1PDh79iyKi4tx5MgRrF+/Hjdu3ICvry8XiWUiVqrhQUe9Yt3RJN6eblO2FHe5suBI
iyLVGsLtfn7RoqVdBrVabQkXfGIi1WQyIS8vD+vXr0dcXBw+/PBD1e+syamzEDumqqqKxCrRYUis
OpGysjLRx7t3746jR49yP0+YMAETJkxw1bAQGxsr+1gr1maEg9HpdAgODsaoUaMwatQo7nFhw4NP
PvkEW7dutdjwwMfHh/tdseig0I6I3VyZt6PWRaozt8YdVdxla3RQS3nDcpGTk2rJpcDSAs0ZHaWs
IVek5ufnY+3atYiKisKuXbu4SKXascU3uSO/RxBikFglJNHpdHjooYfg4eGBpKQkPP3000oP6Y5F
p9OhU6dOGD58OIYPH849Lmx4cPLkSezYscNiwwO+iK2ursaVK1fQq1cvs8r4hoYGyXQCtd90lI46
yinuEm53W0vfcEeRyvey7WiaiS1WW/bYmtlyTszhQ9i5jY3r9OnTSElJQVhYGLZv344+ffrY9Zqu
Rk6dhfCYqqoqREZGumyMhPtBYtVNkeNSYI2TJ08iIiICV65cQWJiImJjYzF69GhHD5WwA1YglJCQ
gISEBO5xYcODM2fOYO/evVzDg65du+LWrVs4ffo05s+fj5deesks+iP0ihUrgBHrNa8kahd0cqKD
YsVd7BhPT0/RPFut4QiRag1H2prJud5yROq3336LNWvWoHPnznjjjTcQExOjyfdRTp3F1KlTkZqa
ilmzZqGgoADBwcGUAkDYBYlVN8WaS4EcIiIiAAChoaF49NFHUVhYSGJVI0g1PPjqq6+wdu1aHD9+
HOPHj8fSpUtRWlqKyZMny2p4ILzRK2UMz0fYbcoZPeGdiVjVPBM/BoMBXl5eXMSbRWItdUlT67m7
QqTKoaNWW2I530zsGgwG+Pr6iorUs2fPYs2aNfD09ERKSgruuece1b5HcpCqs+C3R504cSKysrLQ
t29fBAQEYNeuXQqPmtA61G71DmbcuHHYsGED7rvvvnbPNTQ0wGAwoFOnTrh16xbGjx+PFStWYPz4
8U4bj1yXAjkef0R7zp8/j9GjR2Pp0qV4+umnERgYyD0n1vCgqKjIYsMDKREr1f/ckVXcYpZaWmu3
KYZQ0Emdk9h1VnrRIIXcc1IrYjnf7N/Ab+L38uXL+P777xEbG4uoqCiUl5cjJSUFbW1tWLFiBeLj
4zV13gShEKJfEhKrdyCHDh1CcnIyampqEBQUhMGDByM7O9vMpeCnn37iOje1tbXhP//zP/HSSy85
dVwlJSXQ6/VISkriLFyEGAwGxMTEmHn8paenU3tamRgMBpuLjFjDg6KiIu6/8vJytLS0oFu3bmbu
BNYaHtgrYsUstYTRLK3BhJClbWRb/5bwWivRYELrIlUMYTGYp6cn9xn/6quvsHr1apSVlaGmpgZe
Xl4YMWIERo4ciQEDBiAuLo7aohKEdUisEtpg3LhxkmL1yy+/xKpVq5CTkwMASElJAQAsX77cpWMk
bovY6upqs0isrQ0PxISslBUREz8A3MKtwJXCW7hosHa97cmL5YtUsa1xLWLJVotRUVGBtWvXorq6
Gs8//zy6dOmCkpISlJSUoLi4GMXFxejatSs+//xzhc6CIDSB6GRBOauEppDj8Ue4Br1ej4iICKc2
PGAWW2xRzQpm2PNq8NO0Fb5JPACXRIc7WtxlS+cuoUjVehMJwLxoTyrPtqqqCuvWrUNFRQX+8pe/
YOzYsdwxwhQrJa0Aa2trMXPmTPzyyy+IiorC/v37ERwc3O44agZDqBESq4RLsdelQOs3vzsBRzQ8
6NmzJw4ePIg9e/bgX//6F0JCQuDh4WHRK1bN7VCB9g0X1BAdtrclKmtTy57z8/NzO5EqVbR36dIl
rF+/HsXFxXj55ZeRmJho9byVvC4pKSlITEzEsmXLsHbtWqSkpHA7U3yoGQyhRkisEi7FXpcCOR5/
hDqR0/CgsLAQf/3rX/HVV19h8ODBiImJwerVq602PJBrs6VExbwaRao1rLVE5XeRMplM3LkwgaeW
4i5bMRqNaGpqsihSL1++jM2bN+Obb77B8uXLsW3bNk1E9zMzM5GXlwcAmDt3LsaOHSsqVgFqBkOo
DxKrhCqRmizlePwR2oI1PPj000+xfv16TJs2De+99x769+9vc8MDvmhQ2iuWidSmpibo9Xq38EgF
fhN0rDsTS2EQRmId2bnL2cgRqVevXsWWLVvw5Zdf4vnnn8fmzZs1IVIZ1dXVnNdpWFgYqqurRY+j
ZjCEGqECK0I1yHEpAIDs7GzOumrevHlOdykAKN/LFXzyySfo378/evXqZfE4fsMDllJQVFTENTyI
iooyE7GsO5eUV6yjbZ/Y+Jqbm+Hh4cFVjWsZexwLXFncZSv8bmfe3t7w9vZuJ0Dr6uqwdetW5OXl
YenSpZg+fbrD2vY6Gqk0q9dffx1z587FtWvXuMe6dOmC2tradsf++uuvZs1gtm7dSv7ahCshNwCC
6CjLli3DXXfdxeV7Xbt2TXQLrXfv3vj6668p30sBWOHSTz/9xBV3FRUV4fz58zCZTKIND/jCyF6v
WBKptv9tKb9YZ+chC1vy+vj4tBOpN27cwFtvvYV//etfWLx4MWbPnq1akSqH2NhY5ObmIjw8HL/+
+ivGjRuHkpISi7+zatUqBAYG4vnnn3fRKAmCxCpBdJjY2Fjk5eUhLCwMly5dwtixY0Un+t69e+Or
r75C165dFRglIYYjGh5Y84plos7T05NEqgNeW2rhYG8eshyRWl9fj7///e/IzMzEggUL8Pjjj5sV
n2mVZcuWoWvXrnjxxReRkpKCurq6dgtuJZrBEIQAEqsE0VFCQkK4LTSTyYQuXbqYbakxoqOjERQU
RPleGoHf8IClFIg1PIiLi0O/fv3MGh7U1NTgu+++w3333ceJViaulN7e7ihqb7rQ0c5dLIe2paVF
UqQ2NjZix44dyMjIwFNPPYUnnngC3t7eCp2p46mtrcWf/vQnnD9/3iyVSelmMAQhgMQqQViC8r0I
hqWGB35+fjAYDPj2228xefJkbNiwAYGBgRYbHvC3t8V6zCtdqKN2kWoNSykcrPhLr9fD29sbzc3N
0Ov1XLvhpqYmvP/++/jwww8xZ84cPPPMM5zbBEEQLofEKkF0FMr3Ii5cuIB169Zh9+7dGDt2LP7j
P/4DFRUVNjU8kCruUsorVusiVQqTyYTm5mY0NzfD09PTrC3q4cOHsWjRIoSGhqJHjx746aef8Pvf
/x4LFixAQkICQkJClB4+QdzJkFgliI6itnyvnJwczhHhqaeewosvvtjumOTkZGRnZ8Pf3x9paWkY
PHiww8dxp2AymfC73/0OI0eOxJ///Gd079693fOs4UFRURHXXlOs4UFsbCy6du3aTsSK5cU6yyvW
3UVqS0sLlz8sLIpqbW3F3r17kZGRgXvuuQehoaE4d+4c954FBARg8uTJ2LFjh0JnQRB3NCRWCaKj
qCnfy2AwICYmBp988gkiIyMxbNgwpKenIy4ujjsmKysLqampyMrKwqlTp7BkyRIUFBQ4fCx3EgaD
weZqcH7DA+ZOUFxcjKtXr8LHxwf9+vVr1/DAklesJRErx2bLnUUqc2KQEqltbW3IyMjA9u3bMWnS
JCxZsgRBQUHt/s6FCxdw9epVxMfHu/IUOA4cOICVK1eipKQEp0+fxpAhQ0SPk7NgJQgNQmKVINyB
L7/8EqtWrUJOTg4AcBHe5cuXc8fMnz8f48aNw8yZMwGYuxkQymMymcwaHjARyxoe9OnTxywSK2x4
YKtXrE6n41qIMjN/tXfRkoMckWowGPDPf/4T27ZtQ2JiIp577jlVb/WXlJRAr9cjKSkJGzduFBWr
chasBKFRRCclbfurEMQdyIULF9CzZ0/u5x49euDUqVNWj6mqqiKxqhJ0Oh38/f2RkJCAhIQE7nFh
w4MzZ85g7969Fhse8COjYl2kmIgFAA8PD7P8TTV1kbIFoadtQEBAO5FqNBpx9OhRbNmyBaNHj8aR
I0dw1113KTRi+cTGxlo9prCwEH379kVUVBQAYNasWTh8+DCJVcJtIbFKEBpDrrgQ7ppoUZTcaeh0
Ovj4+GDgwIEYOHAg97hYw4ODBw9KNjyIiopCTk4Otm7dip07dyIiIsLMWqu1tRXNzc2aaIXKR65I
PXbsGDZt2oRhw4bh0KFDbrdIk7NgJQh3gsQqQWiMyMhIVFZWcj9XVlaiR48eFo+pqqpCZGSky8ZI
OBadTgcvLy/ExMQgJiaGy40WNjz44YcfsH37dnz99dcIDQ3FiBEjsGfPHsTFxXEND3x8fCRttlg+
q9q8Yk0mE1pbW9HU1AQPDw/4+/u3a7xgNBqRm5uLDRs2YODAgdi3b1+7Qji1IGWTt3r1akyZMsXq
76txIUEQzoTEKkFojKFDh6KsrAwVFRXo3r079u3bh/T0dLNjpk6ditTUVMyaNQsFBQUIDg52u+gS
AU5QRkdH46effsK+ffsAALt378bkyZNx8eJFzis2Ly9PdsMDMRGrhFcsE6nNzc1c6oRQpJpMJnzx
xRdYt24d+vTpg/fffx933323w8fiSI4dO2bX78tZsBKEO0FilSA0hqenJ1JTU/Hwww/DYDBg3rx5
iIuLw/bt2wEASUlJmDhxIrKystC3b18EBARg165dLh2jtUrl3NxcPPLII4iOjgYATJ8+Ha+88opL
x+hutLa2YuXKlZg6dSonOnv16oVevXrhD3/4A3ecsOFBWloa1/AgODiYs9mKi4tDTEwMAgICLHrF
tra2OtwrVihS/fz8REXqqVOnkJKSgsjISLz77rvc58ldkCqAlrNgJQh3gtwACIJwKHIqlXNzc7Fp
0yZkZmYqOFKCj8lkwtWrV7mc2KKiIpsbHojZbAEQzYsVE7FCkerr69su9cBkMuGbb75BSkoKQkJC
8Nprr6F///6uu1BO5tChQ0hOTkZNTQ2CgoIwePBgZGdnm9nkAUB2dja3IJw3bx61RSXcBbKuIgjC
+cix1srNzcXGjRvxv//7v4qMkZCPsOEBE7FyGh4A8rxi9Xo9J1SZSBVaa5lMJnz//fdYs2YNfH19
sWLFCsTFxVH+JkG4F2RdRRCE85FTqazT6ZCfn4/4+HhERkZiw4YNGDBggKuHSshAp9MhODgYo0aN
wqhRo7jHhQ0PPvnkE2zduhW1tbXw9va22vCAORxcuXIFAQEB3GsZjUY0NTUhJSUFfn5+iIuLg7+/
Pz744APo9Xr89a9/xb333ksilSDuIEisEgThUOSIiCFDhqCyshL+/v7Izs7GtGnTUFpa6oLREY5C
p9OhU6dOGD58OIYPH849Lmx4cPLkSezYscOs4UH//v1hMBhw4MABhIaGIiMjg4ukspzYgQMH4tSp
U3jrrbfw448/oqGhAX369MHf/vY3DBgwAAMGDMCYMWMQHh6u4FUgCMIVkFglCMKhyKlU7tSpE/fv
CRMmYOHChaitrUWXLl1cNk7COVhqeNDc3IwPPvgA69evR11dHR544AGcP38ekydPNmt4EBgYiM8+
+wy1tbXYtGkT7r//fjQ1NaG0tJRLRdi/fz9CQ0MVE6ty26JGRUWhc+fO8PDwgJeXFwoLC108UoLQ
PiRWCYJwKHIqlaurq9GtWzfodDoUFhbCZDK5TKg++eSTOHr0KLp164bvv/9e9Jjk5GRkZ2fD398f
aWlpGDx4sEvG5s7odDrMnTsX3377LVasWIGZM2fCw8NDtOFBRkYG3nzzTYwePZqL1Pv5+SE+Ph7x
8fEKn8ltBg0ahEOHDiEpKcnicTqdDrm5ubQQIwg7ILFKEIRDkWOtlZGRgbfffhuenp7w9/fHRx99
5LLxPfHEE1i8eDHmzJkj+nxWVhbKy8tRVlaGU6dOYcGCBSgoKHDZ+NyZlStXol+/fmY2VGIND7Rg
YyanLSrDSiEzQRBWIDcAgiDuOCoqKjBlyhTRyOr8+fMxbtw4zJw5E8BtUZKXl0dNFQhRxo0bh40b
N0qmAURHRyMoKAgeHh5ISkrC008/7eIREoSmIDcAgiAIa4i5GVRVVZFYvQOxty0qAJw8eRIRERG4
cuUKEhMTERsbi9GjRzt6qATh1pBYJQiCECDccSKbpDsTe9uiAkBERAQAIDQ0FI8++igKCwtJrBKE
jTi+mTNBEISGEboZVFVVITIyUsEREWpHKp2uoaEBN2/eBADcunULH3/8MQYNGuTKoRGEW0BilSAI
gsfUqVOxe/duAEBBQQGCg4MpBYBox6FDh9CzZ08UFBRg0qRJmDBhAgDg4sWLmDRpEgDg0qVLGD16
NBISEjBixAhMnjwZ48ePV3LYBKFJqMCKIIg7itmzZyMvLw81NTUICwvDqlWr0NraCgCcDdGiRYuQ
k5ODgIAA7Nq1S7J4xhlYs9bKzc3FI488gujoaADA9OnTNVE9TxAEIQPRnCsSqwRBECrixIkTCAwM
xJw5cyTF6qZNm5CZmanA6AiCIJyKqFilNACCIAgVMXr0aISEhFg8hnw7CYK4kyCxShAEoSF0Oh3y
8/MRHx+PiRMnoqioSOkhEQRBOBUSqwRBEBpiyJAhqKysxL///W8sXrwY06ZNU3pIquaFF15AXFwc
4uPj8cc//hHXr18XPS4nJwexsbHo168f1q5d6+JREgRhCRKrBEEQGqJTp07w9/cHAEyYMAGtra2o
ra1VeFTqZfz48Th79iz+/e9/o3///lizZk27YwwGA1dUV1RUhPT0dBQXFyswWoIgxCCxShAEoSGq
q6u5nNXCwkKYTCZ06dJF4VGpl8TEROj1t291I0aMQFVVVbtjCgsL0bdvX0RFRcHLywuzZs3C4cOH
XT1UgiAkILFKEAShImbPno2RI0fixx9/RM+ePbFz505s374d27dvBwBkZGRg0KBBSEhIwNKlS/HR
Rx+5fIyVlZUYN24c7rnnHgwcOBBvvvmm6HHJycno168f4uPjcebMGRePsj07d4Ydjv4AAAJKSURB
VO7ExIkT2z0u1mL3woULrhwaQRAWoHarBEEQKiI9Pd3i888++yyeffZZF41GHC8vL2zevBkJCQmo
r6/Hfffdh8TERMTFxXHHZGVloby8HGVlZTh16hQWLFiAgoICp4wnMTERly5davf46tWrMWXKFADA
66+/Dm9vbzz22GPtjqN2ugShbkisEgRBEDYRHh6O8PBwAEBgYCDi4uJw8eJFM7GamZmJuXPnAri9
/V5XV4fq6mqndAM7duyYxefT0tKQlZWF48ePiz4vbLFbWVmJHj16OHSMBEF0HEoDIAiCIDpMRUUF
zpw5gxEjRpg9Lra1LpYv6mxycnKwfv16HD58GL6+vqLHDB06FGVlZaioqEBLSwv27duHqVOnunik
BEFIQWKVIAiC6BD19fWYMWMGtmzZgsDAwHbPC5sXKLHdvnjxYtTX1yMxMRGDBw/GwoULAQAXL17E
pEmTAACenp5ITU3Fww8/jAEDBmDmzJlmUWKCIJSF2q0SBEEQNtPa2orJkydjwoQJWLp0abvn58+f
j7Fjx2LWrFkAgNjYWOTl5TklDYAgCLeB2q0SBEEQ9mMymTBv3jwMGDBAVKgCwNSpU7F7924AQEFB
AYKDg0moEgTRIaxFVgmCIAjCDJ1O9x8APgfwHX7bgXsZQC8AMJlM2//vuFQAfwBwC8ATJpPpG9eP
liAIrUNilSAIgiAIglAtlAZAEARBEARBqBYSqwRBEARBEIRqIbFKEARBEARBqBYSqwRBEARBEIRq
IbFKEARBEARBqJb/D6nRM2cdX17QAAAAAElFTkSuQmCC
)

3维 `RBF` 插值：

In [33]:

```py
zz = Rbf(x, y, z)

```

In [34]:

```py
xx, yy = np.mgrid[-np.pi/2:np.pi/2:50j, -np.pi/2:np.pi/2:50j]
fig = plt.figure(figsize=(12,6))
ax = fig.gca(projection="3d")
ax.plot_surface(xx,yy,zz(xx,yy),rstride=1, cstride=1, cmap=plt.cm.jet)

```

Out[34]:

```py
<mpl_toolkits.mplot3d.art3d.Poly3DCollection at 0x176e5c50>
```

![](data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAqsAAAFdCAYAAAAkOCRoAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz
AAALEgAACxIB0t1+/AAAIABJREFUeJzsnXecFPX5x9/br3NU6V0FFCsGFWMBG7boz4g1NjRq7C0x
+kuixm5CfrHGkmg0SjRorFhiQYko0SiIoogKSJFycMfVvW3z++OZ797cMru3uze7Nwff9+vF67jb
2ZnvzM7OfOb5fp7n8RiGgUaj0Wg0Go1G40a8XT0AjUaj0Wg0Go0mHVqsajQajUaj0WhcixarGo1G
o9FoNBrXosWqRqPRaDQajca1aLGq0Wg0Go1Go3EtWqxqNBqNRqPRaFyLv4PXdV0rjUaj0Wg0Gk0x
8Nj9UUdWNRqNRqPRaDSuRYtVjUaj0Wg0Go1r0WJVo9FoNBqNRuNatFjVaDQajUaj0bgWLVY1Go1G
o9FoNK5Fi1WNRqPRaDQajWvRYlWj0Wg0Go1G41q0WNVoNBqNRqPRuBYtVjUajUaj0Wg0rkWLVY1G
o9FoNBqNa9FiVaPRaDQajUbjWrRY1Wg0Go1Go9G4Fi1WNRqNRqPRaDSuRYtVjUaj0Wg0Go1r0WJV
o9FoNBqNRuNatFjVaDQajUaj0bgWLVY1Go1Go9FoNK5Fi1WNRqPRaDQajWvRYlWj0Wg0Go1G41q0
WNVoNBqNRqPRuBZ/Vw9Ao9Fs/RiGQSKRoLW1FZ/Ph9frxev14vF4kv80Go1Go7HDYxhGptczvqjR
aDTpMAwDwzCIx+PE43EMwyASiZBIJLYQp4lEgkAggM/n02JWo9Fotl1sL/Y6sqrRaBzFMAxisRjx
eJympiZCoRB+vx+Px5MUoanLt7a24vF4kqI2VZyq9ykxq9alxaxGo9Fs/WixqtFoOo2a5o/FYiQS
CYCk+FRiMpFIEI1G2wlWq9D0eDz4fD7bdQPE43FisVhaMasislrMajQazdaFFqsajSYvlEBV0/zA
FuJQRVnD4TDRaDT5dyVolaBUQlYJUfV3tU7rT7txqO2kszWlE7NW0azRaDQad6I9qxqNJmvsfKjA
FtHLWCxGJBIhHA7j9XopKSkhGAy2i4wqsatsAEo4qr9Dm5hN9zOXMav/22G1GFi3ocWsRqPRFBXb
i60WqxqNpkOUQLVGL1MFaiKRIBKJ0NraSiKRIBQKEY1GKSsrIxAIABCJRGyn8VtaWggEAvj9/uT2
1Dqtotb6EworZg3DIBqNEgqF2nlmrclfuWxHo9FoNB2iE6w0Gk32pPOhpk7zRyIRIpEIsViMQCBA
WVlZMqGqoaEhbTQzE2r9dh5WtV31zypg4/F48nc1znRC1movsBOchmEQDoeTNgVlVbAbqxazGo1G
Uzi0WNVoNEms0/yxWAywF6jRaDQpUn0+H6FQiIqKiqIJM+t40iVlpYpZZVvIVszabctuO4AWsxqN
RlNAtFjVaLZxsvWhxuNxWltbiUQieDwegsEgPXr02KIUlRtwSswCyeiqXWQ2m+QvIBn11WJWo9Fo
ckeLVY1mG0UJtHA4jGEY7WqhKlJ9qMFgkIqKimRGfUeoRKpsx1MsshGziUSClpYWfD7fFhaDdJHZ
VCHrpJi1CtnUbWk0Gs3WjBarGs02hJ0PVQmkYDCYXCYajdLa2pr0oZaWlhIIBDotjNKJV7cJLqto
V8lhVtL5ZVX5rdQSXOmisrmKWUVrayvBYLCdYM5UZ1aj0Wi6M1qsajRbOdn6UGOxWHKaX/lQy8vL
OzXNn0tktTthFYl22IlZay3ZzorZRCLRLiJsFbOp1Ra0mNVoNN0dLVY1mq2QXHyoqjWqKtNUVVWV
Ngtfkx2FFrPW7Vh/2m0HMovZVGuBFrMajcZtaLGq0WxFWAWqtdyUnQ81EokQj8fx+Xz4/f6iZvNv
62QjZlNry1oTwACam5ttk7HStbJNtx3ouJWtFrMajaYr0WJVo+nmZFsPVZWbikaj+P1+SkpKCAQC
tLa2Eo/HCyI6srUBbK12gXzxeDwZo9uNjY2UlJS0E7MqKptLwwSnxWxqBzAtZjUajRNosarRdEPs
fKjAFgI11YcaDAYpKytrF9HTQrF7kqmslV1kthhiVj0wqWQ9tZ10pbm0mNVoNNmgxapG041Q3sNM
PtREIpEUqIZhEAwGu9SHqoVw8ckUmU3XyjYbMWvX/cv6U61LbTuXyKzP57O1GGgxq9FotFjVaFyO
ipCmClRrdFS1PVVT+iqCqmqnZqKQkdXUdXcn4WGNUHencXdEpvqy0LlWtkropm6rszaDTJUMtqbP
RqPR2KPFqkbjQlJ9qE1NTQSDwWRtTbWMmuZXPtRQKNRume6EjsC6A6sAzLX7l6o40NTU1GFpLrUt
60+7bQFJIZuLmLUmmmk0mu6NFqsajUvIxofq8XiIxWLJKKrX6yUUCm3hQ82FQkdWU6NtdoJD+2a7
D5nEbCQSSXpWO2pl65SYVQ9t6c4fLWY1mu6PFqsaTReTjQ8VRAiEw2ESiQShUIjKykr8/u7xFU5t
25raMlSJDk33x2pRyRSZTWcxSBWz6RomqG1lEptWMRuNRtslfxmGkbGSQaYENo1GU1y6x51Oo9nK
yKYeqvKhqnJTPp8vax9qLhQqqqn2UZXMCgQChEKhdsXp850+1nRfrELUDqe6f1m3pf6vRKl1W9b1
p44jUyUDLWY1muKhxapGUySsUSQlzlJvrioKpESqanuqbpJ2ferdhtWmoPatqqoKr9ebtDekCpVM
08epEbdsRIqma3DioadQYlY9FFptKJnOGWvVBDsxq96vxaxGU3i0WNVoCkgubU9VuSmPx0MwGKRH
jx7JG7b1vU7jRGTVOs1vLZelpl878geqv+c6fZxOpHTUplRTOAp9nPMVs+o7FIvF0j705NP9S61b
i1mNpnBosarRFIB0PlS7tqfKxxkMBqmoqEgmgVhxYwKSqs3Z2tpKLBYjEAhsYVNwUmRnI1KcqB2q
6d6kO09UpD8QCHTYyjZTwwTrNtT/7chVzKZrmqDRaLRY1WgcI1sfaqrAKy0tJRAIZLwx2WXVO0Uu
Qljto7UrVigUoqKiostvrB5PboXws6kdqt7jpiiY9eFHkzuZzhMofvcvVaIuHA5TWlq6xVg7qjOr
0WwLaLGq0XQCdQNTHlNV4zTVh2on8MrLy3MqN9WVkdXUrlihUKhLu2LlivoscimEr3zF4XBY+2W3
AlTCVEfk+tDjpJhNTf5S21Lnot1YtZjVbAtosarR5IidD1UV5y8pKUkuF4/Hk9P8QKcEXiFvOuki
q9lM8+e7bju6Uoxbb+zWz6exsZGysjJgy4ib9stue2Tz0AP2Ylb9H9qL2dSZl3wis9YKG9bl1Xa0
mNV0d7RY1WiyJJMP1TplrKKsqu1pOh9qLhTDs6rWX8hp/o4SrNyK9stmR7bRy62VfCP46hxRpds6
iuJbt5WtmLWzj1j9slrMatyMFqsaTQay9aHGYjHi8TibN2/G7/dTUlLSoQ/VLagxhsNhR6LAqbgt
MSwX1ENCR59jIfyyWjQ4SzafY6FJF8FXD4ilpaW2Ytb6u9NiVnXMszs+1gcqn8+nxaymy9BiVaNJ
Idt6qNYIpBKv1nJTTlKIyKphGO1sCvF4nPLyckebDuibWf7RtlSBkioQ4vG49stuJdiVtMtUvq0r
xGw0Gm1ncwK2iMqmzhbo81LjFFqsajRkXw81NdFI1RP1eDzU1dUVbArUKbGqosDKquD3+wmFQsRi
McrKyrbpKdyuIluBYo3MAsmatnbJX3alljTuJpvPKJ9zJd/GGtafVkFq3RZkF5m1ClktZjX5oMWq
ZpvGOoWfrh6qNQKpfKipiUbqvW6YarTDLtnLGgVubm4uyHazFdnF8OR2V1L9ssoPa038stoL8s1O
dwI3f4Zu/W46STbe6mwTBa0/03X/sv602xZ0LGYzJX9t7Z+XJnu0WNVsc6TzoaZO86sM/2g0moxA
qtJUqRT6opqPmLMT2d2p6YAmO7IRKJmy0532y2qBkTvFEtL5iln1MK8SwHKNzKbbFpAUslrMajKh
xapmmyAbHyq072vv9XoJhUJZT48rwVeIC2i2YtJOZLst2cst49hWUMkxduTqgdT1Zbdu0olZq+3J
zmZgjeJna0nJRsyq61m6a58SsUrQWreZad2a7ocWq5qtFqsPVflMS0tLbX2o1ranoVCIyspK/P7c
vh5dGZ207qPH40laFbL1oBZq7Dpi627y8UBmmjZW4sWNflk32wDcPDag3UNLPlH8bC0p0F7EZjom
VjEbiUQIh8OUlJRs8f50YtbNx1uzJVqsarY67HyoIFFTq+9PJRnlW/C+mNiJvlym+TWafMhl2tg6
c2G12BTLL6vpejJF8cG5VrZqW6nRWWuAwSpmo9HoFuPIVMlAn5vuQ4tVzVZBRz5U64VRidRCFLwv
dBRRCQKnp/mLEVm1NkywuzHoCGz3I1XMxmIxgsFgUjR05JcFbM+Fba2OZ3eIrDpRKaQjSwrk18o2
3bY68staZwrs3q/FrHvQYlXTbcnWh6rEXSKRoLm5mWAwWJB6qIUUXOpCvXnz5py9tF2JOh6NjY1J
ce31em1vQgAtLS1pvZGa7kFq9Mspv2zqFG6u54XbBeG2TiY7CnTcXAPkOpPNw0+2yV9azLoHLVY1
3QqrD7WjeqhWH2owGARI1kQtBE6L1dTWrQAVFRUEAgHHtqFweuxWDy3IDaisrAyPx5NMXlOoG09L
Swt+v18n+Wwj5OOXjcfjHZZZ6o4JNk5FLguFG4R+pnNF+VZLSkpyfvjprJhV56TdeNPVmNViNne0
WNV0C9SFx5oZmjoFpKJ1ra2tSR9qaWlpUtypGqOFHmdn36+sCqnT/IVsOuAE6Ty09fX1ycQHu5ue
VXDaCfFMST7aF7n1kotfNl1meqoIUb51fV7khhvEakdYzxW3dP9S5ySQDLCowIlVzK5evZp4PM6Y
MWOcPShbEVqsalyLuojEYrGM9VCtUTzlQy0vLy+6sOvMxVztQ6aSWYW8WeQbWU09/vl6aDNtPxvR
Uqg6otpL615yPS+graanVcy6wS/bHcSgm8nm+GUbyU8Vs6ndv/IVs4lEImmLSRWzr7/+OoFAQIvV
DGixqnEV1gzOjnyoqR2ZqqqqMmaipovsOUWuwsauZFamfSi0cMp17Epcw5YdsezWXcjjnqsvMpv2
k8pb6zbcOCY3Yj0vVNS/tLQ0+Xsx/bLdHbeLaSfGl68tJdtWtkqsqm1Zf27atImddtqpU+Pf2tFi
VdPl5OpDVR7OXEs1FVrsZbP+TFaFrrwZZLNtu7GXl5d3WO6rq/crnxuQNfoWDoe3iMB1deKXW4WD
20WNopB+2XzErNuPmx6fM61soS3C+vnnn/PVV18xfPhw1q9fzwEHHOD4mM8++2xefvll+vXrx6JF
i2yXueSSS3jllVcoKyvj0UcfZffdd3d8HE6gxaqmy7D6UJubmwkEAgQCAVsfqp2HM9eLUzGmdNOt
39oZy+fzEQwGc7YqdFVkVXXEKkS5r64m0w3IMIxk9QgVGUmNpljfrxO/3EuuYsZJv2x391F3h0i+
G8R0R+eMqnSibADr169n9uzZfPfddyxbtoyHHnqI4cOHJ/+NGDGC3XffnUMPPTTvMZ111llcfPHF
nH766bavz549m6+//pqlS5cyf/58LrjgAj744IO8t1dItFjVFJV0PlTr/+18qLl2ZLKj2JFV6zS/
YUirwo6sCrms30lSL/ROjj2XcbvhpqOw3nw6292puwsWTXvy9VGnE7Pq3HHzQ44bx2TF7eMDieKr
GsRTp05l6tSpAEybNo0HH3yQhoYGli9fzrJly1i+fDkLFizolFj94Q9/yPLly9O+/sILL3DGGWcA
MHHiROrq6li3bh3bbbdd3tssFFqsagqOdZo/FosBW/pQPR4P8XiclpaWdn2oOyPuUimGWLV6abtD
ZywrVptFNBot6tjdfmzscEqwuCHBZ2un2NHBXH3UQHIGqbNJgU7jpgfIdHT3MTY0NDBw4EB8Ph/j
xo0r2phWr17NkCFDkr8PHjyYVatWabGq2XbI1oeqEh/UhVplwRdKIBXipqX2U7VuVclSTk+VF0ps
q4cI9a+7NBxwO/kkfqUm+KTr1tMdpmbdhlvEjJ1fViV/qe+49dzINZFnW3zQ6c5iVX2Xu+p6m3ot
cetx1GJV4yhWgWqd2k/1oSofpPKh+v3+ZOH4QuH0l1BlxKtoiJriqaqqcnQ7CifFqnpIUDVRvV4v
gUCAyspKR9ZvpRhe4e5GPgk+qbVlm5ubtxArXR2V7Q6iwe04cW446ZftDp9pdx9jV41/0KBBrFy5
Mvn7qlWrGDRoUNHHkQ1arGo6TTofaupN05pklFpLtKWlpV3bzULghGiyy4hXkeBoNEo4HHZotM5j
95CgktWUaC0Gbr+puIFMFgPVNjgUCm1hMdBll+xx88OSddYpG5z2y24N9hM3f76QeXzKctUVHHPM
Mdxzzz2cdNJJfPDBB1RXV7vSAgBarGryJBsfKtjXEq2srEyazBXFiL7luw27hC+7af5i+DrzGb+1
JqrH47FNVit08lY261bLdcebZbHJxWKQTdmlbSHxa2vdr1Q6Ojegred9OvuJ9VxILbnktuOYq9jv
CqzHNZWamhp69+5dkO2efPLJvPPOO9TU1DBkyBBuuOGGZGvY8847jyOOOILZs2czevRoysvLeeSR
RwoyDifQYlWTNbn6UJWHM5tEnWIUYM9VkNkVvu/Kov2QfQQh9TPItSZtIdGCtLDkMo28rUTe3Ewx
vw/W8yKbLk7Wfy0tLa72y7r5vMz0GW/cuJE+ffoUZLszZ87scJl77rmnINt2Gi1WNR2Siw9VCaRc
63EWK7LakdXATuRlU/herb/Q1QYyrT/bCHA+69ZsPWSaRs418paa+OVW9ANSdtg96ESjUeLxOCUl
JVn5ZdM95BQqat8dPttM19aamhr69u1bxNF0T7RY1dhi9aE2Nzfj9/uThfitFwarOFJTzJnabqaj
K20AnRXaHa3fKdKJ7dSaqNm0ni0mqcelu033b0siPtvIWyax0tLS4lhyz7aA278L1vE57Zd1IjHQ
7cdPkSmyqsVqx2ixqkli50MF2kVU1O9WH6oTU8xdIVatNVGh4/72bkCNP1OiVz6fQbEiq+qYA52+
SRUDt46rq+goKtvU1JRz4pe2GLibXMRgrn7ZTB3htqbzI9MxrKmpcW0GvpvQYlWTvGCk86F6PPbF
7p3saV9MG4DyocbjcUe9nMWyATQ3N7dr29odWp9GIpGk5021G0y9SRmGkdwvt/jgNLmTa23ZbOqH
KnGc73ng5uibm8fmJLn6ZbM9P6wP8G49jh2J1d12263II+p+aLG6jZKtD1VFWePxOH6/n1AolHNP
+2wopNBT0/zhcDgpukOhULLnu1OodTl90VSR7HA4TCKRwOfzOT7N7/TxV8dclclSNXRViS/rMVI3
ItU7W92sOqob2d2jLdsauSR+WaNuhZxC1nSMYRhFmW3K5/ywniNNTU1F98tmS6Z7wqZNmwqWYLU1
ocXqNoTVh5qpHmrq9Lh6Eq6oqCjKGJ26qFj3w+PxEAgEiMViBSl8r3DKj5kq9vx+P8FgkFgsVtDG
CZ0ltUyWmhIOBoNpawlaz0HVHMJKuhtURwk/nY3G5UssFmP58uV8/PHHPPvssyxYsICGhgai0Wi7
8lHWsft8PsrLy+nZsydjxoxh0KBBHHrooRx88MFblHnbWsnVD5nNFHJq9M2NuDkiCO4ZX7rzw9qe
u9h+2WzJJPg3btxIv379CrbtrYVt4yq4DZPOh5r65bT2hU+dHlftUAuJGk9nL4wqm99uml8JKTeT
mrBmbZwQjUbbfYZO0pkbeqp/NtVaYbWX5Du2jqaWs+3m45QHrra2luuvv57nnnuO2tpa1FoMwAuk
psGpC60H8FmWNQwDDINoIkFdXR11dXWsWLYMH/Dnhx/G7qhVVVWxzz77cOmll7LffvvlNf5CUGhR
k+t5kFpbFuQ657aom6ZzWK1r2fhlc3nYccovqyOrnUeL1a2Ujnyo0CYylBi1djSyLlesyES+27GL
Qqbbj0KTzz6kE9hd0TghF5SwVj7TfCooWMln/3KNxtmVYcrkkQTxlF1xxRW8/NJLSfEYQESnEqV+
8//qE2s1lzHMv0WBOCJkrbfTBFCOiNgG2sSsYb5fPSIa5t99QH19Pa+99hqvvfZau33dbbfdmDFj
BhMmTMj+AG4ldHQeqM5yfr8/Y9StKxJ73BK5TIfbxwcdX9sz2Qugc37qbHz1mY6hesDXZEaL1a2I
XHyo1lqcdh2NrHg8HdcndYJcxUqmKGSm9Rfy4pvtPiiBraLZ6QR2schl3FZhnW2ZLOu6iym684nK
fvzxx/zkJz9h7dq1eKBddNOLXDQ9iPj0mL8b5r+o+bvP8prX8t4o0AsYAZQBy4Fl5rJey3uqzdcb
gHVAyFxHzFymJ7DZXFbNFSxesIApkycnx9u7d2+effZZdt999xyP2taH1WaSSjqhks1DTTZCRVNY
nPDU5uuXzbYrnOr+lW69mo7RYrWbY40Yqd7udhdQNQVu9fdkm6RTjO5SkJ2ISWdXyMbX54bIql1X
rGzLZXVVZDX1ASdXYe3WG7n1O3LFFVfwl7/8JflaCCgBwubvPkRAVgCbgGZErA4GqoCN5r8EMAYY
hojPjxCxOQIYbS6zAfjQMg4lTscCg8zX55ivRc2xhIDx5s8vgbVA0Hw9aG5LRV9j5jo3b9zIAQcc
gN/828EHH8yDDz64TU45ZhI0nREqTngh3R651ONzpr5sOBxOrmPWrFlUV1czdOjQgnUVfPXVV7ns
ssuIx+Occ845/OIXv2j3ek1NDaeddhpr164lFotx1VVXceaZZzo+DqfQYrUboi6esViMlpaW5BSC
3TR/6vRyPrU4u9oGkK1dIZdtFHpaL/X31Jqo2XbFslLIz8Fu3akPON2hDm22rFu3jqOPPpovv/wS
P20XQiXs1JFQgtALNAL1iGDc3vxbC/CVudz2iIhdB3xuvq6E4zqgDpnar0VE7WRE2K4FVgMLgbm0
WQpGAUeYy38JLDLHoNLUyhBxuwSJtvZHRO/X5piVu1lFbd944w1GjxxJAhg5ciRvv/02PXv27MRR
3DbIV6hkk/jlZhGo0GK1YzLN4CQSCZqbm5P36UQiwaJFi/jyyy9ZsWIFK1asYLvttmPEiBHt/h19
9NH0798/r/HE43Euuugi3njjDQYNGsRee+3FMcccw9ixY5PL3HPPPey+++7ceuut1NTUsOOOO3La
aae5NqHTnaPS2JLqQzUMqblZUlKSXMbOv9nZMk3FmD63bkdh9UR6vd4Op/nz2YbTWI+P+hw60xWr
2NgJ6840GwD3eG0TiQTTpk3j9ddft/WbBhHxV4YIUAPYy/z9c0Rw+pFoqgeJgG5ExOseiFAMAe+Z
yx0L7IRM128EnkME60BgPfA2MB+oRERvPbALMAH4ztzmXUiEF2S6v7+5zCLLeA4G+gKvAwvMMSTM
fz7a7Achc9xhYOW33zJi2DASwNixY/n3v/+dtlpDtrhBNHQF2VhNUpN6UhO/lNXKzjfblbjhe9sR
3WGMqRaU2267DYCvv/6aGTNmcPvtt7Ns2bLkv/fff5/99tsvb7H6n//8h9GjRzN8+HAATjrpJJ5/
/vl2YnXAgAF8+umngPjge/fu7VqhClqsup5MPlT1JVXLqCiqU8JOUawLprpgh8PhZHesUChEZWWl
Y1+iYggnawH8XOwWHVHIsatzq66uLnn+FKKebiYKtX+33XYbt9xyCz5k6j6ICLk+SKQyggjTnsAa
2oReKRK13IwI1gm0Cdv/muuZADQhkdGPkWhmwlzfi8AbiGDcZC5/DiKIQcTpbHMbqpjat+b6dgdO
AZ4yxzQcEbCbgVXACeb43gVeQYRoBLEf7AF8YG5zFLAD8B9EMJcjtoVay/H5+osv6N27NwCnnnoq
999/fy6Ht1vQVUI6G4uBdXo4XeKXnQ+ymJHZrhbNHeHm8WU69zZs2EC/fv0YOHAgAwcOZNKkSY5s
c/Xq1QwZMiT5++DBg5k/f367Zc4991wmT57MwIEDaWho4Omnn3Zk24VCi1UXkq0PVd3Y6+vrCyLs
rCghWYh+8+oCrabOgsGgo92xrBRCEKXaFKwF8AtxEXXqxptqEwEKdv4Um40bNzJhwgQ2btyIHxF2
LbRN85fRNi2/MxItnYsIy4sRkbcIeASJZh6NiM31SIS0PyI8VeXhFxAReSywN2IH2Ai8jCRRjUIi
oQ8ikdJKRCjHEFE6DomcfotEVJ9GBGgcOAg4BBHAXyHC825zrBEk0rovYiP4yFzvFETg/sscW8jc
9xba7AEJ2pK6gub6nnjiCZ544gkqKipYvHgx1dXVOR55TS6o77Hf79/ie2ctt5Qp8SuTkO3sdaI7
RMvdPsZM49u4cSN9+/Z1fJvZHI9bbrmF3XbbjTlz5vDNN99wyCGHsHDhwoLWIe8M3f+utJWgpoSy
KTelEoxisVgyCz4UChX0C1uIJCuVDa+iwT6fL+nnLBROilU7m4K6WXR2StUOpz5fO3tCMBhMRlWd
Rj3oWH8vFG+++SbHHXdcMotfRVO9iDAdiURUP0IE6y7A98CbtGXt34WIwABygdwIPIaISVVaajVw
PW3lpLxI1PITRLQOQJKoNgLnIQlWIFPwc4G3kKoAG4F/INP4uyCieSkS5T0eWIlESd9BIrK7mO/x
AZPMZZeY4z0B+DHwPvC8ub2YOa6xiPj2AdOQqOsb5hiGIUJXHa8A0NjYyOihQ4kA11133RbJGZrC
Y43I5puhnq6CgRssBk7QHSwAmcRqTU1NQRIeBw0axMqVK5O/r1y5ksGDB7dbZt68eVx33XUAjBo1
ihEjRrBkyRLXlr7TYrWLSVcPNbXclLXMkdX/2NDQULBsQitOiTyVzd/a2rrFNLlqh1pIOrsfdqWb
rNHI5uZmp4ZqS74JYqnHPduSU92F888/nyeffDLp71S+TRVJ9SDZ+GuQSGccibauRsTlD4D9kCny
Oea/CwAfrnhZAAAgAElEQVTVsfstZEr+JCRyCjJdfxsSKT0OmVrfAKxAxHDMHMffETG6A1CDREaP
NbeXMMezGPGcYo71IGBHpALAVMQC8ABiLQggU/1Hm9teiYjtW2mLxgaB/RGBut7c198jtoFnzd9P
A74x/1ZmjleV44I2T+9tN9/MrTffzIGTJ/Pcc8+l+QTcjZujb/mOrRCJX6mRWTcfN6DdfriVjiKr
hSgtN2HCBJYuXcry5csZOHAgTz31FDNnzmy3zJgxY3jjjTeYNGkS69atY8mSJYwcOdLxsTiFFqtd
QCYfqpXUOqLBYHCLbOyuztTPhmyTdoqxL/lswy5pLV01gmLsQ7brTx13R8lShRq73XrtLuD5bP+I
I47gvX//OzmVHUPE3CgkergZEV0DkAhqGPg5sCciKO9AkqBGA5+Zf1uLTKH/GxFy3yNT+KOQqOZc
RCQ+Y673fNrqoNYgkdCdgTPM5VcgGfovm2MpAz6lLTFrmPmaHzgdEZfvIZHPfojI/RBJ4LrSfP01
4BpznMchkdig+VP5Ywcg0dklwCzgCmBXJCL7HvAkEk2tQITxInNMB5j7GEfEexSxD8x76y2qqqoY
M2YMH3zwwRbXK7cLm22NXBK/1D0ptQi++k6qe1BXtjHurmS6phXKBuD3+7nnnns47LDDiMfjTJ8+
nbFjx/LAAw8AcN5553Httddy1llnseuuu5JIJLjjjjvo1auX42NxCk8HNwf3x9i7Cel8qNaf0D4C
pvyboVAobfS0qakJn8/XriJAIWhsbCQQCBAKhTpeGPvmAx1VJVD7XUjPTFNTE16vl9LS0g6XtSat
qYeFUCiUcapcRYcLZWWoq6ujsrIyY0TUWstV2USCwWCHU/zZrDsflFiuqBCHZywWIxaLbTEe63Hu
iAkTJrD8q6+IIOLPoG3qPkFb/dErkanzG5Ho5Xbmsg20RVzLEcG23nz/RNosAZ8gHtAJ5s9mRAxa
31+GRCoDiNAdBlxCW4mpGPA7872XIdHXT5HM/QZzW15EfFo7hK8H7kcEcACJsp4I9DBfXw08bv5M
AIchU/xRJBL8T/MYHGuOcSaS1OUzj8MViAieBQxBIskvAfOQiHJvJGJbjVggWhHRqqLWPfr0YfHi
xUn7SywWIxqNZvXdKjbNzc3J66jbaGpqorS01FUl4ZRgVS2erZ2/nKgt6xTqHlNWVlaU7eVDpuva
eeedxw033MD222/fBSNzLbYnj46sFpBcfKipkcdsE4zcFlntTPOBVG9jIehoP+xq01r73Hd2/Z0l
3fpTz6Fcx51p3W5i1113ZfmyZUlRCiK+okh09HjgVSQzvwK4FxGZZUjEcDRtkckrkCgjiE+1DrgF
KS0FMu3fCFyLeF1BxN41iHg9D7ECrEPE50vmcuvMdVchiVQ1SMTzV+Y4tkMirz9EROxYJAJ7M2IX
2BtJmHoUiQRfjwjdl4BfIsldxyBRX1UZoAWJzv4HOBU4HKnjejciUkEiyBchloL7gN8AZyFJX4+a
697TXOZ+8/j2RyLDqnWsIgrU1dQwuF8/SquqWLBwYfKBWXm4uyJrPR066psbVouACjRYsfPKWiOz
dhaDQnT86g6fq/IO21GoyOrWiBarBUBNv3bkQ7WLPOZaLqhYAkO1jLPDqdqcXWUDyCcKnIliCj5r
kpdba7laj3k8HiccDrerKZlNsseUKVP48MMPqUBEk8pir0aikxVIBPP35muTkAip8njehwjBd5Fk
qeOQae5Z5t+WI1Pyz5rrX2H+bSKSoV+LRE/vRUTfeeZ2KhGrwSvAUcD/mONtQqbf70cE6nrgfxHx
txeS2PQwcCQS+fQggvV9xLs62xzfZbQlZ+2ECN8ngT+bfzvW3C7mul43t1lq7kcMEaRhRLT+Fok2
/wmpFPAQEqk9ELENvI9YIYKI8F5jrmuiuT+15j7XI5HsGBCpr2fEiBGMHj2auXPn4vF40vZV31oT
fTpDdxBcqWRjMbCK2dTask6dD93h2GUaY1NTk2uz792GFqsOYY2gxuNxNm/eTHV19RZPkdapZaDT
iS5er5doNOrIPmQiNeqZTuB1RigVo62rdT8KkXRUjEQ36zS/SvJyIlmqUA8L6oZVX19PPB5Pzhik
JnyoMSgh6/F4uO666/jTn/6UnBeKI37RQ5Go4le0RQDXIkLqUWRq/2IkW34UcDkiKqPmOl6hfb3R
SUiE1uOBbwyJjv4AEWVvI4K4CRFoC4BLERFaQZvQPdayzwFkin4kEon1IGJvARIhVZYFFRUOItPu
Y5FSU/shF+e7EEE+BYmWfoRk7v+Pue2/IwL1eKQ5wFGI3WEJIqZ7I2WxhpnreNw8FuPN8Y5FotBP
m+t7ALEp3IEI3PvM8T6DRKZHIeW8Rpv7sAqxB5QgBc4HDBjA1KlTeeqpp9p9/tYIXGot0WJF4TS5
k48YzDfxK9VikCnxqzPjKzbpxmit2KDpGO1ZdQDDMJKCR52UdXV1yWQou372mXyouVAMnye0+Q7L
ysq2aMEZDAYd8YIZhkFtbW1BTd7hcDiZLKCiwKFQyLGaqNFolJaWFqqqqhwYbRsqWt/Y2IhhGMlx
O1mLtr6+Pmk/cQKV3KU8W+Xl5QQCgWR5ndSZhkgkQiKRwO/388ILL3DWWWehzirV9tRARGKT+bcr
EOF2MRIVHGq+VodEBPdE2qAGEJF1gbm8B7EL3IkIs3Hmdj5Fpv2vRqbiQcTwxeb6bkIE7vdI0pTK
9K8xl6tESmOtQSKV15njVHwM/BE4ExF7r5vvHWiO8x1kWl9FW1vMvz1HWzTzl7RVJIgiiVhP0ubV
HW6OvwL4m7mNnWizJrwN/ME8Jj2BGYiw/S0iPi839/1eJPp6FPAjJDJci1QZeN18f7W5rwFz2z7a
KjD8IouSV3aJPlZR61QUrrGxkfLyctcJG8MwaGpqcuXYIDcfuROkOx+sP62fvdIvahbMjQ836TzJ
hmEwdepU3nvvvS4amWux/QC1WHUIFSlV1NbWUlpamkw6UG1PnS50XyhxZMUwpK1rJBIB5MIQDAYd
L3qvxGrPnj0dv+BYp8sBSktLC1KbNhaL0dTURI8ePTpeOAusUVRFSUlJQRLqGhoakg8f+aIe3Kyl
yXw+H62trclzVE0Jpl68I5EIS5YsYdKkScnkpAAwyAM1hvg2x5r/nkF8n03IlL0HEaaTEMH5LhJF
HIYIrOMR0XWBud5PgKsQ4ad8q6vN109HxJni1+ZrdyNCGUQ0no9ETq+lrf3qEuAec5kWRMwNRabZ
g4hIPB+JcirWIJaAheb+7o6IWfXIFkOEYj0ihL9BPLMXIhFkEN/pv8xtVCAJXrta1v+geVyqzeMx
BRGdt5vL32oeq9mImB5i7tcztDUVUNUBmhBxOxw59pjbDZv/lFhVNW5ffvllfvjDH5IP6URLrt5I
t4tVlXzoNootVjsiVchaZxUzJX51leUk08NIOBzmxBNP5K233irqmLoBOsGqkHi93qQFQN2ow+Ew
JSUljrU9TbfdQiQlqUieigirL3qPHj0K9oW3lkpxYhuplRVUC9rW1taCVU9wYirdzgNcXl6O3++n
qanJlTdcqyXE7/e3SxDM1qayy/jxrPn+e0K0Rem8HlhqiEh60AOPGuJDNYCEB7yGCLxnEPH0LJLB
fhEScVyCRFw95t9nI9PWys/5W7UuJHIaRUTu35GLYysiTEcjns/tkSjlDciYfkFb5YB+iF+0Apk+
9yDT/u8jYjGOiN04bd2jQITwIsRL2gtpEnAh0iDgWHO7ap1VyDT/nxEv6q6ISK5FLAPDkMSwGxDB
eQ2S0DXeHEvYXNeRiLifaK53OiJgr6atesG5yPT+CeZ7ZprjORP4GRJdvgexXXwKnOGDmXHZ77h5
3OLAkUceSUVFOatWrc75OpiNNzI1ycfOGwkkH5C0VzZ73DZNnWoxiMfjyWYykF9t2WJYTuzWW1NT
k2xzrOkYLVYdIhwOt+sHr2pxFvqJ1GmfYTpPLUjkrRiezM7sjxLZ1pqoVuEUi8Vcm/Fu1xEr1QNc
yCS0XNdt5/lNrQOczXpvuOEG/vj73yc7KEUQ4TjKB4YBnxkQ9MCZhoinX3jhDA88Z8AvDClu/3tE
xG1CBNIjSETzG0TAnYFEFSsRv+l+HrjaEGHlQQRYpQduMSRy2IhUDJgF/BRY74FlwHuGJEsFEeH4
G0QI7o9k439Bm2AFidpuj9Q1PQ4RqH8H/mKOaxdkiv9S2qKtuyMC9BlESHoRkajmTsaZ+zsfqSCQ
MLczkrZarUchyVM/M8fqRaK6eyLWgCsRoXu7+f/DEYH8FiL+T0Y8u79CfMGPAEcgdoi3gL8iwv9n
SBT6KOD6OEzwyLb+a8BAD6w3I+LRxiaqq6v58Y9/zF/+8hfb8yBXrOIiXYcnq4h1i3BJHaObRXN3
G59TDzfprCedHZ+VmpoaXQkgB7RYdQiv19suA76pqangZZigTQh05qKSTbkmaxJMIclXjKU2UFBR
1FyFU2fJdf12x97aEcttpD4M5Fv5AWD16tWMHTsWL3IhUm1RS4BzS2FmGOoMmOSHHwXgphY423z9
6LgkNiWQiOnOHthoiHiabi5zE9Ld6SHaptTPQKbSrzHa6qD+FolM3mOImK0y3/cM4jk9BJKGqFmI
gJyBZO+rRgJPIlPlVUjk9xjEy9oMXOKBgww4BxHGZyOJX48jQjVormcf2kRuOWJl2AMRog8jEdNp
iOhdgXhtD0CE7AwPHG/AKUgt1l5Iaax3zHW1IEI+gERkD0FKYh2FiOT3gB4e2N+MXEcQAbs3Em09
0DxOr5nHdar570BzXC+a+/au+UARBhqNtmYJCXPbs2bNYtasWcyZM4c99tiDQqKEi9frpbW1tV35
pWyEixvqiGoyk8u1NpuHm0yJgEBGIZsuiSrduaLLVuWGO++I3ZBQKNSuVWihRZF1O/lMndtFIDOV
a3JCFGdDLsctncjOJPTcIlbVsVfT5uk6YuW7/nzItO5U72y6h4Fst3PggQeyYMECQESMxyOircmA
Ug/8X4sIt/k9oDUBUxpEDN0P9DYkgeoqD5zjhVID9kyIcPoZbclTTyBlqiJI8fvHkQSnn9FmJfgM
iRD+AhGW5ebyF3jgGMMUqiZfINPet9LWhnUKkmh1LuITbQHmeOAZQ8bfAgw0JHKqPlkPkti0AJju
ge0NeMwDJxkwAomM/h8SKb0DuUj/yNynB5Dp+BbgVA/81IwO/9WQiOcMxAoxxtznnyPi9kWkNeyT
5roHI2J1OlIZoRcw2xzzaUgE9WBE6D9srvOXwCBz/FHzfR7gHJ9Eo5+Pw69KxEbwxzBMCsLqOHwX
b7NaRM33HHzggfTpvx1ffbXU7hQpONlGZbOZTrYTLdleI7tb5NKNODW+VIuBFXVdtApZFa3PdE6o
99kdx5qaGvr06ePI2LcFtFh1iNQTUXlYi7XtbAWMXVembERHsS5YHe1Lqpc2F6GXzfqdwu7i5FSp
rEKO37puuyiq8s7mcj5Yj/nrr7/Oj445hhBm9ycP7FICKyKwKQH7lMBOQXi0Hnb1wxEN8vdxPris
FCb7Ye/NcLQHLvGKTeCYhEzNJxBRtxFJRgI4CbnIeRHBNAJ4zSPbbjIkE387JPP9TtrKSAUMiUou
RATaMMRL+hMkAqoII/7YkxFvJ8DphojJ6Ug0c4P52o6IEBwB/MwDkw042xSb+xtSrP9JpNuWFynP
pS7QfiQK2h+JdJYh4nIsYkHwIMJ5ornP75vbmWy+dgwSab0VicTuiojlfZGI6TWI2L8Z6YQ12zwe
/2P+XoNEvmvNYzQnBAN9cEorvJiAF0JwtB9+GoZDAvB8JZzQCOP9cGAQ/hqGiSUwPwwtpq1j7dp1
9Kiq4q677+aMM85IfwJ1knwEV67TyarCxdYWlXW7WC3W+KwPNh1FZe3sJ6pz4ueff87MmTMZPnw4
NTU1DBw4kMbGRscT7F599VUuu+wy4vE455xzjm1Vjjlz5nD55ZcTjUbp06cPc+bMcXQMTqOrAThE
PB4nFoslf09tMVlINm/enBQRdthFIPMpnVVbW2vrSXSSdG1d7SJ7HbU+taOQFQcUmzZtorq6Olk3
NlXwdaZUlvJFF6K9YHNzc9JCkU+71nTE43EaGhrYY4/dWbfme+JI9BRDkqRiBpR44KWBIlKfbYSI
AfuXwvIoGAn4pBoqPLDPJlhgiNha7YV1CfG57uSDMV7Y0YA/xOAwD/zKKxHMuAG7JMSTeb45pgQi
1PZDBJzifiR6+TAi0FYA33jhpYREDL1IEf2ByBjmAv08cLfRljAF4ul8BGl5uh0S5XzeA6+Zy/mQ
aGVqkbazPbKdowyzoYAHzjJEhC9Eykpdikz1P4mI7P5IlLQfcKlHhPIjBtzqgXmGTPufa66/HvHn
rja3/TQixg1EjN+ACN67kajzleZxKAHmBGCIF34Vg8ficGsQzvLDTVG4Owq/CohgPT4sY5hVCRc3
w/IEXFgGdzTBSD+si0Ndoi3SGvBAsKyM779fm+Esyp9EIkFLS0vBWiCnkksFA5DvR0lJSVG9stni
xlawVtxa5UFh7eSYSCRYsWIFL730EsuXL2fRokWsXbuW9evXU1FRwYgRIxg5ciQTJ07ksssuy3ub
8XicHXfckTfeeINBgwax1157MXPmTMaOHZtcpq6ujkmTJvHaa68xePBgt0V5bT9MLVYdQj1ZK4pR
UkphV3Io3TR/Z0pndSSKnaCpqQmfz0dJSckWWfFOlczatGlTQcVqbW0tlZWVybE7IfgU4XCYeDzu
+I3XMAwaGxuTkQAnawHPmzePKZMnYwDlXhFqMSQqOqYUPmuGwaaIAbiyB1zRAx7cDL+pg3NDMC8G
X8RF4OxqRuv6eeBXTfD3EBxsnpLTwzA/Ae96TUEMHBqTaOlTtAnKSxBLwKu0+Sq/QqKODyIiVnGn
+d43kUjqQiT7/W+I+KtCBN9kpETWN8g0+n2I8LOiGhUM8sAnBoz2wIWGJDNdA3yOCNyeSCWCWUiW
P8hU+xWITUCxGbjfA08ZclyHIaWm1Df0HaREV5m5nd8h4vlJ4BYPvGhIl6xzzOVXIQllKxEheaIP
rg/CuVFYEIeZAZjohVfi8rf9fPCPILxtwMlhGOyBnb0wKy7HNYJZ1cH8P8iDSdiAco9Et0s8cqNp
NeD+++/n1FNPxUlU17RiidVMpEbgYrFYsjFCptJLXRWVdbMYzFQWyi1kKv116aWXctlllzF+/HjW
rVvHt99+y7fffgvAaaedlvc233//fW644QZeffVVAG677TYArrnmmuQy9913H2vXruXGG2/MezsF
xPbD1DaAAlGs6ebUbWWbaNTZ7RQKj0daNTY1NTnWGctuG4WYPrIa8hsaGmwT1ZzajlNYKxCoG2Nl
ZaVj4x05cgQbvv8eD+JN9ZuR1Gm9Jfv+kRr5295V8GodHFsOJ1fASevg/VYRp+8YMK4UFjfCv6ph
vyDEEjBkI5zrbxOqz8fEN/mmD0IGrDVgRkIE4F3AB+aYPkIy95+iTajGkOSr02gvVBcimft/QyKq
PZDp+SqkfNSLyPT428DrHviTIcJ4EBJ9tfI4ksE/GxhiTvv/DRGTHkSczkaEKubYTjXHcyyy3r95
YIQhU/qY45luSOKTDxGZj9ImPg9AErWmG1IvdhBS0N8L/J8BRyMe3ucRf+8cJJo8yiOdvIZ5ob8X
XgjCjBgcG4GLfXBtAOZ54ZgIDGmRsSYQ28OrCbihJ/T0wDW1cEkvmFQKJ6+Gwyqhpx+erIVefojH
RLgGzdPtggsu4KqrrmLVqlWONBpRuEXM2PkiVWQVtozKqqlkp72y2eDWqimpuOWztSNT6a9NmzbR
t29fPB4P/fv3p3///uy77762y+bC6tWrGTJkSPL3wYMHM3/+/HbLLF26lGg0ykEHHURDQwOXXnop
P/nJTzq97UKixapD2HlWi1ENQKGieNkmGuVDIcVqqp+zpKTEkRaidji9H9ZkKSVMKyoqHOsEZcWJ
C7MS1SpKqyoQqAQSJ7bx+eefs+eee+L1QMKQqV6ASELEysu10JSAi/rBtf3hkCVQn4BXW+DxBgh5
4IqecGW1CJnhy+GX5SJUAQ6vE5HTaMDUFlhlwAZDhO+UuERAwSwx5ZGsfg8QNUQUBpAoqNdcxkAu
hv/2wvSElJvaGSlN9TMP7Gk5XRqR5gE/py3Rak/gKgMO9YiALDPEJ9ob8ZT+EElsegCpfwpSWuta
09JwNTKdPw34MTLd7ze3dRLieb0esSdcYa7jDmRbJyJ+2KeRSPEVSOT0QaQ+7DOIP/UKHzxpiOf2
iYS8NgXxt57vgUlmdPaxUjgmCHNjcEIz/CsOs0NwZQD29cK0MPwzLoJ9LTDID9/HYFYfmFwKP62F
GXXwXH94ewAcsRbmN8P7w2HqSujjhzsGws/XwJE94a3N8rl4zM+mqamJnj178swzz3DIIdYUt62f
bLyyqWJWfW+hMFFZt4pBt/tpIfMYN23aVJCp92yOSTQa5eOPP+bNN9+kubmZffbZh7333pvtt9/e
8fE4hRarBaLQ2fPWaX5VtL+srMzxDllWnBZ5SjRFIpGknzMYDBbMk6lwYj8Mo61Tk2o4oMT15s2b
HRrplnRm7NYoqopYW6s/WD3XneGQQw5h7ty5lHmhOQGlXpjYAz7aDHjA54X6KBzbQ4TLyEUiXA+u
grP7wE1rYJAXbuglVQImficid24ERkVhbVSis8P8sC4E+wTgrw2wrw9+XwG9PNDTCzvVwlQ/3G2Z
/d2/QaKuL5fK703AUxG4Mgz3hETwfpWALwx4NC5T148CL3thh4REKv8KjPfAuSkfw63I+1/ySRmo
egNeNeT9LyYkKWoN7RsCrESm/+/0ieh8xYCbDPGPHmHAex4pX3WzKSQvMiSZ6w5EwHoRsfu0ub7D
EWF8MyKWhyD+1KcCcIAPLjPg+gQcmoDzkCoIS4BPDRjrgyUJeCEGR/nhh374tAJObIEdW+A5M9O/
rxdWJmRf5vWH3YLwQAP8eCP8sgoe7Ql3++HItXBjT1g0GA5fC0ethDeGwk/Xwo1r4eEhcNFq2KEE
GhPwfRQCCbED+IDjjz+eESNGsHDhws6cjq6OEOZyf8iUra7WlU9UVq0vdRxuF4NuHx9kPvdUa2mn
GTRoECtXrkz+vnLlSgYPHtxumSFDhtCnTx9KS0spLS1l//33Z+HChVqsbgtYS0il/u7kF8qucLzP
5yORSHSbBgR2+6CsCspjW0jy3Q87H7C14YB1/W4hNbmuowoEnfl8o9EolZWVSSGW8IhvdHIfmLMR
BpTA73aEm76G1a3wUj08t1m8q++NgT3L4ecrYWUr/KgaJq6ELyLinRwbgnEVcHwQrvoeHu0ndgGA
u+ognIDHe0Ifc+OXNkA0AXdYnnn+3AILI/BZpYhgAH8CrmuFm4PwY8vV8Jko/DcOn1TAZgM+isPc
ONwYFQHbywvT4yIwD0Hat/4F+KcpVEEiutM88OcE7OWHKR6YEZVC/Ach0dQTvXCCB04233OkR0Tq
22algIQh9UytZ1RvJKr7ogeqPbA4IRHb88zXyxGxugHx2VZ6ZSwg/tDbfHCUB86MSAS2Dik5dV05
LI7BkQ0wvgneLod+XnijDC4Ow2QzXD29Emb0hqs2wf7r4PFecF4l7BSAozfAB63wQh8YH4RjN8Cr
zTC9QiwBeyyDah+sj8NZK2W/5jdBhVceWMq9bVF4rwHLli2jqqqKFStW0LOnMkjkjpu+k4XCyais
ErDFKFeYL24dVyp2YyzkA9SECRNYunQpy5cvZ+DAgTz11FPMnDmz3TI/+tGPuOiii5L34vnz53PF
FVcUbExOoMVqAXFK3Nm1DbUWjldCpNBYkwByxU402RW/L5YvNpdt5FpjtJD7kO2686nj2pkL/+23
3871v/kNAAEftMYhkYCgD15ZD0NK4ObR8NPPoT4Gx/eDswbAKZ/BjYNEoBz2FbzfKFPBL0Zg7x7w
+QZ4bhgcXinb2XMpHFQKJ5nR0jUxuK4WZla1CdUFUXi4Beb0aEuy2piAy5vhgTLxYCqOa4EdPPBT
y2nYmIBLYjCjFEab9/49/XBUAl6JwWPlEvl7MQbXtMLFhpn45YGxBu2U5Z1x+NaABSXQxwOXB+CN
ONyVgMlR8CTgJ9727/F4YE5CrBB/KIHfROBZA65JSNH/MHCYFw4OwOMhGcf5LeJnfSghloBfIV7V
j3vA4xGxSpzig9/5wOuFfTwwxQcvxcUGMc7c/3F++KwapjfCuAb4cyl8b8CTEdgjBItaoSYhNoq7
+8CeQThlI1wWgZt7wsIBcOgGGP497BOS4zKvFd4PwyE9oU8A/l4Dvx4K2wXg6mVw6nZQF4M5tVAd
gA0Rqa0b8spPnwdGDBvGiSefzAMPPJD3OepGill6KZeorIrIAskWz+ksBmr9xaY7iNV0Y0wkEgVr
+ev3+7nnnns47LDDiMfjTJ8+nbFjxya/O+eddx5jxozh8MMPZ5dddsHr9XLuuecybtw4x8fiJLoa
gINYn1IB6uvrk5G3XEk3RW4nOIpVeSDXTPR8KhIUY1/SlceyklqJIJeSU9msP19isRhNTU306NHD
dsxKVKdm9GeDepiorKzMaUyDBw+kftMmIgko9cGgMljbAiU+GF8Nc9ZB3yCsj0CZF/49AXavhB3n
wcow9AxCTUQE68X94ZqB0MMP238CB1bAQ2am0owNcNN6+GIwLI/BB2G4qU78juP90OCBhriIKb8H
KvwStU0kxA/rAwYHoCwBPQyp9zkvAX8MwPF+qDbv44eF5f2vlrVFYAF2aYCJQXjUcvobBhzYABsS
Mv6lcRjuhRMT4g09zoB/lsAPUz6CGRH4fQyOD8ETYRgB3OmFvc0yWRck4K0K2MMnpbcej8I1Yemw
lTBgqB9eK2tLTGo04Fdh+EtEkqjWA//tAaNNEfrfmNQ9BXjcB7+JwecemL8dvBmGi2thWgAeLhcx
CzoAZcgAACAASURBVHB7C/xvswjTvw+AYyrg6wgcskYioe8PkJ/zw+JL3cUPB4Xg7iaJPscN+NNI
OLonHLEEVkXgw13gnXo4cyn8cqgk1h33OZw+UD6v+76DS0bBH7+BUj80RaHFvKT6AU/Az8aNm3I6
P6PRaLskJjeRKVu8q4nFYkSj0WRlFrsyXPl2dnICN3+ukLlawcaNG7n44ot58cUXu2h0rkZXAyg2
+UTYVMF7uylyJ7eTD9luJ9/GA7lsozNk2oadRSHXSgTFrAShOqlYo6h21oRCsGLFCsbsuCM+04ca
8EBlENa0wEU7Qm0r/H059AnBz7aHGV/Ab0fCP9bB5I9l6v7wvnDGQBEpmyNw0xCJpF29HJrjMK0S
rv4e5jbB4lYRj4O+g0qfiDYfcFov2M4HPX0wsw6MGNzfv22czzfAE/Xwp34iWjfFYXUM/lIPu4Tg
tjhc3iJT5H5DaoQe6od/RMW7WeaFG8OwyYC7U6zUz0dECH7WC4b7pFvTU2F4qAV+Z8j0ezzlVPgs
AbfG4LkecHAQbqqAO5vhhBYYkIA1CbivTIQqyPE4MyhickIDLEO6YjUa4s8FqUH7h1KJZP41AlV+
aT872tzmnn5Y3AMuaYEpLeKf/W6wiM2zKuAHQThqA4xtgLmV8FUc7myBPUuk1u3tm+HwMhgdhIVD
YNo6GLUK3uoPY4NwXDk80gAfRuEPw2F6P7hsBVy4DAYH4e2xcOa3MG4BzNkJXt8JjlgMx/SGebvB
lE9hjyqYsSNc9iWcMwJmroShFbCmGZpiEqVvjsaorqri5VdeYdKkSY6ez11Bpmxxt5BtVDZTZ6dC
RGW7Q2QV7PfPZXVNuwVarDpIvhUB7Kb5c8mEd4NYtWs8kE/Zpq4Qq9laFHKh0DYAu25YnW3YkMux
v+mmm7j5ppsAmX6JJ8DvhcYIDCiFR7+Bxij8785w5Y6w44tS6P/ab6HcL9O7c38AE3rA09/DvDr4
ZDw8tgEeWQcLwhIxnbYSdquEpVGYUg03D4bhIakEMOITeGwwHGUG4b9thWvWwb+GwD6mqGxOwCnf
w7194URLwPi4NbBzCbzfXwRw3JBtTFwNZ1fB+gT8MgxntUAPr4jcY4NSF7TS07bu6c0wo0KEKsBQ
H1xdDh/GoTQh2fHT6qFHXLL6r/HDMa1wQakIVYDtvPC7Cri2FEbXShLTH6KSxLWL5RS8txU2eODd
fnDzZti+Ea4MwrVmYGlmBB6LwL8GwButMLkWTg7Cg2USLY0CH0VhaABqYnD4enijH5R4pWvYZwPg
nE0wyoxW/7I3/KafLHvUKhixAuYNgmFBmD0Art0EP1gtJ8CgELw2Fv6wDn69Gg7tAXcNh+1L4Mgl
cN9weGIU/GoV7LMIntoBPtoV9lsECxvhikHwv8vhswaYVA33fgM/6Cm/V/rlnNkUkbGGEzB16lSm
TZvGww8/nMsprsmBbMWg8spm29nJKmYh/6is28VqpvHV1NTQt2/fIo+oe6PFagHpSNylTjOXlZXl
VfC+WGWy7ESeNapnl2GezzYKvS9qG/n4OrNdfyFQxzuRSLB58+ZOnTOdYeDAAdRuqqUsAC1Rma4d
VgUbmyXLf1NE6qAeM1g8iP3+KclOZ46E80fD1Dnwi5EiVN/eAGd+ZloGFkkSVk0YTuwHNw6HgSF4
aA180gAPj4DepqPmkMViETjK4hY5agWcVNkmVAGmrREhdqpFqL7XAq81w4JBbdP8Pg9cvQnGl4qw
VX+vj8P4FTCuDL4FhtVJBYOdDViVkAL456bMQr7eCi+3wif9YYcA3FoF/2iGO+vh/lbAgAttZi6n
N8BAP7zRH26ugx82wF4+KSX1VRxuicDLfWHfELzcD15pgemb4K9NcIlfEsX+th3sWyr/jimFH6+D
YZvh6Qq4sAkiXlg8VFrY/s/3MHSNrHOvkPh7e/lkDs7raSvi38cPc4fBRetgl5Uwsz+MDsC/mkQ8
tiTg9L5wcA84qAouWQG7fgYv7yi2jmFBOOVr+CoMF/aH/zTCsV+aNx+PPMTc/B3sVAWNcZi3Gbav
krq6CQPWtYotQ9lMfEht21n/eJp//vPZDm0BbhY1W/vYMkVl1b0kl6is9f9uj0pnOn4bN27UkdUc
0WLVQewiq6mJT6k1OYPBIOXl5Y586Qp94csU1XOqJqoaf6H2RYlU5cdyIiKZitPR4dQEL6AgbW87
Gnd9fT39+vUDRKBG4lDih1PGwD+/hpYY/GYv+GAtPLcM/rUWnvkOAl744FDxrx77rgjZ+XWw3Tti
FdipEq4aLVUD7lsGf14Bd42GMh80xuDqb+EBi1B9ugY+bYSlO7SNbcY6KWl151DxqHq9MKcJ3m6E
RcPaxGciASeth2t6wg4Wm+C7LfBWC3w6tL1P9ZF6KW/14mCo8kny1TtNcNtGWNIipacm1cPFQTgx
JFHR0xrh5h4iVEHsBT8pl6n3M2rh4HIYVwsTgvBAOYz1w2Mt8EYUFg6G/n5JXrqyB1xdJ1PzCeDW
ajjAInKnlsI3A+C8WrimCcb44Uelba/vFoLPh8DPa+HAOrEKrBsuEfB+Xnh3MNy0CQ5cD1dUwqdx
mB+BhWNgfQyOXAbzW+HVQfIZPtAfJpSIyE0YcFQveH9H+LBRpvS/CsNjo+He4TAyCId9IZ/bCb3h
vO3g1jVw5xoYUQEnDYZZq+GXY+HyHeDwd2FlC3x0GPz0I5i3AV49BKa9A4MrYGSVnFM+jxnJj5vG
tliMqqoqPv30UwYPHtxO3GjcjfqMconKqqYrKqARj8eJx+O2VoOuPgcy3cM2bNigI6s5ohOsHCQe
j7erVakSi8rKytqJu1wTX7Khtra2IAJGoabKVWZoZ3vcZ2LTpk1UV1c7ti+piV7qYuZkpyYrTrRE
TZfg5fP5qKuro1ev1K7ynSdT8tajjz7K+eefT8gPGOJRNUxRGIlD0Avzjoer3oN5a2FIJVy3J1w2
VwTJ0YNg+nxYUCci43+GQa8APLQUvpoiEdXvmmHcW/DiznCQWaXowE/gu1Y4tQ8sboZlrfB1q/hj
vV6JtoXjEnlrSbS/YJV7JWpX4pXIbcgrCTvNCRF6u4ckYWrfEhi7Bi7sAb+0VEeqi8GwFfDXgXCs
JTIbScDAr+Hm/jCxFJ7YDI/XijXBl4D+Plg0QKKTisYEDFsLt/WFc6vhmwjcVANP1cNILyyLSzmu
Eyq2/FxGrRKfrdeAGdVwhmWZ2gSM/x5+UAFLIlAXh+f6wF6mqI0bcPR6+DwKLXEY4od3TK+q4tUm
OGKNtGT9bpx8LiB1T6cug81xeH+oRF5P+R4+aBGbwDG94G/mA8NXLXDQZzA8CHPHyWfztw1w9rcS
Ca0OwAlD4KmVsHs1zN4X3q+Fqe/BWcPhjl3g+Pfhw03w38Pg+s/h2ZXw/BQ4fx7ghcOHwkOLYf8h
8PZ3ct55zYirzwNnn3MuN9544xY1RdU9ztruuKuFjKK5udnxe4FTuDn5yzAMWlpakvefVN9sR1HZ
Ynz+mRLA7rzzTvbaay+OPvrogo+jG2L74Wix6iDqyQ/avkwqGlZIcQewefNmysvLHS8ynJpwFI/H
6dmzZ0G/7HV1dVRWVnb6Ap6a6KUsCtFolGg0SkWFjTJwgHA4TCwWy2v91iiqdczWuoe1tbUF+Qzi
8TgNDQ1UV1e3+/uUKVN477338AIlAQj5oTUmV5Sh1bB8E+zaBxbXStT07v3hrLEw5Tn4aB30LYWV
jZIg8+vxcMU4WW7gLLhjHJwzTLYz5k2IxmH7UvgmCmvDIkj6lcDICtihTGwDFT74vzFQ7RcRdNan
Ilre3KVtzNd8CzPXwce7SYWATTH4shnO/QYuGyhR2C/C8G2LVCmo8EEfH+wcgEPKRDSetA7K/DB7
UPvjdMIqWJGAD0a0CVLDgN9vgF+vF+Fc5YdTQ3BDDxHLB2yQkl7/Gtw+crsmCruYgnDPUniiN4yy
aINzN8C/WuGzHeGfm+HiVVIJ4Pk+4o+dUiPNBz4eIwLy5vVw5zo4pRwe6C0e1FfD8NU4mdY/6Vv4
bxM80x8OLJPappNXQS0y5rURmLc9DDXH0JqA6Svhxc1S4qp/Cby3lxyzAz+GIUGYu7NEazdE4ZDP
oSEGF24Hv10DPUOwPgzTh8Efd5Pku/3ekaS7Dw4QT+qB78LU/vDYRJj+Eby4GuYdCo9+C/cuhWcO
gusXwupmOHcnuPVjOHQEvLZMjmkkLnYUkGLnn332WbuInLVuc1dmr9uhxWr+ZDp21qisNTKb6pW1
S/xy6hyIRCLJmcdUrrnmGk4//XQmTpzY6e1shehqAIXGrqsUQHV1dcEvgE5OPadL+PJ6vdTW1jqy
jUx0Zl/UzcnaSjS19Wyhk7hy/axTo6iZ2uUWOyJUXl6GYV7cS4Mwqg+s2AiVIbj3aPjpPyWKVh+H
kE+iXwcPgR/8AxZvgoHlcOmu8Ny30BiGq3YSgfejt6FfCJY0wq7vwDeN0pVqpx6wQ184tSdc/gn8
eke4epSMZUkDPLESPtgbdjEjnfNr4T/1sGhC25hrInDvanhurFgHegdgOPCzb+CInnDzsLZl17TC
Dh/DQ6MkMvpeI/ypHi7fICJzWABu3ADn94R+fmkbOrsJ/juqfeQ0bsCdG+GmwfCzvvBMrYjXe9fA
QI9k+C8d1V6oAtxVK8dt8Vi4ZT2MXwMHlcDjfaQ+6ZONMH8HEdM/6QVHV8HP18L4tTDEB7UGLDfL
IwY8cP12EgU+YQX0+U4eChbvImWhAF7bHv5vPRy5Gs6uhP+0Qr0XPttN7hAXLofxX8HMIXBED4lG
n9ULZtVBqwduHSqitsoPC34AhyyQ4/fxbtA3AHeNkAjrdSvh9p3hku3h080iSGui8MRe8NFk+X3n
t2DBZPjwIBGwR8yFP+wKi+pgwquwd1+xPxz9JvQvhRVNcNvH0Pf/2TvvsCjO9+t/ZukdFaVZQFTA
gg3sBXvD3jCWiN0Ya2JMNLElsX4tUbHFFhsxFtTYNXbF3hW7KDZUEBCWBZad949nl10QrGDI7/Vc
FxewO7vzTNnZM+c597nNYccdqOwE556CpakYu0otuvXY2dkRExOT/vnRtRDWka73rV7PTUUur3tW
/6ue0Ld5ZTNbDAw7feXUOfDZs5qz+Kys5iDUajXR0dEZiozi4uI+qvPKu+LVq1fp6/0QvGsmam7b
DeDD8mkze4HfVOiV21mu75pX+rb2p9kht46BrnArX758xMbG4uLshEYGU2NAI5Q7Y4Xwq/5UHybu
BzszmNcMjkfC7BPglR/CY4QtYF5d+NIL9j+EVtvgYgCcjYZpV+HmK/F+fgWhiStMuwiL/KCLmxjL
yPPC73qjvvBLApQ7BLXtYb6XfszFj0CgA0xy1z9W9wLYmcBWT/1jO2Kg0w24XRmcDD4iVS+AmwWs
M1hWo4HC5+CLgiLvdXM0XEmA/MbCQ9vaHlZn7F5Ij0g4q4JLZcSUtA4nE6DBTUHEPczgt4LQUCu4
X1VBlfuwpyTU1J4q15NgeCQcfiUI8KzCMDCL77TJUfDzU7A1gS3FoGomx0nIS+jzQFzAJ7jCSKeM
zx9PgFrXRSzXI1+xv3T4PQqG3YURBaGkGQx8CFO8oLgldD4PA11hurYroyoNOl0VU/qtC0DIc/jS
TairO57ACX8oaSNuRmodgvL2sKO6sGI0OSo6mU31ht8fwD/PRGveQhbgYCludgK9wNkKZp2Ddt7w
MgkO3Qcna3gUL9ZvpLWEmChAadD87sKFCxQvXvy9FMLsFLm3tSzVPf6+xDMxMRELC4s8SQqTkpIw
MTHJlZagOYGEhIQsM0w/FjmlyqpUKoyMjLL8Hmvbti2hoaHvnWn9/wmyPKB57xPyH4aRkRF2dnZY
WFikRzbpTvzcxocmAqSlpaFUKomLi0OpVGJsbIydnR02NjZZEqd/OwfVELIso1KpiIuL49WrV0iS
hK2tLba2tpiZmb3xrju3ldU3pUAkJycTHx9PfHw8sixjY2Pz1jF/SqxZswZnJ0FUrcwgVQ0mxlDA
SlwwTIxg5E5AhuNBcPMFzD8NxkbgXxy8HaCWiyCqKWnQcacguJV2wOCzgqgOLwevvoQjAXAuGsrk
g0Ct4vlMBQtuw/IKeqK67AE8VMIkD/04p9wRHtSfiuof2/8SzrwSRT46aDTQ5y5MKJaRqG6PgWtJ
Qg00xMj72rakxeGnYnC2EryoAVVsxLZvewUFwoWf82ACXEqCjfGwtnhGogow+jFUs4eH1aF1IRGZ
5REBa2KFT3RAIT1RBfCygJ2loJiFuDH46SmEZCp2v5cMk6LgtxIw0Bnq34Gg+2I7AS4mQd9IWOwN
W8rDpKdQ+4aIfAJRHDX1KRQxg6r5wfMiXE3Uv39fR/inrGjC0DcS1paHwW7QohAcrgbLnkDLC2J9
5kYw3UOQz1XP4HdfmF8ZVlYRpNXvoPCheljD2fpwKwGqHhRNI8rawoNECDoPlhawqyUUsQVHGzgV
CBOqw/qb0MwdFjaE0HD4sjx0KgMvVbCkHViZQjkXvTVFd75IQIUKFZgwYcJ7qZc60mFsbJxeW2Bh
YYGVlRVWVlZYWFikTz0bpqEolUoSExNRKpXp9q/U1FTUanU60ckKeVlZzcvI7et3VueApaUlVlZW
WFpapp8DkiSl282SkpJITEwkMTGRpKSk9OIvtVpNWlpaBjuKSqX6qJqG7LBr1y68vLwoWbIkU6dO
zXa506dPY2xszKZNm3J8DLmFz8pqDkPnU9Ehp4uFsoNSqUSSJCwsLN66bFaZqDo/7dvwMV253hVv
6gD1rgrwm5CdNzOnkFWh0oeqqFkhpzy9mSHLMi1btuTQgX2kaiv9TYxFhuq3jWHmHqH2tasAmy9A
j/Kw/Ra8UELXsvC/xvD3TRi4DVY3ht8uwrEnolFAv3LQyRNWXYNNN+FGR0EsLkRDja2iqMZbu7uq
7Ib4FGheCG4mwAMV3FcK8iYjFNlktVBvE7VhG5L2x1gSYyxoKnrQO2g7Z91VwW/uggyWsAAXEyh6
Dka6wHAX/T54lgLFz8KOclDH4PSISYFipyC0ItTLD4djYGUUbHwiSJuTCRwoJQigDttiIfAehPuK
drMgFMeFT2BchLARLC4KXxTIeBymP4UpUXCjGoQ+h29uQXEzoaA6m0Clm+BhCVvKieUvJUCn62Jf
LHUWKm9nZ/hNW/wUlQwdLov0gq3usDJW2BRu1BHK7OibEBwBwe7Qw1G85pdImPpI+IVNgHM1hX8X
RNW+/wmwMoIfikHf66KArrw9/HoN/qoGzZzFspPDYdJ12FAFmjjBqRiocUgcJ58CMK0mzLkEx5/A
lS5CIa29CSxM4FQnmHcRRofB1jbwIgmCdsHiADj2EEKuwPxW0H8LtCgNu6+LG6ZXyaBKFZYLCShR
shRhYWG5es2C11uWZlblsppaVqlU79ww5VMjL/tpZVl0h8qtuoMPhaEqq6vz0D3eo0cPzp49i5ub
G0qlknbt2uHh4UHx4sUpXrw4rq6uH3UepKWl4enpyb59+3B1dcXPz4+QkBC8vb1fW65Ro0ZYWloS
FBRE+/btP2qbcwGfC6w+BTKT1dwiFpmRlJSELMtYWlpm+byO5KWkpKTnir4vyYOPtxu8CxITEzEy
MspQRZk5vsnMzAwzM7MP+nAbTnfnBnRk1dbW9rVmAzlx8c+NYjpZlilQID+pyUloZK2CaiwuAF38
4M/TUNoZQnpDg5nwIlEQgwKWgnhcGQAxSigxT5BKtQbqFIeDdyCsC5QvBI8ToNRS2NkUajsJkuf+
l+ga5WgBj1LgmVI8XtQa3O3B0x4ORAIyzK8GdqZiynrIKXieBMcbivFrZJhxXfzsrwsPkwTBvfUK
5t2GyvkgOhliU0TBlTJNbFuHglDPBvyswccKGlwFR3OJjd4ZL33+F4SKt71Sxv02+S7Mvg+V7eHA
C3A3h+8LwRf5weUK/FgUhmQq0LqaCFXOwWB3WHgfHM3g98JQxwbuq6BMOGwoB021JDYmFUbcEp2/
CpuAErhfRd8WFUSO7fhImH5fZKU+rZtxnRoZJkWIH40MN+pCMYNLxaan8OVF6OIgCPf0R7DfH7xs
oV0YXHoJJ6vrXxObCqUOQbwapleEwVpivPQODDkLiytDV61S/vtdGHZBqLgnYqCms9gmZSpc7CSS
Jb7YBwcj4WKguEmqswkkBZwNhN+vwMijsL6luEnpugPmNoOrz2HpeVjQBgZugYal4NAdyG8NkS8h
KUUo4WkakBGWrH8L2U0t66INDe0FmW0G/1YMU162KGg0GpKSknJFncwpZN5/Go2GqKgo7ty5w9ix
YwkICODu3bvcuXOHu3fvEhMTw7p162jduvUHrS8sLIwJEyawa9cuAKZMmQKIYi5DzJ49G1NTU06f
Pk1AQMB/hqzmTTPKfxiZp4B1AfS5TVYVCkWGaQYdsiJ5H+N3/JQ2gKwKj3Qk7WMu3rm9DbovodjY
2BxtNpAb0F30CxQogEISRMbMWNsiVAYjI1h2DBysYWpbqDkdlCkwpinUKg5N58OKVtB0DYQ9hCJ2
MKEhtCkNleZBUBlBVAHabAYPGwi+CkHHIDJOEJWaLlDTFSoVgn57YUhZGK0lhU+VsOwa/NMYqmnf
5/4r+OcxHG+kL1hKS4Mp4YIklbETPwABR6FWIdhbW7/N8Snguh2GloB7iTD3GTyLhLhUQZRKyjIz
IqGvsygkOvhSZIlez9TdM0ENU+7BqkrQykmkFyyNFLmw/R+AqQQ9HV/f562uQp+iMMUTxnjAtHvQ
7DZ4mkN0CnRy1BNVEFFSK0pDOSv48a4g6ydfQXWDhDET7Q1CPhOxT73C4HBlKKS9p1RIUN5a/DYz
gqArsMdX3FgAtHMCLyuoESZ8oAfrga82HW1nLRh0AXyOwvbKorNU36ugkaC+C/x8DVq5QDFr6O0B
+U2h2wl4ngxDS4riLgk4Fg1j/WCMn7BvNNoKZf+ES4GwtiF8uR981sGFTnC0PfhvAp/VsDEA6heG
dlugXEFxjPpvAztziE+GXhvBxRY2XYLyLhD+DIrkh8ex4lw1N4HkVBlbW1uePHnyrxCcrAp+dOqg
lZXVa2RWN22c19IL8gr+C/aJzGNUKBQ4Oztja2uLnZ0d48aNy7C8bnb0Q/Ho0SOKFCmS/n/hwoU5
efLka8ts2bKF/fv3c/r06Ty/Dw3xmazmMgxz/nIThgQst0he5vXkFgwr+nVT5tbW1nm6ElfnRdUl
KAA51ighMz72GBhaKR4/foyPjw9GCqFAWZlDYQd4HA3qNKjlDQcug70lNJkjlKpDw6ByEXAeI8jO
l1uFb1AhwZ5e4JYP5h6H56/guyow5gisuQFRiWBrBqVt4Iey8M1uWNAQumhnqaafAkmGb8rrx9pp
LzR21RNVgA4HoV0RKG8gjPc/I1S/9gYqZng87H8G5xtl3P6up6FKAfilXMbHi+0U09f5TWFZJIyO
gIJmEJcMXZyhSCaHTaeLUMkOWmoJqZM5jCkJbRzB7wiUsgWXE9DQHhaWEn7Z8RGQJMNkbUGXjTH8
XBIGF4WGp+Bpmpi2T1ILn68O0alCFZ1QBpJlaHgZ2hWAPzyFwro7BoIfwomGYj/0PgMlw2CxJ3R2
gqsJ8MVV+K0yNHeBgCOiOO2oHxTVqqUn4kRTA+/80OEEnGkgtslIgoUVwdMKmpwBZzNIVcD1jpDf
DAYeg4p7BMH1yQdti8A2U2h5GGbfFirs3HrgYAGBO0WUWb+y8E9raLwFSq+FK4GwsgH0PgDl18Gc
WuBhDxtuQ6UQcLQS59y5h9DVV5xvP/wNfWuL827lCfB1h+tPBDG+/Uz4rY0VwhJgYSqUdGdnZw4d
OkTFihXf8inJfRgWbBkG5Ge1XHbtSnMzvSAvE8K8PDZ4s6f2xYsXWSYBZDcr+q54l/0xbNgwpkyZ
8knraXIKeU/f/48jq4KkT9UKVaPRkJiYSGxsLCqVClNTU+zt7bGyssoxZS+3yKph4ZFOBX6XYqkP
ge7L4WO3Q0f6EhISiI2NJTU1FQsLi3Svam6p6R86dp2Kqium27p1K5Ur+WBspCeq5YvDkxgxlbp3
LBwLF2TIszDYW8HXdeHaE8g3SmRbjmgE93+Fhy9hTD1BVG88h+92giyB53LY9RhikuDX+hD1DYS0
gaMPxDR/oLayP0UNk05BcG2h/AGEPYUzz+A3P/02/PMYwuNgegX9Y4+V8NcDoaoaniadT0APN/A0
KGAKj4d/oiDY4PUAs2+K7ZldESb5wNUW8LQtVHMAhRGsi4KCB6HlOVH5fjoODr2E38u/HkfV4awI
uj/dEA7VA7UpFD8FNS7A/yJhlY/ozmUIVZrIfF3gC7ESuByH3x6I52QZgq5LuFvDd17wkzecbABn
k8D1FGx6Dp2vwa8+UNYObEzgr+oQXAl634A2F6HheejqLpRPZwsIawBNXaDcMdj6FLY/g8FX4a+6
cLI51HUC791wxqC4q6ebyEeNVEHvUuBgLojiwprwdWmo9Q8cjBLLKiSh9j5Phi6eQmFvWRw2toAR
x2DeJUHG97YGdzvwDoF7ceBiIc6VXgfghQa294TSTmBrCYcHwW9tIeQclHeFkC9h9UmoUwIG14Ob
TyFkEFiYQUMfcQ6bmwjympQi7CVmJlDPv+4bi0/yGiRJwsjIKL3gx9zc/LWiLxMTk/SiL51QkZiY
SEJCAkqlEpVKle7zN4xpyg7/JRKTl5HV91Z0dHSudK9ydXUlMjIy/f/IyEgKF84YW3L27FkCAwNx
d3dn48aNfPXVV2zdujXHx5Ib+Kys5jJyW1nVZaKqVCo0Gg0mJia5puhBzpJvw2panY/W3Nw8vSVq
blonPoasZtVu1rBIwlDh/rfv/jMXpJmYmGBtbU2PHj3YsmUTaWlgaiJ8o4kqOH1DfKEPDYCmv0BB
W1gzBP44CLsTYfUZiEkQZOTQN+DnBsPWCWKSmgYlZsL9GHDPDz82ghbeMPMQRL+CwVrS+TAe0bxf
AQAAIABJREFU1l+DA530RK/XHihhDzWd4PQzeJAAg44I7+r0axCtEq1Zjz0ThVUdwyQUyChkuBQr
fLN/3Ic9UVDAFCKVIpd1XTVB9nTrCTwB3YsJL6YOag1MDBdE0dzglLNQiDilFbUgoAgcfAp/3IZG
58TzRSxEFqshFkdAlAoma1XbyvlgWy3hna22XwTz/3xbqJSFDZTaFuclOrpBLw+ZoOKw6SEMOA1z
H0O3QnA4RuZeC/3yZe3gUmP49YZE4FUZBzMYbJCUANCtGFTJD2V3axsylNE/Z2oEi32hWj7oclZ4
XhdUh+baWcTVteGXS+B/CJb6QiNHqHkAClrDmqbQ/G94roK5NcS+nVhZRE4FHIYAFxHs/2NNaOEB
ddYCMixoAE3dYHMAtNkmkiJGVIRl9cDnTygTAsXzwYbusDUctl0D3yJwoC/UWgi+s+HMMPG6gEWw
eyCs7Ao9VsPKnqCuCd3mw9pB0HUBNKsEx66Dixk8jYF4pX77p039lb1797Jv377sPzy5jJy4PrxP
nqihvUD3eFbxS4bv9W9fv7JDXri2vglvGl92yurHwtfXl1u3bhEREYGLiwvr1q0jJCQkwzJ3795N
/zsoKIiWLVvSqlWrHB9LbuAzWc1hfAplVXf3nJKSkk5ALCwsSExM/OiphLdB18XqY5AV2TP00WYu
UsstvM86siJ9lpaWWVor8kIDiKw6YekItbe3NxER95BlsLIAVQqYmUJ+C3iVCOam8M1yoVD9Mxb+
PAZrjoKdFYzpAHO2gX8pQVTXn4XFR8U6/7wKrSrCwoOwtRd4OUK8CuYehfXthYUAoON68HUSBVfj
j8PRJ3A0EpLTwG0NWGt9lkmp4OkAESmQz1L4E40UMNwPNLKMWgP34yEsGjp7iuKkc9FiuYh4oTBW
2ifIqqsF5DOFK3HCR/koCVzMBdEacA6KWEKnohn3Ye9TUMIG2hQVyzVyET9zr8GES1DcQaLkARl3
SxjlAYGu8P11mFdJVNkb4mKsSDE4GgDTL4PnEWjsAMvLwopH8EQlM7u87vhC+yLQ1BmGnoUpEeBj
JywDhjBWgLEkY28ufMYldsFBf/20PsCq+6KLVOMi4L0DQmoIG4AODZ0EcZUUsPE+BJUQSrokwU/l
wdMWgo4KEl8iH4S1F88f7wD+ocKnu76+eK++nrDiJmx5BCOqwA/VxePHu0GtNaIb1rJG0LAobG8F
LbbAlrtw5jmUcQJLM4iIhmaloHVp6K6BcrMg/Bs41A9qzIcac+H4YHGuNF0I+7+GZV2gxwpR/JcG
dJ0Pa76CL+ZDSz84dBWKOcKDZ6BMFoWBSclw5swpnJwcefo06o2fpf8q3tdeoCOzhqprUlJStjaD
fxP/dbKaG8qqsbEx8+bNo0mTJqSlpdG7d2+8vb1ZtGgRAP3798/xdX5KfE4DyGHoctV00JGbnIjY
yNz61LAVpyznXhtOQ7xr4H1mZEX2sms/m9uh/fDuFfVva3+aHXKzeUJWaQmQ9T42NzdPzwMEsLa2
RKHQkJIC5mbgUhCePIev2sMf20GpgsZV4cAZ6FIL9l0R/tUv68KsnrBwD0z4C772h+Vh8Cwe6nrB
7M5Q2gXKjIOGHvCbtqC1xRJ4lQST/OFgBITehItPxBRwPgtRCHP7Bfi5wrLWUEj7MXH5n8SP1WW+
qiz+12jAaQ5MrQtBBm1VfVZI1C8sM9tf/9i88zDxBET2FSQuIhaOPIbB+8HJEhKTRTKAqUJkfZ6L
hakVYGAJfcHRg0Tw3g5Hm0NFg2IntQYc18GcmtC1lCgAW3od5l6BOBVYGEFEc7A1CMtI04DTNpjo
CwO1/tzLMTD8lMSJpzKpaRBSU/hwMx5PaHQAYjWQKktEKWGtr0x9rUf2/EuodQD2toSKDkKJXn8H
ZpSHfsWF3aH1cTjaGioUhMXhMPwYfF0CplaEhFSotAe8HGC+PzQIBYUGTrfQ3zAkpkLlvyEiEbqU
hOUN9eOLiBcxUx62oiVqk90QrYZf6kG/bTCzHvTXWkNvREPNNdCkqFBm9z0Q/lWlGrpVhMUdRKV/
oyXwKE4QVCMFdA6BY/cgfIQo+qsWDM62cGgQDN4Mf5yCfjVg53W4+wIqFIYLD8WNUZXicOA61C8D
5yKgSCG4HyW+1NRp4lzXITY29pNXvavV6nTrUF6DWq1GpVJhbm6eZYoBvB6M/ynTC/J6K9g3Hdt5
8+ZRokQJOnbs+C+M7D+Bz9FVnwIajSZDVb5uiv5DiVfmTFQdWcqKZH2K7lLvSyQNp/nflexllVOa
03hTXmzmArWsSN/bkJuRZZnJ6rsQao1Gg5WVJUYKoaIZK8DYWFTRf9Uelm0TCtu6iTB6EZwKF1/4
TvkhJQVuzYGnL8F7uFCmCtmJ4qtNYXB3ChS0gVVhMGQtRIyBx/HwxxmYcVAkDOS3hGIOcO859KsK
kwPEuC48ghpz4PoQKKrNNZ18GIJPwr2v9GrsuMOw8jLc7idIDMDuu9BhM9zvK1RhsZ3guBBm1IUe
BtPeiy7Cj8cgsp+oJtdo4MRTCNROR6dqhJJby1GitbPM4jtQOh+EZIqA6ncMjr+AS50ytlu9HQc+
68HHAa68gDoOsLCyUDn7nIETcRIX28jpY9eh0ma4His8rNMrQFBx/XPr7kP/0/CgO1gZw8zLMP60
mJJf6Qc+e6CZGyyoo3/N5nvQYz9UzCcybMdWyViwdvoZtNgpukrZKCAiGa51E2ppQgq03Q6XnsOJ
5uBqCQ33iuzZ0PbgvwYqOcD2AH1s1jOliJmKTBDNIE70EefWrtvQfj1MqgNDta1w77yEGqtFC9eX
KTCyHvh7QLPfYVJTGFpLHIP6i0UM2tXhgARtV8H5x3D6a9hwGYZsFTchRgqws4DYJKhWChzsYdsp
aOYHsYlw8joUKQgPn4vZA7UG8tvAywSwtQK1WiisGu233KNHjz5pR6G8TFZ11+2sZuqyaldqSGYN
i76yI7MfC5VKhUKhyLNkVecNziwoAIwfP56WLVvi7+//6Qf230CWJ8jnAqtcxod4VnVkSVe4k5KS
grm5Ofb29ulTz1khr3SXyqpLk7W1NXZ2dpibm7+VTP9b25GWlpZegKRrNWhvb4+1tfV7Jynk5jbo
rCW6cyQuLo60tDSsrKywtbV9bR/HxsZiZSW+dExMSSesKSlCvZu7HpJU8Pc0GPs7nL0BnevD4bkQ
9RJm9IA208BrOJRwhm1j4FYw7LkAE9sIopqqhmEh4GQD3tOgym8w7yg0Lg33J8HzGTC8vlAZxxhU
53dbC3199URVrYbpR2F2Qz1RTVHDnDPwWwMykL0Be+H7KnqiCoKQ2ppBV4McbI0GxobBtDqCqIIg
WwXMRND80W4QPRROfQklHWWm3BAe06NRMO48hMeK1zxLgrX34Pe6GYkqQKd/INBL4kRnONoJzKzA
c5ewIax9ACtqv05Udz+EG7FwowfMqAMjLoD3TrgaBy+SBVGdUUOotEYKGFkeLnSAhylQeLtIBQiu
lfE927jDlU5wKhrUEjTPZG3wKwRXOwlP76HnouBJd6pYm8Ku1tChJJTfCvV3w70EuNAHvAvCud5w
Mx6qbBDED4QyGpsiMmjjU8XxBWhaAv4OhNGHYUqYeCwxVRzTlymCpI5tDHU8hGVk9C5YdEI0A9jX
F2zMoMJcsZ9H1YWYRHCfClMPQ9dawpLS0hce/Q69G8ClCJjTFyZ2g33n4LcB0MwX4pSwbaqYRWhX
X5z/lmYQlyAIrLmZ/pvR1dWViIgIPhXy8lT2m8amI5+6VqK6oi9dhycrK6sMcX267zPDDk+6oi+d
lU2XcPA+yKv7Dt68/6Kjo3PFs/p/HZ/Jag7jYzyrhmRJqVSmt2/NrvVpVuv+FCQvu+3RKaKxsbEk
JydjZmaWnkbwPgH2nzrLNSUlhVevXhEfH49Go8lArPPaBVFXfKZr8ahrj2ttbZ1l4sPZs2dxcnJC
lsHMTJBBIyMo4gJGxuDoIAqqfL2g0XA4cwPmD4dVY+DLSYAMPedDVJIgDlt/gLpl4IfVgvjVLglD
/gS7wUKhdHaAWV9CyBDhe1zZEwrnE4Txmw0wqTlYa7s87bgmirHG+evHO3QXuFhDixLwPBHuvoTA
zaIZQHF7uB4Nt2Jgxil4qYShBiH9KjXMvwhz6mUktePDRPelHqUz7suuu6FrGeHFBChbEIIbg6W5
xOCqMLo2/P0U/LaB23oxHV7LBao7ZXyf7ffh5kuYWl2csxUKQmgAhPeA+0nCq/r1SbhlkEmv0UDP
IzC+OhSxgS9LQ0QQNCgGfnug7A4R3dQ7Y/MZStrDzOpiSjwuFXof1LdZ1WHtbUE8+1eGKqGwPDzj
8xdeQIwKWpSCGuvh4EP9c0YKCK4HVZzgbDSMrKYn+K42cCYIZCMJ7z8lLr2AKusF4bz3AxSylfBe
KKFMEcvXd4ddX8AvYdBiPVRfDQHl4eJoOBkJPdaK5RqUgk09YcQ2WH5GEN8D/SEuCezHQ7Plorq/
fDGwsYSVAyFsAuy9BF8vhTlB0LQiVBgKfRvBVy2g9jcwpTeUc4OekyD0F9h1XMwiWJpDjYqixWtK
KhhOrvj4+BAaGspnfDgypxdk1bLW1NQ0Pb1Adz3LLr0gq5a1eZnow9vJaqFChbJ87jOyx+cCq1yG
TlnN7uTNqvWptbX1e005G64rt2OyMivFmYulTE1NPzqNwJBI5uYFSUf4ciPLNScJd2YvqkKhwMTE
BCsrqzeOd+XKlQwY0A8QBFUGChWAcqXh4DEY1gtOX4SnL+DyPbC1FtOmjf2gXE+4/Qja+cOEXtD0
GxjeEtwd4cYjCN4h1LX6/wPvokKd+/s78NcSwqKDYExzKKD1oE7eJVS1vtXEVG94FPRaB6UKwDd7
Je6+hAcxMs8SRWcjm/+J5Y0lMW4zE6gTIv7WaETygCyD7VywNAF7c6HcKVMF+YpKFGSvmA3MOQ8r
m2YksIcfQvgL2J6pecuG6/D0lcyY6kKhHVhZbOePB2HuGTj8GGpslRheRqa1m7BO9D8sptsLZpox
vfxCEPgzQTD7NJQPhWoFYbU/TL8kCPQwgyl6OzOY5w/lCsDww5ASD6H3oK27fpkkNXyxH4b4iha3
rTeARwjsbwnutoKI/nwWdneBWkWgTmHovhX2PII19UXMV8e98Et9GFYN5pyGFltF29NB2rGsCIeT
T2F6AIzaKZTTsVoFN58FHO0m0+wviRobobEn/NVNPLevt0yLPyS8FsCV/mBrDjWKQJMSsPMWtCgL
CwPFsse/garToc9fsKQTNPGCdT2g80p48BL+DhdtU20swcMJto6EBBXUHAfVxsGJCXB4LNQYBw42
8McgaDMdfIbCjfliqr/aUDgXDIGTYfBvsH48dBwPY/vC1D+gti8cPg3mFpCohKQkMbaePb/k9OnT
TJo0KdvPVk4gLxOu3Brb29ILgAyWAsOCL0N7QVpaWvp75ESmbE5Dl7SQFWJjY8mfP/8nHtF/H589
q7mAzNXsMTExGQqfMkc2fWyveB0SEhLSC5dyC7pCLmtr6/QpnA9t3fomZN5nOQHDGwO1Wo2xsTFW
Vla54ivNiba02XlRU1JS0qf9s0O/fv1YuXIlxsba6m4FpKkhfz5ITIBfR8L+Y7DnKAS1h8a1oPNQ
qFkWwq5pg+BHQrcmMCMEpq2G1UMheLfEzrMyBWzhh84wMADaTIBkFez9Qax73m6YuBEeTBJT+Mfu
QOASQXRS0+BZgvAcKiQoU1gUWZUsBLuvgqkx7PkarLVWr06LxfIHh+i3bdZ+mLYPHowXxPVeDFx+
DD3XQFsfePoKHsUreJkoE50go5ahkqMgbtWdwdcRmoRCJ0/4tU7G/VZ4gcS3VWWG+WV8vNzvUL8E
TPCHH/+BDVdFdqdXPohMFKqoaabTyHWZxHA/mW+rif/vvIRRhxRsv6FBI8PWVtCkWMbXqNTgsQL6
+ImuTN/sAt9CsK2xUEuHHYOtDyXuDpTTlx+6F9ZcgXGVYf5VMQW/oJn+PW/FQNN1YCxJmEsyTnaw
u5v++d23ocMGCCwJPUtD41AI6QqtSsPxCGi6DAK9YXFzsfzTBKi0TESeKVPhwlAxVhDHu80q4UU+
1Qv67oDzURJzusj0WgE/NBLdzwBuREH1GdC5PCzoIJTUpr/DxUdQuQTs/Qnik6DyKKjkBlu+FbFp
fj9CcSfY+z2cug31f4Ffu8DAxtDwZ3ieAMcmQ5vJcD0SpvWFoQvAMT+0rQ1zNsIvA2HiEqhfHfYe
g0IFIeqFIKy6S3e1atXYs2dPlp+vnIDueyI3r9cfirw4NkOPrEqlwtjY+LXmCNl5ZeHT2gZ0NrLM
M4qyLNO8eXOOHDmSp8h1HsPnAqtPhcxkVVdsI0lSOkHVXQh00yE5geyqxHMKOvKUlJSUnkZgZmaW
KwVdOVkslpaWlu6P0t0Y6OK3civq60NvHN4lNUGlUr2RrPr7+3PixAlMtX48dZpQKRVGoqDK2UFE
+CQmwpSR0K8zOFQRxK9yWfE7KQFOL4HHz8G7q74LkE9JOBsOlxZCCVe49QjKD4Bzk8DLFV7EQ6kR
4GwniMv9aEFALc0hsAbUKwONfKDkYBjXGgbUE2OOSYCi38L+YVBFqyS+SAC30dqOWVrvpUYDTj9K
zGgl092AUAaugCfxcMiA1CpTwOlHCO4o1LoDt0Rno6hXQvGs5yYR6CXT0A3c7IT6OeUkPPg6I/Hc
eQc6hcL9EaJQTIftN6DDOvF3/cIwrqqYPgeYcAJ+vwZ3v3qdxFZcBvfjhL/z24rwU1X9c2NOSKy+
AfdHiOvHo3j4crPEmYcyA71gzhU4FQRlMiXf7LwD7TeKG4DoYUKJNkRiiiCYD+LgQA+olil54Npz
aLBKRI195w/jDHzF4VFQd5GIG1vTCqqsgGIFxU1F0BrYdhnOfA3u2tQEdRq0Ww37b0MhG7gwToT6
H7sFTWbB2Gbwnfb9rz2BGjOhlhuceABO+aBXAxi7DnZ8D3XKwIPn4Ps9tKgAywfCk5dQeQzU9oJ1
Q2D/FQiYDq394P5zCLsppvatTMWNWooa7G0gMUl4q2VZqOUm2girimXg0nUo7AJPn0FyivicADg5
OXHz5k1yA3m5oj0vklVDJCQkvJZtnbngy7DwCz5ty1qlUomZmdlr3+2yLNOsWTOOHTuWo+v7P4bP
BVafCoYnvo60JiYmphfCWFpaYmdnh4WFRY6qerlhAzD0dMbFxaHRaJAkCWtraywsLHIteeBj82kz
F3lJkpShI9anaIP7Pu+fubvUm7yob7IYFC5cmBMnTmCs7RGfzwHMzcHEDFoEQGoqRMWIu1AvDzHN
mt8P7Gzg78WwcCKcvQI/94Em34B7J/HFP6EvRO+B2FcQ1FQQVYDOv4KfB2w8BeVHgdMAQcLcXGBk
J4hcKUjyX8NhTi9oWxWW/CP8rL1r68fdaznUKCGlE1WAoJVQu5SUTlQBJu8Bc2OZLyrrH4tJFAHy
M9pk3Bf910FZV4nufjCmMewbBBETRKODr+pCMSeZqecVlF4KTvNg3DH4oszrV8qBeyV+qJORqAKE
hoOXk8Sd0WBiDQ02gW8IhN6GmRdgUbPXier+CLgZDVdGwJousPAaFF4G++7DrZcw66zMXx31x9bV
FvZ2l5nXAqZeEOpqsSxCMqxNxD4t4QhuiyRuRGd8/uRjePQK+teGhmtg+YWMz3vkg/zmQoFffUki
MVn/nLcjnBsiUguKzQdrS0FUFQpY0Q06+0lUmitILYgOVOHPREc0pVpfjFWzJOwYBhN3wuz92vU6
iA5U+28Lf+mVWTAiQCilAVPhwj0oWhCOTITQszByNTjng2PjYc9Fcc4FzgETY9h0CvIXgj3zwNUB
alaCR/vAqzgULAhX/gYrK2jXAiZ/Dxqgmh9cvikI9oOHYpvMzERSBsDTp09xcHB4a8en/2vI6xYF
4LVrokKhwNjYOP0GX1f0ZW1tjZWVVYab/rS0NFJSUjIUfSUlJaWLSWq1+oOKvgzHmNX+S0tLy9Vm
N/+X8dmzmktQq9XpU84gQpl16mpuIScbEBhmumb2dKrV6jyROpAVdKqkYUesrOwJuV3E9S7HOSsV
VVeM9qbXZzd2W1tbUlJEdYuREZhbwqt4cCgA330P330L5cvBoH4wYIgI/+/7k4iiCp0PvuWgZH3x
f7sfoWoF8fehBVDWA7YchogncGgqnL0FM0Phwl0xZR+XAm0bQMQ6+HOUiA8C6DYdyhYBf22MlEYD
k0IlZnaWMdERgljYewXCvtNv0+NY+Oc6nPrW0B8NM/fDwk4Z/adBIVDTQ4FvUf25H5cEoZdh31cZ
99PKUyJndVproRSDBrUa2i+Bw3dg1TWJxedlWpWEHuVERmtCkszw6hn3dYwS1l2F3X1lXOxgc5BQ
ckf+DV12CfVO56s1PJQ9t8P39cS0uYst3B0FM45A6+0ie7ZWMaiaSfWUJIiMA0db8HKWKBoss6YV
NNN2rFKmQuAWGFIHfm4B322DystFokKfChCtFMrw6Mbip34J+GIlnHsCc7V2gQG7FCTIMk+nybRd
DCVmSpwdJKdP77vYQllniYO3ZFQaCbVGxlTbPCC4g4y1mUS1+TLru0L/UJFpGv49dA6GMuMlro6X
yW8NdUrB30MgYI4Y18aLEspUmbXfQrdZMHsbDAuAoc0h5hX4j4ezU8DTFQ6Mgzpj4Vkc3IoS6vid
KGhSHdZPgkWb4bt5MOVrOLIEKnWDYdNg7wLw7Qq9f4Ijq8CvExR2gkE9YMk6WDQTBn4Lvn5w5rSw
AphrixFBqIz29vY8fvw4R9W5N/ka/23k5bHp8L7pLEZGRtk2R8gcv5WamvpWe8GbMmWzI6sxMTGf
/aofiM9kNRegVCpJSkrCzMwMW1tbkpKS3jv66EPwsQQsq0zXrIqlPoUq+T7r0Kmo2XXEygqfgqxm
9/6GXlQgXQH4mC8HkVwg/jYxhZRkkDVCKSrqBt8Mh2aNYflCKFJKqKUBAbB/v1CgrCzAsxFERkH3
tjBmEHQYBJ0bCaIKMHCaRGEHGZ8B8EolyOPg9jBriFhPnyng4QxNtbmaMfGw+TjsH6cf58QNYGki
00XbBvVlIrQLhlKF4Gk83DkPCcnw6y4Rg3UiAs4+EKR5w3nxmqL54F60aP2ZkAz7bkDYsIw3ab1D
oEpRqOaWcT/9sENiYktZS1T1OHxPYmWQTEsfmWO3YdpuUZikVEM5Rwh/DpUMOj912wg13aGGgRJs
aQqj6sOyU9CjOvTaKeF0GGY1kGnsDtNPCII10sAna2YMo+uBs7XIDz0eCVMOw/cGy9yPhV8Owd8D
oF4pmeAj0CEUWpUQ0/KjDkmYm8HkVuJ8m9laxr84dF0lsmgTUqFYfkFUAVqVg+PDoNF8uBAFQRVg
41UN18aLG4+dg2R6r5EoO1viUF+Zcs4wZjccj5AJnwYdgsHrV4krP8hYmgrCOq2VjKwRmajeLnB4
jFjXukHQYY5M2QkS1ybI2FtCPS8Y3Rx+3gaerjJ3F2gL9Kwg4Gewt4Ke9WB8J6GaVx0DV2aIGKoC
NrD+FFQoBU+2w+U70GQorN4FA9vBo2dQpy9c+QsOLoJqQVDEGQ4vhYqBMPl32LcM/L8U6mpAfRg1
AWb9At/8BL36wLIlYG0LxIMqSX8cXFxciI6OThcFdMqbIanJzWzRzxDIadX3bUVfmcmsLjbwTfaC
7MYZHR1NgQIFXlvPZ7wdnz2ruYCUlJT06XIQ5FWSpFwPf/6Qzk+Zi73epVjqUxRyvW0dmVXJ9y3y
+thmDW9DUlISsiyne2Lfp4PX22B4nHXeVSMTkNMEgTQzB2MT0KjFtK4qCezs4Jex8O0YcCwIW/6C
02fhq6FQoTRcvC4IYfAE+LI97D4M7QdA+Do4fB5+WgxPXoB3cRj8hYj96TceHoYKK0F8Ari2gZ0/
Qy2titpqAigTYUE/uBoJVx7AtC3CT2mkED5VCeEdtLIAYxMFJpIGWRbqWXEn0EgK4TFUyzyJlrGz
gFSNRHKqjCpFRDhJgG8xKOOioJyjBicb6P0nHBkClQxUyvlHYMJuiPxZ+Gh1GLoe/rktcflHOYMK
OmknzDsoyNepu+BsKzG8qkzVwlBrKZwfAZ6ZEmhqBksUdYCQXjJqNYzcBMuOgbs93IuDFR2hbdmM
r1GligzRYQ3ApzB8+Qfks1CwrYuGkgWg0QqQTWDfYP1rrj+FNr+LfvexSXD+O/B0zPi+d16A/1zh
/b32A7hninZ89goaBIvOT8FdoGcN/XOyDGP/htn/QP8qsOgkhI0XKrkqBVrMgBuP4cposLeEWCVU
mQ4aI4iKhf0/gJ+2wYE6Ddr9BmfuwfWJsOEcDF4LgfXgz0Owcii0rymW/fsUBE6HNUOgTRUxjrYz
JPZfktFoIKgl1KsM3SfA5qnQqCpsPgRdx8HWaVDfD4J+ldgVJnM7FC7ehCaDIfh7qOoDVbvD0O5Q
uzK0GQwrZsCydXDjHgzsDT9Phy+6w5pV4FJU4sE9mZTkjPFgUVFRr13Ls1LnDP82VON0pCYlJQUT
E5MsG5P828iuQCgv4E0NCz41sjvmOiIrSRJJSUlMmDABd3d3TExMuHfvHrNmzcqRrpaG2LVrF8OG
DSMtLY0+ffowatSoDM+vWbOGadOmIcsyNjY2LFiwAB8fn2ze7V/F5wKrT4XMLVczE5fcwvt0fsoc
OfU+xVK5Xcj1pnV8zLgNkdstXXVFUBYWFunEGIQC+i7tWt8E3XG2tLQUGbzaXWRsAmgkPH1MeBqp
5mW0hvY9zdn8hwprG3jxQlRwH9gliklKVRBfwi2bCxX2ymW4uluoXK7VhKE9LgGsLCFBCUsmQGdt
JXfhBvBtIAzrJP5vPwaiX8KSIXA8HHafhY3HRI6ltaVQy5QpQkkc0RlKu0HFEtDtV7C3ktgwRn+p
afg92JnDxh/02zxmJaw/Bjfm6afVn74E9wEwvx88eAGX7sPdZxK3HsrpXYnKuEjUcZeU0BCRAAAg
AElEQVSp5gaDNklMaSnTy2BKX5UCjqNhQz9oZJDDqtFAwVESC7rJdKoipoT/txsWH4DIWDEtvrMP
lDbIXD39AOrOh5sTRbas4TpKT4AncVC/lILglhrcDGYCJ+6DJWfgwWTxf4IKvt2sYNVxDf7F4MgD
ePgL2Ga6101MBscfhFo7uy18VTvj8w9jwWsSeBeGO1ESe/rL+Br4f5NSoOwUUKaJ7Qv7DkpkIt/f
h8Lc/dDbH+b00D+eqoYOwQpO3tQQNgLaLZOQTOHM/2SmboTJG2D/9+BrQFjbzJE4el0mVQ3rf4Tm
VWHdQeg1E7aMgYYVxLKrD8KA+bDlO7gQIYqt8tsJH+mtv8TvBaHw3Vw4tkgU/c3fCKOCIWwxeLlB
i5EStyNlbmyANbtgwGTo3Rou3YHjF8DNFV68FM0wynjC+StQ2BmcHOHWXWjTDkJDwcFRIuqxuPFI
1rZnVRjB1SvhuLq68i7IrtuTrsgT/t3WpVlBqVRm2ynx30ZeIqtZQTc+CwsLZFkmPj6eNWvWcO/e
PW7cuMGNGzeIi4vDxsYGDw8PPDw88Pb2ZvTo0R+1Tk9PT/bt24erqyt+fn6EhITg7a0Pag4LC6N0
6dLY2dmxa9cuxo8fz4kTJ3Jik3MaWZ7wee9M/D8IhUKRoQVrbuFtU9tZtRHVdcTKK92ZslpHVqrk
h4w7u/fPaejU6tTU1HT15F28qO+DuLg4nJwdMTaF1GSdN1LCvZQRz56k8SpOJmR/PoZ0iUUDVKpp
SviFVOrXkVn7FyxcCu5FYf0aKJAfSvnAruVw9AwMHi+IZ4Vy8Mf38Pce2LkPOmqnkeetFd2vBraB
O48g9DBsPy4IScXBUDA/xL2CGhUgZIKIDNJowKEpzB8BrbWZnQ+fw/ErcD7YwKsaDcevwflZ+m3V
aGDhblgyMKP/s3cwNKigIKiBXvZ6ES9TrD+ETRZK8cYTMoeuiql5ZbLM6K1w+K6CgNIa6pWEUVug
pKNEQ++M58KYLZDfCjpoLQ3GxvB9C2hYGmpPhmJO4DsbqhaTGNtIxt8DuoeIwi1DogqieUFUAmz7
Bib9raH0TBhUHcY1hDgVTD0E2wbpl7c2h4WBGjpXhPqzhHL5NP51sjrjgIS9lcyiPtBlHuy4LrG1
t4xCIc6HrqskqpSEf0bL/BIq4z8P5raDIG2U1rBQ0CgkHgbLjFgFladIbBsgU7uUdl8mwLLjUM8H
lh4GLxf4qqF4zsQYNg3W0GOxhM9kmUL5ZW7MFjc6P3QULUzrT4UD30Nld5FS4GIno06DfPZQv6J4
n87+QpVtOxn2TYSqntDNH249hpZThK968wyoXRFq9YUqveHMchjYFh69kKj7lczVtSLs/9FzqDMQ
Lq+FUV1lmo8AO39BxPPZw9Kt4FcJun8Bf66HToHiHPkzBBq3kLh4Vub6bZEEEBIiot5AxjYfvIoD
SSGhUspo0qB0GW+2bvmbunUz9ePNAtlNMyuVSkxMTNLD8Q1J7NummT+FvSCvWhfycvEX6Men+7G3
t2fQIPEBX7JkCQUKFKBbt248efKEO3fucPfuXV6+fPlR6zx16hQlSpTAzc0NgMDAQLZs2ZKBrFav
rr9Lr1q1Kg8fPsz8Nnkan8lqLuBTF/PokF0agOE0vy6v08rK6oPVvZws5HrbOnQVmrpxf6y30/D9
c/qY6FRflUqVXqBga2ub44UK9+7do1z5cigkUKeITlQaDSQnydy/rQYZRk+35uvAOGJjZBZvtOFh
RBo7N6UQGgsKEwkjSWbVUvD2hAYtwMYKBoyVePBIRpZh2Sz4oh0oldAmCDbOFEQkSQXj5kNBe3Dr
CPGJ2rzUkrDgR6hSDh4/gxItIHiEIKoAYxaCg51Eq5r6fd5rCjT1k/Ason8saCY08VXgWVh/fo0P
gXxW0LqKfh88i4WDV+HElIznYZ/5ULOMgvLu4vEyWiXRMQhm9RGWhVUHNAzfqiAqWoOJMbQpL3Mz
Cjy1KqlaDQuPSqzsI5P50AWtUNC/EczuriEmAYb+IdNmuYhJepkEY5rxGgKXQdPyEg3KyjQoC6fv
QpdgiWWnZTwcoEJRiXqer5+Le8PBzQEC/KDSNPi+EfyoVbbvPIepe2R2/wC1vODyVAj4HxT7ReLw
IJl/bsLlxzIPgwXB/6kd+BSFrvPg5H1oWRbWnoVLM2SMjOC3nuBeEJoGw+KuEOgLbRZAcWfYNg72
nheEMlYJo1uJMSgkMDKSkBQyMfHw+KWo3AcY00lMy9WbIhTW3/ZK7Lwgc34FBE2RKD8Iri6QMTaG
/s0hNlGi0TiZ41Ph9hOYuQU8isLDKPB0EwVP+4KhcjcI+AZ2zIKf+8g8jJKo9KXM7Q0wpCOs3QOl
OgoyXbUS3IqAar6w8Q8YOV5i+WqZDWugcgUYPQ4OHQeFscTmTTLbD5vSom4KTdqY8eShhhOHUjEy
gZgXkJwEltYy5paCsMoaaNmqJUuXLKVjx46vH/R3hGEOaHbFP+8Skp/TPtm8TAjz8tjg7d2rvLy8
UCgUuLq64urqSp06dbJc9n3w6NEjihTRe54KFy7MyZMns11+6dKlNG/e/KPX+ynxmazmAjKfqJ+i
s5QhdCQsq85YOTGto+sgkhvQqb+64HtdCsGHdPR6E3KKrGZX0a8jrjlNVA8cOECz5oIRaTRgbiVh
bCKRkqRBYST+NjKS+XVkAgoJpi+xxtEZBnRUYmMnMWqSJasXqahQP41yZWDGHDh6HPLlk2jUQiYl
BfbthEBtDFSfb8GzuESqWqbTN7BlP5iagpsbBHWEmn5Qqi6smgSltYVYQT9C0+oS3u5y+jgXbZZY
PkrvCX38Ao5ehnPz9MfgaYx47MxM/WdFo4HgnRKL+2ckjr0XQJ1yCsoV0y8b8wr2XoSjv2b8rP22
TaQjdKsnlLT2NQA0dJsBp27B1WiJypNlHKwlulWRufUMCueTCSif4W04GA73ojT89KP4P781rBok
yG3BAcLi4DtF4n/tZNpUECTx3AM4HQHhU/Xb6Vccbs+QGfUnzNsDXi6CLJcy8JzeeyH8ogfGQ9VS
0K4KdJoFf52H/YOh5xoF/mU01PISyxcrCGd/lRmyAnymCVVw5SCRb6tDa18ImwiNJsGqMzD5C3A3
WOewFjJFHaD7XJh/CG6/kLi/VIy7UUXYPR6ajhdFcdO7wLTtsPWMhvDlMH4lVBwG52frCeuPnUCT
Bv6/grmpzKVV4OIAu/8nU+dr8B0C5+aJm6BRHWVeJkpU/04ol3NGQ6920O9nBX49NNzYAPa2cPh3
qNgV+k2CxaNhyfcyDb6Goq1FdrBHcYkyhWReJcKBzRDxACo3gp8mwdSxMncjJPxqy4Sfhzv3oJE/
nL0kExkp0al5Cpv2mtK8VjJfjTLneZQGdZoCC2sF4edTSFPLJCfLWFhKJCllkKF37948fPiQ4cOH
kxt4WxV75lzRzFXsb1Jl/6vI62T1TcitAqv32R8HDhxg2bJl/7ms189k9RPgUymruhM2MTGR1NTU
HOuMldV6cnp7Mqu/RkZGKBSKN3Zp+hh87DZk9s5mruhPTU3N8X20fv16uvfojoSY5jW3UlCiggV3
Lykp6GpC7QAbNi2KwdxKQUEXYxwdNfyzI4VhPVIoXcGIkL22nDqSyt3rafTsBB5lIS4evugG8xfK
qFTgUQw2LhZEa89BCN0ByakyPcdCjepgYQVLpkCHFmJMTbpD45oSpT3Etj6MgiPn4Nwf+m0fsxAc
bGVa1RTELuoltB8LpQrD7cdw6Z4gGtPWQyF7OHoNTt0U6tiWE6BJkylWUITDF7QVXs39lyBsckZS
2nchVPeSqFg8436fHKpgSg8Nxgbf90oVbDkFOydCrTLCk7h0j8yiHXDzEdhbwJy90L2GIKUAfVcp
GN5cQwGbjMdl2SFBhiNX8//YO+voKq62i/9mruTGE6IkIcGCuxd39+IS3IsVd3cKxaW4FIoUKxBc
ChR3dwgWCCF2k5srM98fw81NILTQEl7e9+tei7XIzNyZM2dmzuzZ53n2w6QNSib94K0yP3wLA7dA
pwoQ9E5ykyzDvusiDUpLxCVAgfEwqBoMqa4kf3VbByVzKEQVoEIeuDMbOiwUyDRaBlkifGHKfWrV
sKCDkgx25THsvwqNSqTcJk8GyBskcOKWzI+hIiHlJNyS5Xk0LA4PXipxorWLyuiSuSaUygVHJ0GF
4XDuIZy+B/ung78XLP4eVCqRwt/LnJshE+ilnOPjCBGVSsIkKab8oCTTHZwFJbpAmX5wfCbExsPp
6zKqtz6nDSop9+DCYRLPXwkUaClzezP4eyuEtXgbcHeB2ESRMzckHB0hZxBcOCgTFwdFq0K1prBv
I+z5BSo2hODM8PMimbK1oEwV+OMQPHgkUOYbmVPnZKpXgb6dTazboaVJTQNjZzsye3wCHj4q/AJV
CBoVLx6bSIyXUGvA/Daya9SoUdy/f585c+bwKfinpMs6Tn5o3++SWeuYZE3+/bNqT18zIfya2wZ/
3r6IiAh8fHxSXfdP4O/vT1hYWNLfYWFhBAQEvLfd5cuX6dSpE6Ghobi7u7+3/mvGvwlWaQSrLRHY
SpR+7vKhViQnTlYV9XMXHEiOz5Wc9G4MrVarTcqQt56Ps7PzX+/ob+JTS7p+Ska/yWQiPj7+o5Ld
PgazZs1i0OBBCIKSDKXViWjsBExGCU9fNS2+92De4HBKVneidogL/b99ioOjgJ29QFy0xO5zrmTO
JlLI9w2vI8DDE0pW1nJ4p5GbdwVcXQVCWkncuAztm8LspfDqNQQFwpL5UKIYjBgLGzfB7SOKGvbk
OWQrC+c3KMbrAJU7A2YY0xFuPITLd2H5bySponHxYKdVppCdHUBtJ6JRC4DE83CZzAEgI2CRRcxm
mRevJFzelmk1GJV/MkoEfskckCcQcmcA/3TQ6kc4Mh4KZ7H129xdMH4zhC0lydcVoN0suPEUTs5I
2c/d5ioVkFpVggXbBZ5FyFTJq6JIBgvT98KTuUo1JiskCdJ/JzIxRKJDNduyIStgwW9KstSOfkr1
peTYchba/wThPytK9fFr0GSyiFaQ6V5WZtwueLyAFEQSIDYB/DorCU51CisVnJIrzptPQfvFAnun
yNQfDRncBY6NkpPcD1YdhV6r4M4qaD8NTl6Hk+MVyzFQMvlz9IG2tWD1HqXa2LoBKdvw6wloOg0K
Z4OTc23LZRm6zxbZdFjm7A8ys3eKrDwkc3mjzA9rRFZukzm/TCbw7bs6IgqKdRII9JJ5HimgtRf4
Y4NE64EC56/K3PlN6ZtEI5Rrq3xgXFyrkNje02HRr4qH8J71SmJU/gpQvhSsXQDPwyF/efi2NiyY
Btt2Q4tuELoRcueAguWgUEFYsxTKVwezDFt3CHxTVKZwCYF6jdX07mRi1monBnbSU662Ayf2GfDL
Yset8wYcXFTERVtIjH8bV6qGShWqsHnzZj4Wer0+TQurfAip2TG9W+0JSBIMvoaEr+T4mit/wZ+3
r379+uzYseOzJ4eZzWayZ8/OgQMH8PPzo1ixYu8lWD1+/JiKFSuyZs0aSpQo8Sd7+4/jXzeAL4l3
S65+7lr3qREnrVZLQkICDg4OaWqH8imuA6khtYID76q/aZ2tDx9f0vXvOBD80z5Kjv79+zN37lxU
GgGLSUZQAZKSlaxSQVBOHQ+vGyhZ3YlRy3ypk/kekgR9p3ixbvYbylVVU7uRhu9axhLzRqbHUAe6
D3bgm6A39Okt0eM72LdXplljhWgFZRZp1ErF7EkmTh6GXDkURTR9ZsXqp97bRKvKLUAww8B2cOIS
7DkJ568qpMXVRcQ9HcTrJbDA5EGQOxvkyqr4t1rMsDOZMtiwJ+jjYc8i27IZq2DGSni0WzlPUBK3
/KrAxJ7wMhIu34GHz0Xuh0lY3paVzZdJoFwumeLB0HkBTGwNHara9htvAN+2sHM0lElmI2Uwgk9L
gS1j5KQEoHtPYfAS+O0k2GtgXBNoVw4c3jqqTdkOs/fCoxWkUG4BMrQBT1e4EwYV84jMaSUR5KkQ
zYzfQ4+6MLSpbXtJgr6LYfEuCPaHUxPA/h3ntj4rBHZfFtg5WaLWEEhMFDk6XCLQU/EhzdQLxneA
7vXgdTTUGQ4PnsOJUQpZz9kflvSHphWU4/VbKLI8VGbrAJmyOaHCGBE0MkfmyTx4BqW7Q55Agd0j
lTCMqDjI3VPx5j18Firmh/UjbO2TZegxW2TtfgkBOLMOgoOU5V0niGw5IHN1pYz321jmw+ehQi/w
84KwYwrxTkyEym1FoqLh0iYJUVSue7Hm4OGiJG/dDoP2rWHBMoWsli4Bd+8rU/79usPIfnD1BnxT
E8YNhj5dYOZCGD0dju2CP85A1+8hY5ByvGfPFRIsispzZVJqa6CzBy8fgadhMmVr2PPHfgOFyjty
4ageRzc1cW/MmC0yFqNCWIOzZOfMmTN/9jgnIS4uDkdHx/84+UsOK4m1lgt9l9BaY/H/EwlfVhgM
BlQq1Vdp+QV/3r4aNWrw+++/p0k/7d69O8m6qkOHDgwZMoRFi5QBtUuXLnTs2JEtW7YQGKgE8ms0
Gk6fPv3Z2/EZ8C9Z/ZJ4l6xGRUXh7Oz8j9XO5Iby1qSj5FZIsbGxScvSChaLhdjYWNzc3D76N6kV
HEitdrIVn5PsfQh/dk3+qS/q3+mj1NCyZUs2/7oZlVZAkAERRFHA3kmFMcGMZBGUl6wAbYekY8n4
SDy8RdacDOR4qJ7RHcIpWFzN9ctmBARm/+xClbp2LJyq56fpeiZMFJgxAx49kMmSTWT1dh0ZgkQa
VErAy8nChtVKOwYNh5274PR2OHISNu+CddsVEpLOQyRDgMSz51AwD2xfpbz0JQl8cinerU3ehg1E
xYD/N3BsDRR8axUVpwffMnB4ORTJbTv39OUVUtouWRnVkOHw4Cn8vty2LD4BfCrB3gWKarv5gBKK
cOU26A1K6EDNIlCzMJTPC/2WwbUnIqdmpAwj6DYXTt4ROb9ASuE6sOkItJ8OozrArA0ib6IlulUV
6F1VJt9gmN8Dmr6TFL5sLwxYBk82KVPcTUbB6RvQo7KSLDb3gMizNe/Hsc/fCaPXviXDFtjUH4q8
VYpvPoVCA+HUQsibBQyJCjHceFBiQVs4cEPg1D2Za8n6xmyBPvMFVu+VCfIELw+BA9NTDutztgoM
+UmmSl44flvg8WYZq2Pc8wgo00PA0wmOTZKpMVbkTSKcXSdx/wl8EwJl88LGkbb9rdoL3X4ErQ5u
bAbftyEQkgSth4scOi1zfbXM43Ao3xMqlYEDx6FdQ/jhrXtPbBx800TA0w0OL1Pa+8NKGDQDfHzg
7lmljPCshTBqMlw8CJmC4MRpqNIYlsyE5g3hwFGoGwILp4FeD/1HK33i4irgHyRy44qFui0daNjW
gc61XxPS14XS1expVymcbuM8uX3RyKEtMWTJY8fNCwbFIUAG34waXj83JxFWBDAmKB+Sfr7+3Lhx
471rmxyyLKPX6786sgq20s+phWClZsGVWmGEtIyT/Zo9YOHD7ZNlmRo1anDs2LGv7pp/ZfiXrH5J
JLceAcVqyGpf9Kn40HR5aklHX8ID1RrW8DFl45KXP7W262OM+z8X2fszpHZNPpePqyRJREdH/6O4
oGrVqnHk6BFUGgFRFHDy1JIQZSJrERfehCcS8dBA3d4B7F745K2tjoRKhHm7/PEJUNEk/2PMZpmi
FR3QOap49TCB7afdiYm2UCooktgY8PIVqVhXx7bV8Ry+6ECWbCIP70uUzR3P+ROQJTNcvQ7lqir2
TXo9pEsHCYlQvBhsWKeQhlevIHtOOL1HmWYF+GE+/LhI4OFROUkZbd4bnr+Aw6ts59lmMNwLEzm2
0va8LP0VBv8Iz/Yq1bYADAbwrgS/zYayhW2/7zwWLt6C02tT9l9AVRjUAdK5wM+74OItkVevJbQa
qFcCRjSHHG8TaBON4N0Sfh0NlQql3E/GFtCjMQxopfy97xT0nw03HiiK79WFtml0K3xbCYxuK9O1
nm3ZmRvQbKzIg+cS39WGWV1TWnHFxEOGEFg4AJpXgV4zYelv0LeWwKjGMuXHiHh5SmydkPJYGw5C
h6mK+n1tGWT24z10ngE/H4CBTWFkyPvrZ2yE4cuhWSVY9o7dY2QMVOwt8PyVjAw83K0UhQB4+BS+
aQMlcsCWMXD0MtQYAmtnwNb9InuOylzZKOP59jGwWODb/iJnrsjExst0aAYzR8Ol61DmWxjRAwZ0
UrZ9+RoK14eiecDRXmTHYZmhw2TGT4BBvWHo25ymXoNFNm6Vuf2HjIsLbNoBbXsq8aqiCCHfQdgz
cPMQadhKy8VTJl48h/3X3AndYqRfm1jWHPbCZJRpUyWCySs9kGUY2u41Cw8GMWfwS149txAy2Jtp
PZ5SvrknB9e+QjIrtXTNRhm1BlQaFSaTBckEzs7OPH369P2OfgsrWf3cxvCfA3/Xx/RjCiP8mXvB
x8Kq+qZVmNs/xYfaJ0kSNWvW/K9LbPoP4F+y+iXxLln9O4rnx0yXv4svUS3rr2JwP1VFTQ2fg+z9
FWJiYrC3t0etVn+26lJWfAqhTw3FihXj8uXLiGoQVCKWRAm1nUg6Py1aexUvHyQwYW8+Fva+w5Ob
CRSt7k74gwT8MoC7h5oda2Jw81Cx+FAgTi4q6gffZekON04fNTJ/Ujz2TjBiljv1WjnStFQ4mTLJ
LFyjfODUKqUHE5QrAz+vl3kVoZSf7NpHTbsuKsxmKJQ5kZPHIXt2pb2Nm4JRD6G/2M7BN4/I1IES
IQ2Vv+Pjwac47PkJSr6dZjcYwLs0/DYXyhax/TZDVZGBIRI9m9uWfTcJjl8WubDO9lyZTOBZAX79
ASoVt237Syh0mwjPDiq2R1Z0HAkHToOLI9x7DB4uAi0rwO0nMvfC4fxC3lNVO86AZ7+lzKw3myFd
dQjwUghbg9IC41vJZPJVEsVmbYeHG1LGyQIMXiywfLdMYiLkzSSwsq9M5rdEt98S+O0M3Fpn2/7s
TagzSESNREw8PN+ash3WtuRqA08jIGN6kRM/Srgm40DhkRDcBno0h/m/QINSsGKgbX2iEXJ3EMie
VebYOWhVFeb1S3mM7ceg6Ujw9oBbWyD5t/Dj51AiBLL7w/nbSqnegZ0VYtq8r8iJczLXf5Vxedum
M1ehZBtwdoKXF5SPIICjp6BmCCwcB63ekvwjp6B8K3B1gUsXldjU4yegTj1YNhuaNFAU23otRW7f
hRvHJVQqhaxu2gEIUKaKBp8AFdt/MXLstitqtUD1wtFkzKpixU43Zo/T89PMBPbc8OaPg0aGd3rD
muO+HNoez8qZsaw+k4letcLwzagld3EnNs55RdMhGVgz9jFZi7lx90w0hlgLgggaOxFJBrNBQqPR
8Pr1a1LD/yJZ/TN8qDCC9f/w8YUR9Ho9Op3uqyWrH4pFjomJoX379uzZs+c/1LL/GvxbFOBL4u96
raZG9FxcXD76wfxSHqjW80l+nslVVLVa/dEq6oeOkdxLMC0gyzKJiYnEx8cnqaify8c1+TE+tf3Z
smXj8ePHCCoQVSole1cFskUi+pUJQTbSoG8A83rc4dmdBIatz47GTmRYzWs8f6DCyUNCoxGYvjmA
TDl0tC35AEEU6Fg3mnTpVag0ArM3eFCyko7bV41cv2Bi6ToHHj+UWPRjIudOyTg4gFFQ890YByYN
jGXBSg1Vair3YNPaRipWEsmeXbnPoqLgwEH4fbvtHBauUNrbvI5tWc8xEOQn4Octc+Oe4tk6YRG4
OSsZ4lduKxW2jpyF6BiJDsmm/81mWLsLfn7HAWDoHAjwEahYLOWzNXiuyJCOMjo7OcU+Nu2HDTOh
6ltngmWbZRZtgJv3wdVBURhDqio+sgD9fxIZ1k56jyAOngf+3gLXtsrcfwJth8nk7goNS8LuczCv
7/tENTwS5myS2bsQCuaARv1l8naHwU0EmpeTWbATjs5L+ZsiOeD+LxLpaoJZgj5zYPE7CU8LtgnE
JMDzQzKthkDWNgK7J8oUefsh0W22SJ5gmUl9ZNrVhwodoHQfgcPTFZ/ToctELMCOBcp1KRei+Nhu
HGdrd9sJCgk98IdIrkZwdaOUpK4Gpoc98yFfYwjwVYgqKKrzzzMkGvQQyddE4PpmiUfPoWo36N4B
/jgrULyewJkdSlxq2eKwdg60eFtYwt0FGvSAsuUEzp6V2bYNunSGUiXhp0XQoauSAFi8MGxYJlGy
ukCxauDqLHL2skymHCoiwmXmrnNCqxV49shCjSIxHLvtwi/7nalaIJrJQ+IYNNGROzfMNCz6kgP3
fLl3w4l2lV6y66YvD26a6FT+EUuOBhFS7CFBOXQUr+bM1llPqd3Nl9AlL8lR2p1bx6OwWCSMeuX+
VOsEJMmCm7sbUW+ieBdfc0Z7WrTtQ4URrMd7V5W1FkZILU72XUeDr60fP9R/aWVb9f8F/yqraQSz
2ZzCi/TPFE9rfKTRaEwiep9S5z45rOpgWn+xW+M9BUH4LNPmqeFzJ6VBylhUa19b1dXPPej9nfYH
BAQQ8TpC+UMEjZ0KOycNibFGBAQc0mnQv05EY6fCYpJo1M+fGp286ZznIsjQaXomjqx/hbOjhcnr
/Vk4+iXrZr0hIFhH/9k+7Fj2hvCHRjYeVwIJ6xYKx5RgwclZ4OYVC6JGoHwNHbPXKcUMJg2M5vCO
BE5et0MQBF5HSOQLSuT3Q5DnbXJS67bw4gmsmgO378Ht+zBysqIAurtBRCRERinT+ZKkkBi1SkAU
ZQxGcNQpSTOS9La4gQlki+IA4OwAbq4CiUaZiEgY0RmyBUFwIGQJgMx1BFaMkalb3taHu49B00GK
quqUTBwaOAN2HBG4/pucQj3tOwn2nYROTWHeKnj8DMoVECmYWWLhztRVVa8aAmsmy9RK5ud95xGU
b6ckfnWtJzKuvYRbMjOLTtPg/F04t9627Og5aD5Y5FWkRJ4scH7Z+/fEpDWwYB+E5DIAACAASURB
VKvAziUydbsI2KkFDs+U8PWAl28gS3NYPQnqV1JiiCf+JDBpiczUThDkAy0mwL1QkqbiI95AtS4C
0TECc7+TaDQGTm2E3FmV9Q+fQplWAln9YP9MmUp9RCwqmd83KIpw3c4it+7B5Q0SLk6Kglqlm8ir
WJmISJkyhWDDbFv7jUao1Unk7iOZmDiZb+vBopmKbVrxygKBfrBvre1V89M6+H4MWCTo3ldk5Dg1
+/dItG5iZt0aqPY2WW7GTIGp0+DiURnPdNB7qMCq9TKevgL7r3ug0wm0qBRDfJzE7nMuJCTI1C0R
g7uHwIaDLlw6a6ZRuRgmLXaiVmMd35ZRSOWmk970ahLJxTMmloR60a32K9QagY4jvBjd/jndJ/ly
YGM0ej1kyOnA1d9j8Ayy59XjRPRRJox6C6JGRLZICCoByaSU3EyOP4sL/U/DZDJhNpvTdHbuU/Cu
Imv1r07rwgh/t60fUszPnDnDtm3bmDVr1hdt038h/g0D+JKwWCyYzeakvxMSEpBlOcXUijVZypqM
9TmI3pewfJJlmejoaFQqVVLZ1n86bZ4aPjZb/2OQWixq8vjftMCntt/Dw4OExAQks4SgFlBrRPzy
uRNxV3nRNRiXj3V9zqHWiGTI58abx7FUbu3F5pnPcfdSs+BiQcIfGehb8jIt+qRj8+I3mE0ydTqk
o/+P6YmONFM38BZrDnnh4iYwZ2wsO9fH4+kjUqWJCzVaONO+7BP23/TCP1CFxSJRxOslC1ZqqF5H
UVVbNTCgfyMzYRycOweHj4mE7pIwJICDIzi7qpBlibgYmZDOajJmgizZBXZutXD8gMS5S7YXyMTx
EuvWwvUrtqn3Yyegbj14fFMhtXfuKgS4ex8oXgTi4uD5c4iNhTfRCsktUwgqFFFiG4vkgnIdBZpV
lxmTrISpJIFXWYGl42XqV0653KOkwJofZGpVVJY9fgrDZ8CmXYo6OqwtdK5PEvHsOxP2nRO48mtK
0ms2g1c5RYFcvlEk7JnEuA7QvT6EvYQ8bRSimjNzyut+7jqUaqOM0D0awYROSqIYKGQ0c2PYPB+q
lVEcE7qOFNlxQGJxf9h+XOTOCzj1c0rFeffv0LS/cn4ju8LADimPaUiEZgNF9p+QaFEHFo9Nuf7l
aygXIhATI2M0Q9gJ29S/0QgNu4lcugFXNkhMWSGyfLvMvQsyLyOgeBVFuV4z3ba/sOeQqQI4OcHr
uza7rfCXULgClC0G697aYC1ZD71HAio4e02Nf4Cy8erlEoO/t3B4v0yePAox79VbZMtWGY1aRuek
Zsh0B74PiaXPaAc6fe9IdJREzYJvKFhUzYINTrx8IVE1fzS1m2gYP8eJnZsT6RMSx8JfXXnyQGJY
t1jcPEWMBpnEBBmVFnQ6EZNJRrLIiCoRi1kGWcaYCL6Z7Yh+ZcYtvRZZFpAFgTdPDMo2gMUoIWre
J6xfc317k8mExWJJ07yHv4t3E9M+Jk72SxZG+LOPkN27d3P79m2GDx/+2Y/7P4Z/yeqXhNWE2Qqr
4uno6JgiWepzE73P7e+ZHMmdCCRJQqvVfvZp8+T4pw4Kf5XRn9bJaJ/SfhcXF4wmI4iC8iIXRERR
RmOvRjJKdN1YikVNj+OVyZH2S4sypdxB1HYqUAmYE8wM35iDotXdaR10mpdhJtx91JRp6sO+pc/Z
/jgbrunU9Kn5kHuXEwjMrOLKWROiWqB+O2cGzVKML1uXCiM4GKatUObApw+LIXRjPEcu2HHymMS+
XRKrFpsxJoKrG3j4qIiLk0nnIbB2jwtePsp9UCrLG9p0UtFnsDIPLkkS2bwTmTVHoEFD2z2eKYPE
1MnQvJmtH4qWgIplYfpE27L5i2HyD/Dgus3CCsA/K3RqD4YEOH4SHj8WeRUhYZGgWkloVgMqFlOm
pscthGXbBO7tSVkJa8QsWB8qcPtASuK5bS+EDIBpI2DqPJFnLyRa1RDp01SiZCdYNxVqlEl5DftN
g93H4dpehXxv3g09R4EIBPqAnQ4OLX3/2pduC/4BMLwn1G4roFXBhrEyBbNBx8kiFx/C2S0pyeja
bdBlpGIBdnsnZPB9f7/dxgms2i6TM4vIiVUS74bL95kisnK7hAyELoIS73jBHjkNVTuCjxfc3p8y
TtVkgiY9RY6dkUgwwMn9tsS6u/fhm2rQoDL8NEEJ9/imiYDOVSA+AezVcCJUSroODx5B0UrQqj5k
zCAw8geZZZt1bN8osX+XmXM3RJyclI3Hj5RYutDChbMynp4waozAnLkyTi4CZ194IIoixw8a6VAn
mkW/ulCumh2P71uoVSiSLv119B7uwPXLZhqUiqHXMB1qjcCPYxMwGmVc3EUy5Xfi8u+x1OrkQ4sh
/nTMd5kS9T1p1D8DPQufo/HwzKi1ImuH36Vy10zsX/wQJAlToozaTiQxzoJfLmciHsZjMUvIFhDU
AhaTBBJJhPVrJqvJxZOvDZ+iSP9VnOxfFUb4O+/jP7uua9cqGaBdu3b95P3+P0OqHf9l3Yj/H8NK
nKKjo5OsLVxdXXFycvrbcZ2pwTo98rlgdSKIi4sjOjoai8WCo6MjGo0GjUaTpobWf7fKlCRJGAwG
YmJikghpan39JSqL/dX+rf1pNBoRtUo8KYKA8Nb63mK0EFjInbn1f8feVcPwk5WY0+AYkixQuk0Q
mYu4k72oM57+dnTOd4GoV2baTMjEmmclOftbJG2GeOHgJPLLnAjO7I8jIV7GM6sz47cFI1lkOg1X
Yqge3DJy60ICfcY4Icsy1y4YWTNPT2QEZElnoFtbC+tXWwjOo+WPl76cjgxgxxUf9LEyw6c5JBHV
E4eNvAqXaN/dxioXz7FgZydQN1lm/IplCvlq3Mi27OZNuHMH+vVK2UdTZ8LwQSmJ6vI1irI2bABM
Hge/74NHtyRy5YQ6tcElPYxaLBJcG/wrwQ+roFFVpVKVFZIEC9bDpP4piSpAv8kig7pD51Zw9w+J
o1vhWphEgdZKmILPO6FnRiMs3SLwwzCbSvxtDXh2GkoVh0t3IdEM95+k/N2BU3DlDiyfDnlzwoM/
ZCqVkyndHbr/ILBun8QvP74fg968jhL/K6igWleRyHfCIq/dhVXbZfZsBp0TZK0t8uylbf2Zq/DT
Jonje2BYP4EqHWH7Qdt6QyK0GybQvAVkzCySu4ZIfLxtvUYDUwZKRMeCWgvpvW3rsmaG33fC5j3Q
YzQ07iWiNwqEHhXZvk/Fqyio1SzZR0sQHNquTP8Pmyqzfo+OCtXUTF+kIWc+FeWL25Jwho0RqFJd
xTdlBMpXFFi9VmT1YS/cPNS0rx0LQKmKWkbNdKJ7k1ge3DETmFnFsp2uzJ1kYPeWRGKjZfyDVMwc
m8BPs820HJKekrXTobHXMmVnNsZvycZvi1/y6EYC0/fn4tDacC4djmLUtjysH32PgByOlG7iy/G1
YQzcUQJJEmgyvRBqrQqds5qX9/SYDRZUahFEGYtRQvXWhNfF1QWLxfJVx6z+r8BKPtVqdZJQYW9v
j4ODA46Ojtjb2ycl/sqynEQ09Xo9er2e+Ph4EhISksQOs9mcRHY/hL+qXuXl5ZVWp/s/j3/JahrB
SoQSExOJiYlJCgNwcnLC1dUVnU6XJkTvcxEw6xdsdHQ08fHxqNXqFITvc5Pi1PAp52L9GLCSarPZ
jIODA66urh+sEpPWZPVDg5Y1iS4mJgZHJycssoTaQQOSjKhSIYoCokbEPp0dFqPMg3ORqNQCdYbl
ZGCW3cRFmhjxezkqdM7EjUMvkWXo/c0lXj5KpP2ULDQbGsSB1eFEhiciCFDT7xbzBodTtJo72yIK
MXhZFhYOeErT7u6k81LUz5FtnxOcS8PCKXqK+rykUcnXIIq0/D4doWGZ2fkgExazwNCZrqTzVH4z
a2Qs3ulVlKlsM78e2Sue9t21uLjYzn3ONJmhw0Clsi2bPAkGD7JlggN81xsa1hdJn0wl3LpDmfoP
aZGyD8dPhsH9bLZWALfuKP9mzoCVK+DmdYmIl1C+ElhkWLEN3ItDoz4iW/fD+AXg6AANq6fc977f
IfyVxHftbcuK5IcjWxST+Hx5oExbqNQRzl1T1vebDoF+MtXf8VsFOHlJZGBfcPaAvI1gzEIlA1+S
oOcUgXZNwSrEiCIsnARHNsHP+2Q0Wt4j0gBrtyuxsc+uQY6cEFxH4PgFZZ0sQ7sRAnVqQKkScHCb
ROUKkKehwB+XwGiCFoMEQppDzmzQ/zuZedOgxQBY/NbNYeB0EUEtsGAu7NgmkTkr5KwmEq3wQRIT
oX5Xgeq1RcpVUpO/nEhUMsKcIxsc2QnLN8PvZyQOnVEUq3TpBHYfUnHpOrTsYtt+7yEBlRok4PFD
5ZlUqQRW/KpFawe1KirLBEGgfRd48Vzmxi2ZAw+9KVjCjhX7Pbl42sS4fkoDm3e2p1kHexqViSY2
RqJoKS3NOuro2TKO1jVjCMzrTPMB6dHHStRo68Hw1UE4OIkMqHqHolVc6TQhgBH1buHkpmLEumws
7nMPjU6k04ysTG18iW8HZ8Q3sz2r+lyh6/JC/Dr0Is1mFkKyyJTsmguVnQplaFEunsVoQVSLCKKA
ezp3DAbD+xf1K8HXTKQ/V9usRNZq3m9nZ5dUMtvJyQlHR8cUs3AWiwWj0UhCQkISmbUSWaPRmERk
rYptanj9+vW/ZPUf4F+ymkaQJImoqCgSExOxs7NLSkZKayPj5HE8nworiYqNjSU6OhpJknBycsLF
xeU9cv0lVMmPOUZyFTUuLu6DKurf3f8/wbv7t1gsxMfHExUVhcFgwNvbG0RQ2akwJ5qxc7VD0IjY
p9NRqH0eEqONBH6THq8srqjUAuv7XcYQY6Te0JwEFXBjarVjmI0yMTEiFbpnxd5ZTc2ufsTHmlny
/T0MeomtS2KpPygzsizQY2YGRFHkyvFYntyJp90gdy6fTGBYSDg3zify9JHEzdsq+i/KiIOziqHz
vOk83AMPbzUzB7wiMKuGIqXtkvr9l5/iGTBOl9THN6+aeXjXwnf9bPfJ1g1m4vUWWrSy9Uvobono
KGjXxrbs5Us4dxaGDUipIg4ZJdK3Z8op6NB9EPkGOrRJsSnde0ODBiJ+yTxP1Wo4fBTGTxJ4+FQk
9ABIThLdxotMWQoebnDwhEIcreg5VqRPJwGXd8K+h0wEfz+BYweUkARXHyjbDsq1g1U7YMaw94nl
2m0QEyvRv4dS6jN0MyzbIZCtrsDQOUpM6vRUQthiYpUYrDJlIH8dWLfDti5OD30mwMQRMq6usGmF
xJDvoWpXmLIU1v4G95/CyvnK9hoNLJmtbFOlM9TvDQaTwNyptn22bgobV8D306B5P1i2WWLbNmWq
XqeDXzdJ5M0PuaoJRERC73EiCSaBVRtElv8skL+ISL6yIsnziM5fBpVaKWW6ZIGtg9P7Cew+rCb0
APQeAguWCYyZKrNqrxuzf3alXxcjxw4rEriDg8Cm/ToePpTp0MrMrxstNKhhplVvF9y9NfRtrjBk
X38Vy/d5snaRgQ3LEwAYNt2BvIU01CgYxbel37BxRSLBhZywc9DQf1Eg7Uenp2RNN7p+cweVGqaH
ZuXuJT3zBzymUW8fyn3rwXffXKVwVVdaDfdnZI0rlGrgScXWvgwpc4aBG/Ohj0zk7Nbn1OqXlfV9
ztFqXhFO/nSD0t/lRlAJpC/kg9ZJAwJIZultYJ2An79f0hib1uPop+L/A1n9KwiCkERktVptEpF1
dHTE0dExhdONNeQvISEhibgmJCRgMBi4ePEiW7du5dKlS2lGVkNDQ8mRIwfBwcFMmTIl1W169epF
cHAw+fPn58KFC5+9DV8C/8aspiESEhKSCN4/9d38FHxqYo91+sNoNCZVxbKzs/vTQSG1hLHPjbi4
uCQLrOSwTtkYDIZ/5Iua1s4JsbGxSb64yQs66HS6pJgrUacCWUC2WFDbaUCWyNciJ1fW3aBMnwI4
Bzixs9/vOHrYk6W8H/f2P6bPryVY2PosEWHxdFlTnIL1/enru51OP2Qm5pWJ1aMeoFKL9Fmdh+J1
vRlW7ix+gSqGrc4EQJucVzAazJhNEB8nIckypWq7M2ptRgA2zQnn58kvCH2cCZVKGYzLetxj5s/p
KFdDyRBePjOGZTPiOPXQDVmGZ2ESbevEolFLNG2t4sUzeBomc2CPBZUAvunBaBRITITXr2VkCby9
ldrvWq1S7tJshLq1IUOA4qcZEwMTp8G544pSZ720eYuLNKgtM3aEbXh6+Qqy5oXTf0BwsO0abN0G
nbvB/UcCOp3t3lixTGLkCChZVuTEYRkRmU7NIF8O6DAYnpxTnAyskCTwzANLF0CdmrblUVFQpAyE
h0Pl0iKzRkhkDrStDygJ/XtB72QqIsCQsTBnkaJs7l8LbslCzCUJ8lQRqFBZZsZ0+GUD9OwFtSuI
LBorMWmRwMY9ArfOpCT2h49Bw9aKajtnCrRvxXuYtwQGjILG9WxkNjn2H4bqjSFfPjj5jne52Qxt
24scPChhTIQTV9QEBSljjMkk0/JbiRtXZK4ek7h5B8rXhTk/O+HuIdKyeiyTpom062yL5bh6WaJq
WTMWEyzf5UrJisqH0Io5CUwbHse+0/Zkza7s/8E9ibJ545FlGL/CmxpNnXn2yESjgk9o0dWRfhOV
DjywPYG+LSJZs9eV3AU0jO8Xzy9L9TilU7Pxfl60OoFBte/z/KGRVVezYzZB15K3cXJRMftQMDfP
6fmu3G0G/JSR8o3S0avsLRAFZh/Lxfjmd7h6IpaJBwowpt41LCaZ5mOyMLvdVWp+n4Vnt/TcPxdN
+S7B7J56nUItgzn/812cA1yIDovBZDAjJaa8ZtevX8fNze0/XsI0Ob7mcqZfc/IXKH1nJbqSJLF3
715WrFjBgwcPePToEW5ubgQHB5M1a1ayZMlC1qxZKV68OJkzZ/7rnacCi8VC9uzZ2b9/P/7+/hQt
WpR169aRM2fOpG127drF3Llz2bVrF6dOnaJ3796cPHnyc51yWuDfBKsvjeQlV//KSP9z4mMSez5U
FetjlV+DwYDZbE5Tiyy9Xo8oikkWKp+rupQVaemcIEkSMTExSR6BOp0uibjqdDrlcRQFRK0aEaUy
kCCAWqsiMcaIfyFv8jXJwv4xpynQNJhaU0owJeta3P11vHqoR1QJNBiTh2p9s7Gy+zmOLL6Ho6sG
nYsW/ZtEus7PSbkW6Xl6K46+BU+y7HIeHl1PYPWEF9y/EkdAdidqfedPwarp6Jr9JCsv5yQgq/IC
aJjhCt1GudOwo0IA5o2MYO8vsey+5s2DW2aunTcyrncUWq0yVRvxUkJrB8jg7afGwVWNm6eIxQwX
j8fTa3w6HJ1FHJxEXr8w8+PQSGZvSIckCcTrJaIjJaYNjqZuCwcMCTKvnluIioSHd4zYaZQpZ8kC
/v4Cvt4yp87C/B+hWmXwS6/0W+NWoDeI7Niakgzkzi/SoiUMGpLy+uQIhp4DVXT6Trnft/xiZtYU
M9evyHilg0VToVZlW9b6iClKedkbF1Kqp0YjpM8qMGORmlWLLZw5IdG2EYzrC5tDYegPEHYlpTIM
sHQNDJsg4JNe5NljC6tmQs23bgTrt8N3IwUePZCTwiRehEPNmiIxURKvo+DgdsVf9F107y+wcr1M
Bn+Rk3skkheAk2UoU1PErIab12XqVpNZ9Q5h7dRH5MBxiI6SqV5VZvk7CWGPwyB3XiVZ7Nx1Nb7p
bc+e0SjTvIHM7esW9HqZpp10DJ2sfJQdCjXSuVEc85eINGysjEsH9kq0bGTGbIHJi5xp1MZmlTRp
YDwblsdz7JoOTy+Bkf3MrF1qJNEoM3aJN7VbKs/sldMG2ld8xriFbtRrpRxr2Q9xzBkbg04n4+Bq
R58FQYxqco8GXT3pPMGf+DgLHQrdJGNuHZO2ZCEy3ESbfDeo3MyN3rMCObAhkskdHvPDvmw8u5fI
hJD7uPtoMRkk9DFmVFoRO3sVZpOEZJHQ6NSYEiwYDYpy6uihRZZAVAsElvDh8ZkIVHYqLEYZQ3Qi
5nhb4i3AtWvX8PPz+8sSpl/KmulrLmf6NSd/wZ8T/erVq/Pzzz/z4MED7t27x927d7l37x61a9cm
JCSVsnIfgT/++IMxY8YQGhoKwOTJkwEYPHhw0jZdu3alQoUKNG3aFIAcOXJw5MgRfHx8/tYxvwD+
LQrwn4R1kJEkKc0rb1inJlI7TmpVsZycnD550PsSMavW/jKbzSlUVAcHh8/invC5wwCscbNWIm9V
qZOrz0lEVQaVnQbZZAaNCq2TFlOcEY2TDmO8icQ4E7sGnSB9bg8a/1Se6fnWEx9txNXPkeJdcnPl
lztU7J6Fk+sfc3z5A9x87ak/IT+v7sdxZs19yjRTAj9ntrqGg7OKHiVvgCBiMlmo1SOQ9tMUU81R
NS5SspZ7ElENXRWBMcFCnRAXXoebOXM4nnWzo0CAfI5P0TmIqDUiJpNA/a6e5CnhSL7Sjoxr+xgV
Ej9uz5B0ri0K36dJFzfa9rNVIWtV6gn1WjtSqa6tT8b3eUOmbBom/GSbdXj6yEy1HC/47YY3fhlU
PHlk5vQRI5MHxODtB2Mmy/QeoKiyuXMJXL4sM2a0RGIiWN9jJ/6A588kunQTSD7+7dopER0NLdvb
0uMbNFUTnFOkcrFEytZU07avGa0GBnaHdk1h/iqFIL97yw0aDgFBIg2aqGjYVM31qxJdW5jIWEbC
zg7GDXufqCYmwtBxMGSCiradNcz7wUSz78zUriQyc6TE92NhQH85RTyvrw+cPyeRv5ASq3r56vtk
9eZtWLVeZvtRe34YZyFbcTMHt0jkyaWsX/8r3Lgjc/mZPc+eQL1yBirVl9n3q+KQcOQ4rP9V4tA1
Zyxmmbql4vm2iczmDcozIknQpp1IibJqvP3VlC5s4Ph58PFVCKtWK7B6IwT7K8p5/7E28lmhupaZ
yx3p0U6Pm6uApze0bmKm/zR30mdQ0695BD5+ImWqKBdv8BR7noVZqFwkkTIVRPbuklh9LjN3LhsY
GfKcDFk15C+uI28xHRNXeTM05BVBwWryFNYSGSFhMkogqlh3NQ9arcjUXdnoW/Em2Qo5UP5bd2bu
y0rbAjdYPu4Z7Ub4MWNPVrqVvkVQLnt0DiIaO4HeFW7i5KYlWylPHpx9Q/nuwVTpm4OxBXdTvE1W
ynTJzqRCO6gyojBaBw3b+p+k7qyy7Bp8QnECMMnc2vcUi8GCc3oHEqON6NI5kAiYEs1KIDWQO19e
Lp47n6q6llo2u8ViSVMi+zWHAfy3wvqeCQwMJCgoiPLly3+W/T59+pQMGWxjbkBAAKdOnfrLbZ48
efI1k9VU8W/Mahri71ax+qd4l0gmT/SyWqe4uLjg4uLyl9P9H0Jan4uVpBqNxk+ORf1YpFUymtXp
4V23BIWoCiCDqFMjatSoHbT4V8mOKdZIgR7fIJstqDQqRAcdGp2aysMLMzn4ZyLuRFFryjf0udyU
CytvUbJVIBNKHWJJ29MEFfFg2pMGFG+ZkcNzb9N2ejBPbuqZ0ugyj67F4OJtT6tZ+RiwswRmg0TD
Aco8ddRLI1ePvqH9GGXQio0ys3DwM5xcReoEP6R60APGd3uFLAqEjAlkzb1CbHtTHCd3Le2G+9Jt
oh9l6rpipxM5fzCWzqM8k8716QMjD64badvfNr8d8cLMjfOJdBlsU7IlSWLbmgR6jXZJ0aejur+h
XA0dfhmUD66AIDWlq2iJjZVZd9iTY0/Sc1Xvw7JQD17HCWh0MHGKgJcvlKuoYtp06NwV2rYHN7eU
98rQISp69NPg4JByed8uFhq11vHjckeuRDjz/Tgds1YIeOeF+AQoXjTldTebYdV6gdFTVEn3Y648
Ikcv29E4RMRghEk/Cuw/nPJ3i1aAnU6kbWdFfenRT8PpO3ZcfSgQ9I1iht+n9/v32bnzEBYG05Y4
MnCMQEg3kYQE2/ruA0TKVVVRoIiKlVs0hHTV8E0NgU3bISoaegyAEVO16HQimbOKHDiv49lrkfxl
RSIjoWVn6NhbS4YgkYxZVOw+48jFywLVa4lIEsyeI3DnLiz5zYXpyx0pW01HqcIS4S9savbkseDo
rCI4nx3VC8WlqKZXu7EdY350pFUTC7UrmWnc2YkW3V2oUMeBITPS0eXbWK5fVlRHQRCYvsKJhASJ
bRtMrLuYkcCsWio1dKHzKC+6Vn9B+BMlrrVKQye6jkhHhxqRfFvsFb+uMjD7RF6CcjrSu9wt5boU
d6LfooxMaPuIhzcS8A2yY+pvWVk7OZw/dkVj5yCSJY89c/o+Yf6gF5RoEUSOst44etoz6HB5uq4r
wZFFd4l7lUif3RU4Ov8WYRde02VLBXYNO4N3DlcKtcxG6PCTdNhVB9lsocyosjj5OOGY3gljgoTZ
KKF/HovKXo3aTo2ofSsmWCQKFCzAmTNn3rvm1illtVqdFEJkb2+fFDtpb2+fNB5aZ8veTQIyGAxJ
sZRWJ4L/VnztRPqv2pcWlcE+Bu9e86+5Dz+Ef8nqF8SXKIVqPY5V5dPr9UmJXjqdDjc3NxwcHP6x
upsWZPXdjH6rOvxnGf2f45h/93epWXolT0az9pEkSbYYK1lG5aBBRkAymnAJ9uLp/luUnlaDh/vu
YIhJpMzkagiAxkHN+g6HiAnXU6J9HioOLMj6NgeIi0zkwLx7uGRJh0ot0uxHRWLbNOgCpkQLu+c9
pX/RU5zfF0GZVhmZfKUipZpnYGnXS1TrFICbt6Iozutyk8BsOk6FxtC5+G3qeF8iLsaCXx5XWkwM
Zn1MeeydtXSaFMS3vdLjFWDHleMxvHpioEFXm3fT7H5PyZxbR67CNiVtYrdwytZ2xjfAJg+O6x5B
8QoOBGWxLVs9V4/WTqBiHZv8GBcncfqIkZ4jUoaYjOwRQ8mKDgRmVn4viiIFiqsJfyozbbUHpyL8
Cb3pS4EKDixbq+LZc1i7Grp1kTm4X8Zkkjl1UuLpEwude6a8/8MeSVy9vpq3LQAAIABJREFUaKbP
ME3Svlt3tuPkAxccnAU8fURyFoKOPUQePVZ+M3QUpPcXqFTt/fty9w6BET86U7+tjoZtoH4rkSdP
IT4eRk+BUVNTHt/HV2TnMQ2iGqJjoVdfkeQJ47IMfb8XqVZfw7etdRy66cbxcyKFKwjcfwg798KF
yzLz19i9bb/AkHEaZv6kpW0PKFsT/APVtO5om5709hEJPaXD1VtFliKgdRAZPMF2Df0ziOw+48jj
pwLFvhEYM05mznpndDoRURSYvsKRMlUUwvrqpcS+3RJLFphZut+bJXu9EdUidYrrU4x5dZtpsXcU
SDBAk862j5bGnZ1o+70rzSrE8PyJGUmSGdxRj0qtwsNfy/jO4UnbhvR3p9K3rjQv8YyEBGXfRcrZ
kaC3cP+WiRV38hNc0InxO7LxMiyRqR0fAFC1lSf1u/nQs/xd4uPM5CvlRNPvfRje+D5t8l1D0jlQ
OiQjZjM0Gp+LXpuKY4w3s6jFaQrV86dGvxzMqHII72An2i4pxpr2J3APcKTexCIsrbuXqkPz45nJ
mc1dDtNifXUODT9M5WkVMOtN5AopgMZRg87LEWOcEXO8CVEUEHRv7wMZKlWuxKFDh967lz6E5NZM
1jCu1IisVbwwmUwYDIYU1kypEdmvmRB+zW2DD7fPZDKlSViFv78/YWFhSX+HhYUREBDwp9s8efIE
f3//z96WtMa/ZDUN8e5N+yWmzq3kKD4+ntjYWARBSFJRrTGTnwOfk6zKspxqRr+9vX2aJhj8nf0m
b+ufebha928ymZQwAJWIoBIRNCpkWfFRlWV4feEJbpnScWnWH0TdiqDhztZIkkTEzZeoHe0oMbg0
oiBQaUQh9ow+w9Ut98lcxo/+t1tjjDWRs2J6ggq5c+m3pxxZeBdRLaLxcaXnwRpYTDL1hyvZRo8u
R/PkegyNBgfy5JaelUPvcS40grDbBnYsjyG4cnq8MjrRcEBGRm7LT4WW6Tm7MwJ9tJGqITbFdH7v
xzTo4oWTq/KSlSSJgxui6Tratk1cjJkLv+vpOsKmlhoMEn/sS+C7kSnNvJdMi+O7kc6Ioq3fpvSP
InseLbkLalL8/tg+Iz1HpCwBuWRGPI7OImWrK2Q3QyY1/Se54hOgpkJdZ6at8+ZBuJa2bWX8fGSa
NYbylUWc3glT7tPZROVaWjJkTDkkrlyQiEYrcPCuN1vPenL5joo8RSGkEyxfKzBm6vvhKMsXmTCZ
ZL4N0dF/nDPHH3nyKl5NzhJQvxW4p1PxbfP3X1wLZkr4+mkIvebFnn0ihYoKXHtrjRW6B27dlpm2
VCHw3r4iR247kyW/hoLloH1P6NpfnWSeb0WDZhqmzLfj7iPwTv/+8+rkJDBishpDIkRFyTx5lPJj
2stHZOvvDty8KaO1FyhR3nZNRFHgh5WOlK5iR4kCEu1amOk7xY0sObU4OomsOORFTCw0qagHQJJk
ujfV4+qhpVF3T1qWfsXrlzbj2x6jnKnSwJG6xWIY0D6OI3uNLLuUkzmHs3P1tIHpfV8AynM1dKE3
gcF2tCz+nO2rY+hY+RkN+2cgcwFX+ldS1FRXDw3T9uXk4C+RbJmvkN3Ok/3JVsiRjkVuM7blQ9bP
CMcjyBGndPYMCC1Jm/kFyFzEnXElj2LnqGLQ3lJc3v2MPT/eou7InGQt4cGkb/ZTtGkg5bsGM7P8
Hkp3CqZAvSDmlNlB+61ViHsRx5XNd6k0rCg7O++m7sraXF1yjqIDSmOKSSRTw/yoHbTKVL5ZRu2g
RdCIIIrUq1+PLVu2vHedPhUfQ2S1Wm2Sx6g1f0Gv1yeNcVYia01q+hoU2f9WshoZGYmHh0cqv/hn
KFKkCHfu3OHhw4cYjUZ++eUX6tatm2KbunXrsmrVKgBOnjyJm5vbf10IAPybYJWmsH6tWvFuwtDn
QnJDY2tGv0ql+luxqB8LqzXX33U3eLfN1qz/5LGo1iktFxeXv9jb34MkSURHR+Pu7v6X21orYX2o
ralBr9crA5RGhSCIyEYTooMW0U6NbLRgn94d/cNwVHZaZIuF7A1z4xjowsW5J8ndIj8Vf6zGsuxz
8c3tyotrkegjEshcNoAOoXWJfBTDjJxraDAhP8eXP+DF7Wg8M7sw+GI91Fo1M0v9RmAOezovVcoS
DS18mLgIA3b2Kl6FGRDVAgG5XBj5e2nUapG7Z94wvvzvrAgrjXM6hZB0y3WKKi3S0Wq48hUedieB
zvkvseFOTrz9FXV2xcQX7FwaydY7mYmLloiKsPBD3xfcv57I8HmemIxgMsr8uiSaGxeMjF/sjp1O
wE4Hty6bmDo4mv130uPjJybNPBT1DGfWzy6Uq25TW8f2ieb0URO/nfdM0ccl/CPoM86Jxu1tJDgq
UqJMhudsOpueLDlt5Grvr3q+bxKBi5sKySLRvI2a1p1EfNJD3gyJ7D7tRPbcKRXPggF6ug91oFV3
2/4f3DHTqlIEES9kmrfRMHS8Cm8f232QO8BI71EONO+U8jnfu81Ar+YxeHgJrN6iJX8hG7F8EymT
N9DAgi3ulKmiQ5IkhnSMYecvCYwdLTB3PtRtacfA8e9X7unRPJa9/8feWUdHcf3v/7UedyMJEhII
GiC4hgSCuxR3CsUJFCvuTiktpTgUd3d31wQSCBHirpvNZvX3x36SsIU60H5/p885HHJm7ty5M3Nn
9rlved7HVIz7RsaE6cZzUq/X06xmAXZuEsKDNTg5wZnbEsRiw7m1Wj1+Pkoq1TNFKhNzdl8ux66b
4F25mEwvn6Vi1xY11g5ihHodpx5ZFR0PhsSq2iXSUCrhSqwrNnbFx6anaPmiThIVq4ioXF3Mzg0F
HHzjhbmliNn9EnhyVc7p1y6YmRWPp7V3AslxGna/qoJLaYOlOPyZgpGNXjF+mSPdRxi+OfIcLW3L
vEGp0DFlT2UadnYkN0PNSJ+H1Aq0ZvJWTwDun81kTrfXLDvrTZX6FuxalMjWuXGY2UhY8Lg5tq4m
LPK/iVatY87dpuTnqple/RJla9syem9dQi4m822nO0w814RS1WyYXeMiJavbMHxvQ75teQ15uoqg
661YWucUMispzaZVZ3uPiwTOqUP8k3Ri7qfQaHpDLky8SN3pftydfw3XQG8Sr0WAUIAmVwkI0Gm1
CMQi9AUaVq9ezeDB7wj9fiYUljM1MTH5YMIX8MEY2b9T9enPQKFQIJVK/5XJX78sBfsuQkJC2Lp1
Kxs2bPjo5z1z5gzjx49Hq9UyZMgQpk2bxvr16wEYPtwgQzJ69GjOnj2Lubk5W7duxdfX96OP4yPi
PzWAzw2tVovmnZI5H1vu6dey41UqVZFb+lPhr6obFMbP/pGM/sIwhk9ROrZwLL91DYW6s0ql8k+r
D+h0OsNzlooRioTo8lUITSXYNvAm6/Zryk9uR8TqM2g1Wkp1rUX0nrtYl7IjKyINWy97hoaN4vqM
S9xbcguZpZSK/avzYutjxj7ogVNFW1b77CExJB0zWxlV+1Tk+Y6XDD4QQMVAN5LDs1la7QjLggOI
Cc7m1IpIop5k4FTGirqDyuL3lRdT3Y8w8VhdKvkZyN/MuteoWNeS4WsMltiwe9lMD3jM/riaWNqK
0Wr1BPm9QJWnpd0QW+LC1USHFvD8di7qAh16HYjEAqQmArRaPRZWYsQSIQj0IIDMFDW2DmIQGFQC
dFo98hw1YpGBzGo0YGFlsKLnZOroM9KM8pXFlCknpoyXkA41M1m21YrmHYoJ7Lkj+UwelMOd5BLI
ZMXPb2LfdJISBGy/bKxpOKh5MtYOYpbtdeX6KTmbFmYQ/lyJUAhOJYRceGyBmXlxP8f3q5g0XMm9
RGdk78he6XQ66rikM2iqDef2yIl4qWTUBAljJos4sk/L/Ola7sbaI5Uaz6nvFyo4sE1FbX8Zp3fl
MnSUlKnzhJiYCJg9Scv5s3rOBBuT8RsXlIzrkYVGred2tA129sZkOjNDR73SWQybbc+2JZk08BPx
447ieNwDO9VMH6/hUkIp8uV6hrdKIiddw6VHUmxshKz/Ts13iw37BQIB38/MYvf3Wew5a0qt+mJe
PNPSvkEeG6+VplR5KcP8Y9GptJx5UkxYv52jYNeGAirXNyf0voJTL50xtyx+R5LjNXTxTUSerWPb
Qy+8qhieoUajJ6hNDMlvVZx44YRYLGTrylx+nJ+NQ0kZVtYifrxZvqifu2ezmdE1klVH3ajTzJwl
o1I4ty8HrVZPh9FuDFhoSFCKDctjXJ3HDFlYki5jDKK7B79N5Od5cTi6SclM09JlUVX2THhGpxne
tP3am9z0AqZVvYhvxxIMXudLcoScGTUu0W1BJVqOLcfpleEcXxTGotBWxL/MYXngNTxq2aPIUpMY
lg1CkJoYCJReDyKpEE2BFk2BFvQgszUp+gX2aOdN5KnX2Pm4khmWilpegFapRigWo1OqQCoGtYb5
8+YzbtwHgpc/IX6LcBWGCHyIxP4WkS30jn0MIqtQKIqqTv3bUHjvPqSQc+3aNe7cucPChQv/gZH9
n8N/ZPVzo1AsuBAfQ+7p9+rdA0UWwE8hyfQu/qie6x+xon4IWq2W3NxcbN7V3/nIyMjIeI+sFmq4
Fo5VJpP9qaQutVptuPcyCag1oNMjMpchNJeiy1Ph8aU/sbtuI5KJaHpmPJcaL0Gj0uLWqiqJ54Lp
cqwnacEpXJt2EedarnQ81ofjHffgVNqERkHVOPLVVRJDUqk1rBotV/hxZtwVEu/GM/lRBwQCAcvr
Hif9TTZ6nR6xiQSNRke1Nu4M3F4fgH1BD3hzJYnFT/wQCAQkR8iZXPUyG17Xx8HdBLVKxzjf+4iF
erxrWxF2P5eYV3mIpUKs7KRY2MmwdjNBq9YR+SCTeRdr4uptjpmFmAOLI7m0OYHN4bWL7tepn+LZ
PTeaXXF1iqpYxYQpGFnjCXve1sTWSYI8W0NMWD7T2oZStaEVWo2O5CgN8kw12RkqNGrwqiShThMp
vvXFVK0lYXinbDr0NWX0O+EGGo2O2vaJrD3uRB2/YmKbk6XDzy2OXfdL4VW5WPZGnqulqUMENvZi
5NkaegySMjxIShlPEfW8cunxpQVfTTFe9K1fJufntUpOR5VBKBTw6IaC+V+mkJ6kRiKFoLkW9Bth
bFXNzdFR1z2d5XudadLGnFfPCxjfKRm9Vsui1WKG91Wx87I9NepKjY5T5utp4J6MmaUItVLHluMW
1KhTbC2eOTaf29d07H9WiqwMDQPqxSGTaNl/ToaVtYAapRWMX2pPty8NC74CpY7JPdN4ekfB1oMS
erZWsmK/C03aFF/j9pXZrJ2Twfq9JsyZWEDVRhbM2uQKQF6uluEBsWjytZx5asXzh1p6N8ti7TUv
ylUzY0qnaN6+zOdkqDMmJv/TSH2tpqtvInq9gE7DbJnwbXHVBqVCx5eNo5GJdfQbb86sLzNZfKEy
buXMGFnjKdWbmDN7l0dR+2M/pbF2chy+Tcx48aCAxQ8akJlYwJyA+wRtKY9fD4N78/GFDOZ1CmHx
qQpU87Pi+I8prJ0QhVAi5If0jkhlYl5eTmZ1+5tMOt2Qin6OxIZkM6feVQb+WJ3G/UsTfCGZ1Z3v
MOVcI2TmYpa1voUiRw16PVaulmTFyfEZUJUKHctzqMdR/Fe2wKWmK7ubbKXFz1+Q/Sadh8uu03TT
F1wZdsAgVScQUJCTjy5fg8zODJ1Gi9TREmVijqFoAEBhUReNjpEjRxbJEX0O/Bbh+r3jgA+S2HeJ
7N/Vks3Ly/tk+Qt/F4WJth8yEh06dIjMzEyCgoL+gZH9n8N/ZPVz45dk9e/oeup0uiKLJPCbVr5P
7T4vxO/puf4ZK+qH8Gfc9H8VhYRbIBAUPR+tVls01j+7gi8oKDBYgkVCQ1q3RAyF7j21BpGpFIFY
jF6tJuDyJG52X4cmV0nDnwfx+oer5EclITGTkv46FfsKTvR9PIKUZ0nsrvMT7jWcSHqRjkAswqeH
Nx3WN0el1LDCZR1DDgYgFAs5O+8p0feScalkT8CsOrjVdGS518/MfNYO53JW6HQ6JjkdZNiW6tTq
YCANCwJuokgvoE57B56czyDiaTZiiRBHD0tcKlji7efIy0vJqLI1zLjSoOhaJ1W6TNM+znSfXkwm
hpa8Qb/5pQgcWExIBnvep/N4FzqNcS3aNrlZMPYuMqbv8izadut4Bkv6veFQci2kJsVzpEepR7Qe
4oSphYinl7OIDS0gM0WJqgAq15DRtqcJ9QJkVPCRsGp6DheOKTn5ooTRD+DkvqkkxgvYfMU4sWDp
+BQeXFPz85NyPLuZyw9fJ/DmeT4VqooJC9ZyL8kJSyvj+VrPNY2xS+xp39/4/Zo/PJnTu7JxcBaz
dJMFDfyLieeaBQoO/azm5Gvj5IcVk1LZuzYHW3shl8OdjCy4ABuW57HjRyUnojxZPTmJA2uzmLbY
nEFjpERH6Aj0yWbn/ZKU+5+1UqfTMa5DIs9vK2jYVERYqIhjocbn1On0rPg6k/3rsyjrLWH/45L8
Eoc35bJoXCpmZkLOJ3sZvbMKuY6vmsWSn6MhJ0tNi34OjF5muK+qAh0T2kSTFlvA8RAntBro5JOE
V11rvphSkqBGzxk4zZ5B05yK+svO0NDfN5L0RBVTdlegcVeDdTn+TT6jaz/ji3EODJlj6F+j1tO3
0gtS4lSsftkEZw+Dl+rWvkR+HBrMypvVKVvN8H09/n08P8+MolI9C0Lv5zFoe31OzHuBibmYqVcN
dXEvfBfO0TkvWBoaiI2LCQ8Ox7N+wENm3fLDpZwlqzvfIexmGgKBgBLVnclNVmBXzo4+p7pxZ+UD
ri+6w8hXw4m/l8ChHkfofX0Q6S/TOD/yFL0ej+bOtPOkPkui2d4+HG38I3W+/4LnC88hkEnQ5qsp
SMlCq1AjdbBAm6cyED21DoFUjF6pAmDgwIGsWbPmvWf0KfBbhOvv4NessYWW2j9KZOVy+Qetvv8G
FBpkPuQ5Xb9+PSVKlKBPnz7/wMj+z+GDD/fftzz5/wgfkq76M2oAv5Zx/nvZ8Z9LIuvXzvOuCoFa
rcbU1PQvZfR/ruvIz883Ko37VxUTFApFcciCXo/ARAZ6PUITGdIS9ghEQvQIQK/DqWE5rrX9HlW6
nOYXgpDZW5B0NYyc2GxMvFwRikUErG1HQZaSw622G95eKwvaHeuPVqWh6ex6AJwacwmNSsv+UXfY
2PkSsc8yqNypHKMf9KBSew8OD7tClVbuOJczEKuzi19gaiXGsbQZx5a85pua13hzL4OsVA0Pryrw
alcWj3ouVG/rzoKQlow+2AD/EZ68vpZWlKwFEPUki5RoOa1GFBOhO0eSUcjV+PUqDt4Pvp5JZnIB
LQcVb8vL0RB6N5fe096piwpsmhZH57GuRkT18aUs5JlaenztSo+Jriw+VYmdkTUoW82S+h3s8Wpk
z96tGvo2TaO6VQK7fpTj21BGVnrxe6bR6Lh8QsmIOcaLHp1Ox8kduXw5z0CcqjWyZONdb47EVCH8
lUF7tHvDDC4eV6LTGebhng15aHV6WvV6f8F5+7ySYQvdaNTFhqEds/myUy4JsVpyc3T8tCyPyavf
X3T1GWuLTgd6gYhWVdMIfV68uM3J1vH9/FwmrjaMb/wyF749UZJVc/MZ2lnBjFH5+DY2LSKqYLBe
fX/SjZa9Lbl0VoOXz/uxfUKhgIYtTRAIIeKVmsvH8t5rU62hDPQgl2s5syvHaJ+ZhZD1l0uSlakl
Nwe+WlT8HKUyIStOlsHKQULXGinMGJwBIjGTd5SnrI85C09XYuvCNI5tzii+zgwtOZkaBGIhz65k
F2138zJl0ZlK7Fmewtkd6Wg0emZ2i6KgQEhlf2cWtHpU9D1t2KMEHSaUZVrzYHIyDCSvRqANGrWO
Z9dzmP+qHdXbuzPulB/xL7PZPeEpAM3HelGjvRtz618zWOW7uNF8hCcLmlxnhPMJ4sIUOFdxwrKE
FYOufcGgS92IvR3HjSV3qDehFp7NyrC9wQ48W5elwaT6HGy5C88O5ak2uAaH/TYSsKETQrGAh7PO
E7C1Bw/GHaDe2h4oEzJx/6IOInNTLH3LolGo0CpVCISG74NeqTIsdMUitm3bRt++HyhH9gnwqRKY
fq986bveK61W+6sSXGD4ffm/VqY2PT0dBweHD+77D38M/5HVz4g/qgbwS91OsVj8pzRGP7dEFhRn
yWdnZyOXyxEKhVhbW2NpafmXVQgKj/kUElkqlYrc3Nyilf3f1Z3Nz88vTjYTgMBEhsjFDqFMgn0v
f7RZuYhtLXHq6YcmV0nyrTfotBrKdKsFej2XWn2HqZMVLW9PRatU496wDKlPk9hQagUFOQX0fDCK
LheGcHvKWWoN8UFmJeXGsgcE7w7D1M6UCn2rM+T5V2jyNTSfXQsARZaSiKtxtJtTFY1ax4tzCZxb
/oLU6DzmNrnJzX2p5OToKNvAlfkJvQm62Y6ACVWIfZxGm2+8i67t5MJQrBylVA4o/tj+PDYE/35u
RclYAHtmRtIlqCRSWfFnZdPEKNp9VQJTi2Liv35iFOV9LfCoUmyBeBuqIDEyn85jjLNU1018S4ev
nDE1Lz4+M0VF+JM8hiwtw1eryrI+uAaHshrQcZwbWr2Qmxc0+LnH07VmEttX5zB/VCbObmJqNjF2
ze/4NgtTcyEN2xpbSNMSVGhUen5+XY3qLeyYPCiHgPJpHN+Tz9qF+QyfZYdEYjxHLhzKJSdLQ8dh
9oxZ7s7ByMqkZ4sIqJDB0A45OJaQGrnaC/HT3Cy8a1qwP7oKPv7WdKufzvpleeh0ejYsU+DsLqNp
x2JiXCfAnKMRZQkL1XH3egHDZ384wTE+UoeHjwX3rqgY1jLJ6HugKtAza2gq3Se6MmG9J5N7p3Bg
QzFJ1On0TO+fSp229nyztyILRyRzeFOmUf8Pr+aRr9Dj5m3BgBoRaDTF/ZuYCll93oMCNVw8qmDZ
9SpFi9QqjayZvq8CK8clcf14DvJsLaObv6VGG2eW3GvA+e0pHFwVV9RXxXpWTN5ZnhUjYpkQGE7o
IyWLnvsz7mAtRFIR81s8Kmr7xRxPKvvZE1TnGfdPpzGu9mNqdPPAvboDazveBMDKyYSgc025tiGS
u/tiEAgEDNjoi5mNhGUtbnFhbQSXNkQiEAsxd7QgKHoYAy93ByHs63YS65JW9D7akesL7vD2Riwd
trVGIIKDXY/QeGZDXOu4sqfhVvyWN8emrC3HWm+n07lBJN6OIut1Kj5jGnF7wHb89g4h4ocLVJjR
EcWreFz7+SM0kSK0tkRgJgORwBBCpNeDSMTx48dp27btB5/1/3X8npasiYmJkWa1RqN5j8gWhpj9
k0T298iqo6PjB/f9hz+G/8jqJ8Sfsay+S6AKNUYtLCyMdDv/KD6HRFbhedRq9Uexov4aPqZ19d1F
QH5+fpF0y98N2FcoFMahClIp+nwl2uQMzKp6kHHoJmJ7ayqfmE3q/uuYlHLEc04v9AUaEAo412Q5
ApGQdi/nIrE0IenSS+Jvv+XO/GuIzWTU/toPx2quJN6PJeV5InqdjuWu67ky7w723o6Mih1Po5lN
ODviFN4ty+BY3jCWw8OvYGEn48KKUILs9vFT9+voBQIGn+nA7MxhjLzXDUVqPi1n+hQN/fCEe5Sq
bkvp6sXXc21DFJ1nli+az9kpSiIfZdB5UumiNm9DckmMzKPtyGIrW0qMkugQOZ3HF2/T6XTcPpxB
n+nFIQEAa0ZH07iLPbZOxeQ3MUpJ7Kt8ugYZW2B/GBdN5YY2uHkZk8+re9LoO6cMW6PrsTOhPj5t
nNm1XsmxHXko5Dr2r8smK71YnWPHqmyGzHExks0CWDEqgRZ9HXF0lTJqZWmOpNagWX8nZo3KISFG
jZmFsMjSWjT+qZn0n+qMialhzts4iPnhihcLDpThyX0VCrmWJ7eVRsfER6s5uTuHqVtKIxQKmbKh
DMvPlGPjSgXdGmSwdbWcGRvfl5ixtBZhZinCtoSUES0TuHpcbrT/wVUFj28qWHq2Ihue+hAXo6dT
1UQUeYZvz7YV2QiEIgbOKUVgX0dmHyzP0gkZrF9gsHYe2pRLXLSWybvK06CjPTMOVGDF+BT2rTXs
z87QMqt/Ir3nebL4mi8CiYjBtSOMvm0psWpSE9RY2MtY3PON0fjqtrVjzI9ezOwTz8iAaEztTAja
U51SVSyZerwm22fGcvNQWlH7hp3sKVvNnJB7cr4+VRcLGykyMzHTztcn+nkuW8a9BAzfirE7q1JQ
oGVepxd0WFqLAdsbM+JEAKnRefw8wiC6X7qGHQM312Xb0EfEh2YjkYloN70CL6+ksHdqCG3XBTI+
8kt0Gj2HBpxBaiah/9kuRFyK4daqh3j4lSRwQSP2dTqCSq6i95nuRF+J5u639+m8twPqvAJODzxG
56M9yI3J5P7CK7Q72IfHiy/h3KgMjr7uPJ50hDoruxI64wBVl/cicedVXAc1Q5+Xj4mHK0KZFCQi
QyiRVgsCATdu3MDf3/+9+fAx8W+ThnqXyBbmOPxbiyL8Hll1cnL64L7/8MfwH1n9xPil7iYYWwq1
Wi0KhYKsrKwiAmVjY4O5uflfLin6qSyShSi0ohZq830MK+qv4e+S1cIP2C8XAdbW1kXxs3+nf7lc
jl2hfp5QADIpaLSAAH1+AfLnUegLCnAZ2JznAd9gVcOT+i++J3bVUbRKNYlXw5FYmOK7uDOaXCVn
GyxFIBRSdmgTfNf1Q6tUUePrRigz8znZ6Wf0Wh1vriTit7M/IomIpkv8EQgEKDIUxFx5S+Dc2iQ8
TeXIiKuEnoxCXaAjLVNAz7O9MHe0oOXceni3NJCjczPvYVvSAs/GhtKsOp2OZ4fe0mFmxaLru7sv
BrVSQ/0e7ui0etLj8vm+10PsXE0IvprB4WVRbJsczqzAR8hMRawe/IZZrV8wrVkwo30fIRTB9yOi
WNwznFVDIvjaLwSFXENSdAE3j2bw8m4uUS/kvLybS+9vjAnsd6P7+dp8AAAgAElEQVSiqNfWFgfX
4thPjUbHvdNZ9JlpHHsacjObzGQVrb40EFsrOykD5pel88SSyCzE+A8txdaV2QS6RTKiZTyrp6ai
zNfRso+xaz41QUXYIwW9pxaTRKFQyMBZ7lg5yPAJsGXFxDS6VI7h1jmDJuXNM3mkJavoMvJ9HcU3
zwpwcDOlYU9nhrVIZO7wdOQ5BlL34+xsKtayoLR3sRu/ehNLDsZWJTXNMHezM7Tv9Xn9pJy4CDWb
wmoxfHVZpvZO4sfZGeh0erRaPQu+SqXVICcsbMQ4uEpZ96AKdu6mtCkXz5Nb+WxYlMHk7cWxwnVb
27LsfCU2L8vhm4EpLP86ndHrPJFKDT8PdVrbMedoJb6bksqOleksGp6Mk4c5ncaXwsxSzKIrNVBr
BAypayCsBUodUzpFU7tTCZY+aUJ8hJK5XcKMriGwvxOVGlgRFapk1LaqRdur+tszYlMVlg0MJ+xB
LgBbpsYQ+0pJrS88WdL6HkqFQWHFtoQJ31xowKUt8VzcHINer+fwoigU2Rok5hLSIgzHW9ibMOZ8
IHd3RnFja4ThmnqUxn9keZb5X2fLkIdsGviAqn0ro9MJkFlKMbGS0f9cF14eDufR5mBsy1jT61B7
Ls26TcydBOqNq0G5lh5sbbQb61KW9DjcmWuzrnF7xV2cqjoRujeEDeXXkJ+u4MXWRxwK3IS2QMPZ
LtuJvfyajJB4ni04i1AiJHTWQdy+qEPS7us4tKuNOikdsaMNIgcbBGbFxUQAHj16RNWqxffrY+Pf
RlbfxS/H9qmKInys8b2LjIyM/8IA/ib+S7D6xFCpVEYvQGZmJlZWVkUZ51qttuhF+5jacYXn+ZgS
H7/UGgUQiUQfTYrrQ8jOzi4i7n8G7yakCQSCooSpX35M5HJ5kaLCn0VWVhYuLi4gFILeUIscmQSB
TGqozykSIRAJEIhFaHMUCKVi6j3+lsdt51PwNgX34S0R21mQsv0SFcYG8HTWMfRAu5cLsCjjwMmy
U6jY1weRRMT9JVfRafW0Pj0ct4By3JlwlOSLoQx59iUCgYADHfYSdyMGC0czcpLyEEhE2JW1YciD
QQBEnI/kULdDzEwcgtTcYL2c77yZL9bWo0Y3Q4LU2UVPub/5FdNvBxAfkk1cSDbH5r1Er9MjkYnI
TStALBMiEIClowkycxkSCzEiUxFv7yRTs4cHJlYSQxuhgGtrw2jQ3xORVIgyV41KoSHkdAJ2JU0R
i4QUyA3bcjML0GnA0k6Mi4cJHlXMcK8gY+e8eOYe8qZ2y2I1iK2zYrmyP53Nob5Gz3JU7WdUbGDF
iO+K42oBBnrcp+3YknQMMliBU2Py2T37Dbf2JyEUCPhirBNdRtrh5G4gxJM6RCEQiVlwxNOon2fX
c5jUJpyf4xthailk65Q3XNiYgEcFGRkpGlr1s2foXGMraH6elvZuLwnaWoGGnR1JjMpnXvsQspKU
jFlgy/IJ6WwProSbp4nRccmxKnp7v6BjUElOroml42Bbxi93RCI1yIJ1KheJX18nBs4rA8Cbp3Km
t3hB5VoyGrY2ZeOCLPYn+hp5NrRaPd+Pecv57cmUqmjKTw99+CWiQhSMqP0cUysxB5Lrvrf/+bVs
ZrR9gV6vZ0t0I6wdixcR8kw1kxo8wsZOSPlqJtw6m8fqN/4IhULSYhRMrXWD+u1tmbjZ8HxuHEpj
xcBwfLuW5vmpeNaENsLKobi/I0ujOLIkgg4jXTj2QyJT7rbBubwla1pdITcpjyXP/Iqu7/GpJNb0
eED1QAdeXM9k1LX2aNV61jQ+Tt+NDajdyyBp9exYDFv7XGfy9WaU8bUn/FYqy/wuIjYVMSJkKLal
rXmy5Tlngy4zOrg/NqWsCD32hoN9TjP0di9K+DhyY9kDbi59wLjwQYgkIlaX24xQKkKdp0FToEGr
Bcf6ZbHydiFi+23q7RmBTqnm4Zdb8XuwkIhlJ0k68xSvxX0IHb0Jka0FFKhR5+ajz1chtjFHjx6x
jSWa7DwEZqZoM3PRF6gMVlYAoRBXFxfCwowXAB8DhQUAiiru/Yug0WiKvHd/B+/Kb30o8aswqevX
ZLh+DUqlsigu95do1aoVN2/e/NcuBP5l+E8N4J+AWq0uco9ptVpycgzJCoXu549tiSzEXyV5v8Rv
ZfR/bN3YDyEnJ6dohfxHxvp7sl6/hFwuL5LS+jNQKBSGGFWJBNRqw/8SEeIKZdFFxiIwkWIWWB/5
wQtISzigy87FtnElMq6/RJuvpPq+Sdg28+FGiYFoFAWYOFqhFwjw7Fefaku68mbzDe4P3YbYVIK5
ux0apZpyPapTZ3kHdBoNO51m0mFHR8yczLm3/A5vTr3G0s2aCkPrUm18Q7aVWECnnR3wam0gXRur
baJy+9K0XGBIzLqz7jmX5z9g2vPOvH2QStStFK6ueUFBnhqRRIiFvSlCEzHZ8bkEzq6Ley0n3Gs7
cfPbpwQfeMPUF92K7umeodfIDM8h6FrLovtzePJDws4nMPNpcZxd6KUE1nW+zqqkzsjMDPNSp9MR
5HSUgZvrYGot4c2tFGKeZBF2ORG9Vo+6QIeJuQiv6uZU87Pk8PdJDF1ahlaDXYr6TY1TMqjcYza+
qoNTqeLnGHw9k1ltQtia6IeZZfF78PpBNtObPuSrjT6cXBFJXGgOtZtZ02WUHTO6R7PmRkXK1zCO
Lx3q+xKfZg4MWl5MYlVKDQs6BfPiRia1/K2ZtM4V55LFhGv3qlQO/pDBlkhj4ndoZQy7ZkdhbiPm
5+BKWNkav6OLh8QQFaZi2a1aJEYomBHwBCtrWHXMjUfXFKyZmsbuhNpGZDQvV8OEBsFEheQxdHFJ
ek81VgAAeHYtm2ltw9Dp4JsdnjTpamzpeXQxi1mdXyMxE1GpjiXzTlQ02p+bqWGA50Py87T0neNB
92keRvtz0tUE1X5ARoKSlS+b4lK2WP4oPiyX6fVv0W6YEy0HOzO61jN6r61Nvb4ebOx1h8i7KXz/
quE7WqV6lnR4zPOLaYw47k/lQIPVXSlXs6jWGUp4mjL5lGEu67R6ZtW/TkxwNqOudaBMHYO79emB
SPYMvsakO21wq2KwoJ+e94wra0LxH1GOc6tCqTHcl7BDryjjX5LO2wxz9dTw84SfiWBc5BDEYiGX
Ztzi4cZgxkcMRmouYUerwyQ8TkZdoEFiJkOZW0CZL2rScHM/rnfbRFZoEm1fzCZk3ile/XiN1pHL
CJ1zjLe77+IftoI7TRcgsrXEY2onHndeSqWDM3g99Duk5UuiTkhDFZ+KTq5EaGOBPi8foZMduoxc
9Hod/E8hALEYa3NzozKaHwOFxpW/snj/1PgcRPpDWrJ/tChCoWf0l7+5er2e1q1b/0dW/zj+UwP4
J1BI9nJycoqIqpmZ2d9K5vkj+Lvu8z+S0f85svX/yDn+TAnUD/X/ZyGXyw1EVSAwuPylUsPfQiG6
yHgQibCfOxL5oYvYdG2GRdemqDNySTv/FKRi7BtVwtavCvdqTkSbr8LtyxaU/2kkmtx8Kk5pRdSu
uzwauxtzd1tq7RhJje1fUZAux2dKAAD3ppxEnafiypTL7G62k8grb3GsUZI+r6dQc3JTHi2+gqmd
KZ6tDBal5OfJpIdn0HBcNfLS83m2P5yz0+8iT1cy3W0Pu7+8w93d0egFAobe7cc3iomMjx+Npasl
dQZVJmBaLcoHlsLMxoQHm0MJ/KZ60X3T6XSEHH1Li2mVje7R/R2RtP7GeNvhKU/x/6pcEVEFuLw2
HKmpkGrt3ajQ1Jl206sy8mBjhGIxg7Y34EdFD4YfaIK9jwsnt2WiUupZ81UEQys/ZuPkKB5dyGT1
sAh8W9gbEVWA9UERtBxe0oioAmwe95qAgaVp1NudJY+b8F14M3RmZkzvFo1GoycmTIlGUzznol4o
eBuqoNNEYwIoNRGTk6qlYa+SZOaK6FkhjM1zklHmG1zh2xYk0W9hmffmT4POjqg1esztTOhV7gX3
zhUnN8VHFnBxTzrjtlUCoISnGRuj6mPvaUmPalGsCEqm79xS78WDm1uKadTVAXNrEXuWJBByyziD
X6vVs2pYFE2HlGHYZl8WD4jk8PeJRftVBTqWD46k1XhPFj3y583zfCYHvDCKQ103Ngr70pZMvtiU
vQtjOLgs+r1ry8vSIJKJ2T4u1Gi7WwVLZl2qx/Efkwlq+JwaXUrRoH9ZhEIBQ3bUxb6MJVNq3y86
X8TDbIKvpGPvZc2+scVZ/yYWEoIuNiP8XiY7JwWj0+r5sd9j0mILqNSpPNu7XUKjMoQJVO9eFr/x
VVkdcB5FjoHk+Y2pgE6n48yKl/S+1JsWq5rT+3xPQg+95tEmg0JAy++bYe5szs+BhwDwn9cAFx9H
fvLdya52x4i+EYdWB3bVS9EzaQmBx4bz9sBj0h9E03DHAHRqDbf6bKHqrLbY+5biWuNFVFnaHcty
TtxruZi6pyaR8yyS9KsvKDe7B6/6LKPSvqkoHoThMKQtIlMTLDo1NXj+hUK0yRnoVQWg04OpicGT
o9GQLc/76HGQ/7YM+8+NQgJaaCEtDC0oVC4wMzMzynEolKvKy8sr8uYplUoKCgo4f/48t27dIikp
6ZOHV2RkZBAYGEj58uVp0aIFWVlZ77WJjY3F39+fypUrU6VKlc8mh/ax8B9Z/cRQKBSoVCpMTEyw
sbH5QxbCj4G/ogjwZzP6P4fqwG+R1V8SajMzsz+d3PVnCXdOTs7/Yo8EIJaAiRQEQkAPWh16VQHS
SmVJGbcUq1b1sRnVjcx1hzGpUIZSu+agy5Zj36YmN8oOQxGdTK2rC6n04wjejN+Ms583Fxst5f6w
7YjNZQS+WYVb19o8+2orVUY2AqGAR3PPEvrTLUwdLHDuXIvOictBo6POvMCiMb786R5N5jY2PB+N
jmP9TmBiI+Mnv8MscN3C0dHXURdoab21E+Ozp/FV3EQkplIafF0Xt9quCIVC8tIUJDxOovHE6kX9
Bh96g0qhpvoXZYu2XV8TgsxcTMUWxTGk93dFoNVoqdGlVNG2zLg8El5mETC2uCIRwMVvX9NqSiWj
JKfrm94gFAqo3t4NoVBIxQAXen1bE7FUTIspVVmW1I06gyvw5I6KxX1eE3w9m8QIBSfXxZMWb9Ah
Tn6bT+xLBR2CShmdLz1BSeTTbNp9XWwVtHc3ZdzeGggkQmp1deeHCXF0L/mUo+tSKFDqWDUihqa9
S2DrYmxtig2VExMqp8d8b+Zca8C0c/U4+XM2Xcq8ZMmwWMwsJfj3ej9BavfcGMrXtWf586a0n1KO
Gd2iWPplLPl5WjbNTMK7rjVu5Yq9FUKhkBlHfKjb0QlVAcS/LkCrMZ6zmSkq9i+PJehoPdp8XY7J
LUI5vyO1aP+ZLSnkZuvo920VGvZyZ8KRumz6Jo4NU6IB2LcsEb1AxBfzK2Hvbsr8+01IilUT1NBA
WJ9cyuLm0TTGnWiId2NHJpxuzJ55bzm88i1g+HasGRyGo5cVc1+0J/xBNt/3fWI0xrK+NlRsYo9S
oaNCQPF9EUtFjDnZBI0O5jV/RGpMPvNbPaTx2KqMv9sJgUjIdy0uF7W3dTdn/IXmXPzpLXMa3SD4
Sjqjn/Wl2/ZALF0t+KHp6aK2rebWpExdZ1bUO0PSqywWVT+BtYcdVqVsuLvsHgAO3vZ03t2Rc0FX
SHyajFgqotfJriQHp3J+2nXSwzMN1e5icoh9nka36Hm0vz+Z9KfxhK6/iVvzClSf3opLbdehU2tp
fnY08aee83rjDRrtG0pBhpxHw7dS/8gY8qJTeb34GPVOTubt6hOYV3bHobkPrwauosKuSSTO3Yb7
ipEoLtzFdlgXEImQ1K+BwNQUVGooUBkk8aRS0GlRqlQfXYf632r9+6fjaT9EZN+V4AKKknYBLl26
xIwZM6hfvz6PHj2iRo0adO/enWnTprF582auXbtWpJv+d7FkyRICAwN5/fo1zZo1+2AhCYlEwrff
fsuLFy+4e/cua9euJTQ09AO9/TvxH1n9xLCwsDAie59LO/TPJA79VV3Uz6E68Mv7VWip/hCh/jNV
pn6t/9+CVqs1WDJEYjAxAb0WdAA6wzaJGL1Wh/LmE4RiESJPN6L8R2Beryrln24nZfpP6NUaImbt
ARMZzm1rY9OgIpFLD5EXlUzy1VeYBfgitbGk8sIvEMkkpN97Q9aLOOSxWewuOYfnq69h4mxNp9il
1JjfiedzTmDpboO7v8E9HbLhHlqVBomZmGP9TrDMdiXp4RlYlnWk3PDGDEqfj5mrLbXH1adybx/E
JhJSgpPIjMqg1ohiYnpm3EXKNnLDwas4XvTC7Pv4B1VFLC2Og77x3UtaTqtiRDbPLgwhcEIlRO/U
j9875gFVW7ph515Mwl7fTCEnJZ+GA43dyWeXhdFyckWEouLj40KySH8rp+mI8ljYmdBiYmUm32hF
3QFe2JSywqtlaQ6uSmSw1z2GV3rAzDbB+AQ44OBubG3dMCqMaoHOOHkYh64cWfQGK0dThu2sx7eJ
HWk3uyq7lqbQ2eUxoffltB9nnNAF8MPw1zTq5Y5tCcM5KjayZ01kM9pM9OLq4Wxk5iISIvKNjkmO
zuf6gWS+2mKIGe0wyYsVIU15clNBT68XXD+SwbhtFd87lyJXw73jaXRdXJXLe9L4umkI2WnFmqw/
z4zDvZI1lZs60mVGBUbursV3I6PYNC0WeZaGDZPf0mdlsYSUT6ATM6824sTGNL5pH8buJXGM2FFc
L9zG2YR5d5sgz9Uz0jeYJX1f0XKid9Hz827iSNCpRuyaHc3R1TFc35tM8LVMxpwNwNbdnMm3WvL4
TCqbRgYX9Xl1WyyvbmXQ9cfG7Bz1kJDzCUX7TC0lfH05gNiwPIJ8blKmgSvtFtVBZi5hxMU2xAVn
sXPEvaL2Javb4u3nwtvn2XTa1BwLJzPEUhH9T3UgIzqXvV9eBwyasv32+htCNnyO49bUk/6PvuKL
c32JuhzN7eV3ACjfvhz1J9ZlZ4sDFMhVWDib03VvB26tfMTaattRyyxofWU8qsx8Es6HYeXpiP/e
QdyfeIT05/H4TA3Eub4H5xqvwsrLCb+9Q3g88SC5UWk0OzuO2H33STz5jCZnJ/J2y1XyY9Op+u0A
nvdejdeCnoikIpI3nKX01B7ETfiBUj+MI3vdAewm9kP75CXShjURWFqATIZekW8oOiKTgliCVqv9
aAVg/mlC+Fv4N4+tcFxisbiIyC5dupQrV65w6dIlOnXqxKZNm+jatSvm5ubcuHGD6dOnk5f3vsbx
X8Hx48cZMGAAAAMGDODo0aPvtXFxcaF6dcM33sLCgooVK5KQkPBeu38r/iOrnxi/fLmEQuFn10D9
ED6GLurnCgPQ6XRotdoiQq1SqT6aRNYfvQa9Xm9YPYulIJWBMh9kpmBmCiYmCNu2Aq0WaeO6CG2t
QCIhY9VuBAIouWkqSXM2oQh9i7lvBUqfXIk2MxeP2T14PXErkfP2YePvQ93YHZh5u6PXaSg9sDG5
rxO53W4lApGAzLe51L06F7FMSvUFHRH8bx5Fb7tDnfmB6DQ6ok6+5NaUU+Rn5nNm1AUy5SJsqpSk
ZDNvOt0cQ7VxTVAk5JD5KhnfsXWKru3SmLNU610ZcwcDEdFqdEScjqTptGLykvwinfSILBp8VUyk
Xl+OR56moG6/4jjOuOfppEXn0GR4caKTRqUh7HISLScXa7cCHJj4lCZDvTCxKPY2RD1IJzM+j8ZD
yhq13TvuMTW7l8bC3ti6eWd7FO3nVafbyjrMCe/GivTeVO9XnqRIJcFX0xhT5Q6nfoghO1WFSqnh
2aUMOk83Tp4CuLAulg6zKhbN+4CvvFgW3Q5Hb2vEMiFT/R5z7LtY1AWGdzctTkn4wxw6ffN+X9ZO
JphYybApa8tInwfsXRiDWmU4bs/8WDxr2uLiWRzP6VjajFWh/kjMpej0eq5sT0arNZ6TR1fGYu1s
Sstx3iyLaoNaL+HLyo95/TCXuNf5XNyZxMhdxc+rdkdX5t7149TmVAZVeoaNqxmN+hhXqipb04aF
D5ry6GI2UlMx3o2MNVst7aXMudWY7AwNilwd7acbk+gKfk6MP9GIHTMi+W5IKD1+qIOFnYG4O3la
Mul6C27sjmfXtJckvJKzeXQwPbY0pe5Ab7p824Afu90i5mmxfquVkwklq9uhUelx9S1WVrByMWPk
5bbc2xXFxdUGmapjM54RcSeN2mPrcKDfeXKSDD/65vamDL7Yhcd7I7i13tD2xYm35KYYCJ6tt6Ff
6zK2dD7Sk+tzb/L2egwAjWc1wrVWCbY23EXo0dcc7HEcc1drhDIp9df3xLm+B0229eP2iH1kvUqm
ZJvKVJ0QwLnAtWjz1TTZPQBVbj43BmzDvU0VqkxszpUW3yEQCynbrx6PRmzn5ZxjSCxNeDRgHa/m
HkKdk8+Nal+jypSTdvo+qUfvoNdoSZy1Bdvu/uSsO4DNwPZoHoUg8vZAYGdj+Oao1KDRgVoFMhMQ
irCyskKlUhXFdv7/5tL/N5PV37rXaWlpuLm5UbNmTXr27MmMGTPYtm0bN2/eLNbm/ptITk7G2dng
rXB2diY5Ofk320dHR/PkyRPq1n0/kfLfio+Xfv4fPoh/wnX+W+f5ZUb/uzp1f+Ucn/KDqNfr0Wq1
RWOWyWQfXeHgj1yDTqfDzMwcRBJDbKqqwEBYxRJQ5iPu3wfNjt2YTR6J+nEwugIVJg1row0Nx7pt
fRLGfEv2lYc4zxhIiXnDCK/RH5MSdjxsOgOdTofE2hyfcwsRSsTEL9pHqQGNedjnJ+JOPAQE+D1f
iaW3K5FrTiMQCSj9hUH0/8XSs6gVBcScesWF/vsQiIToNDraPZ+NbRU3NEoVh5wm0uTC8KJruTHq
CBW6VcbCxSA0r8hQkPggng7rmxe1ub7gNlILCVILCSFHIsiKyeXayidIzMTs7H0VRWYBiswCMuPl
6DQ6prjsQ6fVo9eDVq1Dr9PzTdmjSExESM3EKHNVKOUaLq0O58mReGxcTZCaiYh5lkGvNb5GP0L7
JjyhYX9PzKyLE5UUOSoi7qbxzf3WRs/lzs8GGaJqnYpd/VIzMblJSkpUtmf0zfZcWfGc49+Hs/Xr
19g4S7Gwl1KmhrVRPzf3xFOg1FC3hzGZUyo0JL6UE3SlFakRORyZ/Ih9C6IYsNiTO4dTqdHaGRdP
40QsnVbP/lmvaD6xIi0mVib8ZjJbet3k/NZEBi324MqeJJY+afLeHIsPyyUjQcnQA/7sGXqbR2fT
mXqwCvauMnIz1Bxe8ZYxxxoCIJGJ+eZWAHsnPWOiXzDOpU2o0MQB1/LGVbVKVrZi6oX6zKh9DRMb
GbnpKiztpUZtkiPyEEtESK1lzKp/k3l3Ghkt/tJiFOSmq3AoZ8tMn0vMf9bMyLJeoakjparZEvkg
HdX/JKUK4VrZhqCLgaz0P8/lTbFU7eRBtS4GK3q9LyuQk5TP8oDLzH7SEofSFpxZGkrk/XR6HO3K
vs5HcCpnRa2+hrCREpXtGHK0BZvanyP+WRaPDscy8PYAHCo5II/PY13d/UwM74dYKsa5kj299rVh
T/dTJIVkcm/rawK398DMyZwjrbZSoo4bZZp7UtrfgyYLmrG/0yFGhH2JhZMFrde34gfPHznU6wS+
SzpTaVwAt4fs5Ezj1XQNn4lHtxqk3o7irP8aukXPpcac1qTeieZ0k+/o8HASLc+O5Hjt5dyz3Y8m
S0l+ai4nqs7F1NkGqZsDCRdf4jyuK6rweLIvPcbj+HKSZq5Hm5uP3YR2ZKzdh6SEI+qsHNJ2X4QC
FVm7zhgq4aVlIBALoKQ7+pg4gzqAXggFSkNYgAYcHBxITk7+y5nt/3ZC+G8dWyE+NL60tLSPIlsV
GBhIUlLSe9sXLlz43hh+6z7J5XK6devGd999h4WFxa+2+7fhP8vqZ8bnsqy+66L/Ldf531Ej+FRk
9V3tWa1Wi1Ao/MslUH8Pf+QaAlu2ApEItGpDnqJEYohTVSvB3ALNlp+RNamH5m0c6vPXsFw0BVFr
P9SxiWT8fJqcOyFIbCxxmTmYtE3HyHv2BnVWHg4LRyKSSvFYNgShREzEN1vJT8zgzXfnkGdpMPN0
x2NYIJbehkzoqGXH8ZnbHlWWgpcrzhO84DRCiYiU6DzqHJ+EqbsDlYJaYFvF4LJ+Mu0INuUcca5r
kG1SZilIuh1FnSkNAMO8ODvkGGYOpoQefs3B7sf5wXsTt5bdIy9dyZY2Jzkx8S63N4UjT8mnZMsK
mPt6ULp3LapOaIIe6HGhH/0eDmfwi9EMeDwckVRE70v96HWlP213daHx0hZodUIq9ahIgbkVr5/l
c2NnAvu+fopYJmKZ/yVGmO1jeoVTfNf2OtEP03H2tiAzQVF0/w9MekJpX3tcK9sYPZczi14SOKmK
UbgBwMO90TSfXh2piZiWM3yZ+qoH0yN7kpmiIT9XyzDn8+yf/ZqMBINI/8E54bSdXMGIhAHsm/gM
10q2lK7lQK0eZZn/tjvtFtZix8y3PL+aSbn6Nu/NnftHElEp9TQPMlghyzVyZuHbzlRqX4YVA8Kw
tJdi7/a+9M6+GeF4NXbGp10p5sd0AzMzRlS6y/2TaRxYHIOjhwWVm7kYHdNzeTU6z69KYpQSW1dT
tJr3vyuH54Tj2bgEMlszvvG9SkpUsdtRo9axcdhTGo2twsSHXVAWCJnicw3N/6zAOp2enwY8oUqn
soy+1RmZrQkzfC6iURVrv97ZFUNCaC4997ZlX9Aj7u6MNDp/mVr2VO9QigKFlrJNjccfOKM6vj28
WFj3Io8Ox3Jifgi9TnXHq4UHXXa2Y/9Xt4i4WZwEVj7AjbpDvLm//y0t17bCsbIjAoGAtptaY1HC
go1NDxe1rdDGAw8/d+5sDqPFrh6U61oFt8YeNFnelqPdDpATZ0hqqzmuLp6ty7Gt/k5ibsawudZW
rMs7oxMKEJkZLP51f+yB2MqUC+03AFBrWUcsPew5F/A9AvqtywYAACAASURBVKGQpgcGoUjK5nyH
n3i+8Dw6jZZX62+SHJFDxT1TEdtZYdmuPr6hm7Gs7on88lM8ds7A1MuNtBW7KHt6FbrMHARmJrgs
H48uMwfHc5sRmsqQ9e+CwM4WvVqLOjYRfWYO+tdvEHiVNZRjFf3P3qTHIJ8nEODs7IyJiUmR1mhh
QtC7aikf0hp9V7nmP/w5/BaRTktL+yjVqy5cuEBwcPB7/zp06ICzs3MRkU1MTPzVxDu1Wk3Xrl3p
27cvnTp1+ttj+pz4j6x+YnzIsvo53DOFltVP4Tp/9xyFMh9/F+9W8MrJySkqgWpmZva7+nZ/B7/3
PEaOGsWtGzdAqwETM9CoAcH/yKsecgzC45pXUaj2HMVsYHfErZuimL4coZU55kunINRqcVkykqTJ
a4kfvxqLFnUol3AabUomIjMpNk2q8HrQKuK+O4Zlo6pUD99JyZXDUUYm4Dm1IwAx266Qn5hJ/LHn
HC45leCl5xGaSmmZsoEGF6YjsTFHHpGM91hDhRudTsfbXfeoOas48er6yMOY2JkStu8Fe5psY5XF
QqIuRKJHSPCxGJRWttg1rYBQJmFI5kIGpMynV+R0nBt54FzTnda7e9J4aWtqTmhM3NUoPAPLUdq/
LPbejth42PJozT1K1HCljH8ZXGqUwKNZWYQSIXqdno7b2tNhSzv6nOvFwPsDEYhEdD/2BVMVUxgW
MpxakxoSE5aLxELKuW/fMM3rBKNtDrDc/zIP9sdQMdAFVX6x5e7t43TSY3JpONRYV/XmplcIhAKq
dChttP3FiRjMbGXMSB5K543NuXMsnTGel5jrf4fUmDz8hhuHHeh0Ou7vj6PNbGM90sbDvPFu4YqZ
gxlHFr1hRv3bRD81EB+9Xs/eGa9pNMzL6P0SCoW0nFwJrU6PQCZhXPkrvLyeXrQ/PiyXx6eT6LvZ
YDkVS8WMvdiC9otqsqxXCMfXvKXfOl9+Cb1ez8MD8ZQLLMXTs2ksCLiNPFNVtD/8bgbPLyTTf28z
xt7qSMl6LnxT8yqRjwyZwufWRKHVCGg9ryZmtjLG3myP1MaMiRWvoJRruLr5LWlxSnpsb4bMXMLw
i+0xdTBjepULqJQaspOV/DzqMW3XNKVKFy967GrFzuH3eHTobdEYXl5M5OnxGAJXNuPI+Hs8PxZV
tE8gENBlbQNK1XFiY7/bNJnTEPe6hoVZxc7labbQj43tzpMeZVA2iLqTzL0tr3Dz8+TixMsoswyL
DZFURI9T3cmMyeXQ4Avo9XouzLzD29tJlPAvz42gM+g0hrnjM7Iu5bpWZXfDreg0WgQCAa02t6dA
XsAO/914DGlCu5C5NNnzJQ+CDpH+PA6RTEKzUyNJuRfN08XnEIpFBBz9kqzXKdybeJi4sy8RiIUk
XHpFwrNkqt/6lpKjO6KKTMKxS318zi4gdfsF0o/cosKR2Sgj4oj7ZiNexxaSHxJJ6g8H8Ti5gsyV
O5CUL41luyZk9pyAw+HvUR08g9ncIJBKEA4Zgl4oBjNT9KGvoKAApBKDl0etMug8C4QgEGBjY4NO
p/vNzPYPEdnC8LAPEdl/OrTg32xZ/acLAnTo0IH/x95Zh0d1b1//M5qJG/EQLCSEhEBwCe5upTgU
p2gLxb20eCkOxV0DFGtwh+CuEUggSnxio2feP4ZMmNLetrfAvff9dT0PD3D0e3TW2Xvttbds2QLA
li1bfpOIGgwGBgwYQPny5fnqq68+6ng+Bv4hq58YHzuyWhhFzc/PR6fTffTuUn+XfP9WC9TCDl4S
ieSjk/t/tf0xY8awccMGwGAkqnJLkFlArWZgMCBq1BqRlaWxyKHgbZWuqxOZFZojdnHGJeYCupsP
0avUJH69lLRtxxHLpBQPmw9SKZnLdiOxs+JGwGDehN9B5mBL4LnFWHi7EDt4McX71Edqb0XsT6d4
NHwjUjtLVHIbqj75CZmdFeWmdkQiN0Z/Ho3YjG/vWiiKGVPBz1eewyAYPyQujTjI9tLf8/LQIwwG
EVHnk7AKDaR4rzpYeTjSMXYOra5NIHRDb9IjYqk4si4SiyIf1Jf7H1B1Yv2ia6bT8epUNNUn1Cqa
JghEhj2j5sSiaQCXZ1yk+ihjH/dCRCy4hpWzJSXqG9P3TmUcqdgvGHWWhg472jMibgTjc8fx+bFu
5Btk6PVwflUUox32MKdaOIdn3Gdr/whq9vbF2tFcw3pq3hMaja9oVpwFcG7BQxpMrIJYIqZCZ19G
3+vO+Ji+vLivRCwRMyf0HDfDXiO8NV7/Zf5zLO3lBLY0L6zS6QQeHIqn69amTEocgHXpYkyrc4WV
fe5zYUs8ylQ1bWZWfO9eOjn/KZ5BLkyK7k2V/oHMbXWdjcMfo87XmaKqjt7mkoIGwwKo8nkZxBIx
O0beIyM+32z+49MpJDxV0ntvMybE9CQ/X8zEiudJiszFYDCwafhDKnUtg42LMZLbd08Tagwqz+wG
l7m49RVhM5/SZW1dE7G2sJHx5emWFPN3ZIz/WbaOeUiHFfWQvo1cy61kDDnVFht3G6ZWOM3Gfrfw
qOBCSC9jFDmwgy+dNzZlU98IHoUnkJehZn23S4ROqU21oSG0XdOc7T3Pm0VLBZ1AZlwOIomExzuf
m70ba4yuQqW+FVhS6wjx99NY2yqcyuMb0P5oH9xr+LCx+hbT8lbOVvQ63Z0HYVFsbHqQqyvu0/ry
aJodGIDM3pKDzbeYtttwdTsUrjbsabINbb6Go71+RtAZEFvKTdHU4u0qUf6rJpxuuhxtnhprb0ca
HRzC/e9OkHQxCoWzNf4Da/F4+QWuDNuLS99m+K0eiTouFamzLSXmfoGilDsPGk/BJrgUfj+NJHrA
YvR5Ksof+443qw6Se+sZfsfmkbZkN7rsPLwWjSKx6wScZw9FbG1J7oINOM4fQ96I6dhuWIBh+3ak
X40yRlE79wGZHFQqY3crmcz4QW0Q3rqTgKOj4+9Wm/+eRVNhO9O/GpH9FET2f5WspqWlffRWqxMn
TuTUqVP4+flx9uxZJk6cCEBiYiKtWxv9g69cucL27ds5d+4cISEhhISEcPz48Y86rg+Jf8jqR8an
iqy+W9FfaJVV+OL5EFHU38O/czx/1AL11y31/hNkNSwsjFWrVhn/o7AGnc6Y9g8JheunYeAYDJGP
MajUMGkuIk0BBrGE/PlrQSzC8eAa9MmpqPYcQSyTYjFuKGJLBW6zhyKSSYlrNgJtRg6CQYrXhU2I
RVB8zgBEUgn5z1+TcycKrbKAU26DeDZlNwaJmBrx2wncP5X8yATUqVmUGGT0XS1IzCDzzgsCxjcl
495rHsw6yr3JP6POLuDyqMOkROdgEVASS3dHWr5eQsNLUwie04XU8IdUmNzcdL6zo1LIikohcHht
03l4uv46IqmYkq2KiqNuzLmAjZsNXnWKtKIPNt5FLBVRppWvaVrmy0zSI9Op8qV5VPDO6nvUnljL
7DrfXH4LuY2c0k2NmkaxWIxPneLkxudR/7tGjEgey7CXI/FpG8jtY29IfZHD9e0xrO18npu7X5Cf
peZFxBuykvOoOcC8kCv6YiLKlHyq9TcvEDIIoFUJDLvfl9Jt/dg6/B5jih/j7JpozqyIodX04Pee
3yPT7mDvbUPp+l7IFVJ67GzOmKe9iYvWsHrAPdzK2b/XSiUnTcXFtc/ptLouAC2/q8GYe125eyqD
Ub7nzKKq7yIrMZ8bu2IYfPlzFO72TA06wePTxsIJQTCwc/R9qvYrh1whRa6QMvrWZ5Rs4M2UqufZ
Of4xb17m0WW1+Xbbza9Bux9qsX7wPaxdFJRvZW7tJVNIGXC4GVJrGXodlAo1T93LLKUMOtEGCwcF
T86l0H1/a7P5wV39abe8IWu6XGJF2/PYl3Sk7tsPmOBegTT6rh5rW58g6XGG8XyOv0Fupo6BsWNR
5WnZ1eaA2faa/dgIz2oeLK1zhOLN/Kk5vTEisZiWe7ohUsjY2WyPadli5YpR/rMA4q4lUmNxB5yD
PJBYSGkRPpjUB8lcGm+0tJLIpbQ72ofUJ6msLrGE5AdpNI9aQN1jX/No7nGSzxrtfIK/bYtjsDcn
6v0IgHt9Pyp/147T7deyv9z3PFsXQbHOdTEYRHgNbYVnn0Z49GjAg3rjAQPlD04l7/lrXkzejFvP
Rrj3aMjjemOxrlSa0kuG8bLnd8iLu1LihxG87j4N2w51cWhbj/hGQ/E6thT19fvoM5RYt29EwZjZ
WP8wDf3iH5FOHI/o2F5o1Rms7cDFA8RSI2E1GEDQG7X1gIuLC+np6fxZGAwGk6b1r0RkPwWR/V8l
qxkZGR9EBvCv4OTkxOnTp4mMjOTkyZM4OBglU56enhw7dgyA0NBQBEHg3r173L17l7t379KiRYuP
Oq4PiX/I6ifAb5GvD/XwvqtFFYlE2NnZmaKonwJ/hUy+G0XNz89HJpOZoqi/12nrP0FW4+Li6NWr
t/E/Ysnb1L8BNCq4cRY8iiM6tg8S4mDPaTh5CEOBGnG1Ooj9/LHu1BzttXukVeuAxLcUjnERiORy
DFoNYkc7npdoR971x7itnYb3gzAKLt8FMbj0bEL+45c8afA1CAayn6dS4sB8ZK7OlBj3GVJrY4Qs
9psN+I5qidRagaDVceOzJYjEYsJrzuNk/UVEbrqGAWiavI6Gr9ZQ4/gU8h7GUW5KG9O9mHj0Hmpl
AaW6VzMd941ReynTMRgrt6JCnQeLLlBlXD2zSOWT9beoMamOOdlccJWa42qZLXd61An82/ph414k
4n9xJpb8jHyCepg3DLi19Da1x9c022b89QRyknII/sIYqbT1tCN0ej2KVXDFrUpxul/qj9rSloMT
7zPBfQ8rWp3Gu7ILeq155uLwNzeoOTgICxvzZ+LQyAv4NS2FUxkHms2txzdJQwmdWouDM56SmZSP
MkVlJj0QBIGIjS9oMrO62TgdfWxptSgUqUJK6st8ZpY/QvSVN6b5ZxY/o1gZB3yqFXmLFvN1YHxk
DyTWFggGA5fWRL6nOQ3/9gEewS54VXbji/AONJhWk6Xtr3Do26fcCotH+UZNm4W1zdbpsbUJTWbV
4PiyF5So7Y5U/v5z5VPdBYNYhDKlgDPz7783/9XNVLIT8/FrV44fKoaREWfeYECn0ZP+Qomluy1r
6+43mfAXokq/8oT0CeDV/QwazTMvJqv5VVVqjKzK8npHubruKdc2PKPzmS+wdLKiy7n+JNxK5sjQ
E0UrGAxocrUYDAbyk4v0tlJLGR1P9iflYSrHRxmXv7H0Jk/3P8N3cAMixhwmN94od7Byt6Pl8SHc
X3mdyL0PAFCl5YMB1EoNAXM6Y+Fkg0tdf4Lnf86Fzj+Rn5yNSCym7r7B5KcouTpkB+qMPDJuv0av
1pGXnk/1xB0E7pqAS7ta3Kk7AUEQ8F06CJmzLY9bz0Tu4kCFo7OIX/ozGafuUHrpEKTOdjxrPQ33
QS0p1qEOT2t8CQ5WiO2siQzujaBWo36ZQFzNvshKeKD8fg2CWIwuJQ31+l0o2jbBsGYN0r69EV88
gSikOiJBD5bWIFUYHUrenrdClCpVisjIyPeu86/xZ96zf2Sa/7GI7H+7s8Gn0Kz+X8c/ZPUT40Ok
zn8dRS3Uor5bgPQhSfG/wp+xyNJqteTm5pKdnY1er8fa2ho7OztT9PfvbP/v4t3zpNPpSExMxL/c
O0RK9jbNLJYYfwzEYkiKx5AYBz0Hw5LZcOsqzFuO0H84wpNHqCPuoJy4AEQi7A9vADtbVN8tRZ+Z
Q9KoH8DTC0VJb+wGdAJAuWATju3rENlmCg+qfok2M5eyNzbge3szYmsFqrgkPEe2AyDnXgx50QnY
VvTh3oC1HHMcSPb9OGxrl6fsxrHUygxD6mBNmVGtsXA2ks7ko7fRKvMp0aOm6bAeT9lP+ZENkSqM
aU9dvoY3l2OoOK4o3Z9y8xU5CVkE9je6Dwg6PVH7H1GQnkfx+iXJSVCifJ3Ny5PRZL/Kwr9zOYS3
hEun0RF3IY4a3xRZZAGcn3ieKkMqI7Mqsqt6deU1OW9yCe5bwWzZ02PPEty3EhZ2Ral+QRCIPhxN
9Yl1cK/sSdvtnRkc+zV9bg9BlaMl43UBM7x2sLppOHf2xJAanUXiw3RCvzZPzWtUOqLPxFN3ShFZ
F4vF1BgWgsLRCv9O5bi4JprJ3vs4v+IpWrWeC6ueI5KKCOporm8FODPrJmXblmVk/EhKtvFnSfMz
bOp9ldQXOZxZ9pT2y96PnKZFZ5OdkMdnBz/jyqYY5lU9RuoLowY643UeEVuj6LShSHNcd2wVBl3o
wukV0azucY1awwJNKfp3IZNLsLBX8OJSMj9/fQ1BMPcp3j/sKn7t/Ol5vi+n5t7j0JhrpmdM0Avs
GXCRwN4VaL+7I+U+K8+PVfaTFlPUZevYuGvYeNrzxZNRWLjYsrzSbnTvEO2c5Dzu7XhG8cZ+7P3s
MKlPzSN7DWeH4te2LAe/vkbNbxvjWNao57P1sqPLuX483PmUS/OvGe+BCRdJfZ5J52fTyYhK59TA
/abtWLvb0vFUf+5tesjPvQ5zbuoF6h8bRZUfuuDTMYTDtZeZiLRLleLUW9+VUwMP8HjTLfbUWo17
l1qEbBjMrf6byIkxRqx9hzfGs3VFToYuRBAE5A5WND4xmpht19lXYgqpT9Op8mA1cidbnvf5wbjO
TyMRWch51GkOYrmMCkemkX3zOXFzd2NX3R/fRYN4+vlcNG+y8PqqPRmn7nDdvSspO8+izVQSO3gx
uLoiyCzIOncf2YBe6HILUOUJiKpXJ293OGJXV7TPX1Cw6xD6xGS0e8IQ1CqIjcJg72CMriKAXTGw
sDJJAQpRtWo1Ll269N698lv4OwW3H5vI/i9GVnNycj6YD+7/ZfxjXfUJ8GvCVahb/Svp+cICJJVK
hSAIf2jj9C4p/pgP+O+RycKor1qtNvWaLiyW+hDb/1Ao3LZSqSQ/P5/SZcsZK/4NBrCwhpIVIe4+
VGoEjy+BRoASARB9D9HhPRiyMxF/1gOhQ1dElUtgEIvQ+4UgsorFqm5FRNaWZNfqgE6Zh7xbB6xW
fEeOTzWcd89DJBLx5qsFaJLSSNt+Gnnz+shrVMTa1Q6rEGMqO2nkYryHtkbmYEPuw5c8bDMDQaXl
/rBNKKoFYlW/MuLUDCqenANA3vPX5D2Pp8TxSaZjjJq8C7+RTZEojJHFnOgUlJHJ+A8fbrxOablE
DN+NRCEl/nQUzzbcJDc2k9cXohE0ejaWmI+2QIug1SOWSRFLYGOF1aYOznqtHrFIxBq/VcZ/S8Qg
AkEr8MuQ49h52mJXwg4LRwuSH6RQ45vqFGQUYOlkjAKdHXeOkP6VkL8T+czPyCfpbjKtN7U1u163
lt9EZiOjVDNzf9OI7y5Rsqkf7cO/ICc+m2uzTnPom5soE5TYuluTk5KPQ/GiiPGJKRE4+zriXd3D
bDvxN5PIfK2kV0Q/LB0tebjtASemnOPYrPsgFtF0Vo339LApTzJ4cTmBUa9HGIupfmxKrbE1COsQ
xjT/Q9h7WFOmwftNBU7Nuo13TS/KtvBlZNwI9nc5wPfBh+i+uhZR51PwCnHDLdDZbB3vqm40+b42
R7+6wI2NzwjpXha3gCKvRnWulvCp12m8sjWeNbzYWXsjadFK+uxthNxSyuMjcSQ/zWTk2X5IFVL6
3hzA9tqbyU1V0W1TPa6tf0ZehobmK1siEolotqoFUoWUJdX2M/JKRwqy1NzeGUnvhyOQWcrofLIP
+xptYkWlnYy41wOJRMT+/qcpVsGT1oe+4Or4X9gYupMhd/vi4GP8wTYIBtKepiOWS7m3/AaVhtcw
RYCLBbrR8WgvDrTaStbLLB7ueErbWxOwKe5Ey7MjOVx9EU4BrlQZa5RUuAR7UHV8PW7Ov0Dg5Fa4
hRoL7qqv6cmpegv5peEq2l0ZBYBv9yrEHXzE2eGHKDupI+WmGT8Ws2++5EK9ebR8uRCJXEqV9f04
XfVbLrRbReieQTyZdwKRRIxea8B/90SsfL0ICp/N7ZARJK4Lx3NQS4KOzeJ2xWG8Wn4Yn5HtCD4w
mfutZ2FftwKWfp4YxCKulRmAzMEGi9ohqO88xuHAauTB5UgNboWse3tsO7cko2ILJP6+yMO2kN+h
F9JlSzBs3oJw/Sbs/AW6toSeI+HnzcaOeYmvjZZ6BXkQVA2iH4OtIyiNMgs0hU0pDLRu3Zrly5eb
zON/jY8dFCj8Hfr1b1ZhsKDQbqvQV/vX9lsAGo3mD+23/hMolE/81nTgo0rx/q9A9Ac36H937P1/
BL+2BFEqlSZ/0z/Cr31RLSws/rQvalZWFra2th/c7uld5OXlIZFIUCgUvzlehUKBVCr9t18qBoOB
zMxMHB0dP+iLSa/Xm77iDQYDNjY29B/0JWF7dgIGkFuBpS2ocqFma3gSAeo8mLoTpnc0PhmBNeD5
LdhxGEYPhNQU2HrQqG/9oiPWXw0gb/kmEImx3boMefvm5A6fjOj6DVyWTSB9/BLyH0ahaBaK09YF
CHkFvCnVEL+bG1GUL4XqaSzPK/bGZ0IX0sIuU/DqDYJOoOTOWTh0boggCDx1bYX/5q8p1sZo7vyg
6WSs3W2ptG0EADnPE7hUaTytYxchkknIuhPH7eHbUCdnYePjTM6LVAx6ASRiLN3skRWzQ+bhiNzN
gYRt56n00yDsgryx9HRCr9Fx1n8MLaMXYOVlbPGoUeZzxOMrWtyahn2AJ4IgoMnM45fA6fgOqIPC
zY7cmFTyXmWQfD4SiQQkEjGqrAIkcjH2Pg5kxGRQfWRV/Dv44VbJDbm1nEP9jqCMy6XH2V5m121V
6RVUG1uLysOLIraCXs9yl0W0PtCL4g2Kop46jY41jt/iHORB1tNk7D1tqDu2IpW6+zG/zHbarG5M
YCdzN4F1tXfhGuJFs5XmWq7wL4/xePtDrJ0UtF9Rn4A2JU33464eJ1Gma+hxorvZOtp8LYtcfkQq
FeNd2ZVuWxri6GMkzBmxShaU382Qx4NwLFXULvPx3ieED/4FTb6OoRFd8a5i3q5Vp9Ez32cD1ac2
5M2dJCL3PqTXrqYEti0JwIkZN7m96wUDI0cCoFKq2F51HQpLGPRLC5bU/JngwVUJnVaUns9NzmVz
lXV4BjoSez2ZFuvaUv7zouyCwWDgwpTz3Fl1C0t7GSU7BNJoaZFWVZOrZm/9jYj1OkK/CeHIyAv0
jZuM3E5hXHfIQV4cesSwx/2wLmbFxe8juL78Lp2iZnCy+SoMBSp63h5i9oN+a/EVrkw7Q9D4JlSZ
UbSvpPORnGy9hlZ7ulG6TQBv7iSwr/5aijUOIv3ic9o+moGVp1Gvp0rL4WiFbynZPpC6az7nxf77
nO+zAwsfV2SWMhrcMX7gCTo9VxvMBkGg0dUpAOS/TudEhWmIJCLkrk74n/mBpAV7yAi7QPUXGxDL
5aQducbT7vMJufYjNkElyThxm8edv6PyxXlYlfXkQfvvyL7+HLFCjqxedbQPI5FXroDT3qXkLlhL
zoL1FIs+h/bWAzI7DMX+3G7IziG7wyCsToQhXLmOev4yZBFX0XXsjODpg6FlR0Qzx2FYvAdGfwZ9
p8C2+cZIqqYANBqwtAKpJRTkGDNBGg0YdBgTqQYmT55kKsB5F4UyrcLWof8NeDfrpdVqkUqlCILw
b/vIfiwUFBQgk8nek7MZDAZatmzJlStXPtlY/j/Ab164f+j+J8Bf7WL1rhY1JyfnPS3qn30IP0UD
gsJ9fMgWqL/e/oeKrhZGp5VKJUql0nReRSIRq1evIWzfXqNvoVhifPErU43FCnfPgTINZh+E73sZ
C65+DEf8+jl4ekO31pCWAgtWQq16iMcOApUa1eYDUCUUacniyNo1Q1Cp0O48gPZ1CgmtRlCQq0Ns
ZYnz7iWIra3JGjIduwaVsQgoSe6V+0Q3GIZBEEjZcwWLPp1QNKyBY+s6OHQ22lOlLd2DxNoC51bG
VLZOmUf21SeUntAOQaMjIyKSm23mg1jEyeBpHPH4imu915EXl45Dy+o4D21HpZvLKLNmJBJrBXUi
V1LzxgKqHJoEgkCxmv6U6FMPx8qlUbg78HjMNjyaVTARVYCHE/fhVMkH+wCj5ZBYLCbtagyCWkvw
jLYEjGpMtaXdqLd/KGIR1N03lE4pi+lWsJJmEZPRWVpi4WpH5Ml49nU6yEKHxSwtsYLnByJxKudE
ZkyG6dq/uvyKvDd5BPU1T+lfm38FhbMV3vXN27ZGTDuFg68Lna+Ppl/GbEr2qs6ZOfeYWWwd+ZkF
uAWZRy2Vibkk3n1D9W/e7+oSfzGBSmPq49uvBrv7nGZV7f3E33lD5qscHv0cQ8s17xcq3NtwHxtX
W/onTUErtWRB4G4iVj9GEAycnn0HjyoeZkQVIPDz8pRt64/EUsr2DkdJup9qNv/2hseIZVJCRtSk
+caO1F/Siu3dT3Fq1i1yUvI5v+guzda2MS2vsFPQ/9lwJI42fF92N3q9yIyoAti42zD4+XBe309H
EKB4qHlzBJFIRIM5DSlez4ec1ALK961kNl9uY0GXc/3QI+Hg4DPUWdIWuZ3CtG79NR3walCGnypt
4eWFOC7NiaDRoSHIbRU0C/8Sdb6OA823mbanVqq4syQCW38Pniy5QE5ckYzAo4EftVd+TniPPcSd
jORA042UGtqEWge/xqtDVY7XnG9K/SuK2dL41FdEbb/NhQG7ON9nBwHrR1L92gLU6bnc+WINAGKp
hOqHxpL7MpU7o7cDkHY5CkGrQ6NU4bPuG+SexfBZNBR5cVceNp0KQLG2NSk+qj0Pm05Gr9Lg1LwK
3qPac7fRFC669aLgdSby4HJIvD1xPbgC1xPrKTh+gdx1e7AeNwiLWiFk1uuGRZNQbCd9SU7rL5DW
rITN5OGoOvRC2r8Hsnq10LVtj2TvLrgZAWlvEHXoinj6IJi7GbbMgeELQKuG9iOMNlZIIF9pLAjV
642uAVIFxt7QBubMmUv//v3fu1//GwuY3iWfYrH4HO4ZnQAAIABJREFUN6UFcrn8T0kLdDrdR3Mt
+L1zp9FoPln9yP/v+IesfgL8WUeA39Ki/h0z/HcbA3wM6PV6tFqt6WXwoX1cC/Eh7bFUKhUWFhZm
5/XgwYNMmDzdSFL1OpDIQf5Oxyp1LgTWgsntQJ0Pm27Bz2sRUpMQZ2VBSENEXiWgTgP4vAVCWioM
GYv+fCSi+9exXDQd/ZNIlMFNMGi0iJo0RhH9CElmJnazRiOSyRCUOWhOXUJSwp3n/l2JaTHGaGcT
sROvyF+wH9kT1YWbuEz9wnRcGUv24DO1m7H1qlbHk27zQCzi4cC1hNv14Ubb+eS/TsexexN8Nk+l
ct4JHD5vjG2FUgTunoT38HbYlC9B4vwwSn3THrFUYjpfqT/fxHd8EekRdDpSTz+i7DhzUpaw/zYB
482nPZp+iHLDGyF5p7jn6Y+nkTtY49bAKG8Qi8XYl/cgPzaDWuv60Or+DDqlLKZL5hKcQsshiMS8
PBvP+oprWeKymJ+7HuCXAUcI7BmM3Mbcrur+mjtUm9Tgvefs2bZ7hEwyOiaIpVKqTm1Kj5dTsXSx
w9LDjpWVtrGjzc+8vmbsj310+BlKNyuDw68IZMq9ZDJfZhA8sg41ZzajX9JULEq7sabuAdbU249r
kMt7pFOv1XPpu8tUm94IuZWcjqf603x7N8Kn32R5zQPc2fWc1uvMO3IBZL/K5sn+p3S+8RXebYNY
XXsPN356aNR+F+g4OfUqtb8r6jYWPLAqn18ayKUVj1hUYQ9OfsXwaWBO2sViMR1/7oYgQEG2ioTr
Ce/tN+tFJppcLV7NAllfcT2ZLzPN5me/yib2zEtKdKnKvkZbSLmXZDbfwk6BXQkHDMCTtbfMPpJF
YjFNtnfDMciDHa32U3ZgbVxrlARAbm9Jq/OjSX30hvC+B4yNKvocQOZgS5Pbs/DpWoOjtRajyVWZ
tlf2i5qUH1qPI5124FjLjwoLeyASiaj0Uz8UXo6cafCDaVnHIC/8RzYkevddSk7tikf3esjsral8
ciYJ+68Tu/aMcRzOttQ6PpGXGy5xue0Sbg3ZTMnNk/GZO5io9tPQZigRSSX4HZpN7pNXvJi8GYAS
s3tj5V+cB/XHE7/kIPErj2CQSZH6eOEWdRKXE+vRZylJHzQNWRkfiu1YSPbXc9A+icZhxyKEbCVZ
AydiNelL5JWDUNbvimLScGTVK1HQuCMWG5eDToMwYyayndth6VyE1p0wuLkj2r4Mcb8xiNZNhaHf
w7G10HowIokYSlc2ypj0WtDkv21mYgliOWAgLCyMJk2K7qP/RRQSWalU+rsa2XeJrFar/WhE9vfI
alpaGs7Ozr+xxj/4q/iHrP4H8G5ktTCKqlQq/1YU9bfwMfSe7463MDopl8s/io9rIf6OPVZhYVeh
PZadnZ2ZPdazZ88YNnIMIICFjfEF71UB5ApjlLVcA1AXwKNrxihr7/GwZAycPwANOyNsewgPLmIo
XwFCg+DebZi2GCbPg+mjENvbotsaRnb1VuiT32BxYDeKDavRHzqGUJCPdb9O6F4n8abW5wj5KnLC
ryPq0x1Z/drYtqyLoloQAGljFmBVwRerykayl33kMurkdASVhkctp3PJrhNZFx4h9yuBtEU9fJ/v
x6ZLM2wr+1N6/QQcWtZALJWSufssxSd9bjpPOQ9ekB+XgvfAxqZp8T+dQqyQ4dq8yBA/av5hFG52
FKtTlDZ/ucVYsOHZpijSmfcqnexnSZQdVlSoBRC18gLlJzQzuz8iV11AainDo2mRpZTcRkHGtViC
Z3ek5bM5dFauosauoSi1FuQk5vBo6z3W+a/g0rSzJN1KICY8ElV2Af49zKOtz3bfR6/WUbqzual/
8tWXqDLz6fRoKl1efItaYcOWZvtZWWkrMadfUWuSeXU9wMmRJwjoVQXLYsb0qFQhp/mOHrQ5MYDs
xDxSHqcSseAaem1RZ6dHu54glkoJ7FfVNK1M+/L0i59IZlIBiES8vhT/3n196dsruIR44+jvRv1V
n9FsX1/CJ15hd9fjXFx4Gws7SwL7hpit4xbiSeezX5CXqaYgW2XqzvQuImZfwqGsKxXGN2Nn421E
HS2qDjcYDBwfGk7x1kE0DBtA6W5V2VRlI6mPi6K6J4cdx6Vmaepu6UvQ2KbsbbDJjLBGH3rKq/Mv
aXX/W3KTcznSfKPZ/iUyCbbFHUAkIuVCjBmZtfKwp9WF0UQffsbeBhuIvxRHvYuTjAR0ZW/sg304
UnWRaR1BL5B2+xUiiYSc58mm6WKZlFpHx5LzKpOr/bcCEH/sAc+XncW+RXXifjiEJsNYwGbt703w
7nE8HLOdzFvGrlvWvm7Y+nmQfOYJpfd/j3OXhriN7Ypdg0o8qTPa2BrZ1RH/I98Tv/QQ6SduIZJI
8BzZluwbz3k5cyeOm+biEXkCQZlLxqjvENvZ4PLLT+TtOkbe3nCs2jbEfngPMpr2BQs5zr+sR7X7
KKp9v2C3exn6lDRyhk3BesN8hIRE8vuNQNqrC7qDh9AfOIg4KAjR0O4YOvXAcO8agjILUYVqiI+s
R9S8B6JL+6ByE0QZ8eDkCa6+RkmTVg06tVEWIFGASMqNGzcICCh69v4bI6uF+Ktj+9RE9vfGl56e
/o8TwAfCP2T1E+C3Iqt6vf49X9QP3VL0Q8oA3m2BqlarTeO1sLD445X/Jv4KWS3swKJUKsnLy0Mq
lWJvb/+b9lgajYaOXbobi6n0GmME1c4NspOMkYhhe+H5JXDyhuqdQNAh2r8GLh9CXLURzA2DiZ0g
LxfRxbNQsxXY2EC3/pCUAEf3oE9KQRX1Bhq3R1rOH0k9Y1W4/vt5KNo2IqvnNySXbYIuNgGb7Sux
jbmOYlR/dOevYj99KPA2Mrz/JK7T+1HwKIbkGeuJ7T4NRCLiV4SjKlEKmyHdkLo5UfrWVlxnDkZa
3I3c/Wdwm9zTdLypW8IxGASc2xW5Arz4eh1e3UKROxUVH8UtPoLvuDaI3omOv1p7Dv8JrczJ5rxw
yo1tZlZwdOfr3Xg1DzLpBgHeXImm4E02pXqap9efLzlDwDfNzPaTev0FeclZlP7CSBrFYjGeTQOR
WskpVtOfdpmr8BnWjMiT8expup0D7XZjV8KRN3cTze6Rm9+eo9LYBkhk5s/S1bFH8e9fG7mtAit3
OxqFDaLbm3moDTIMBgNHeh/i2YGnGN5W0Ocm55J0O4lK481T5wC3Zp2lVJeqNPp5GNeX32GV30/E
novFIBi4OP0iFUe/T3w12WoK0guoOKsdpyeeY3fLveS9MVoyZb9W8nDnIxqsL/qYKNGqPN2jJpHw
OJPTMyIIHvm+RAHg1rwruNUug12AN5srriHpVlH0VPkqizurbxK6pTeVZ7SixtLP+bnbAe6vv2e8
joeek/Y0jbpbeyMSiaix7DPKfVmXLXU2k3gzgZjj0by6FEf9/YMBCJ7W0oywqrNVnBzwM0HfdsC2
rBtNLk8k7VkaxzpuNY3h1clInu++R92I2WjUBo43XmE2fns/N2r82Jmkm4kU71MHuYPxw0AsEVNr
/wgMUinHmxjXuTXuZzKepFDn5VrE1pZcaTLftB0LZ1tCT08kLuwW17/czqWuaym5bDgBYdNwaFCR
mzUnmN6JLq2rUnpCZyJazicnKplLtWagyRdw7tuGuH7zEN4W85TcOhlBqyOmp7EHu23N8pRcOJSn
3ebzpOtcnn2xGMt+nRG0ekQKCySO9rgeW0PuhgPkHT6LPLAszutmkzFwGrq4BOzmfIWsdHEyGvdF
FlgWx7WzUQ6aRN6yzSg8XFGt301WyVBcHJzwinlFw6cvadqmNa2ylfQIDqZSQAChV09RMqA8imM7
4MpJhJjHSJ7fwZCTBYkx4ORq/PDOTwc3fyNhFctArwa9CkQSEFuQkJCAm5tRF/3/E1n9V/jQRFan
0/3uvtLS0j5696r/K/jHDeAT4tcV/QqF4l9W9P9d/F0ZwLsPqk6nQy6XvzfeT6WL/aPjeLewSyaT
YWVl9YeFXR06deHli1gQGYzpMUEH2W8APbQYAys/B99qMGwLjC0HBhGGCk3g2n6EEQsQLRqO4clN
aNETw+SNiNp7YZi+EHb8BHMmgoMzrD2Mwbc8olruSHcbu+ioZ89DFxePfl8G1K4PbTsje/EIi27G
1qp5X81EEVIOi5AADAYD6SPnoMvM4fXAueiVeYg93THoBLxizyB1N361J5VoRLFp/UzHm/nTQUQy
KQ6tiohpytwd+HzT2ZTu1+Xmo7z+lMCl80zLZN2MpiAhHc8uNVAlZ6HLVZF28SkFyZnYlHEl/YYx
CpUfn0FOTAqu9f0pSM5GZqtAbCEh5cwzGh4dbnae747fT9n+dZHZKEzT0m/FkpeURZl+5oTuzjf7
KdOnNjJbS9M0QRBICn9IzT3DkCrk+I1uht/oZuS9SueY73hwcOBQqy1I5BLK962CWw0vsmIzKD+k
ptm285OVpN5PoN6ufmbTpQo5quRcqm8eQPaDBMKHhHN+wlkazG/E4+2P8GlUFgdf8x8cVVY+iVdj
aX1jAo6BnnSM+547Uw6xp10YxQKc0eRpqfxN3ffuuTsLL2Hv50bQN03xGxLK2ZYrWeW/hnZb2hJ9
9AUulbxxDDAvqrIsZoNf72rcnn+Wq9PPYlfCAb/ORQVQ6U/eEPnzEzo8nYmNjxO3JhxkV4PNtN7S
Ef/O5bkw4Qwu1UpQrLKxAYD/gFpYe9tzqssGsuOyuLfhLkGTmiF96xYhEomo8n1bZHYKdjTegUwh
IWBsUywcrEz7DJ5mlDDsbbCJ4qE+WHo6UW600WbL0sOBplcmcqL6d5zsvZv6y9tzsucuyk7rhH0F
H+qcn8qFKlM402UDjfcNAECTo+L2lCM41A/ixdqLeLQIxr250cpMam1B/TPjOFVpOofr/EDWwySq
316M3MmOkBMzuVZxNHeHbyZk5RcA2JXzJHDO5zwavxuXfs1wH2Acq+/WcdyvOoL77eYQctSoOy05
tQtZ155zrtJErKsE4Ht+JSJBoOBBFJGNxlDu8gok1pb4HV/A48qDSPnpMG5D2qHw90afpyL16A1c
n59E5u1BXs0Q0nuMQ/7sGPKQ8jgtn0JGnwlYPDmGdffWaC/e4k293rjHnMR5/1ISyjQnI7QbRMVh
Z2dHg8cJtBk6ikqVKuHr6/unpVS5ubncuHGDx4+fcPGmN+fOnEGv06MvyIXyDSD6OngGQfJz0IqM
ZBWD8X0nllNQUICdvT3paWl/an//CXwqIv1uwdZvjaGwsKvw73eLp/Pz8xGJRGRnZ7Nt2zZKly5N
amoqtra2723rQyEjI4OuXbsSFxdHyZIl2bt3r6khwK+h1+upWrUq3t7eHDly5KON6WPhHzeATwC9
Xk92drapQl4ikaDVarG3t/+o+1WpVCZf07+CwoIptVqNSCRCoVD8boq/UGf7MY8lNzfX9AX8LgrJ
v1qtRq/Xo1AosLCw+FMv+YGDBrF9xz4jUUVs/FskMlbVit9W1soVMO0sfN8MrOxg3H7EK/si2Nog
Sk3EoMxE3Lw7wqR1sGwc7F2KyNUDg1oN+Tmw8xwEV4OpQ5E+u450whi0M+egfx0PofVh5UawskIc
WALrrUuQt2qMoNOhdAvGafE49Emp5KwNQ5uaidSvFBajByHv1Zm8pl1RlPbEccN3AOSHXyS92xjK
JYcjtjQSwmjfjriN7ozbyM4A5N2L4mntYdR4sQldZi4FMUnEzd1D/r0XuDYPQZWQgSo5k4KkTNDq
EMkkRpsqmQS9RodEIXurQX1rIaPMQywzfgwIWh2CRofhrdemtY8TVh4O2Pg4I3e3JXrdJaos+gzP
lkFYl3BGLBFzsv4iHMp5UP2nosivJiufMK/xtLwzAzv/os5JTxefJHLZGVq9XGh2D17puBwQU+3g
GARBIGHfNWKXHifr9gvECim15rambM/KWNgbie+JLlvQFRhocnSI2b3wfP0Vbk/7hfbxixBLjBKd
RzMPE7PqLFqVhhozmhLyTX2zfZ/stYucpAKanRltti1VWi5hJadg0AvUX9yGCkOqmSLHqqwC1nvN
pcmJUbiHFnX6erryPHcnHUSn0tEpYhSuVcwLnDQ5KrZ6z6bmtoFoswu4NWwblYZUJ3R+U8QSMT+3
2YHaIKXJsaKPhJgdN7g2ZAeBvYJ5vO0+naNmYO1p/iOWfu814Q2Wggh6pi8wi3AX4myXDbw69oiG
B4bg3SLwvfnXhu0ieus16uwbhldLc5/cnJg3nKzxHXIbOVJHO+rfLfooyotN5UKVyZTpUZnayz/n
fLdNpD56Q81HK4hfd5LIsRtpdHUyDkFF5+L13htc77MWly51qLhtTNF+HsVxo9Z4ghd2o/TQJuTG
pHC22nTkQb6oH8YQ8ngdFp5G3aD69RvuVhyKz1dt8Z3ejbzIBG7WmYhWpcW+RS1K7jNGT3WpmTwL
6kWxXk3w+cF4XrOORRDddSbFujQgbd8FrCYMRb3zMLKAMjgdWGlcpvc4NBF3cIsMRywWk9FvMqqL
t3CPOo5IpyOlelcMegF5di7OdvY0D63HkMGD8fHxMdk2FRKzX1e3F/7/j0ibwWAgMjKSzVu2cuDY
cZJeRoFMAfYekJ9lfLfpVMauV4JgjLIatACkpqZ+kmzZX4VKpTL5t/63odBZxtLSEkEQSElJYdWq
VcTExBAZGcmrV69wcnLC19eXsmXL4uvrS/Xq1T+IZnj8+PEUK1aM8ePHM3/+fDIzM5k3b95vLrt4
8WJu375NTk4Ohw8f/tv7/oj4zRv8H7L6CSAIAkql0pRa0Ov15OTk/O4X0IdCIZH7M192hZWUKpXK
FEW1sLD43c5ShfgUx/Jreyy9Xm8i04XT/4rrQEREBA0btwBEYOlojDDoVeDbAiKPgJUTaHOhdFWI
MpqTs/QJ3DsOP30JCisIaQV3j8H+F5CVCv2rg1wOHUdB7CPEQi7ClhNQUIColhsGjRaxtTVCUC24
cwHR/WhE1jYIC79Heng3dk8vQoGKnO5foj162phO9C2D3i8Azp/BMfGusRArI5OsEtXwuL0fWTmj
TVNKxQ7YtamN6/dfGs/XlfvENR1BubM/oopJpOBOFG82HkOfnYdILEJia4XU3hZ1WhaKEH8sgsog
L+WFxNOF5EGz8bu5Ccsg47a1bzJ4UqIjgU93YFHS6EkqqFQ8cGlL4MUlWIcUaVjvluiBy+BWKMr5
oIp8jSomkYwjEYgFPXJLCzRZuegKNFh5OKBKzaFUzxr4dArBqUoJLN3siBi8lZxnb2h8cYLZ9TpS
eiJlx7XE98tGpmmCTsch55HUDJ+Ic20/03RdropjLoPxGdqcjCM3yU9Ix7dzRQKG1uSX1htoeuxL
3EPNPVrDfL+lzIhGlPuqqdn021/v4uX2G4h0Whz9XKi7vB3u1X3QaXRscJ1No8Nf4l7P3Poq6Xwk
5zqsIWTdQB4M34R9CQeabf8cJ38Xrn97hme7HtH+6Yz37skr/bbyct8drFytaXmoP84Vivxfb39/
mmebb9M6ai4A2c+SON9oIY5lHKg+pT5HPttN59jvURSzMdtm2q04TjRcjIWTNV2iZyL+lSSiIDWH
PSWnI7aQ4d3Inwa7vjBbJvdVBvsDvsN7SDNerz1Fg139Kd62SAOs1+j4OWAW2NmheplCs4hJ2AeY
+9ZGrTnP3W/2Urx/fSouM49oKx+95mLtGXjUK03K5RfUilyDhavxPRIzbQevV4fT/NFsLN0dUKfn
ciJwCoqaQShP3yZ411hc2xbZl6WG3+ZBl/lU2z6U+yO2YVm/MiW3z+B1/7nknL1N5ZhNiN++y5RX
HvOo2UTKzu3Ni5m7sezQBKepg3gV8jkeswfhMqorAPl3nhNddyild07DqX0omoRUHlcdjC4rF6er
+5GHBKJ7+Zq0iq2xmzMG2xG9MRSoeFO5A7KA0rgcWIZBpSa5ymeIPV2xLlWcvH3HqVK5MnNnzqJS
JXNXhUL82nP01//+V1ZNv/UOfPnyJdNmzOTC5WtkpyWBtQuoc4yEFZFRHiBoTMtnZGT84Xv/U+O/
nayq1WqsrKzem/fdd9/RuHFjypcvT1RUFNHR0URFReHi4sK4ceP+9r7LlSvHhQsXcHNzIzk5mQYN
GvDs2bP3louPj+eLL75gypQpLF68+L89svqPddV/CmKxGEtLy/e6S31s/Jn9/DstUP/qPv4uCqUG
Go2GnJwclEolBoMBOzs77Ozs/lJhl1KppHvvAbx1/jdO1BdAk7kQ/Quici2hRG1j9OHFHZDKEXcY
C3EPYNPX4BMAS54gfnUPUcchiLfNhb5VwNUHwhKh8yi4eRJh3Fz4ZR/U8caAGAZMRjiTijg+BvGX
oxFZ2xiNpLetR9qxJQVDJpDpFoz2/DXE3XsgeRqN+EIE4gf3sBw/DNHbl3TeVzOwrBViIqqaqFjU
kS+x7Vif7L2nSB65iNgWoxAK1ES2nEDCzG2k3opFr9LgvPsHvHNv45V5E+tZI5FYW1Li/Do8Vk/B
efwXFFy+h03VABNRBUgYswz7+iEmogqQOGMjlr5eZkQ1++J9NOnZeHz9GcU618N7Uk9Krx2LRDBQ
dssEQl7tpIbyMNWS9iD1L4HU1Yk3j9O5NmQnB0tOYo/z18TuuY2iuCPpt2IRdMZipdQrUeS/UVKi
t7lc4Ml3R7D0csKpljlZfDRuB46Vy1D+x36ERq+i1s2FZGYaONJ8Ldo8NcqoN+jVWtPyyVeMGtky
A0LNtiMIAnE7bhD80yAaJa1DUq4kPzday7F2Wzg3ZD/WxZ1wq+vLr/Fg5jHc21XGu0sNWsSvQFrS
g52Vl3Nt+mluL7pE5R86v7dOQYqSF3tuEXp5Jk5NKrG/5jIer44wZg6UKu7MP0vFH7ualrcv50Hr
F/PQ6GUcaLmVYnXKvEdUATTZBSAWoxdEHG+yAo2ywGz+nSnHsAsoTqPoFby58YqTLVahyy8iLddG
hmFfw4+Axf0IXDWY8903Erf/rmn+40Wn0WsM1Lj9A8W/bMmpOvNQRqUU7T8rn/tTDuD6RTNebbpE
1ELzH0i7oOKErB9EwunnFPs81ERUAUp/2wOXVlU5U2022jwVEZ1XIC/pid/Pcyi58mse9vyRnEdx
puVdWlbBd1ZPbvRcg8TbnVI7ZiISifD+aRxSd2ceNxxftN86gXhP6ErUpG0o2jTAfeMs5KW98Qj7
gaTJP5F37REAVpX98V41jpd95pC+5yyPKvRDFByErE4NcgZNBkBaqjgOe5ahnLgQzb0niCwVOP+y
joLTEShX7USfmY2iXGl0V+/Sx6E4T+7cJWzHToKDzQv/3sW7msrCoIGlpSXW1tYmTWXhx3lhKrqg
oMCkqSwoKECtVqPVatHpdJQoUYJtWzYTG/WE9evX4+1ibySq0rdSG0EDIimFqkAnJyeUSuXvju8/
gf9VPW16ejqurq54e3vTsGFDBg0axIIFCz4IUQVISUkxaY7d3NxISUn5zeW+/vprFi5c+D/dnOB/
d+T/Y3j3Zv5Pt0L9rRaohZXyf6YF6m/t42MdiyAIJj1qofFyIZn+q1pfg8HA5937kJz4toBKJAGN
EoqVg5PfIPJtgiGgIzwPR1SmHtQZabR+ib0Piz4DRw9Y9AAenUNIiMJw8CcMl8JBKoPx640R1/n9
wMYW0ejuMHUYaLWwaD8MmQ53LiMkv8Yw8EsMBQUYRg5CeJOKetUWVE+SMXQdhsjaGsnSFYjt7BBu
3kCfmIjFYKMxvqDToTt2GtspQ9C9TiJ380FS6vXBoNLwot4QUiasIeN+PAatHsd74ThlPsI+6iLS
gDJYVgnC5vOWiN9Gp3PnrcNpbC9E75zDvANnKTa+KC0vCAK54RG4fNPN7DxmbT+Jx/iuZtNeT1yH
+8BWSKyKdKmpm46DVIJji6KKeHkxewoexlJy2QgCI1ZS8fU+quaF49yvFQaRmIwnaZxv/iP77IZz
tsFCIvpuwLtdCFJr89Rk7IbL+E5sZ3avCoJA0v4blJzYwTTNNsiHKsemILW3wblNdW5PP85O98nc
nRVOQWoON8cexHdgfTONLEDMuosgleDevhpShZzKW0bQMHYVuWoJUXseYO3jaCSD7yDjfjypt2Kp
uNzYIUgsl1Jj32hCT0/m7qprIAJrr/czEI/nn8KunBcOlUpSae0gqoZ9zbUp4Rxvv5nbs09h5e6A
dxvzKJxUISd4fmckljJSLkURG3bHbL7BYODmqH149G1EaNRK8rM0HK62kLyELOM1fJpM9PbrVNr9
FXInG+o9+5GceCW/1F+KOiufxHORJJ6NpFLYNwB49WlA0LovudhnCy/23CLnZRoPvg+n/I6xiMVi
yszphWe/JpysOYfcWKP28c6oXSiKu+G3YhgVjs3i2awDxG44VzRGvUD0/CMoypckeecl0k4UHYNI
JCJgwwgs/bw4Vmo82c+S8Tu/FIBifVvgPqoztxtOM1X3GwSBrEuPEcmkqF+nIqhUb6+BjNJH55Mf
nUTM8OUA5D99ReKPBxAX90R17haCxkjQrZvWwnnaYF62/gZdhtFRwalvK6yqluNF3zlIRw7ENnwn
1nvXoEt6Q/awaQAoWjbAduwg0pv3R8jPR1qqOE5bF5A1bhHp5dvS3cuPmKfPmDVt+t8utvk1kVUo
FGZE9t0sk16vR6PRmIisWq2mbdu23L0Zwfnz5/Hz8wMMRqJq0AFvJQGAt3dxIiMj/+VYPiX+18nq
30HTpk2pUKHCe39+ncr/vcj60aNHcXV1JSQk5JMEyT4W/iGr/wF8SKP7f4VfNx/4vUp5Gxubf7vL
VOE6H/pYdDqdiUwbDAakUum/RabfxbjxEzl//sJbnepbfapeC4m3QCzFIJHDz0MhpBuGfkfg6jJQ
52FIjAWZBQxaBa8ewbphYOcMfZZhKF4RcfnqEBwKV47AzZOINBoMNbtAve6IfXyhhtEWSrxgBOLm
rREtWYghqBSEH4PPBmCIyMCw+QySU2FIxo6nMlNPAAAgAElEQVQzEUjDlIlYDeiB2N4OQ0EBeV+M
RlDmkN57Aon+rciatRYhKwf5+lVYvnmF/PEdxG5uKBrWRlaxPGAkcNr94dhMHGg6D5pHUWjiEnEY
2NE0LWvTIRCLsGtVFMFMXxmG2FqBbeMispl1+DK6fBVOnYuq47UZSvLuxeA2sogkAiQv3IvX2M5m
Wsg3209jEAw4tikqfhKLxSiPXsd7ai+C7q6jcvphgm6vRSjvR35iFonH7nPYdSS3B20m6Zf7xB+8
hTanAK+utcz292r9OZBIcG1V2XwcB66hL9BQYe9Ear3egv/mMUSHPWR38Wmk3X2NV/v307FP55/A
d1IHo2flW1gUs8OtQzXENpYoX+UQVnIqkesvY3j7jD2cHY5LvQDk9ubpQIfKJREEsKrkyy+1F3J/
9i+myLEqLZenP12kwuoBpuXdW/4/9s46PIrrffufmdW4EIIFd4oFd2uhuBR3L5TiXtydFi1eIDjF
iru7Q3AnBCLEZbNZmXn/GHaTJdDSQmm/76/3deVimTNH5szs2Xue8zz3U5wvn8whJiiea7OPk6tX
9TTjk2WZ64M2k6F1Vb5Y1pfTnQO4NnqXfSzPt17DEBZHwR87otZrKXdtFro8WdjhP42owJec77MF
n5rFcM2j+AarnfVUvj0biySyq+xsTnddh1/PWg4qEZlbV6bI6j6c6bKWw3UX4ln5C7yrKH6sgiCQ
d1YnMrWpyoFSk3gScIag7VcptHucMgdVilBo0w8E9l3Ny60XAEUOzfAqlkIXl5B9Tl9uNJtB3PUn
Kc+FRk3WvvWxxCehzpEFUZ/ywpJ5YlfcqvlzsfRgJIuFJ2M3EHXmHtkf7UGTy48HlfvYz9Wk9yLv
wR8JW32YoInruFlpILqW9ckQuAfRLyOvvvw25V4N7YxztVI8rtATSZIIHb6IxEv3IGs2pFMXlXF5
euC2Zw1JAdtJ2rIXAOexfdEUzk9ktfYkn7yIafhsihQtwvH9B5k5eQpeXik6vH8X8RIEAZVK5UBk
bRHuLi4udrcuQRAoVKgQJ48e4MSJE/iXKqushUggW7FluipVqjTr1q375OP8K/hfJatRUVEf/YJy
6NAhAgMD0/w1bNjQvv0PEBIS8k5ifPbsWXbu3EnOnDlp3bo1R48epUOHDh81pn8C/5HVz4Q/m8Xq
U/Vps6LaZLIsFgvOzs54eHig1+s/ybbAp0o+kDpzV0JCAiqVyj7ODwks+D1cvHiRhYuWg9pTsSRk
bQDIkLEc6DwAAQK3gloHFfvChCyKNuE385C9cyNkyY94bS8MLwNOnrDgJZRsANf3In3VDrFPZRjX
EgqURV4fBu3HIxxfi9R3mhK4tTMA6eFtpD074MQZxV1ApYYxCxRf1+N7scZGIbRWLJvSiyCsgYHI
nm4k1m5DlE9hTDuPQMlyWEbMQL4XgbV6bdSFC6Ft3Vx5niwWpMNH0A/rab/u5OUbQaPGqW6K7mlM
/6l4tqiFyjslKC56+mrSD2rtYGmNmvsrGYa0cZj30LEryNSrEaI2xXfs+eDFuJcrhD53Fvsxw+1n
GINC8e3ytcN9eDl1E5n6N3Xox3DrKUlBoaTvkiKS71wwO7LRhHu5IhSL3ku2lSOJeGXkcrfVnG22
EI2XC6E7r2AxJNvrPJ61l5xDGzm0DfB47Gay9U8Zs2+j8pQO/BnPqkUQXXQcrzeXs62WEHtP0Q0N
PXqXpPA4snZOSxKfzNhNrrFtKB24kLwLenF1xC52Fp3M081XCNobSPHFndPUCVp7BrWznpInplP8
6BTuLT7DLv+pxNwN4c6PR3DLlQHvso4uBVpPVzI1K4vG243AUdt5+PMxh+9Y2JG7xD4IpcDCHmRq
W5XSZ2dwf8lpjjVagik2iUsDt5BtUEO7n6YoipTcMwrflpXYVW424RefUuxNSl4bRLWaCpemImu1
JL1OwLepo5oCQKZm5ck5uCEJwTGkb+IooyUIAvnmdce3SXku9VpHxl710fulaEymq1eGfMv7c7Xj
Yh4vPMD9yTvItW0SolpN+m71yDykNVdqjCEpSNF3TQ6J4lanuXgN6kDys1Ce9Zzl0FfOtSMRvT04
U7A3z+bsItPRFah9vMi0cx6m8BietptgP9+pSG6yzunLiykbUJUtjtfiiQgaDd47F5P88AXh/abb
2/VdMxmrLHM3exMiVuxCf/wgTgd+w3zjLoljlTGoixbCZfF0YrsMx/I8GEEUcV89k+TrdzA27cui
MeM5ffAwhQoVcpijf8qyZSOyGo3Ggcj6+/tz/PBe9u/bi5uHjVBL2Nykvvvue/r374/RaLS7Fvxd
WaB+D/9mi+DvkVWLxfK3+tk2bNiQ1asVlZnVq1fTuHHjNOdMmTKFFy9e8PTpUzZu3EiNGjUICAhI
c96/Hf+R1c+ED81i9algi5QHJUDJlgLV1dX1o1Ogvo2PvZbUGq7vyoT1sfJYcXFxNGvZERkNWGIg
+zcQvBuKDVT8taxmhLxNEJw8IIs/zCsP5iQYcBEK1YW7+5AfX0W+fAC0TtBprpLWcG4LJWHAvD5I
oqeyvvdZDGo1/DIMfDOD0YDQojhM+g4KlYUtz5GWXUI8sQWh+1DQKdvm4uyhqL/7HuLisC5dgqVa
FZAkzGt3YUz3BfSbBhoNbD4AjVuCKCLu/BX1kP726zT/OA/RxxtN1RSSYZy1BPchXe3WTclgIPnC
dTwHtbOfY7h2j+SnL3Gp4k/SjYckngskYtkOkp6FoMmUjrhDl4g7cpnobScw3HmKa6XCGJ+FYo6K
w2oyE7PrHBmHpGiDAjwf+DO+zaqg8XZP6efhS5KehODbvZ7juYMW4dOsmsO5kiQRs/McvkNaIooi
XvUrkH/PdPJdWAJqNdpyxbg1cD1703XnUtM5PJq7D8PLCPy61HBoO+H+SxIehZDlu7oOxyWTibjz
DyiweypF764iJtLC/pITON1kIVd6rydnr1qoU0ltAYQfuI4xMo5MnZUo3kztqlM+dC3OlYtxutNq
tF4uqJzfUqywStwbt40sgxQrtkfZApR7sQptkdzsKjWN2z8dodDctFYOc3wSD2bsJG/AUPJvG8eN
Uds512oplsRkZFnm2qDNZGxbzS435VYkBxUeLSH6cRRbco5CMkvkGtYkTbuF5nZF7e2GJclCxP7r
acotMQYMzyNwr1+ZyzUnEnE00KHcakgmaPFB3BtW4f7AVbwMOOpQLggCol4LKhWv1xzDHJPgUJ6h
dTVyTenE7cHrcatbDrfyKQoDGUd3wLt5dS6WHYo5OoGbzWag9y+I76TvyXZ0CRHrjxAye5P9fFGn
Jcu0HhifhaPxL4S+iOK/rPJyJ8vhJcTsOkPo7A3KdUXFETo5ADFzBiwXA5GiFHcIVfp0pNu/gtgV
24nbtN/etjqDD5aoOITveiAWyIeYMQP6LWsx/rgE06ETAOjaNMGp3TdEV25F8oVrGL5sT5369bly
9hwNGzRMM7dvz9O/BYIgUKFCBR7cu0O/fjZ1C9t6LvHLL79Qu7aSpc4WTJSYmEhCQoKD5ujfRWRt
7f2b5iw13kdWPwfBHj58OIcOHSJfvnwcPXqU4cOHA/Dq1Svq1av3zjr/1nn8I/ynBvCZYMuCYUN8
fLzdef5TwiajYZPJslgsuLm5/a3RnXFxcXan/w+FzeJrk9fS6XTodLp3+qGazWYMBsNfkseSZZmG
TVpy6MAh5dVMUCuR/1mqKCoAYReh7jq4sxqeHQCdu0IEizVE+vIHmF1KEdKuPQVeP0AIOoY89iTC
hh+QT61ByFsR+ds1sLwTorsz0phtkJQI7bKAIQHB3Ru5aG04/ytsfgTps8C1kzCkLpx6CW4ecPEk
dKqBmCsXUlAQQoasyOGvYPUJKKxswYsNCyE3bYncT1mMWLsC4ccJOD+8YbckGgsUx2lcP5y6KP6k
pks3iKnUFN9di5CiYrA8fUlCwG9YHj5Hny8b5ogYpNgEZKsVQatB1GkR1CoEtRpzXCIqZz1qZ72y
6MpgjopB0KhRqVVIJjOSyYycbAYBtBm90WVOjy6rL+qsPoT/so9sY9qR7puK6HNkRFCruF1vFGp3
V/JsGGW/P5LRxOX0TdIoC4Qt2UnwhLUUe/GrgxvBw29GgySQfYciz5J0+wlhk1YSv+s0ssVCtu61
8OtZE7cvFE3Ry7Unok7nSaF1gx2ei0cjVhOx6zJFbi63L96mVxE8aj2JhMv38alSkC/md8ElT4qE
1sniQ/GuV4Zckx3JpSkillN+nXDO44fpRSjF57UnW4fKCIJA8JaLXO+1mgqha9LsYtztMpeQDcdJ
Vzo3pTb1RZ8pZav4wZTfeL7yJP4PV9n7uFN5AIIpmbx9v+TWuF1UCVuF+FbecYvByDHvdohqkbLH
J+BRytFi+2r9Ke72X0nm+QN40XUahaa0JkffFIv27e9/IfzMI/JfX0XEoh0ED11I8Q398a2vPIcP
fljHq60Xyf/gV2J3nuJ56zEUWtyTzO0VK3Ts5YdcrjqSnJcDiBi1mKRLtyl9ZxFq1xTXiCeDlvNy
5UFkSabwteXoc6YE78lWK4+bjCbuzE0EjZpcQfvs15h47BLB9fvZo/PNETHcKtwZ1ZeVSN59lHRj
vsV7UEd7W4ZjF3lZvw+5NowldNxKLFoXXM7sxNCsO9KdB/jc3We/J4ZNe4jpPpIsR5YR0XsK5qgk
5AlTsHbrjH7PVtRllOs3L1uJeexkPO4cQ8zoi2wyEZunAmJUDIsWLKRF8+b8HmRZJjExEVfXtAFx
/zQMBgM6nQ6LxUKTb5px+tQJh3JPT0+CgoKAFMWC1EoFqZULUuuVvq1c8GfJ0r95zgB7LMXbv7GS
JFGvXj1Onz79D43sfxb/qQH8k3iXG8CnevN6VwpUW8rWzxH992csq6nVB4xGIzqd7g8zd32M5Xb8
+AkcOnhYEf2XAcms+GW9vgHhlxDKDofXgfD8EGKBFlB5NpjikZy9YWpBSDbA0AdQujNcDUDOkAd6
50A+tQ6xZGPkoYcU0vvgFFLrkQjbfoKWviDJ0HE28rJQiAxC/KqVQlQBcX5/hBbd4eIJxO51oUtN
8PZFKvsN/BaKXLImYv6idqLKvZtIL58id0jxrVMtmo12YG87UTXt2IXlVShSRDQJnQcTXaw2MRWb
giAQ2W4YMSN/JnbLaSzB4YhNm2HuOQhh+RrEC1cQ9E7oj+zD6eUT9M8forlxCQFwPbYV16eXcHt2
GZenFxG0Otx/W4FXxE3Sxd0lvfERmvy5cR3xPS4rZkHrpiRmzErYjnOg1RKycDfXS/bmrFN9LmZt
Q+yJm8gqkejd5zC9UoJwgkb/glNePweiChA6eysZB7d0IKqSxULc0aukG9Lafszpi1z4LRqCJEOG
xaOIuBHCubI/cKboQIIWHyDq9D2yDvkmzXMRuuoomUc4ujhoM/sgujrhVr0USRYNJ4oO5ma3JRhf
RRF/9yXx91+RpW+DNG29nL8Hlzx+FLy1Br+Fg7g5aAMnyo8n7t4r7o7eQsZutdJ8D62JRsK3niHn
urGY1E4cLjiIkJ2XAUV+68H038g2O+V+a308KHp7OU7li3B14CbcKxRIQ1QBXi7chz6zD+n6tOBC
tTGEbr+Q0meymXsDV+E7qhPpWn5F7r2zuDt6E/d/2IAsy8Tfe8nzVUfJtmEcAD7fNSbrwoFca/kT
rzadJvHBK57N203WjRMB8GhYmezrx3On52JerT2GZLFyq91PuLevh75gTrJsnIyuUC6uFOuD1ajs
8sSev0vw4t1kOrUG9w6NuFv2O8wRMfYxCioVvgOaYU00IqbzVHYp3sClemkyLhnJk3aTSbh0j8eN
R6HKlR2vdXPw2rGEyDGLSNyXQgycq5fBd+ZAnrQeT3KsEeeT2xEEAec185FUKqIbprjLOLesh2v3
FgTX6IY5wQpnLqL6ujbqIcMwNW2LFKOMUd2tE+o6NYmv/A1SfAKWjv3JmS49Rw4c/EOiCv8bvpc6
nY69e3YRGBiIWp1igIiJScDdXTEY2IinzbXgQ7JAGY1GB8WC1FmgbET398b1b8X7xhcTE/O3y1P+
X8K/S0zt/xA+ReanD9Eb/ZzSUu+DTcPV5vOk1WrtQV0fgr9K7O/evcv0WfPAowbEHUXI3BI5bMsb
4X8nJYr/8W6IvIVQpDtSlZ8QVmRGNiUinl+NrPOAij2R3TPCwiqQFIf4+ApSzclwYBjSN4ooP8s6
KG0N+xJcvBWx7d6roGwTiAyGRxeRxixXzj29C+lRIDy5jbh7I1Le8sp4fj4DmXOCJCEc24w0ZXXK
hUzrg/hNayQvb+X/509hDXqGKj4BU6tOWC5eRoqKRvD0wLh6D9bs+eHL9vBwIuw/jzVPfqXejk0I
owegmv8zwpu5t4wZhSpvblTFUgTdTWMmoSlaCHWhFP3S5B+XInq5o6mS4qdouf0A8/NgvAd2RfT2
hDrVAHjtVx7XBeNxaqNk5JKiY4npNgzOXSP+aRTx38/H/DoKQatFliU8a5Qg/uwtXErlR9RqSLz+
CGNwOD6dUyx+ACFT16HJ4I1LBUfZn1dDFuBS+gs8OzXEs1NDJKORiCkruT9iPVajiZDlB1ENaIRz
bsWCF7rpJNZkM97Nqjq0YzEYiT15kzwnF+Hsnx/j/ecEd5zA0bx90fq4k7FFZXQZvBzqWJOSCZqz
g+zrFO3UdO1q49WsGs/aTOCI/0hEjYoSox3VFABeLt2PxscTr2+q4fVNNcIXbedKu5/J2qIcOr90
6NJ7kq6ho1yXKIqka16FyF0XiDpxm0cj1pB7Uls7obfEGXg8aTN+AWPxbFQF/Re5uNl+OkljmpNj
SCOC5u9D1OnI0FchVW5VipPv/FIeVe6FMSSapKAI3L4sjVPBHPY+03Wog+jiRGDHSegzeeH6ZRmc
SxSwl3s0qqIQ1jZjCd96Dkt8Mtl/VmSiBI0avx0zCarVl6v+ffC/9BN3W07DrUdLdF/kQTtnGFJ4
FLf9u1P4/hrUznqscYk8bjMRp55tMe0+xqvGg/Db+VNKf+3qYXnyins1BiC6OpPuuUJOddXL4z5n
DCGthpHt0jq0+ZRrMN18CCoVVoMRLBZQqxGcnXDdt45Y/5rEjp+Px9g+SLHxGA+eQUZAUqfoSwt9
+iFevoSpRj20l08hiiKahT9hrPQVcdnL0KRBA34+fMSuAf2/jLdJV/bs2YmMjKBLl65s3boFsABK
oGtMTMx7DSEfmgXKRlBtWaDepyH7b/ZXhfeT1cjIyP9SrX5C/GdZ/Uz4VJZVmy+qTW8U+F290c8R
yPW+a3mf+sCHarja8FcIt9FopFmLjsiabBB3DHIORQ7fC2ig+FIwR4AxDjn6Gaj1yP79YWUuZEME
FO6OVG4ysmRCLtgAYWElCLoENUYjDXuBELgRsVxrcEsPW0bCw7OI7hmgw2rksp0Q3H2gtELUWNID
sWQNCDyL2MkfRrWAjLlgzG6kgBBAQiz3tUJUATb9BE4uUPkNUYuJgsBLSEVKwIxxiHUrQKu64OaO
Zct+TGJGpO6TQBSRt9/Euv0GzNkMr54hFi0BNqIKiPOmoerZy05UAYStv6Ia4BhoI2/fiXaQY5Yn
8+IA9EN6ODxfiYMm4dK0jkJUbfO+9xjWBAP6prVT+vXyQLoUiNvUoXif2YL387OkT7iDfmgPJAkS
g2O533gMF93rc7t8bx60nIDHlyVRuTtmXotYtof0w9qlkauK23EKr6Ep27+iXo/vhO9Ao8Nr3PdE
XgvmQpHe3Kg1mqgj13k2bgOZBzVH1Dg+gy+GLcWpYE6c/ZU50+fPTp7zK8i+YybJEXGE7ThH8M97
7JH8ACErD6PxcsezfkWH/nNtm4Iub1ZkQcWl4n2Jv/Y4ZczJZp5N2kSGCSkKAL7fNaHgrbWEnXjA
vfFbSN8rrQVXlmWeD12OZ6/mZD8fQPCKI1z7epzdL/T5rN/QZvLBs5Gi1ODdrja5ji7g8bTtBHaY
z6MJm8k8f4BDm04Fc5D/1hpCD9wg8sJDsv3yQ5p+vZpWI+OwdhhDY3Cu5p+m3KNRFTL/2JfXB67j
1qm+A0kR9Tqy7ZuD7OrC+ZxdkNVafH58Q2ZFEZ81U9AUyM0d/+5IFgvPu89E9E2Px5wxeB9fT+K5
QEL6THfoT1MkN7IkIcmikoHpDZy7t8Sla0uCq3TBGpdAzNx1xG7cj+r4WcRceUmokqJxq8qaGbed
q0mYsQzDr3uJqNoWC05w5gnS6wjMfRU1AUEQEBYtRTJbMHVWLLHS9ZtoIqPp0qo1Kxb+/KeI6r/V
Svi+9VUQBFau/IUnT2wqDRZAxNPT8y9psf4ZDVkbkTWZTHZXAJuG7IdYZD8X3ndPX79+/R9Z/YT4
j6z+Q/izltW3t8+1Wu0fbp/b+vnceq62FKwxMTGYzeZPpj7wZ65j0OARPH54H4wPQOMJz+eBNQGq
XYBbA0EWofgcBFFSFAECioEhAhrsgC8XI5z7QfFfXVgF+dUdxIJ1oNYECLmJ/OIyktYZBvjBgbmI
RRsgjbsPRRsgnFyI3GaykrL1yXUIPIp0bh/ikpFIfuUUZYBxe6BETTAa4MYRpA4pPpzilnnIPUbB
4zuwYgY0LAjJRsTZkxCOnEAq+KViuQ24grTuOoxZDmf2IFapAxneRONLEsKhbUjfDUqZkCcPkZ4/
ReiYEq1u3bMbyZiEumGKI75581ZkqwVtw1opxy5cwxL2Gn27lIAdyWTCdPYyTgMco98TR/+E63dt
EVL5YicfPo0lJg6nlvVTrlMUsWzeh0u/rnhc2o1X+A287h3DXKUKxufhxJ0J5KpnPZ60HE/kpqNE
bT+JOSYer9aOWaailv2GoNXgUtvRChmzehcyMl4/dCPTmbVkDTqM0TcLN5tOJfHBS0R3Z+RUpFOS
JCI3Hsd3VKc0z1JUwF6cyvmTbul4nk7czPn8PYg8dA3ZauXZpE34DG2dpk7ipbskPw0hx8vDqKuW
43KloTwZEYCUbCYk4AgqFyfStXVUStBmy4D3d00Q3ZwJGhNA6PJ9Ds981G9nMUfG4TO5N/rCecj5
dDeGSCPnivQj+tRtns3eTqZFQx3adCnzBXlvrSd8/3VkUcDtHWRTk94TwcUJWaPhacPhWOMNDuWS
MZnXP29H16gmoWOWEz5no0O5LMvEbTmOmDMrkXM2EbvtmEO56OKE77TvscYnIXu4O5QJGg2+O+eD
uxs387Qlav9FPA6vBUDllwnvY+uIXb2byNlrADA9CSak4xhUU6Yg5s5NdPnmDuuoy6wf0JQowvPC
TQkfMQ9x3SbEHDkQ167HEhZJQoeU9LiaCqVwnjGKqE7DMRskpF0XwdMbAvYgb9+KdZ0yDsHFBdXm
rVj2Hybp296ILTuy9uefmT1z5r+SeH4M3nc9Pj4+xMXFMWrUaBS1APDz8+PMmTOftO93EVlbCu0/
mwzhcxDZ32s/MjKS9OnTv7f8P/w5/EdWPxP+imXV9mYZHx9PbGwskiTZxft1Ot0HLZSf0w3A5jcb
Hx9vVx9wc3P7aPWBP6tLu379BlasWAVqb5BlMEaClAx+bRGOl1cyVtUKhNADyKZEeHURnDIjZioN
OevCrsbICWGIGjeotw2kZKTaM8BshIAGYDUhXt8HteYAMlJDxYePwz+BWgsunojjv4JhpcHNF4Yf
RZr1AmJDEEvUhMxvgl5WDEbMVQgKloJkI6wYhxQaBLOGQNsKCNvXgcEAU3cjbQ1FXngWwl8glqwK
fm+yTJlMcOkoUrdUJGXLCmS1GmqkkCFh3BDUdeshpH7TnzEN7XfdEVL5PlpnzkHft6uD9TVp6CSc
O3yD6JYS4GAYNwdNDj80JVPcByyhrzHfeYhTrxSlAYCEEbNx7dEGIZVOpiU4hOT7j9H3am8/ps6R
FUwmtEUL4RlxF+fda4nDhRdDl/Go2VhEZz1Ra/ZjSeXjGDF7A95DOqTJax89dSWegzvZfXrVPl5k
WDsNrf8XaArm4eXk9VzN2pKwJbuQkk2ELd4JWg3uqSykoPjJxu8+i8eoHri1rEOWl8fQtajHrWZT
uVisL7JFwqdn2qj7sPErcf6qPCpXZzIsHYPfmQBC1p/kfKHveDJqLemHt01TRzImEzJpNT6Lx+K7
fibPhizjYaspWBOSkCWJZ0OX496juf2FT3R2IvvVDehrVeRyjVGofb1wq14yTbtIMlaDEdE3PffK
dLf7C9sQuXIvUkIyGcPOY0owc798T4c5Dp+xAUGvJ93a2aTbtZSQUUsJnbHGXh7720kSL93B69wO
3FbMILjDeOJ2nUrp3mTm1bdTUbdogjU6gZC63zn0Lzrp8Vk5CdOLcIRsWVClT2cv0xTOj9fOZbwe
s5jYDfsJrt8PoXoNNJ07od64AUusgdim39vPF0QR5/H9sLx6DX7ZEcsr91Pw8ES9bSfJOw+SNFdx
yZFNJsxb9oBGixwbp7gJAOQrBHNWYx0+FOmWks1KyJkLVbNmqPceZP/27dSs6fjS9KH4N1tWP2Rc
Q4cO4dq1lCxmderUZcKECb9T4+Mhy7LdNeCvJEMwGAwORNZqtX4yImubt3fNXURExH+W1U+I/8jq
P4Tfs6x+bArU1Pi73QCsVqt9qyY5ORm9Xo+np6dddupT4UPJanh4ON179AWv70CKB7UXOBcBqwGC
1iBLRig+Bx4tgtA9iNlbQ+WDkBSEVKgLrC0OQUeg2hyktoEIl8YjFm0Oz87AlCwQFwbNNyL1eQS3
NyEWqQMZC4DJAAenIkeHIMxpg6TyBa0eem2EAlXBmAB3jiC1GqMMVJIQTm9CylkE1fBGUMcb1s+C
vKWh/zpYG4NcoQWCd0Yo98YlwGJBuLQfqeOwlAtePhEhY1YoluJLKv4yE3oOAJvF3WRCvnAaevVW
fMbi4pCuXsX64B5C0cJYT53Bcugo5nUbsTx8hODrg2n3YUz7jpK8+zCWqzdQVSmL9UkQUmQ0ssWC
KWArTkNSAoAA4gdOQl+tHKqsme3HpPvOnSIAACAASURBVIgozLfuo/++veO5AybjVKsKqswZHI6b
Nu5CO1jZbtVWKoPbhkW4nN+j+Bo2rE/4zE3c9mvE48o9CZ34C8kvX+PR2VEmyHjzAclBIbh1c0xt
KsUlYLwYiMfm+fiEXEI/qi/BkzdwJVNzXo5fg+/QtmlIb9iklagypENfrbQyt6JIuqkD8As6QuKT
UMxxiYSNXo6UlKL3anwQROzRK/guHmk/pi9eAL8n+yBHNiwJSVhDY5DNFoe+IlbsQe3mgluberg0
rE6W+3uIu/WCa4W/JXjaJixRCfhMdCR6AD6TeiGrVCSHRhM+dXWa70n46KVoixUi/b2DCDmzc8+/
M0m3lW1da4KB4KE/4zp9KCqdjnTXdyJ7enKvdHdML19jCg4nZPpa3FfPUK6jejl89q0gbOIqQib9
otT/djr6Mf0R3d3Qt2qI28KJvGg9ivgD5wCInLQS2SyjX/ojzkd3YLx2n7DWKS9XsiQR9d1EVKVL
I4XHENPZMRWlrlo5PH6ZTki3CZhjk1CvXgWA4OGOZtdvJJ+4QOwPyvikqBhiGveE2k3hdQSWsaPt
7Qi5c6NetQbDqBmYjp3B0LY3locv4OALxCw5EVqkkj37uhFC135YmzZGio9HmDoZ31MnOXv4MHny
5PnbSdC/Gblz5yYmJoZKlaoCMrNmzaJWrVp/WO+v4o+I9J9JhmCL8zAYDPZ7+C4N2Q+9h3+Uveo/
y+qnw3/SVZ8RyckpP2iSJBEbG2vPbPJ2EJJGo0Gv16NSqT7qTdzW3qeU/bCN1Wg0YrFYUKvVSJL0
l6SlPhSxsbF/SNZlWaZu/eacvKLGGnsE9HnAdyi86AoaH9BmBTkEUdAgJT5DyN4OueRyhKPFkWPv
KakG1e6IXtmRWp6DsMuwqQJoXRDUemRJRvRvh1RrNsS9gvl5od8BhLsHkQ/OUup/PR4q94dt3yOG
XUUa+yYae0U3xIi7SBMPwaXdsGECBN1F9PFDylcNSjWFRS1heRB4KAuc2C0rUteJUKeT0kbAJIRD
Acjb7ivuBIBY1w9p0DRo1A6sVrhwHLp9DSOnQEIcTi9fwI0rJN27jZOvL8nR0ai1WvRubohqFb4Z
M6LT6RVLvSwTGxuNb8aMmC0WrBYrRmMS4aFh6J2dSIyLwxAXT1JsHAgCbjmyos3uB5l9MWfxJWHZ
Rpz7dcKpUzNUWTMhiCIxHQfDq3A8D6WIUEuSxOt0JXDfsQxtak3YX/cQ33MEXq+uIaSSQYtv1wci
Y3DatV6pHx5B8sz5mH9ZByYT7nUq4d6rGS5flkFQqQiq0QN1rmz4LB/v8HyEfzsO891neJ3a7HA8
buRMDHNXIWrUZBrfDe8ejRF1irX5dpaGeM0YhFvb+g51YhZuIGbKcty2L8XQpg9yYiLZlw/Do14F
gjpPwfAsnCzHVjg+n5LE87wNEKtXwLr/OBpvN3JumYg+XzYkk5lAvyZ4TemPe7dmb417LPErd+BS
qzzZ9sxL89yH9ZpK4uUHOC2cSHzt9njUKoPfypGIeh3G+8954N8R31t7UedS5Lyie47BuP43cu+a
TsKhy0RuPkH6B4cc2oyq3x3z5Zs4FcqJySLic3K9Q3ny2atEfN0FfZ4sWJMseN5z3Po3LttI/MDx
ZJzVl9CBc3A+uA11acUFQXrynISKdXBr+TXpfx5F7IL1RI9bhHDzHkJwMOaa1XHp0x73SSluLEnb
9hPbYRCyqEF39hRitqz2MunqNZLrNcBj/liMq7ZgjpOQtl2CwCvQuhqqH39E1SIlyE1avhTLhHEI
eifknfeVrf+YSGhcBGo1gCkL35woIXZqALevkTNTRg7u2GEnH28HCaWWbwLSBAnZ/mwShv+2gCwb
iXN2dv7jk1NhwYIFjBgxAlBiJ4KDgz/52JKTkxEEAe071C8+Bn/1Hqb+PbZYLJjNZpycnNK0P2LE
CNq0aUP58uXTlP2H38U7Cc9/agCfEamtg7bPkiTZrZKyLNvfCj+VVfJTugHYtvpti4dOp8PV1RWr
1UpiYuIn6eN9+JDrWLFiJceO7Aa0IGrAvRG86A7eDSDjQLhdCQQ1klMhELXIhafBrdHIUTcRvYsh
FV8Cp2ogVZsPIedgex3QuEDhAchZvoS9XyNVfBOAsrU1yBLMqYXglRvUzsh1J0P5HooF9OYmpO8U
QXJMyXBlC7JXJmjtg+iWDskQD52WIFVT0qAK02sgVG6J9IaocmGnck6NlB9ZcfdSpJ5vCNjLp7B/
A1LYS1wObUFcOYOkp49wcnPDLU9eyjy6Sd6sWclRpSwZWzTCw8ODHDly4O3t/ae0fVMv4JIkYbVa
sVqtREVF8fr1a8LDwwkLCyMkNIRDRYpiOXaVZ8s2Ex0Vg2vuHCS/eImuThWSD5xEXeILVOnTYfhx
OaKXp4OyAIBx4jyc+nZ1IKqSJGHZfwyn9UtT5sHXB93oQZiWr0GzYT3xa9eR2HYUMjKenRthuBCI
34JRDm1LkoRh2xHcA2bxNswHz6Dr3hGhRFHCRk0idOJKMk3pieCkRTKacG3xdZo68bNW4TSyN9oy
xdE+OkXC1IU8bTMB1zIFiTtzk+zXNqWpk7j3FFJsAu5LlYChhNZ9uOvfBb8ZvRB0GkSNNg1RBXCu
XYnEXw9hOH2N0K4T8P15uJ1Mm1+EEr1qJ16XdqP+Ih9e944RV64Rj8p/S879PxE6ZAG6auXsRBXA
a/EE4nJl5VHdIciyjM+h1Wn69N69jIh63Yg/dh6PeWPSlOsqlMBr2SSiOg9H1y6tG4S+eytkUzIh
/SejqljWTlQBxFzZcTmynfiqDZBMZhI37kX1yxpEvR7y5EG9ZQeJTRqg8suIS8+2WINeEttpCPLY
OYg3rmD+shaaa5cQ37yAiyX80S5fSmzX7gguLsgnFC1QipSE2auxDuqIkDc/ov+bMSQmggyyqAXn
Ny/xnulg6QFoUx5KloOmyk6AOrMfXkGPOLhjB15eXlitVgfZpnfFC7xNfGy7T6l3uIxG40frj35K
/NXfiN69e9OhQwf8/PyIi4vD3d39LwVe/ROwWWTfvoe2ufi9e2i7dzYrrNVqTXMPIyIi/lbLalRU
FC1btuT58+fkyJGDzZs3v1MqKyYmhm7dunH79m0EQeCXX36hXLm02en+7fjPsvoZkfpht1gsdk1U
m06dbaviU8IW7PQxVk+bFdVm8X17rFarlfj4+L9VUy4+Ph6dTvfet+s7d+5QqnQlJKsGBAuIzmB9
DbpsUGAf3KoAKmfIswHxSWukLE0QYi4hx9yFvH2g8BSE07XAGobgng3p2WHFUtr+OejTIf5aBLlg
feSi7RCOjER+fAgy+EP1BRBxC070g7GvlHSte0Yi3N2K3Hc74onlSEcWK1vyeWvB1+Mg/B5s+Rbm
hYBGB4kxMCALzL4MWQsCIPYrgly1CXKXCRDxCg6shaXDcCleDvOTe7i4uJA7X36y+/pQr05t8uXL
R968eT+bcHbqRTr1gm6zUiQlJfH06VMOHTpETGICFwNvcu/GTUQXZ4xJSajKlcBlTF/UJQojaDRY
nr4gqtCXeD05j5ghZYFPmrMM49wVuD646PDdMHw/BPnWIzQH9tqPWbbtwDJ0CHJsHC6VSuA+tAtO
NcsrFt4F64mZvpL0z085bPVbgkN4nfdL3G6dRsyqBKglr1iLddJMzFGxuDarhW/AFEcVhH0nCWs1
FJ+QywjOKRYVKS6e6MJfIUXGkH5KHzx6p6SvlWWZFyVaIVQpj9vccfY6yXuPkthhAJboOLwn9sZr
hKNrhSxJBBdoAE0bo/u2I0k1GqF21eG3Zy6abJkI7Toew71gPM5sSxmHxUJ8zbZYbt5BTjbj++w4
ah/vNPcwsnYXko5fwGv6UFz6dXQokyWJ10UbYHb1Rg68ideicbh0SCGlsiwTUaElJpyQbwXi1Lcj
bpMdt++TFqwiYeQsZIuEy9FtqP0dJccsF6+SWL0h5C+A9uRZhzLp6GEsHdvjuWYWhqmLMbtlQl61
G6xWxK6NEV48Rn3pnP2l3rp9B6ZevZXv7P5AyJxCzoWfp8CKH1Gdv4h8+iTWvn1gzkGEeYNALSCv
S9X34e3wQ3vYchzt+mXkf3CDPVt+xc3NTRnXWy5VqeWWAIfPb8Om5CJJkn03KrVl712yTbbPfzeR
/T0L4YdAlmWyZMlKQkIcIPDiRdAn22kzGo12Pdd/Gm8nQzCbzfZ7J0kSAQEB7Nixg1y5cvHq1Su6
dOlC8eLFyZ0795+2Wv8Rhg4dio+PD0OHDmX69OlER0czbdq0NOd17NiRqlWr0qVLl0/CBz4D3vmw
/0dWPyNMJhNGoxGj0Wh/4F1cXD759kZq/FUiaVtYbWO1ZZh610L8tkvD34GEhAQ7UU49RovFQkJC
AvkLlCQhKQ+SZADLXdDkBusj8KwDUXtA7QL+T+DFaAidByo9aPyABKjzFGKuw4kqIAgI6asjJD5C
LtAWudR4CD4Ku2si+JVFDr0BggYxe3WkRtsBEFfkQqrSF6r0h6Q4mJoDLIoIupChKPLre9B0Efgr
maXEmQWRK7VHbqBsn7G0I2L8C6SJR5WAsNsnYcxX6ErWQPXyAXJCLIWKFiN/Nj9aNG9GsWLF8PX1
/dvm+mNhW8htVtjUkbnPnz9n165dBIWFcvriBUKePce1bAniwsIRfdLhenCDneABxOatiLpfD3Q9
HVUH4rMURr1gPqo6KRJZkiRhzpMfadw0OHUc1eE9CM46PAZ3Jm7OWpwGdcOlt2P2qegmPZElFfpf
f3E4brlyg8QqDRDdXdD4+ZLu51E4VSwBwMui36BqVBuXiYMc6khx8URmLoMwaAjC4oVoMqUjw7op
6L7Ig+HkFV416Iv362tpxPyTVv1KfC9l2z7Dhpk4f50S5JW44wivu43FOfi23f/c2LQj1jPnyTB7
IKF9puN14wDqvDnT3IfInBWxvgwj3bYFONV3TENrvv2Q8DLfIMxbBAP74tqzNW7TBttJUeKaHcQN
nIZw+wEcPIClRzc8Zw7B9U3wnGHTHmK+G4t07THCvTvIzeo5EFbry1CiClRHnrse4e5NWDob51M7
URdI0e41/bQI4/QFyAYDqjlzHbbqAaRNG7EM6o/g6oJ8/kVKgoAkA0KTyohermj37Ua6f5/k6l/B
8CWI104gn9mLfOQB2IiXLCMOaIt86QRybAyMXAVftYCYCGhXFKo3hHGL7f2KC8YgBcylUIF87Nq8
CQ8PD7sl1WZNS70zlprAvA0b0bTNq8Visa+nqfEu/dH3Edm3rbGfgsja/DU/1j1hwIABrFihuL9c
unSJ/Pnz/0GNP8b7MkT9G2Bz7dPpdMoLXEQEt27d4vHjx6xdu5YsWbLw6NEjnj59io+PD3nz5mXC
hAlUqlTpo/suUKAAJ06cIEOGDISGhlKtWjXu3bvncE5sbCz+/v6ppMf+J/AfWf2nER0dbU8tqtFo
iI+P/9NpSv8s/iyRTJ1oQK1W28f6ewuiLMtER0fj5eX1t1kAEhMT7YkPbK4TRqMRQRD48af5zFtw
lqQkL7DuRXAfD8YAZNNjEF0AI+ReAYbb8GoaglM25FwbEB7URi4+FyE5HDlwFDhnhrK/QcIDuNYR
2gdD9F3YXQtkM2T+GkpMht2loO1F8PkCHmyHg52h+z7ESyuQLq1VFAHKDoSKw+HGajg1Dka/AJVa
0WtdVA3mBIOLlxJo1ccHuWJznKxGuHEErWAle/bsdGzVgooVK1KoUKHflSf7t8FmcU1OTsZqtaLV
au0awKmJrCRJREZGcuHCBVavX8+dx4+Ijo5C91UVrHVrIKTzIr75t7gH3URIpUSQvHI9yWOmo7t3
24HYWlYHYJk0Fa49QFCpFCvY6uWIC2YhhYbh0q0lLqN7o8qipFCVTCbCfUrhvHcT6jIlHK4hsVpD
5PzFsE6aBSMGIWzbgEvV0rj0aEZYiyH4PD+D6OsY6WuYtQTj4o2IF68hWSxI3/dE3rsL7wHtMZ64
giVnDjwCfnKoI0sSUbkrI7frDDo98rTJeHZvitf0gaBRE1ywITSoh9PkkQ71kucuIXnMVMQM6fF+
ejrN98509AyxTXogDxuLMHk0HlMH49o3hahH1uxEstYT9Zr1SA/uI9X/Gue61fD4ZQpysonQbFUR
Rk9A1UGxuNosnW5jv8etV1tCc1RHGjwasbNiCZavX3UgrHH1O5McaUbedBQAYcYoWLcU1/P7EHNm
x/rgMQlla8Ki3ZAQB4Pbol4VgPhVSpS9dOkiliYNlaQZB65CtlwpFxj5GuqUQlW+NPLVa0jFqsO4
VWCxIPb+GuIjkHZdVSTkAB7dhTpFlSxyvz1PaefJbehaFkbMhW+6giyjnTmIdKd2cf7YETw8PBye
Vxt5tJFGG4G1/aX+DrxNZG3qLrao9reJ7O9ZZN/lV2lr80N8K/8In4qsAhw5coQmTRQr/Ny5c+nc
ufMf1Ph92NLA/hvXwPf508qyTJ06dTh9+rQ9sOvFixc8fPiQggUL4ufn99F9e3l5ER0dbe/P29vb
/n8brl+/To8ePShUqBA3btygZMmSzJ0795NbeT8x/iOr/zTe9lv6o63tT4EPIZK2RTQ5ORmLxWK3
ov6ZxSEqKupvJasGg8FuuTCZTHYr661bt6hUqTpWyReIBLeZYDwG5j2Irq2RLKHAfUQEJONT8KwJ
BfbCo24QuQ5B54NsNYDVCF8/BZ0v4uFcSBnKIBpfI4WcBVTQ7DE4Z4AjDRG1MlLjXWAxworckPga
NDoE37IQeRO5xlTwVwTfxYU5kaoOgkqK8L6woAJCruJIFTsh3tyF/upWksOeUbnGV9StXpmKFSuS
J0+eTxJc97mR+jkCPuhFJ3VdSZIICgriwMED/Hb4MGcOHwY3NzTD+6H5pj6in6IykFi4EkKHDqjf
CLfbYCpRGql9V4SefR0br1sdyccPVWgQ0sNbOH9TG6eR35O0aivJ+07hcvmIw+lSaDjx+csiHL+I
kEMhSFJ0FML3XZFPHEFdIA+eZ7YiptIMlU0mIjOVRpgyE1XzFiltXbuG3L4lUlQU7vsC0FV31INN
3r6f+G9/QLz7WLGcPnwIzRuhcnfCtXtTYiYswfnl7bTpWh8+IaFUDdDpcKpRAde1c+wuCbIsE1O8
NuaSVRCn/oh09iRi55a4tGmI+/zRmE5fJqJBD1Q37yG6K9cghYUhf1kFbdG8aL7Ii+G344gXrzn0
KZ09g6VVczR5syElWpBPOZbbCKumelksJy4gn34CHp62G4w4bgDyzo24XjxAUvMuWHzzwrwtSvmW
FTC5P+odOxBLlkaOj8dSrjRyrfaIyUnIhzchHw1UgqFsePoQahYHdy84GJpyPCEOoV1J5PyFYMkO
iI9DaOCPnPkLeHgZqjaGYYtSzj+1C8a0hpXHUJ/eS9ajWzh5YB/e3mldJ2zz+zaBtf3/bcJou282
MqhWq+3GCdtvwdu/wTYC+nuZoN4eyx8FCb3LtSA1bML7f8af/fdgtVrx9vZGlmUGDx7MmDFp/Z4/
FImJifb18N+G97ko2Mjqx+rQ1qxZk9DQ0DTHJ0+eTMeOHR3Iqbe3N1FRUQ7nXb58mfLly3P27FlK
ly5N//79cXd3/9vlxj4S/wVY/dN4W0bqc2SXSq1R+vYC9XbAlF6vx9XV9S8RJNu1fOoFJXUWE0mS
cHJysm/LGY1GmnzTBqtVBF6DOjeCYTGy9TF4LkDSFIfwskpQlb4mCMGQ42eIvwSRa0DlhJyuO2L0
euRczZF1vnB3PFL8UzC+RvKpj+jsh5ynPbJzBjBGQMgRpIZbEU7/gHxlAUgWKD4MSo5EfrIVzvaF
Im90Rh/uRUqMhDJdwJIMd3YjB11GeHmNLM+O0bheber3+JFixYo5+C5/SsmvzwGbpdtkMqFSqXBy
cvrTRNsW7JAzZ0569uhJzx49SUxM5Pjx42zYsYMDU35CzJcHY7WKWF68RN/eUQpLun4D66tXCK0d
t/ml1+Fw5xbs34g1a0549gjDmJ4YSjUCjQbd0LeILZA0aDSqilWQc6RY8kQvb6T5y8A/P1aDlcgc
FXGdMxZ9+28QRBHjhp0Ier0DUQUQ/f2x+pdCvnaDuPpdcOnXBadx/d+kmpUxjJwFbTqkaKfmzYt0
9RbmLp2IHDgTdf2v3/k8mMdNRyhVEXnhRkxNKxFdoh4e+1ejypEV067DWF+Ewl5FzkmsUAXp8HkM
Dapjefwcy8swaNHGTlQBxAwZkM5fwVS9IkmHz6LauDlNn2KFiqjmLcDcqyc0aJxG91AoXgICNmNu
Vg/KVk0hqsoNRhr3E2KSgXj/Ggg6Lay9klLerCtCTBTWpk3h0BH4aRaCixdyv+lIkoT4+iVCvTJI
x+6A7eX+zFHQO0F8HOzfALXfJGdwdUdedATa+MP0YYi3r4LODXncbxB0B/qXh/z+0PiNf3DlBggd
RyB3+wofHx8OHzn0XqKqXMr7A3NSE0aLxWIngbZ6tuNvE9rUdW1t2T5brdY0/acmsn8mSMjWbur6
oijaA4Q+lQ6sSqUiNjaWVq1aMWvWLE6ePMnhw4f/cnv/1pf2982X0Wj8JFbqQ4cOvbfMtv2fMWNG
QkJC3uka5ufnh5+fH6VLK9J7zZo1e6df6/8C/rd+Ff8/w+cQ7H+7Hxv5S0hIcEg04OHh8cGJBv6o
j08Bm9ZsTEwMRqPRrqGXWr+1ceMWhIa8Br4DTGB5imx5gKgrCaos8LoqaPKB71lE6T6Cb0fE0Jlw
qzI4F4bir8CpAJIpFDlDA8Tz9eHhTPCpA1VfQub2SMYw5EL9lUEda6aQzt+aIDw8iKDxRCg+EMpO
BLUe8cpYhEojlCArQDw2DPxK4Ly9O7qJGSl8+0c6d2zPxbOnuXLmOCOHD6VYsWLKuaksMP+WNIJ/
BKvVisFgICEhwe5/bZMX+xQ/Li4uLtSrV4+1y5bx8slTVg4bQcWb99GoVGg7d8Xy6xZkg5JtyTxy
FKqmrRA83vLNHj0UsUwVyPrGpzNHHuSAw8jDZiEnJZM85UeS6rXGej0QAMlsxnrgOFLfwWkHNHIw
YplqyPsfIQ+dQ+KgycSUrIf58k2Sxs9B7tojTRX56ROsx47ClnPIm85gCPiN6CJfY75xB9PBk1hD
wxFHjnaoI4oiYtt24OSE9dhpkr8bjGw02sut9x+RvOcg8qwV4OmF9VAg1pyFiSpeF9PRMyQOmIDU
oTtiKh8/MWt2rKdvYnzwAsuzYFT9HNOuAkp0fRF/cHJG/mEYcnh42jlY+QvkLwH79yP98I42DuxV
MqnduARzJzkWCgLS98PAmIRskZQMbqnnqtsQaPktlppfYtm9C2nhIduEIE1eD96ZERtVUFKs3r0J
k4bCsA0wdA1M+hYCL6Q0likbLDwAq+cjBV5Dmn1OcQnIURhGbII5A+FGitVLzpILJ42G3zZtIGPG
jGmv+wOQ2jBgSweq0+ns6bBdXV3tL6O2FzyDwWBPR22TApQkCVEU0Wq1aDQa+782lwPAIULd9meT
xUrt52qz+tmyQdn0R52cnNBqtahUKodgobezQX1sWtONGzeyceNGLl68SKtWrf64wjvwb02kAO8f
2+dICNCwYUNWr1aUPFavXk3jxo3TnJMxY0ayZs3KgwcPADh8+DBffPHF3zquvwv/uQF8RtgWBBuM
RiNWqxUXF5ffqfXxiIuLs/t6ppbI0mq1n8yKFxcX99H+t29rzdpS7qnV6jR6sWfPnqV27VaYTIeA
yig7B32BGaAtBqYrIHpCpmeQuA5ieoKgB3UmsIZAsVugz41wLYuSKMBqBFUGEJKgWhCIGsTT+ZDz
tEP2KoJwfRxy7EPIUBOKz4ekEDhVA9oHgT4dBB2EQ02h3wsIPofTvbUk3dxCsVJl6dSqKQ0bNsDX
19d+HSqVyv7Dldoa8y7fuNR+cbbP/9TinfoeSZJkd2P5nONJSkpi9+7dLF67lmuXL6OqVxfDth0I
B04i5CtgP0+yWBAK5UBetA3KVXNoQ6xZELlBJ+RmPWF8V4Sz+9FULofskw7r5VvIxx3VBySTCeGL
nMiLd0GpyspBiwVGdYX9mxHUKlTXbiF6OVrkpH59sN5/irzxxJsDEozsjrB7I4KbC3K9xmhmznao
I8sy1qqVkPxrQKdBiJ2rIrhocNoWgCp3DoytumOKSkYO2OtQj8Wz4aexCHod8p3gNN9t2WyG0l8g
q3QI5kTUv+1ByJcS8CRdv4alQV3Y8QBxTAfk5/dQ792PkC27Un7wANYe3ZH3BMOrZ9C9CjRohDh7
gdL+3dvIdavBsotKEoy+NaH3cPh+mO3CEJtXRxLdlLEF3UHaexdSW6AiwqBadiWhxt4gcE2VnjU+
FqFjGcicBZ4/QvavB32V7Xxhy0zYMAV54w2FqAIc2Pj/2DvrMKnK941/3rOzs013d5d0KI0ICCpS
kiKCIIg0SHeJ0gjIlxBBUrokpEE6VLq7Ntiu8/7+OHtmz8zOJrvLrr+9r4sLmPfMiZk577nf57mf
+4EJX0K4Ct8fghJVLLsSG3+A1ZOQv/0N96/hPqYd+3dso0yZMiQExvtCT6fHVwIT0xwQX32sLWLT
x+rpbJPJZFcbazwXe9rY2Aq9nj17RnBwMPny5Yt2m+g+G39/f9zc3FIkYfX397fbAOf8+fOsXbuW
+fPnJ9mxPT09adOmDffv37eyrnr8+DHdu3dnx44dAFy8eJEvv/ySkJAQChcuzLJly9LcANIQM2zJ
alIY9ttCr5ZXVdXSaCApLLLeRH9r6zxgj0jrXrQeHh74+/tTpkw1njxpBKwA8gEHEUoFpOqLEOWR
XIZMP0P4a/DpCw4ekG4mSsB0yFgbNddIuNUZfPaDR23Iswxxqxqy+HTI3Rkeb4CLbcApI0I4IFVn
lEzFUd/Voj3Kn5Ugz3uoNWdpD+ENZZHBXjgpYRQoUIAvO7WlZctPyJYtm1WxkR4piYtcIjprKD2N
Z/vw0lPvSTGp699RcHCwVdTncQIEwAAAIABJREFUbT9AHj9+zOIlS/hp6TLIlg3/Lt3h07YIN3fU
2TMQq39F7o9sogDAvxegVS3Y+xDSR5BLb08Y1w2O70aULAML/ocoWNjyFnXSaMTuPchtl633BfBR
BXj2CNQwHL7/AaXlp1qE7dkzQiuWg02noZhNNOO3RTChH6JYMUzLVyIKRFbzqwf/JLxrF+Sh51rK
W1URg9rCsV04jRxE0LjpcOgqZM9lvc+wMKhWAHx9cGjZBnX6bCvPWrl8CWLmdNSdj2D8l3BgPaY1
61Cq19AIyfsNCM9ZAib/CoAY1BrOHsC0bRcULEhY5QrIFj2he0Qk+M5V6PYuNG6MmL0I8UFt1GzF
YMIabfziMejXGPqPhq8GwLoViIlDkOsfgRAogxuDz1PU7X9rlf5SovRohnzpjXDPBI+uoG64Epn2
B3jxBD4uAk4usM7QNlZKlHm94OQ21M034OFN6FoTuv8P8eIubJuG/PlfyJQjcvsfuiLP78MpPJjf
V/1CnTp1Yvil2YdRp617Tyfm/BpffazRsQCwW+Rlu39FUQgJCcFkMmEymd5qoZct9AxbUgd0EoKY
iPTevXu5dOkSY8eOfTsnl7qRpll927D9QSeVZtVILPRJzcXFJcEeenFBQmQAts4DemTW3uRm3P+g
QSN58uQBsAhwivi7GlL1B35Cym1georiOwE15B8wlYDsf0PwbtTgqwj5HpwrCMIEeZdD5o7wdCIo
zpC1GeLWBOSNKeCcC3J/h8zaEc7kQS01WTsZn39Qva9AvSWIC9Nwvb0cGeZFt27t6f5FVwoXLmwl
twAwm824urrGW8dpz67F9mGhL4KSIhqr99kODQ3FZDLh6uqaoixkcuXKxdjRoxk9ciR//vknMxcv
5sSUcciWbQjdsRX123FRyeWE/ijNOqCmN0RBM2SCRq3gzGEwZUTWq47Sqh3q0JGIrNkRa1Yhh8+J
uq9Lp+H+Ldj5DHb/ijp4ICxfijJnHnL5MpTCJVBtiSqgbF+LWudTCPYntHYtTNO+R7Rrr/3OJ4xD
NvkskqQpCvLH9fD7MoLG9YaMmSGzHeuyjStRhIK6/gayRw1EyybIX9YhMmZC+vsjp4xFDpqrbTt6
CeQpTFjrlpjm/wQmR9Rbt+Cno5bdyRnrYWJPQps0wqFZcwQOyO4GyULBErD8BHxRC9moFjx6BHNP
Ro6XrwU/7oQBTSHAD36ehRywCJy0SKo6bSfi2zooraqg/n4Wtq1Gnj+BXHoPaTKjDK+P0qUa6qqz
kVX9pw9orhpBwbB6ErSPcEkQAvXr+ShP7yI6vIP094V3u0DNtto98fgKom9V1KU3tc9VCNRO4+DA
KkZPmBBvomq7eEuITjsuiKs+Vp8D9IyHUc9qj8ga32ucO3S7OePxbfWx0X0ecTHRT0mNEBIL9q7h
1atXSS4D+P+GtMhqMkKf4HQktkGvqqqWPse6zZOjoyOBgYEWwppU8Pf3t0zaMSGhzgP6Z7V79266
dOmFECWAR0iZA7gNhAM7gcxARcCEEK2RbISse8BcFZ7mhrCXKE7FUEU5BOeRJa6BBPFvNqRLXvC/
Doo7qEFQ7RE4uMPVDijiEWrtg6CGIg7VQnpfxNnZlRYtPqJHt05Ur17dUkBhLDYym81JEsmODrFF
Y+09wGyjsdFZT6WWwq+HDx+ycMkS5i74CXPF6gR89Z0mAxACXntDjTyw5qxGtgxQPiqBbNwV2X4o
3L+GMrkj6t1/EbXrIs+cgcOPIr0+9ff0aoEa7gDTNM9dggIQI1ojz/2peeb+vB1qWnuc8s95aFcb
tj7W0tz7NyCmd8ehZk1o157wPl8jDz6zTo8D3PwX2lQG9/SIfPmQP/8OWbNrY8HBUKMgdBsPLXtC
SAjK17WRrx7Aum2I7Zvht9Wom25a73PPWpjYTWta0WkQfGWtnwVgWj9YvwA+/BxGLo46fvU8dKyk
FS0tPxt1/Oyf0L+JZhu1+pb1mJ8PondNpLsr3LkGvX6Ceh20sYDXiAHVIEcu5ML98PA2tCsPXy6G
LPlg8vvw7WJo0CFyf4F+0C4HODjC/ww2PmGhKBPqggxFnXsKgvxxHVKHfm2bM2KodTODmGAkqbqU
JyUt3sB+ww7jH50k6gRT17Tqc0BiyApszyU6aYGRtNqTFiS0DWxyIKao7/z58ylUqBBt2rSx8840
xAK7D8vU8fT5jyApIqs6+fP19cXHxwcppUXQr2sJk6OQy5h6sgedSPv4+BAYGIjZbCZDhgy4urrG
KSUuhMDPz4/evQcjxACkrISU3sB9wBVFaQ7cBWoApYG/QDxEcW0I4c/hcW4ID4QMq1EzXEKE7kXm
mg2hj+BmdWSoF0qYgNx7UEweiHzDNaIaFgBe21AL9sLhykhc9uUnl7sPUyeN5/6d6yxbsoDq1atb
Ws7aFhsld6pcj8aazWacnZ1xc3PDw8PDboFHcHAwfn5+vH79Gl9fX0txha+vLwEBATg4OODh4YGz
s3OqIaqgRVtHDhvGjb8vM+HjpuQe1wv3jyvD1t9g3LcoZatGIar8cwb1yQNk84giqXzFUReehmm7
kIcOQnAQbP1V05zquH8L9dg+GGKwQXJ2Rf6wAxp3BikQY7+BKxetDqXMGQtVGkbqMRu0Qq6/g3rv
GWFdOiIr14lKVAFl7kioUBd+vQfSBRqVh3MRkcw1S1AcnTWiCmA2oy45iaz0PvKDOqhzfkA12jXp
aNwW2n6jkdvXntbXpx/39SvIWgB2/QYLx0Yd37gQkbs4PHsMQ6O2XiUoQCOPz5/Ajv9Zj7mnR84+
BNf/0QoT6xmIp2s65JSDyDvXYGgbxOCWUKYB1PoMiteC3r/C7K/g8mHLW8SmWQizCyhm+Lln5L5M
jqiDtyM9n8Hkdjh/34EPKpZg+BA7hXR2oM9fvr6+ljoDvZgwpUEnfsbCKn0e0FPWesbN0dERVVUt
971e6KVHV/UFt22hl/5M0SOxMRV66Yvi6Aq9HB0dLc+P0NBQAgMDLXORrgFOiYWnMRV+pUVWEx8p
7077j8NIHPV/J6Ta0dYY38nJKVrbKT3il5SI7hh60YHujZrQanEhBKNGTSQsrAFSBgG/IsRHSFkH
+BYpzwNrgfTAQeA6Uj2CDMoKAYeAcEi/EFzagfeXSAd3lNcbUG+3BEyQay1q+lbwehNq6EvI2Qdk
OFzvAmG+uP7zNW3btqHXsi2WakpjlAUSlupPLsTk2ahHL0JDQy3bSCkt31tcorEpAfp1hIWF4ejo
SObMmenZ8yt69OjOnj17mDhzNhfOnkVt3lkjn06RhFBM74f4oDOqh22nN6H96TARMX0I/G8Gcvwi
qFQL5edpyBIVkZltqsdDgmH/Oui/FHn+D2hdC9G1H/Kb0fDwDurR/bDRJsKYLgNq/7nwdV04sQ8x
ZyTy67GRkdyb/6Ie3QMrb4HZjPzhICwdBe0bIwaNQ86ZjNp/TtQPZeQyePUUzh1EPLiBrN7Ietzv
Naz/CTpMQv4+BeXlE9SJK0HXul45h7rvd5h3BTyfwJhG4P8aBv6ojV+7gLrzV5hxCUyO8F11xOCP
kN9v0cYD/WHiF/DJKMhdCma304qnGhlI6fFt2muYYHp7GLI6cixjdph2BPqURwoFRp+JHKv6CcJz
MnJ0c5h7Gl4+Qq6dCn3/BEdXmFEDcpWAZhFuHu4ZkSMPwJBy5CtWlCVb/4z1N6wv6vRW025ubinS
7zM26POw3pTGns7SVh+rk8Po9LG6vjU6fayt9ZatfyxEygNsoe9Dtyw02m69SaFXYiKm5/bLly/J
mjWr3bE0JAxpMoBkhm1jAC8vL4tvaFwQFhZGUFCQZfKMi6DfWJyUVDAWi9lqZp2dnd/YP/Tw4cM0
afIxqpodKR9rKX45EygEhCFEa2A7kukgGwLvgAgC2RZwRzjuQ2b+B0KvgGcVIBzhWBUpcyNMV5D5
L2hFH3eKoGZtg3DMhIvnT2RMZ6Jr5zZ8++23llTU2071JxaMJFVP9RsfxPbSifYiJvaKvJILehV2
SEhInCQLu3btYs6SpZw+f4GgTgM1N4CgAGicD5ZegjxFrLZXvqoCJd5F7T5TK2Ba1BcOrkSp2QD1
yB/w83EoVsH6IFuWoPxvHOrKB9r/b55DmfAJ0uwIefJDKMi51o0IAJQ+DVBds8MnQxATm0KuPMhZ
v0OOPCjftkT1DYLJNg4A5/bDuJZal6ftT6wIOADPH0HrotDxe8Sa4YgWXVH7/6Cl/QEx7zvEvs2o
867A65coAytC/sKoc7aBixuiYzVklmLQXyu64s5FGFkP6n8Mo5YgOlZG5igDfX/Rxl8+0AhrqYrI
GdtQZvaDo7tRf4hoA3nqd5jfCUashDot4eVj6FgCPv8ZClaG8VWhbnvoNTfyGq6ehOENQJXQehy0
sE7bK78ORB7+BRkeBg2HwfsR7gPXDsDC5tBvLVT8UHvt2G9kWj+E/bu2UbBgwWgXXrYLn9TofwxR
SWpCnDvspfFjkxfZ+sfaI7FGsmdLZPXP2l6zAuO52J4XxL0Rwpsipq5fHTt2ZPHixWTPnj1Rj/n/
BGluACkBtmTV29sbDw+PGFfrttXyus4zrpOnnlpJZzABT2zo56fbTBk1s286Sfj7+1OoUCl8fHzQ
NKn+wEw0q6r0wCrgF4Q4AOJTpDoXrfDqCpAORG5INxsl/DCq36+g5AO3PaDkRvjmQObZCG4NwPsX
eNIFk6MLTZq2YEC/nlStWhWI1HHqvoPxqepPSbC1nkqoHtVelbL+77hqY9/0OhLaLQu0NoRjpk7n
6ImTBGXOiZIuG+qMPdYbPbkHnUvA4uuQNW/k697PoWdJCAtGfD4C2X4gOEYUQ4WHIz4pgPy4P3w6
IPI9qgozPodjG6BxRxg0L/I9AFfPQa/asOQhuGeAsDDE5ObIq8eh91iYMxJ+uQmZc1qfY6AftM4F
zq6IzNmQP+6CbLktw8rEL5A3ryInHYcntxCjayFKVkSdth58veGTYjB+PxSvrr0hJAhlUCWkWUG2
6Y2YOwL5vyfWFfkPr8F370H23IgXD5GLnlhreV89hO+qaxZSNy/CxNOQp1Tk+PE1sOhLGLcOZeNs
pF8wctjBiH3/DRNrwcf9oOM4CPRDfFUCWb49lG4Gi5pBj0XwriEyGx4GPXNCcCB876m1O9Zxcjms
7wsTjkNoMC7TP2DP1t8pVapUlIWXTmj037JunZfaSOqb2Ggl5Fix6WPtuRUYs4rG1L7x2ahfhxCR
7Uyjyw4Z32NPG6vPS/aisQklsjF1/WrWrBn79+9P0lbq/2GkuQGkBESnW7VHeuJTLR/bMZNK56NP
KLqhta5zTEwtV/PmrfDxCQemASMBN6AbGiFdA2QFViNlEIItgCuIaUAukM1A+sHrr1FlKcAE7pvA
oTD4d0M4F0fKMNxeNkYGnqXhRy2ZMH4MOXLkQFEUywJBtxzTNVepLYqqL3hCQkIsk/+bPMBiq1I2
PrxsnQqiI7JxgW1UO6FV2BUqVGDLmtX8/fffdO3Vm1u3LhCycY6mWTVHPHxm9Uap2gzVSFQBFJMm
I+g8B7FhHGxejBy5FCrVg8NbICQIPuln8x4FxdUdNUtBlOO7kR3KISevhyJlteGfR6GWb6QRVQCT
CTl6F+xeBHP6Q+bckC5zlOsQm+YgMmRH/eEafP8hdCwLM7ZDuZpw/zrq3jXwg9bwgJyFkXNuIr6r
guhcFfIWgYIVkDpRBTA7o866jBhZGyb1QrYaYU1UAfIUhwn74NvyyLxlohSdkTkPTD4BvQpBhuzW
RBWgZjsICYQxrVEdTDDzkWHfZWDwHzCtAXhkQrlzEczpkB9p3bjo+Ass7gwZckIZrXBN2TQBFBMy
eznEjOqoQ85EugdU/xzx4iaMq4eTqzOL5sykUqVKVqdjvDeMBEt3wbBHtlJiJXtyklQdMcmLYnII
iG4uMJlMlm31uUr3ftWfYdG5FQCW/cXknqD/bTwX2wisrbTAHmKSAeitddOQeEiLrCYzdPG5Dlt/
0oRWy8cEVVXx8fEhY8aMb3z+OnRNoz4xms1mgoODE/UYoJn/N23alqCgDUBX4DGKUgMp7yBEPVS1
DDACcAYmA1cQYhdSHkGIMUi5EqGUR6pLEaI3wikLqss6UH3ANy+KCCdf/sIMHdybtm3bYI5ogxkW
FmYR9dumqt6EbCU3jJo7vfDqbZ1vfKOxxgeGUbKgp2UTM6p98eJFhowex7l/rxLQeSzU/hRa5oJp
h6BIReuNv++A8uo56rC9WsR03QjYNw+lemPknX+RlZpBj++t3+P9Ajrnh1FHIX8F+LkbnFqH6DoS
WbMZdK8Bi+9Cehud24Mr0L8ieGRGZMyMnLANskcYq/u/hnZ5oM8aqNhUe23DONg+Hfr9iHJiN9LH
HznqD+t9qiqMrg03T8N3m6FSkyifh9g4Dbl+khalnHwI8lnbbylLvkWe3o0MCUbkLIgcuz+SIALs
no9YOw4pzIhCFZBDt1sf4PUL6FtIk1Z8dwCK1LAe/2c/zGoBSBhxHTLkiTy3oz8htw2F8cfB7xVM
awafH4ZMhRGLK0POEshe2yL3FR6KMjIPLRrWZtXKFZaXbbMMtmly2/S3bfRQX7DZk8G8DSlMUESX
s6Ty0k5MxDQX6DCZTJbPN77+sRB/xwJ70VhbImsks3oQyTZ6KqWkSZMmHD16NEV/BykYaTKAlIDw
8HDCwsIs//f397foHnXyJ4SwGOMnxo9dSomXlxcZM2Z84/2Fh4cTFBRkMZHWJ0YpZaIT4qCgIEqX
rsyjRx8ixFqk9EJL/3sCo1CUXKjqYzSieh5wBUoB5YFzgEBRWqCqq9EkAZXA4yiKuhtHdTZZs2Tg
pwU/UK9ePavq1uhS/dE9uIwFCCmhEMnWeiqla+6iSyXqRRU69IpiPXKSFJ/r8ePHGTRqLH9fvoya
KRfyp3+tvVVDQxHtsyIHbIWStSNf93kOU+rB8zvQdSp81MeKvIllwxEntqNOvhT5nqtHUea3RvXz
gpLvwviovdOV6a2RPq+RfXciFnyEvH4ERv4G1ZoiVoxF7F8TqQfVcWEPzG0LocEw74YW6bTd7/hG
qPeuQbA3DN8M5Qz2Wj4voEch6LYBLm2Bs6tg7J5IqcCDKzCwMgw+Be5ZET/WggxZkZOOatfs/Qx6
F4X2KyB/VcTMalDoHeSQSAKpzGqNfPIAyrRB7h8Lww9rJF6H3ysYXASCA6DbJijd1Pr8d41BHpmH
FBKq9IO6oyPO/SEsfAeqfAZttIIz8+YBVA3/h11bNloIj5HcJSQCaRs1tKfnjm7xlVgwBjb0ItuU
TlLtwVbS4+zsbJFjvIk+NjrngOj0sdGdmz1trLEwWp+Ljh49ipubG4ULF+bzzz/n8OHD0e73TeDp
6Unbtm25d+8eBQydq2wxZcoUfv31VxRFoWzZsixbtsyuZCEFIo2spgQYyaqUWgcM/WY0thdNbHh6
eiaYrMYl2puYhFjH4MEjmDt3HtrP0AEh+iLlB0AzQEVRuiLlZqAHUvYE6gHXUJTiqOpXwHDgGpAX
RamKKq/j5KTQpEkThg3tS9myZa2uT9cg6TrOuF6HcXK0JbH2CpGSqmWq7aQf3+tIKTBeh/596HIZ
e9FYew+vN7lmKSVLlixh+twF+Lhlx7/rD1AsolXn8u8QJ7Yhp0btZKVMro8aEIrwvAbZ8iIHr4T8
pbQIaPtc0H+LZr1kxKOr8F1ZLYLZcwHU6xy530fXoV8FmHQdMkUQzgPzYeNQRLPuyJ1LYMBmKGuz
T0CMr4u8cRqlcAXUYdvAw9AA4Z/DMPlDmPgQji+BHaOg10Ko10m7jvk94Po51MERlfc7xsL+GTBs
I7zzPsqIOqimzNAjwlvW7xViVm2EizPqlL9Q5nRAPr6P7HdCG/d+CDOrIwpXQg7eAud2wNzPYOBt
cM+CcmA88siPyDF/Qc7i2jnMbQlPH6JW7Am7v4Wv/4CChuirlDC+ELx+BoOfgrNBj//sMiypCc0n
QPpcZPtjKGdPHCFjxozJQu7szQXRVdUnRFbwXySpeoAmpmdfdPNsYuhj9f0byWtsRNbf39+yyJFS
MmbMGI4ePcrt27cJCwujfPnyFCtWzPKnaNGilCtX7o0XLEOGDCFLliwMGTKEadOm4eXlxdSpU622
uXv3LvXr1+fKlSs4OTnRtm1bmjZtSpcuXd7o2MmENM1qSoD+w9ajqPpNFh9HgIQgJm1sdNBTyMbJ
JCZ7rMTEtm3bmDt3PkLkRMpMgDdSPgHeR2uvughV3YbWDMANKAEEAktR1RYoyrtAb1Q1EGfnLwgJ
/ZcO7dsyetRQ8uTJY7k+o/4xoZO+cYVuO9naTq7GtKNtlMA4ucbnHGyvIzWkAe0hPtdh78GlS2ze
VK4hhKB79+588cUX/LLyV0aO/5jg0nUI7DQFZe8y1M5zo3ayun8Z9eYpGPsQaXaHXzvCN5URnw4E
kxmRMSeqLVEFlG2TUQu9C7V6IZZ8hfhrM+o3S8E9I8qaMcgiNZGZDJHR+r2heF3kjLqaA0C+slEv
4Npx5O2zMPIectmHMLAcjN4LeUqClIilfZGV24NLOmgwALIUhoUdUZ7fQa3RCvXgr/CdIQLcbCy4
Z4OpLaF+F+TdyzDRoDN1z4wceBxm14M+RVFfv4CRhuYDGfJA/5PIH6shpjZF3j4DdUeBu+ZDqdYf
jRLsB+NrIsefgzunkP8cQH59G1wzIQK9kAubwIATkL2k9h0dXQBBvpC3DmJRRdQ+V7XOVgDZy8Jn
W2B1C5ycHNm0Zwdubm74+vqiKEnXbUpHbHpuI3nVdbJxkRXo2tqk7pqV1LAlqS4uLnEK0MRlnjX+
iYs+VieoRiIbV32s7fc8ZcoUAK5cucKsWbP4+uuvuX79OtevX2fNmjXcvXuX06dPv/Hnt3XrVg4d
OgRAly5dqFu3bhSymi5dOhwdHS1+2QEBAeTOndve7lIN0iKryYyQkBA8PT0tKXQ90uru7p6kx/Xx
8YmzibWtN6qzs3OcJkUvLy/SpUv3xlrC0NBQihUrx9On7yJlLeAbtGIqgFC0oqrcQAPAH0XJgqpK
FKUpqvojsAvojJNTA0ym8/Tu3YNvvulFpkyZLNenF0/Ys2xKDthLfcdkC2UvGpvUOs7kgm1L1ze9
jrhGtuIajfXz8+P7H2cxZ948QkJCYcFTcLXuOqfMa4vq/Rp67op88d5plF9aob68D5+Og5ajrXf8
6gEMLA5DL0LWouDvibKwIarPQ/j8e/ipF0y4Alny25yQJwzJBxkLg/9jGLIdilbTLx4xqjoyQyn4
bJn22rpucHEdDFoPIYGIBV8iJz2zLoy6fw4xvxFSqlC4Nny1JeoHcWoVrO4G2YrD8ItRx/094bsc
YPaAiU+sq/IBvB7A1DIayR7jZT0mJcrW3sjL65FhIdDwR3inW+Tn++d3yHOLkUMvQtBr+KEqNF0P
eeshNtRBiHDU7qcipRfBfjguLEOPz1owcuTwFNttSkdssgKdUAmhGfnrRvopVdpjDzpJDQoKQlGU
WCOpiXncuEa67eljbYms/v6wsDCrxjv6n2PHjnHo0CGmTZuWJNeTMWNGvLy8LOeWKVMmy/+NWLx4
MQMHDsTFxYXGjRuzcuXKJDmfJEBaZDUlwGQyRYmiGluwJhVicwQwrtr1YoP4RnuNN/ibYOrUGfj4
ZEXKBkAftNapHYHdCFEDVT0DfAY4AF+jqiWBwajqcOA0Dg79cXRMz4gR9ejefSUeHh5RKn7fdlV/
bFW0ttX0xmisMa1lNCpPTREWW12t2WzG3d09UR6+cYlsxTUaqygK7u7ujBs9ks/atGLwiDGcGF6a
wNbToeZnWoT15X3UM1vhOxvtaP4qqPWHw+bBsH06SoAXapvJYNZaEitbpyDzlEdmLapt75YJdeA5
2DUOFvTUUv8Zo0ZDxJ7piEwFUftchD9GwMT6iA7fIxv1gsv7kI+vQbdDkW9o8z/IUxm+bwUOJmT9
QVEr+PNVRLZZACs6axHLYH9wsm4jKTzvIl2ygPdzxE/NkL12WI8f/xnhng3pnh8xtTTqkMsRZv8R
8HkMahg4uMHqttB+rfFLQ20xH67ugqBnUNy6E5ZadzJK4CuYURnp7AGFW0JBrTBMfrwHfquCWN0c
2XEHSInzrq/4oH4Nxo4dnSoWcfZ+s/qcpZM7ndipqmrpMpUYsoKkhpGkOjg44OrqmqyLhrhGuu3N
tfYCBXrzFD2IYySzr169YtGiRXh4eFiypglBo0aNePr0aZTXJ02aFOXa7H3Pt27dYtasWdy9e5f0
6dPTunVrVq1aRYcOHaJsm1qQFllNZugTkA6953369OljeNebw8/PzxJ9M0Kf+BLDG/X169cWe62E
4tq1a1St+h7BwaWB02hFUwuBU8BshMiK1mZVoEVYC0VEVMvh5haEs/NN+vbtTs+eX+Hu7m6VWlYU
JVXru/RoN2Ahp0bBv71IbEp6aMGb64OT8rxiK57TP9dTp07Re+BQnkh3AjrMQzm8FHntFLL/Seud
quEwNh/UHAaFG6KsaYGUwcg+ayB7YehXEPqdhNzlrN/36g5MKgmuGRGZcyN7b4JMEfZZvi9hSH7o
sgcKvKu9dmMvYl0bxDtNkPcuIQs0gE9mR73IXaPg0A+IKp8h2y3UWqAazlVMKInM0xjlwV6kkxPy
m/2WVD3ej2FcMfh0K2Qqhvj1XciSB9nvsBbN9HoI40vAR1sgV02UTU3A/z7qsL/B7ArhoYgppZC5
GkOlQbCmGhRrCO1WRZ7DxTWITb0gRx2E51nUXlfAbMg4SRUWlQWv29DTExxdIsf8HsGqilCiBSJP
FfL+O5tTRw8kaSOUpILxXo8p05DS3QpsSWpKjmzbwnZhGxYWZlUYrSgK165dY/Xq1RQpUoQ8efJw
5MgRzp49S79+/fjkk0+SrJipRIkSHDx4kBw5cvDkyRPq1avH1avWC+W1a9eyd+9elixZAsDKlSs5
efIk8+fPT5JzSmSkFVgKTQZ5AAAgAElEQVSlFOgFMJA0tlL2oLsOODs7W1XD6qkMfZX4JrC14Yov
VFWlfPkq3LhxE8gA+ACDgGzAMEAixGcI8SdQNSKSuhiYT5Ys+RkzZjAdO3bAbDaniFR/YkDXDYeG
hlomfHtRVHvpQ3uFB7YPr+SCrd4utSwaoovGhoaGsmr1b0yYOh1/39fQfTuUsGllen4dYuM3yAFP
ItPTewbD2QWQpQCK4oQ66FyUYyq/fYF8fAP52Z+IjR8hHx6BL1fCOx+hrB8MF/eg9rlk/Sa/57Cw
CgS8ggEXNR2qEaGBMD4PVB6GcnEOZC2I+tVWcI2oIj65ArFpMLK3Fs0Rq2uD331kv0OQpSDK8vbI
J3eRnY5r2we8QKyqg3A2ow4+g7K0FdLLG9nmoDYeFoSyuTn43EAd9jfiyFzE4fmoXe9HOAbcgjXV
oWRTaLNCO/8ZxaDKTCjaEWVvc/C7gdrzHzBFRGfvHIC1LSB9WRTVG7XTZc3zVofnVfitGmYTnDx6
kOLFi8fvy37LMC6s31QOk1C3gsQgssZ7PbWRVCP056Re6GmULaiqyt27d9m4cSNnzpzhxo0bPH/+
nODgYIoUKWIpqmrRogXVq1eP5Ujxw5AhQ8icOTNDhw5l6tSpeHt7R9GsXrx4kQ4dOnD69GmcnZ35
/PPPqVq1Kr17907Uc0kipJHVlAI9qgRJU0VvDwEBAYC2IjTefE5OTol23Oiit3FFv379WbhwGdAa
Ic4BKuCElJfRiqqmAheB2cBk3NxW4+R0n65dOzBq1EhMJpMlaqen+nVtV2pCYlpPxSdimFjV9EYY
ybbu85paH1y2ZNvBwYFnz57x1dffcOz0eYI+nAGV2mvSACkRk0sgS7SBBhOsd/bwL1hWB9wyQ7fN
kL9K5JjnfZhcHLpegMwRZOv8z3BwIEqV1qh/rYGu+yCfjS+pqiJmFkWGKxD8ArpugiL1LMPiwFTE
8cWo3W5rRHJNLWSoJ7LvfkiXA0bmg/cmwzs9Ive5qQ3c3w8fT4MN/aD7VUhnKPYK8kGsbYQMeAIB
3vDlHXDNEjkeHoKy9RPki4vIQE/4eDfkMdh9ed2ANTWgzEcoAS+Rns+RH0Y4CIQFoexuBGGvUL+6
BCF+ML8YFO4LJfoj9r8HZkdk2xORC4EQP5zXvkPfbq0YM3pUPL/htwfbeySpZQtJ5VbwXyepxuv3
9/dn8eLFbN68mZ49e9K5c2ccHR3x9fXl5s2blsKqqlWr0rhx40Q9P09PT9q0acP9+/etrKseP35M
9+7d2bFDk+dMnz6dFStWoCgKFStWZMmSJamlo1YaWU0psG256uXllaRuAOHh4fj7+1u8Q5OqWtzf
399SpRofSCm5desWVarUIjBwAOCNRkhNCJEXKR8APwAFUZQuqKovWbJkZ/jwAbRr1xaz2WyJeBmF
+yk9ameL5EyRx8VuK6HV9BBZxJbae6vbRruiI9unT5+m29ff8oTMBHy8ADzvIn75DDnoeWSVegTE
n2MQf29AzdUQri5B1BuAbDwaHBxR1vZA3v87MoKpw/serKyqRUh7n4fMNpHTS2sQ279Bfv4MLvwA
p8cimkxEvtcPAr1hYj5ougYKN4t8z7Y2cH8vlGmKcvskao9bUT+A/YPg9CzIXx8++yPqeJAPzMkO
Dk7Q4x442/g9hofCojwa2ez+KOq45zWNsIYHQbuH4Gyw2Ar1R+ysg3BQkZmKIJ7dQH3/vDYW7InY
WxUyF0N+shMAp/2f06RYCIsXzLZbmJjS5gMjSU0J90hCZQWAReuZmkkqYMk4Smm/A1hgYCBLly5l
3bp1fPHFF3Tr1i3BmcQ0RIu0AquUitiKnxICo15Ib/3m6OiYpBqu+BZY6dHDoKAgevX6ltDQusDf
wFYgF9ARIX5DiPqoajguLqMIDw9hxowZdOqkeUIaW4jq9lyBgYFR7KBS6gMLrAlRcqXI42u3FVOn
KSOJte0IlBpb00Lkb1Mn23oRW3SoUqUK504cZsFPi5gwpRaB0ows2ToKUSXYD3l8JrLxOijwAZTs
gtj1EVz8HdlyDurpX6GLHXsbsysE+0HW6jCvArRaAaVbRpxsGGL3EGS5gVqUseJgyFYNdn+Mcv8U
0j0rIl1+VCNRBWi+Dg4OgnNzUasOtH9hOauAoys8OAJX1kHJNlbD4uIihEtWZMaKsKw0svN5cMsW
ucGNTYjwEMjeCH4pjex82ZqQumYFpJZEOT8BasyMHHN0QzbZj9xcGV5sQ7a4FznmlAlZ/zD8UQl2
d4b875Pl9Ql+mnvIsni1194zOfyOY4MtSU2swsI3RWxFn/YKP43WTnoRkzFwkFLnXFvERlKDg4NZ
sWIFq1atolOnThw5cgRnZ+cY9piGxEYaWX0LsL159UKZxEj92PNGNZvNFuKalNCvIybY6mWdnJzY
t28fx44dRfNL9QSyoLVQPYuq3sfJKR2urtMYPXooXbp0Rghhlep3dXW1TLC2Wq2wsLBkTXvHB7pl
k24RFhshSi7EVj1r+8DSyYDxvYmhgU5uvKlDgclkou83vWn16Sd8+FFL7j/8k8C7h6FAZOpbnPkJ
4ZYNtcAH2gvZKqJ2ugf7OsHCJpA+L2QpFWXfysmpkL4YatP9cH05bPgc5c4B1A9+hEurtQhmxSGR
b8hTG9n+KmysgfS5h/zod7vnrIT5obrmhjNzEU4eyOrDIj1kQwNhb18oNwFcc8GOroiAZ8hK32jj
fk+QR8Yja2+EHA1QTnwOK8oiO56GdPkg2Af29UKWmgwFu6Ocbge/lEF2vGSRCygHvwG3gqgVVsCR
98DBDFUNlj9hgRD4HBRXxMkuyLoGazDXXNDgCPxRFdOdzWz48w/SpTM0BzAgNocNe3NCYs8LxgVQ
YrpfJAeMRFZP9xulPXqgQC9G0v8NpOjCT31xHR4ebre4OCQkhFWrVrF8+XLatm3LoUOHcHV1fYtn
/P8XaTKAtwA9UqXjTQuT9H0GBQVZVuu2HnbJ4TqgRwvsecYaGyEAli5Yjx49olSp8hFV7pXR2qT2
BdKhKNMwmxXGjBnBl19+gaIoCY4+xjftnZRdpvQUuU6I9Mk+tcE2IqxP9LafsW36MKWlZm01aokl
v9i8eQu9+w0isHBzgutN01LlM3JBnZ+gWFvrjQOewbJ84OiOkqMcaovfwD2HNub/HBYUgKYHIVtV
7TWfWyh76iNdMyB9n0KlUVC+T5RzEPu7IW9uAkVAyx2Qy1Ds4XUDVpSHxucg1A9xuDGiWAvUDxaD
gyPi+ETEhaWoLW5r2z89jDjcHCr1QdaeiLL1M+SrB8j3j0V8kCrK6d7Ie+uRnx1DOT8b7h1BbXBZ
G1fDUE63R746iux0CV6ch20tocE1cMkF3ufhSB0o2w8qjde8V//4AOkfgCy9Fk5Vhuy1odaayGtQ
Q3H+sxqdPq7GrJk/xPs7srcAi00OE9/iRFuSmph1AsmJ+GpS7VlDxdY6NbncCmIjqWFhYaxZs4Yl
S5bwySef0KdPn1TpLJFKkaZZTSkwtlwF60r9+MDow6enL6LTPYWHh+Pr62u3h3BiQZ/IjDe1PlEH
BwdbGiHoJFNKyaeftmPPnquEhzdHUdYgpRtmcw5Mpou0bfspEyaMt0SGk8r4PjoSm5hEy+jzCgnr
R55SYJsij0lrF1vzg7cZdTF+J0IkTdtKb29vBg4byZadewnM1xDl9gHUzveibKccHQD3D6LWP4o4
3BTpfRGar4SiH6IcGAC3/0T96Lz1m1QVtlYBn+vQZAPktynk8LkFq8tCg4tw7xe4NRMaLoDSnbVj
bm6BDAhB1tmtbR/wGGV/NchcGLXxYlhWEepuhRz1I/fp9Q9ifx3IWRn54Ci0uAmuOSLHpUQ5PwT1
xs8QHgINL4JHUcN4OMqZjsgXB7UGBAW+gRIjI8c9T8GxBlB+GLjlRpwcgKx5F0zpIPAOnKoK+VtC
lUUAOP79HTWyXGDntg1JsrB8k0Kk8PBwiwzrv0RSEyNrEtdFQmJLuYzfiR4gsm20smHDBhYuXEjT
pk3p169fkttKpiEK0shqSoEtWQ0ICEBvOxfX9+sEMK7eqKqq4u3tbenilBQIDQ0lMDAQDw+PKKl+
I8nUHwKHDx+mZcsOBAb2AG4CGzGZnOjd+2v69++Li4sLqqq+teij7YRqnFjjSrSM0ceYrKdSOozR
R11+8abRx+hIbEx2W4kRdbH3nSR1Qcjhw4dp1b4LIS4FCW26HVwMVfOBL2F5fqh3ALJEdKK6Ph8u
f4co0RL57zpodgiyVrHeaVgQrMkDGevDy50oFQeiVhmjdYgClN2tkK+9ke/t07Z/tAXOdkIp9yVq
0U9hwwfw4R1wzmK1T2V/NVTvK5CpHDQ5E/Vi/B/AtlIgFfj0HphtFsBqOPyeF4JeQd2DkNnGuUCG
w753wO8GvH8PnLNZj786DsfeB1QouQxyGKLQfv/CmVpQpAfkakL6C+25cPY42bLZ7CMJEZdCJH07
PU2enP6miYWkIKlxPW50DiZAlCh3XLJgsZFUVVXZsmUL8+bNo379+gwcODBJn5VpiBFpBVYpBdFp
VmOCPW/U+LQ2NU6gSTlhhoeH4+PjY4lUubu7W6KoxkkoKCiIL7/sRWBgHRwc/kKIE9SsWZ+FC+eS
MWPGZCs0igkxFRzYRgOMPb71iVO/XpPJlGL0qPGFXqhnlG8kVkRYCGGXJCaV7tjY1jW5NcK1a9fm
7vV/GDF6PCtXlyWw5nwoohVIiQs/IDwKoepEFaBYb8j1IXJvJU3H6WAn63J1EYrJDbXyOvC5gDzd
GOXxUdQP1oPvA9Q7u+ADQ4V/7o8g3Vk4UhvOzYd8ba2JKoDJGbXKCthbDV7fAa/LkLGs9TaPdiIc
XMGjGmwthWx6RtOP6rixECFVZIFJcLgx1NoC2SJttPA6B363EBkaw4FyyPqXrAlrphqI9GWRXmch
5IX1sd1LQcX9cLYujvd+ZvnqpclKVCH6eUGfn3W7OV3HqS/wUlKRV0ywJanJPXcZNfNGq6X4dpzS
vx9dcqXXN9iS1J07dzJ79mxq1arFtm3byJIlS5RzSsPbR1pk9S1Av8l0JETrmZDJLakssvRVq265
5OHhYZXqN7ajA20yGjNmPD/+OAsnJ1caNarPmDHDyZUrV6rucW9MK+skFbCKuESni01JDytImRHh
2CJa0dlt2RZNvW2N8IkTJ+j0RU+83CsSVGkS/FYBau+A7HWsNwx6DlvyQ8ZG4LMfqn0PJXppBVBh
AbA6N5RZCLkjIo9hASh/1UUNeoBwz4V0LAA1NkY9gQcb4HQncM4ODQ6Ae6HIMSlR9tdCFfnAMSs8
Ww51N0POBtp4sBdsKghFf4JsbVBu9EC+2IL84BikL64VQ20pAkWWQZZPEU9+Qt4ZAtXXQs6moIYi
9pZButaHgvNRbndG+uyzJqx3/4f4Zygy53J40A6Kz4bc3azO0fxPc2qUDGXn9k2J9K0kDHp2IKZK
ctttU5p+03h+byOSmhiwlwULCwuzPHP0+33KlCkULlyYwoUL8+LFC37++WcqV67MsGHDyJEjR0yH
SEPyIU0GkFJg23JV150aK1mNBNBW65lQeHt74+7unigpT2PETU/1m81mXr9+benGpRNUYzRXCBFR
VFWaatVqMWHCaEqWLJkiSERCYVzhRxcRTsnaTSN0YpfaOn/ZI7H63xAZxTUuFN7mIiEgIICRY8az
eNFCcMuLbBbV41Q5PwCe/Ila8Ty82oW41gGRoxZq7V8Q1xYj/l2MWs+ON+rZdvB8O5SZCkVsiq7U
MMSeosjMXSDwX/D+A2pvg2zvaeOPtiNOdkJWf6JFc+/PgnsjoNpCKNQJ5XRveHwYtVJE0ZSUiDvD
kI8WQcM9KNdnI1/dRpYztJ59thxu9YEqKxD+N+DGPGT5iE5WUkW53QXps1cjrDIE9pWEnMsgQyt4
vQMetIGSiyFnRF/zJ7+SL2Ay504fibenc2LBtijvTTIOsc0NiVHkFdvxUytJtYWetTMWs+mvBwYG
MnfuXC5dusStW7e4desWZrOZ4sWLU7x4cYoVK0aFChVo3rz5W76K//dII6spBbZkVa/UT5cunZU3
qpOTE87Ozok2Kb1+/RoXF5c36mKhR3qDgoKsrLH0KKqXl5dVgZUtIdAnjcuXL1OmTBnMZnOqLjQy
Wk8lNCIcnS42Ou1mYkc4/0sOBcZFlBACR0dHTCaTXTKQnC4Q0WHt2rUMGz6O1+nqEFR2DpgjijmC
nsPWAlD+IKSPcAAI9Ua53BA15IFm6VRhJeT4yPYDQDlWDTXEFULOo+Rrh1p+LigRTiN3/of4ZySy
0iONLN6fAg8nQuV5UKAjYnsRZJauUGhs5D5fbIGrHRGFOyNvLoNKZ8GtpNVhxYPvkXfGASpUuglO
uazGebEOrn8BhEOJXZC+ruGcIwkrHkUgxBmZf1/kuM8meNgRyvwCHpVxvlCZ/X9soUKFCgn6zN8E
RjkWkOQNSOJa5JUQKz4jSU2OzllJCXsk1TZYcOzYMaZNm0ahQoUYOXIk+fPn59WrV1y/fp1r165x
/fp1hBBMmjTpLV5JGkgjqykLxparoaGh+Pr6WiaaxChesYc3sciKKdJrTM8GBAQQFhYWZSIFjZQb
K8hT48SYnMQupkKDxEgbJqUeNbmRENlCbC4QyZWW9fPzY+DgEWzc+geB7yzVPEsvDITHB7Soqi0u
NILXxxHFRyMLDbYUVAHwfA/iXDtk2ScQ8gzl1ntIl+zImtu0ivqdeSHfdMhpSKu/2g43OkD60gj/
e8iqDyJbmOrwPQcX6gCOUOtpJPnVoYbByQIQ/AyKLYfsHazHpYQLlcHvMhSaB9l72IyrcOV98D0O
Rf8Bc0Hrce818OhLzOkKMbRvK4YNHRSHTzbxYLsIett6+rhKYqLTxv6XSKptJsg4F0spOXXqFFOn
TiVHjhyMHj2awoULx7DHpMeDBw/o3Lkzz58/RwhBjx496Nu3b5Tt+vbty65du3B1dWX58uW88847
b+Fs3wrSCqxSGozeqABubm5J2rs3LoVcRthL9RuLuvRolTHVrxsm62P6+42LIj3V/LZT3vGBPWJn
K9ZPbMSl0EB/SMWnU48tsUut7Wkhal/1+BSDJLT5QWIXybi7u7Pop9l83GIXX37VGf/HLQi9uQLK
/xl14zAfeH0SsoyFm9NRXu5DfWcNmDNrKfl/+yEzfgGKMzjnRy15G3HrffijDORsiuKYAdVIVAEy
fwjmA3CpFtKtJMhAtAYdBgQ/AkwIxxKIv4qjVjoL5shqafF4HkKqqNnXwo1OEOYJub+JfP+LNYig
O8jM6+BOB1CDIadhPPQZ+J0ChwqIWzWQRS+ByVA4laEdwn8PmZwOM3hQ/wR9zgmBLUlNKfdKTMWf
9rxN7TXvcHR0tJrL3/Y1xQfG+95eFzApJefPn2fKlCmkT5+eOXPmUKxYsRRxjY6OjsycOZMKFSrg
5+dHpUqVaNSoESVLRmYrdu7cyc2bN7lx4wZ//fUXvXr14uTJkzHs9b+PNLL6luDr62shgK6urnh7
eyf56lZR4tYOVSczxlR/dFX9QJRJ0zjBK4piZa1lSwJsq+iTOuUdX9gSOxcXl7d+TsYHlb1WqTF1
6tG3MZLU1Jju16PbSdENKDYiENPnG19PXn1/wcHB1KpVi7OnjtC2fVfOmVxQlagLV+XhD2DOg5pt
MDJTL3jQEP4sCVW2QNAjCH4BRQ0doBQTsugBuN8PHixEzdEjyj4BlFe/Ic0FEaHByLNVkeX3Rqby
1RDE9V5Ij0HITIMRL9ojTpVEVjwOroUh+Cny9ihktt/A7UNwSA93P4bQV1BgLIR6wa2vkR4zwPVj
ULbCvY8gPBDyDNGkC3e6IR0rIDMcRPh2gpvlkUUuRhLWoH9wDt7G1t27LE0okrJA0ZgiVxQlRdz3
cYXtIkyXbulZMX3hG5dq+ret7bZFXEjq33//zZQpU3B0dGTatGmULl06xZw/QI4cOSzFXO7u7pQs
WZLHjx9bkdWtW7fSpUsXAKpVq4a3tzfPnj0je/bsb+WcUwLSyOpbgpubFrnQb6K4Esk3gU4Wo4Mx
1a9b+xhT/UaPUX1/tobKRg2nq6trFDIVF7si25Z9b6OK3kiGUlIr1Nhg+/kaq5XDw8Mt5FR/GAcG
BtrVvqW0hxTY93p1cXFJ1nOMq92WbTTLHgHQt9ELdFxdXUmXLh2HDuzit9/W0Ld/Y4JzDCI89yAQ
DhDqiXr/R8i7VTuoyR1Z8CQ8HQEnG4JiRmYdCErU81MUiXTIhXy2AoUQ1IJzQSfDQfdQHy2A7IeR
5oqIF03gdAWosBfcyyMezUKgIDOPAEDNug7FcwCcqYQsvwvl8RykUxmk24fa/lwbQK598Oh9CH2F
IvzBVADVPSKi69wAsuyEh81ADQTXkkifE8gs90AoqB6/oPh2Qtwoj1r0Mjikx/VlZyZOGE2xYsWS
NNptW2xkbw5LLbAlqTHNYXHJJkRHZJMDxqBBdCT1ypUrTJkyBVVVGTt2LOXLl09R85c93L17l/Pn
z1OtWjWr1x89ekTevHkt/8+TJw8PHz5MI6tpSH6YTCarlqt6ij4pCZH+gDRCj4Iai7qM9lbGCUzf
h5HE2BIIs9mMh4dHvKNcsaW8o5tEbQnsm0gKUgIZSizo36uujTabzbi5uUW5FnuSAr0dcErxhUwN
2troJAUQ1ZM3KCjI6n7S7bUAy+f82WftqFmzBu07duf61d0EFPwF8XgBwqkAqkd96wPkmAQ4wstp
CP9jyDBvMBmM+oPvoT7/GbIeByUjvHwXxe8iasmtYM6Kcm8QqlM1cK4MgMy+B172h3PvQtF5yDsT
kNnWGy5WQc08C2HKC+cboQoV8t20PifnapD7GDyqgyoDIMc1m/HakHUvPH4fRCjSfS4oEW4owgHV
YyUKHVFulENkbss7ZbLQo0e3OFlCxRTtjm4h9v+VpOqIi6zAOD8kVpFXfK4lOpJ68+ZNpk6dip+f
H6NGjaJKlSopam6IDn5+frRq1YrZs2dHa1tpRGq4pqRE6rwb/4NIjsiq8Rj2Uv3Gqn57qf7oJndF
UZKsqj+mSdSWBNiSrLhWedtey9sunngTxPdaYpMU2Opi3yTl/SbXklIkGAmB/rmEhYURGhpquRb9
fowum5A5c2Z279zIrNnzmTWnIkGBAcgCe6IeQA0Gr4XgPAERuBr5b2kosgNctWp55cl3SHNlpFn7
v5r1FsKzPpwrAwWmoL7cBbltyGaWmfC6NFzvCcID3D6IcliZrh94zYGwR+C3HjJ8a72BuTjCIQMy
1A/h3ROZZaf1uFN1hEs9ZMAeCLtiPSYcUD1+RVFbwqulrFh2LsbfcHTR7rhEC/VtTCbT/zuSGhfE
pu22R2Sjk3XFdY6wvRZ7Mp87d+4wbdo0Xrx4wciRI6lZs2aqmRtCQ0P59NNP6dixIx9//HGU8dy5
c/PgwQPL/x8+fEju3LmT8xRTHFLnXfkfgO1NFVuKPrGOqaoq/v7+VitVnQAkVqo/uaBPfrawN4Ha
I1l6pFlP9afmB9WbFBpFh5geUtGlvAG7D6j4RFqS4lreFuJyLbEV0A0a+C0VypemR8++BPv9j2Dn
CuBgiMR4/YwiHFHdBqEyCPz6wtVakG8WuFZH9dwC2Q1kUDEjsxwFr2/hxlfgVBVMdgzRnSqDKgAn
lIdVUHMds3YBeL0QhVBUx93w8hMIfQRZp1uGhc+PCDUYqdyCoPcQL95FZj4c6TQQuBsZ9CewHQJa
gQyGDPMMJxCGs+kWEyeNI2fOnPH+7GNa6Br9hPXfqj43pgbtphFJRVJjQ1wWuvofI4m1lcUYP2sg
1mt58OAB06dP5/79+4wYMYI6deqkyO8lOkgp6datG6VKlaJfv352t2nRogXz5s2jXbt2nDx5kgwZ
Mvy/lgBAmnXVW4NOknQEBAQghEgSk2s9jRoYGEh4eDjOzs5W/q32oqjGv/8rPpz6dYaGhlrIlU7S
U4tu0xY6EU8J30t0djrRRbttdW86gTDam6W235iOpLgWPz8/evcZxI49fxGY7TdwqQhqAFzNAy5z
wLlj5MbB2xEBHZEo4PguZN0adYeBW+FVR5DhiIz9kenHR9pgSYnyrAZqSEFwXIAS2hSpPEHmPgOm
LBD+Eu4VAoflYGoJ6jkIaQjuTSD7Kgi9D/dLgtgKSgOQLxGyDsLRjJrlNBAETwtD+LcghoP8G6gN
Lq0gw2IAHAO/o06Vf9m8aXWi3YO2iwdb2yZ70Vhbg/7oZAXJDVuSmlosqIwk1tZ2CyIj5eHh4Rw/
fpzixYuTN29enj9/zowZM7h69SrDhw+nYcOGKXpujg5Hjx6ldu3alCtXznL+kydP5v79+wB89dVX
APTp04fdu3fj5ubGsmXLqFix4ls752RGms9qSoJOmnQEBgaiqqql8CqxjqG3ahVC8wYMCAggU6ZM
VnKA2FL9ISEhCCFStYF/TLpHe+ksW5JlTxv7tj4He9rapPDlTUzE5mmqb2MymSxds1L6QsEekmPx
sHbtOvr0HUxQuu+QajDi1RLU9HY6WQVvBd/W4JAPsv0BJoN3qQxDPC2MDO8KohVC1Ec4V0XNshYU
N/DfjHjZFen4RLPBkiEo4Z2R4fuQuQ+i+P4IfpdQHc9E7lO9BSG1ES7FQThCUDhSGMz9pQ9CNkI4
vEY610EEHEZVDRFfeRV4F1yag2svPEJbcPHCiUSJKNlWkSdk8ZBSfHlTK0m1B1upj+4BrqoqT58+
pUePHty8edPillOhQgXq1Klj6TpVvHhxMmTIEMtR0pDKkEZWUxJsyao+kdoTWscX+gNTT9XrFkVS
ah2m0qdPbyFoEH2qX48+GMnD/7V37uFRlGcb/83kfOBsgBDAcEyCUA4qKJYKLUFRQCuWg/WTT4Fy
kFO1FbAqYBXCWQS0WAQELSLwISkkqYgmKhiCqFVJIkGMJiARREAIIcnufH+EGXYns9ndZA+z4f1d
F5dmZ5K8M9mduX3vZi8AACAASURBVOd9n+e+Aw299VRoaKhb9aiOZllsa7J81SFb32pr1cY+wNDa
zKiL3t8PCkb44+GhsLCQP4z8X3K/OgTR6yH8If2gkM7fhFLRE6SzwDvQbAtEDK7afuFl5PN/x6oU
Vy3LW88jy7eiyJUozXfByf7AVAiZZfczZescrBXLQamEsHyQr9f93hK4/GtQikEqgqDrdNtLkZRk
FOvnwIcg6WaLlAKgL0HBlax79UXuv394nc6TJ0SqM1yZjfXEdcL2WlbfRKpRxOvp06dZsWIF2dnZ
TJs2jQ4dOnD06FG+/vpr7V/z5s1JT0/301EIvIQQq2ZC/bCqqB9c26hSd3+ebVd/eHi43YVZnRU4
f/68Xd2mvn4z0Jf6Vbydce9oudtolqWuzUf6pUtVcAci7ghuR0uF/nhQcHQs/nQpKC8vZ+LEqaT+
+30uBb8Oof2vbrz8b6SLY1CsJ4FQ4CWQnkBu9DjWqMfgh3hgJcg2pQNWKzAcrLuR5GYoYT9U/6WK
FS53BuU7CF4MIbqaO6UULrcHJRhZDsHK5yA3stlegWTtgqJcQJJkFOW/INkL2uCg6XTu/DEHD2bW
+tzYlmH481rmidlYvUj1ZAS3r3FFpP7888+sXLmSDz74gBkzZnD//ff7/XgfeeQRdu/eTfPmzfny
yy+rbc/MzOSee+6hffv2AAwfPpynnnrK18OsLwixaib0YrWyspKLFy/SqFGjGr6rOrZL/erN37ar
X91HXeq3/dpisWj/VIKCgjQvTn/YFNUFoxmukJAQn17onM2yuGO1VZ9qOPU33LoIbnceFLyxHGu2
Ge49e/bw0JiJlCoTqAx5GgDpbGcUy2jgOZs9P0cKugNFkZClhlilI9V/mHIKLG0BBULXQNAY++2V
m5Aq/4yibARGgvwQhK3WNsuWWWDZjtXyGbI8GvgEKwdBbl01LmU+kvISVmsusjwORclCUQ6C1PbK
78+hQYNhfPFFNs2bN8ddzCJSnWF0nTCq71b3sXXDCERsJ1OCgoK0z4wt58+fZ/Xq1bzzzjtMmzaN
UaNGmeZ4P/zwQ6Kjo3nooYccitVly5aRmmpQGy5wFxG3aibUm6ftUrw7bgD6pf7o6Gjtw++sq1+W
ZU2kWq1WQkJCtBkhW4sXVfSZYRarJnxlo+UKdbHasj2navdseHh4wHq9QnXB7Ymkqbp68ta2pMC2
VtBMXpzJycl8eugjRo4aS96RDyitvBOUC8Czuj17oFj2AwlYsUDQVyB1tdtDlv4Gches1r9Bxf8i
8xVWeWFV45XyC1ROR1EWAMnAB2C9A6n8GErwbqAAa/mLQCYQhtW6FVl+FEnpjmLNAikcxfI8Cm8D
IVit65HlqUBPFCUbaEtk5MOsWJHitlC1Db5QvZ7N/Jlx1alAnTywWq1cuHDB8GHMjKUxKrarD5Ik
GX5mLly4wJo1a0hNTWXy5Mns27fPFJ8rW/r160dhYWGN+3jbzedax1zviGsYWZa1m6qji47RUr/e
wN+oYaqmrn5n4kE/i6UKLL0NlP4C6gv0tbVmEQ+OqMlqy9YSDK46MahCz+gGZVbU47FtNPJkHKoj
ahIAehHrLObX9hwHgpVWbGws77/3b55/fhELF85CYTJQ/TzI8nMoyk0oSjew3ALyepD/ULVRycVq
eQM4BHQAZT9K5UBk+SuswVuRrfNAao5VeeTKT+sK5IB1EHJlDxQaoEiDQOl5ZXsQVuvLSFILsPYF
KR6k/qD8Wh0NVusqZLkBcDOyPIxbb+3AiBF/cPm4bRva1BQwM4o2V7BdfQgJCakWruJKgIdZJhX0
IjUiIqLatbm0tJS1a9eyfft2xo0bx759+7QGq0BDkiT2799P9+7diYuLY8mSJXTp0sXfw6pXmPfO
fg2gn1l1hH6pPzw83LCT3ZWufsCti7qrs1iq16ZRPKonl2L9JYS8hb4BTBVCet9bW69Cb5/j2qLe
oNTULDOJh5qM4/UPY7bnWN1Hra8zc0NbUFAQzzwzm5tu6s748dO5cKExlZXzAFVY52K1vgUcBNoB
fcE6Flk+gFVZiMyjWEkGOlzZPwHFmofEr5HKe2C1ngCydL81DkX5GMUyEPgU0C+RSijKPOAkKFuA
x6ptt1oXIEnlKMobvPTSJy5dE+ubSK0p717FFV9Tf6RM6cehF6l6wVxWVsaGDRvYvHkzY8aM4aOP
PiIsLMyj4/A1vXr1oqioiMjISNLT07n33ns5csSgzEZQa0TNqh+xNVIHOHv2LA0aNNBmbSorKykr
K9MuYurNEuyfss3U1W/09O+J7m59M4tajxaoN6i6NIA5O8e+ttoyWw1nXVE/dxaLRat5tj3fRn6b
ZqvvLikpYeTIRzh8WKK09F9AS2R5EFZrKGATncoRZPlOrErTqg5+CgG9I4mVKnF7GngJ0NWx8gvQ
CWiJJP2AouylatZV5TSQCNwB7AJSgPE22yuIjOzH888/wh//+ECNM4VqKYb6MBSoVnrgW6eCmmz5
PDEbq67aqYmIRteA8vJyNm7cyKZNmxg9ejSTJk3yiq+4tygsLGTo0KGGNat62rVrx6FDh2jatKkP
RlbvEDWrZkN/QVBrRvVNQpGRkV5d6vf0MdX09G8rrtQx1nTzt50VDoTZrZow+tvol/pcwdVz7Gi5
21PLhPpZYbOXYdSEUXNeVFSU4bkxqos1SkhzN2LSk8TExLB791s899xCXnmlJ2Vl07Fas4EC3Z6d
sVq/BOKpukd8C3TT7fMOknQRRVkITKdq9nSJtlWW5wLNsFp3ACuAfsAWYNCV7Y8D12O1Pg/cCUwB
SoCqbumgoGX06NGC8ePH2V3HbJtA1c+MSlBQkGG9dyBcF1ydSfUErszGOlpVcGU21lakAobX54qK
CjZv3syrr77K/fffz/vvv+8Ri0YzUVJSQvPmzZEkiZycHBRFEULVwwTmnaUeos6KXbhwQRNlvlrq
9xXOlmJtM+jLysrsZoyDg4MDWqTqLY689bdxZ7nbWe2xo5u/7Yx9SEiIKWs4XaU29lOunGN/LcXq
hdDzz89l4MDbue++0VRWdqP6rCnAZmQ5Gqu1P/Ab4FXgvivbKpCkR1GU/wGGAO2BR5CkXBRlF1Wl
BWupmq2VUJQZQCvgD8BSoBNWayqQceXn9QNeAx4BfgQmERa2inXr9tmdB/V8qecRsKt7dNREZ+YZ
b1+KVFdwVuLlrDYW0B4gbO9XKpWVlWzdupU1a9YwdOhQ9u7dS8OGDX17kB5i9OjRZGVlcfr0adq0
acO8efM0n/QJEyawbds2Xn75Za134s033/TziOsfogzAj6gdrOpSv7p8oi6NuLvUr1qCmKlT3x30
s1shISHVbk5mae5yBf3Moxn/Nka1x7ZOErazhOrfR60TNKstkCv4snTB3aXY2ggsZzZnRUVFjBjx
MAUFDbh06VWg2ZUt54HOVM1yDqFqmf5ZZHkSVuvfkaQVSNILWK3vc7VhqwRJeuTKSlADoDlVM6q2
ZFI1CxsCjAL+otteADyILEssWvQ0kyb9ye582dY9uvq3cWQZV5sHMk/ii+V+X2G78qe+d9X39tKl
S/nwww/p1KkTYWFhfPTRRwwcOJC5c+cSExPj76ELAgfhs2o2SktL+eWXXwgLCyMsLEyr9wkPD682
i2r7X6Mmo/ogHFyNdXUksMzSeGTb2a/enAJx5tF2FraiosLOmsXMM1g1YfQA4c/SBWem8c4Elt6y
KSwszOHfoKKigpkzn2Hjxre5dOl14CZk+Ulg15XZT5WjSNJYJOkGrNaDwHKgv+6nXQL+F8gDtlEl
ePX8/cq2gVTNstojSS8RG7ubr7/+VBM9tRGpztDPeDt6IPN0jXd9EqlwtZbbqF5YURRKSkrYunUr
H374IaWlpQQFBXHs2DGOHz9OfHw8iYmJPPHEE/Tt29fPRyIwOUKsmg21g15d6ldnWFXhaVQfpF/q
ry8NBp5oAPNWc5erv7s+P0DYCgdH59iRDZQZZpP17zWzP0A4m/FWxZ2iKISEhLj12Xn77Z386U/T
KC2diKIspWpZvqtur1LgLqqap1ZRtXxvywXgt1TVuhYAL+r2KQSGAY8jSa8A16Mor3N1draYiIjh
7N//Hp06dbKb5VZTjXzxnnEkYl2xNKvpZ14rIhWqjvedd95h+fLl9O7dm5kzZ9r55JaVlWkxqT17
9tRSnryJs8QpgGnTppGenk5kZCQbNmygZ8+ehvsJfI4Qq2bDtrNVXV6xbYixrXNTL6a2EXX+FgC1
QS/qfHUxdzQTW9c6t9rUPJqZupQu6Otibf/fXzPe9SkFzLaZRVEU7eHBSGA5a6I7evQo/fvfzblz
VqzWfwP6ruw84I9ULeG/CUwGJmpbZXk+kInVup6q0oHVwONUOQUoyPIDWK1hwDzgLJL0xJWx/h8Q
QWTkeP785/48/vgMLXrT37PctrjyXjYqP7Kt5Q7k9xrY24MZ1aRarVbef/99lixZwq9+9SuefPJJ
YmNj/TjiqzhLnEpLS2PVqlWkpaVx4MABpk+fTnZ2th9GKjBAiFWzkZWVxXvvvUdiYiKJiYm0a9dO
uyBYLBb2799PXFwczZo10y56tiLWU9nzvkDvwWkW66nazhKqDxrl5eVer3n0Bd6cefTHjLftjdbZ
8rjZcfWByFlJgf59fOnSJf70p2m8++4XlJYuB65XfxKSNApFiQFmA18AzwC3UCVKj1HVgLWaqoYr
qAoSeBoYCtyCJM1FUd4Awq9sv4Qsz0FRjqMo42jXbidZWemEh4ebSqQ6w9F7WW00sm1a8oTjhj+w
LS2xje9WURSFDz/8kEWLFtGpUyf+9re/0bZtWz+O2JiarKYmTpzIgAEDGDlyJACJiYlkZWXRokUL
Xw9TUB1hXWU2unTpwvnz58nNzSUjI4Nvv/1WEwznzp1DlmXmzJnDXXfdpd1sjS6WRpGSenHlr4ul
oxpBs1y8bW8uttTUPa8iy7KWcR8I9ZpGqLP5apa6NzqU3bUzq63Vlm2DnvpAZDZHDHfQ13A6s22r
6b1sZLelKAovv7ycDRs28ve/P0hZ2Tyqlvb/A3xHlR8qwK+ANUjSLCTpLhSlAYrSm6tCFeBGqjxY
HwdSUZQJXBWqABFYrQuQ5UUoyjJeeeXfNG7c2NSlGEbYvpdlWdaaQdWHb7jaDKp33PB3Lb0z9CJV
/9lRFIXs7GwWLlxI69atefXVV2nXrp0fR1x7jh8/Tps2bbSvW7duTXFxsRCrJkaIVT8SExPD0KFD
GTp0KN999x2rV69m3bp19OrViwceeABJksjMzGTt2rWUl5fTvHlzEhISSEhIICkpic6dOxMeHq5d
UPSzKbZ2I96s1zTC1vQ+EO2NbG/8wcHB2vGoNya1O972Am+0PGi2GxIYe4pGRET4ZYyu2pnVZLWl
lsnYNuYEcimGrVNBUFCQYQqQO9gKLD1Wq5UpUyZz8803MnLk//LLL59TWfl/KMoDgG30ZQsU5SVg
NoqSD7xg8JvikeVbsFr3IsvbsFoHAFE224MIDZW55577A7rJxpkFlaOHBUcTDP5uVnRFpB46dIiU
lBSaNWvG6tWr6dSpk0/G5k30q8qBer24VhBi1SS8/vrrWCwWcnJyDAvQrVYrJSUl5ObmcvjwYV57
7TUKCgooKyujcePGJCYmaiI2ISHBztDcVTP+uopYT5nemwWj0gVHM3Wuznj76mGhpuMJhPpaV2YJ
1QZFW7N4WZaprKy0e2+b7WHBEbalJb4KWVDfh7fddhuffbaf3/1uKMeOWVCUZAdjLKYqjnUGVXZU
A2225mO1vkeVDdZ2JGkMirICiLuy/SANGnzNypX/8t4BeZHa+qQ6W1nQP5QZBUx4o9zLtp7bkUj9
4osvWLBgARERESxZsoSkpKSA+Cw5Iy4ujqKiIu3r4uJi4uLiavgOgb8RNasBjqIo/PTTTxw+fJjc
3Fxyc3PJz8+ntLSU6OhoEhIStJrYxMREGjVqZCdindVruuL9WN9cCjztwemt5i53fr+tCDKj36s7
OGoCc+ZlalarLdvj8bdTQUVFBbNmPc1rr/0fly49BXTUtknSq0hSFlbrfOAgVeEBw6hqvrIgSWNR
lOuBhwErsvwWVusHwFwgiYiIibz55ssMHDhQ/2tNja1I9ZXLh1HphqfqvG1FqlE9t6Io5OXlMX/+
fGRZ5plnnqFbt26m+Ky4Q001q7YNVtnZ2cyYMUM0WJkH0WB1LaEoCufOnePw4cPk5eWRm5tLXl4e
58+fJzw8XJuJVWdjmzVr5raIlSSJyspKKisr7W6ygXZRUzGy0vLmzJa3LaACza7JGbU9HrNabZnZ
4mj79u1MnDid0tLxQDJwHJgAzATUOsXvgKVIUkcU5TYk6Q0UZQlX7alAkt5DUbYQFJTInXd25LXX
XnHLBsqfWK1WysrKNFFnFiu6msIPHNlt2doj1iRSjxw5QkpKCmVlZTz99NPceOONAXk9t02catGi
RbXEKYApU6aQkZFBVFQU69evp1evXv4csuAqQqwKqi5IFy5c0ASsKmLPnDlDaGgonTp10gRsYmIi
zZs31y7Q6jL/t99+S2xsrLZUpSiK3ZKVmfw1XcG2ycgMosHINsddo/j6YtcE3jsef1lt6We2zCKC
9OTm5jJs2Ah++qk7lZXfXWkunKHb6xyStAxFOQk8SHU/VoB3CA7eSX7+FzRp0sSpDZS/SzfMKlKd
4Sj8QF8mExISwunTp7lw4QLt27cnNDSUb775hpSUFH7++WeefvppbrnlloC4dgvqJUKsChyjKAqX
Ll3iyJEjWklBXl4eJSUlBAcHEx8fD8Dnn3/OuXPneO+992jRooUmVh1dJB2JK39f/I2ajMxgpVUT
zpK7bN0ibEWdmY/JEUYhC76yn/LWEqw7aVNm4ezZs9xzz0g++SQHeBao3i0tyy9htX6FJMkoyuNc
nXkFsBAZOZ9ly2byP//zoN33GdV5+7N0I1BFqiPUmfvy8nKtKRSq3odvv/02zz33HD/88AMxMTFc
vnyZ5ORkBg4cqJWMNWnSxM9HILhGEWJV4D6nT5/m5ZdfZvXq1TRr1owBAwZQUlLCiRMnkGWZ+Csx
empt7PXXX2+37FSTuHJUE+vNG7g+mclZtKvZsa2vBbSyBfXGb5bmLlfR20+Zrf7ZUaqUozpv1bRf
Fd2B8FCkx2KxMGfO3/nHPzZw6dIEqhqsVPKAFcAMJOlTFCUL+B/g1wDI8n/o1auYzMwMt465ptIN
TzceBcpMt6u4Ul5y/PhxFi9ezDfffMODDz5IdHQ0R44cIT8/X/s3adIkFi1a5KejEFzDCLEqcA9F
Ubj55pvp1q0b06dPp0ePHnbbLBYL33zzjV1zV1FREVarlTZt2tg1drVr184urtMVk3hPLgs6asoJ
JNFgi6tNYM6au1xtovPF8XgjF95XODKKV6+vaie4Lx/MPE1qaipjx07m0qV7UZTfAJVI0mwUJQm4
48peucA24HZgEBERz5Gd/QEdO3Z09GPdwtEqjup/bPRQ5ug97azRKNBwRaSePHmSpUuX8tVXXzF7
9mwGDRpkKMzVpszw8PBq27xBRkYGM2bMwGKxMG7cOGbOnGm3PTMzk3vuuUdzyhk+fDhPPfWUT8Ym
8DlCrArcR73wuYp6M/nuu+80m63c3Fy+/fZbKisradWqlTYLm5SURIcOHexmmhzVEBqJWFdmCPX1
jrbLYYGIp5qmzNJ0pPcUrQ8PEbb2YGqTnqMSGbPVaxphmwb2/fffM3z4A5w6FU95eYMr7gB/xrap
Cn4ANiDLMrNnz+DJJ2d5fYy2D8DOHswALegjLCysXohU9UHckUg9deoUL7zwAgcPHmTmzJncfffd
ppk9tlgsJCQk8O677xIXF8fNN9/M5s2bSUpK0vbJzMxk2bJlpKam+nGkAh8hEqwE7uOOUIWr/pjt
27enffv2DBkyRNtmtVopLi4mLy+Pw4cPk5WVxdGjR+0CD9SZWH3ggX6G0DbwwNHSq5qG5E/Te0+h
F911TZqqTXKXJ0s39HZNgRYaocdZ2pQrRvE1vad9XbphG3ihlmNERkbStWtXDh78iJEjH+KDD1JR
lBHYC1WAWCCZhg3385e/POaT8dYUfKCe54qKCs37WD2Pqie0p0oKfImtJV1wcLDhNeHMmTOsWLGC
ffv28dhjj7F06VLTiFSVnJwcOnbsqPVFjBo1ip07d9qJVahu4i+4thBiVeAzZFmmbdu2tG3bljvu
uEN73WqtW+CBesMvLy/XbkZwVZCpQsJM3pquYNRk1KBBA6+O31bE2j6oGNUf255rV2cI9UuV9UGk
1iZtyplRvO1Mt1EErbdmvV2pGW7YsCG7dm3nL3+ZyaZNb3HpUmOgtc1PuURExAds375ViyD1J+p7
Tr/cX9N72sy13q6I1HPnzrFq1Sr27t3L9OnTSUlJMe3nzCj69MCBA3b7SJLE/v376d69O3FxcSxZ
soQuXbr4eqgCPyLEqsDvyLJMbGwssbGx/O53v9Ne1wcevPXWW4aBBy1btuSjjz5i06ZN7Nq1i6Sk
JGRZtrsRqbNejhphzHATUjFKmvJ3xr2jmStXk7skSdLqOENDQ+s8M+xv9EELnhTdklRzBK3trLen
GhZVkVpWVgY4D/YICgpi+fIl/Pa3tzN27EQuXvwt0OvK977H738/lFtuuaX2J8ED6GtS9Q96Nc3G
6utijR4YjGzNvIlepBq953755Rf+8Y9/sHv3bqZMmcK8efO8noJWV1w5b7169aKoqIjIyEjS09O5
9957OXLkiA9GJzALomZVEHCogQe7du1izZo1HDx4kD59+hAeHk5lZaVLgQfOPEz94RXr6eQsf6MK
V/VGrz5AmK25yx305QtmCFpw1WrLqNbbE41teXl5DBlyH2fOtKW8PJFGjd7m8OHP/WZ95M3GKWfX
D0citi6/3/a64Og9d/HiRf75z3+yY8cOJkyYwJgxY9wu4fIX2dnZzJ07l4yMDAAWLFiALMvVmqxs
adeuHYcOHaJp06a+GqbAd4gGK0H9Ydq0abz11ltMnjyZSZMmERMTU+fAA395xRo5FZh9NqQmnC0l
m6W5yx1c6bQ2I47e02qQh/rfkJAQQkJCan2uf/75Z0aOfJD9+z9k3bq1jBgxwgtHUzP+7O73hjev
vsQkPDy8mki9dOkS69evZ8uWLTz88MOMGzfOFKUX7lBZWUlCQgJ79+6lVatW9O7du1qDVUlJCc2b
N0eSJHJychgxYgSFhYX+G7TAmwix6mv++te/smvXLkJDQ+nQoQPr16+nUaNG1fZzZtshqM6RI0do
27atS9YqzgIP2rdvb2ezFRcXZydiveUVW9+cCuo6S+dOopSvGmHqmwen+je6dOkSslyVZqR/jxut
MLjycGaxWHjvvfcYOHCgTx8uzG5BVZt4VPVz5EikXr58mY0bN/L666/z4IMPMmHCBJ/ZTHmD9PR0
7R44duxYZs+ezZo1a4CqeNTVq1fz8ssvExwcTGRkJMuWLfN7mYnAawix6mv27NnD7373O2RZZtas
KvuWlJQUu31cse0QeAd15qKgoECbic3NzeX48ePI8tXAA7WswCjwwF2vWLh6c1XrN+uDAPKm/ZSj
BwZ3m7vcwdauyYwCyF2M/kbO6mLNbrVlK1IDMWzB6OGssrKymjfv/v37KS8vJzExkdjYWN58803W
r1/PiBEjmDx5MlFRUX4+EoHAowjrKl+TnJys/X+fPn3Yvn17tX1cte0QeB519q9r16507dpVe90o
8GD79u0OAw/UfG1HXrG2lkQqwcHB2oxJIN1gbfGV/VRtm7vctX/Suy+YobGtruhFamRkZI0lJjVZ
mpnFass2tjaQbelsZ7DVv1NQUJC2wqKe6/z8fHbt2sWRI0c4c+YMzZo1o2/fvpSWlrJ79247qz+B
oL4ixKqPWLduHaNHj672uiu2HQLfonZjq01a9913H2AceJCens63336LxWIhNja2WuCBxWJh06ZN
nDp1ij//+c9a7aYqrFQfS3/7arqDrU2YJzxfa4ur9k+udHOrwtvWU9SM595VXOkcd4e6Wm15onNe
L1Lrw9/ItmxG/yChfv5jYmIoKytjwoQJPPLII/z444/k5eWRn5/Pli1byMvL46mnnuKBBx7w49EI
BN5FiNU6kpyczMmTJ6u9Pn/+fIYOHQrA888/T2hoqOHFJJAvttca7gQeZGRksG/fPk6fPk23bt3o
3bs3aWlpDgMPbGesarrZ+7NrXl8baGb7KWf2T6qNlmpnpn5PUFAQFosFwDTNXe7gj7AFd6y2ahMw
Ud9FakRERLXzZ7VaSU1NZeXKlQwYMID09HSt871t27bcdNNN/hi6hit9FtOmTSM9PZ3IyEg2bNhA
z549/TBSQX1BiNU6smfPnhq3b9iwgbS0NPbu3Wu4PS4ujqKiIu3roqIiWrdubbivwLyogQdRUVHs
3LmTtLQ07r//fmbMmEHTpk3tAg+OHDnC5cuX3Qo88JdXrNHSeKAuuwKaSFLFkzqjpYZHeMPD1BfY
uhWYJRHM1YCJmrx51b9DfRGpqpetUcoZVP0d09PTeeGFF+jbty+pqanExMT4cdTVsVgsTJkyxa7P
YtiwYXala2lpaRw9epSCggIOHDjApEmTyM7O9uOoBYGOEKteJCMjg8WLF5OVleWwnuimm26ioKCA
wsJCWrVqxZYtW9i8ebNXx7V161bmzp1Lfn4+Bw8epFevXob7xcfH07BhQ+1mk5OT49Vx1QciIiJo
0aIFeXl5tGzZUnu9toEH6r9GjRo59IpVm4E86RVrZD9VH8SCs7QpbyV3eQu9pZaZZ7tVnJnx276f
VdGqHqNZVhncwVWRunfvXpYuXUqvXr3Yvn273fXDTLjSZ5GamsqYMWOAqn6Ns2fPUlJSQosWLfwx
ZEE9QIhVLzJ16lTKy8u1Rqtbb72Vl156iRMnTjB+/Hh2795NcHAwq1at4o477tBsO7zdXNWtWzfN
PLomJEkiBH7HKwAAFudJREFUMzNTGC+7QWRkJHPmzHG6nyRJXHfdddx+++3cfvvt2utq4MHhw4fJ
y8tj165dLF68mPPnzxMeHq7NxKoi1lHggXrTd9cr1hMm8WajLmlT7jR3+bLhKBBFqjP0y/22TYs1
rTLU1mrL2+gf+IxEqqIoZGVlsXjxYpKSkvjXv/5l+pU1V/osjPYpLi4WYlVQa4RY9SIFBQWGr7dq
1Yrdu3drXw8ePJjBgwf7algkJia6vK8TazOBh5EkicaNG3Pbbbdx2223aa/rAw/effddVq5cWWPg
QVhYmPa9RrODejsi9eaqejsGukj15tK4p5q73J0dDKS6YVdxpSa1JpeCmh7QvJEo5QxXRer+/ftZ
uHAh8fHxrF+/XpupNDvu+CbX5vsEAiOEWBU4RJIkBg4cSFBQEBMmTGD8+PH+HtI1iyRJNGjQgN69
e9O7d2/tdX3gwb59+1i7dm2NgQe2IrakpIRTp07Rtm1bu8740tJSh+UEZr/p+HvW0ZXmLv1yt7Py
jfooUm29bGtbZuKO1VZdbM3cOSbV4UOf3KaO6+DBg6SkpNCiRQvWrFlDhw4d6vQ7fY0rfRb6fYqL
i4mLi/PZGAX1DyFW6ymuuBQ4Y9++fcTGxnLq1CmSk5NJTEykX79+nh6qoA6oDUI9evSgR48e2uv6
wIPPPvuMN954Qws8aNasGRcvXuTgwYNMnDiR2bNn283+6L1ijRpgjLLm/YnZBZ0rs4NGzV3qPsHB
wYZ1toGGJ0SqMzxpa+bK+XZFpH7++ecsWLCAhg0b8sILL5CQkBCQf0dX+iyGDRvGqlWrGDVqFNnZ
2TRu3FiUAAjqhBCr9RRnLgWuEBsbC0BMTAy///3vycnJEWI1QHAUePDJJ5+wcOFC9u7dy6BBg5gx
YwZHjhxhyJAhLgUe6G/0/jKGt0WfNtWgQYOAEgFGXfOq+LFYLISEhGgz3upMbE0paWY9dl+IVFeo
rdWWUc23KnYtFgvh4eGGIvXw4cMsWLCA4OBgUlJSuOGGG0z7N3IFR30WtvGod911F2lpaXTs2JGo
qCjWr1/v51ELAh0Rt3oNM2DAAJYsWcKNN95YbVtpaSkWi4UGDRpw8eJFBg0axJw5cxg0aJDXxuOq
S4ErHn+C6nz//ff069ePGTNmMH78eKKjo7VtRoEHubm5NQYeOBKxjvLPPdnFbWSpFWhxm0boBZ2j
YzI6z/5+aHCEq8dkVoxqvtX/h6vi98cff+TLL78kMTGR+Ph4jh49SkpKCpWVlcyZM4fu3bsH1HEL
BH7C8EMixOo1yI4dO5g2bRqnT5+mUaNG9OzZk/T0dDuXgmPHjmnJTZWVlfzxj39k9uzZXh1Xfn4+
siwzYcIEzcJFj8ViISEhwc7jb/PmzSKe1kUsFovbTUZq4EFubq727+jRo5SXl9O8eXM7dwJngQd1
FbFGllr62axAQxVCNS0ju/uz9OfaHwETgS5SjdA3gwUHB2vv8U8++YT58+dTUFDA6dOnCQkJoU+f
PvTt25cuXbqQlJQkYlEFAucIsSoIDAYMGOBQrH788cfMmzePjIwMAFJSUgCYNWuWT8coqBKxJSUl
djOx7gYeGAlZR1ZEqvgB6oVbgS+Ft/6hwdn5rktdrK1INVoaD0RqstVSKSwsZOHChZSUlPD444/T
tGlT8vPzyc/PJy8vj7y8PJo1a8YHH3zgp6MQCAICw4uFqFkVBBSuePwJfIMsy8TGxno18EC12FIf
qtWGGXW7Gfw03cXWJB7wyexwbZu73Enu0ovUQA+RAPumPUd1tsXFxSxatIjCwkL+9re/0b9/f20f
fYmVP60Az5w5w8iRI/nuu++Ij4/nrbfeonHjxtX2E2EwAjMixKrAp9TVpSDQb37XAp4IPGjTpg3b
t29n06ZN/Oc//6FJkyYEBQXV6BVr5jhUqB64YIbZ4bpGoqoxteq2iIiIeidSHTXtnTx5ksWLF5OX
l8eTTz5JcnKy0+P253lJSUkhOTmZJ554goULF5KSkqKtTNkiwmAEZkSIVYFPqatLgSsefwJz4krg
QU5ODs8++yyffPIJPXv2JCEhgfnz5zsNPHDVZssfHfNmFKnOcBaJapsipSiKdiyqwDNLc5e7WK1W
ysrKahSpP/74I8uXL+fTTz9l1qxZrF69OiBm91NTU8nKygJgzJgx9O/f31CsggiDEZgPIVYFpsTR
xdIVjz9BYKEGHrz33nssXryYe++9l1dffZXOnTu7HXhgKxr87RWritSysjJkWa4XHqlwVdCp6Uxq
CYN+JtaTyV3exhWR+tNPP7FixQo+/vhjHn/8cZYvXx4QIlWlpKRE8zpt0aIFJSUlhvuJMBiBGREN
VgLT4IpLAUB6erpmXTV27FivuxSAqPfyBe+++y6dO3embdu2Ne5nG3iglhTk5uZqgQfx8fF2IlZN
53LkFetp2yd1fJcvXyYoKEjrGg9k6uJY4MvmLnexTTsLDQ0lNDS0mgA9e/YsK1euJCsrixkzZjB8
+HCPxfZ6GkdlVs8//zxjxozh559/1l5r2rQpZ86cqbbvDz/8YBcGs3LlSuGvLfAlwg1AIKgtTzzx
BNddd51W7/Xzzz8bLqG1a9eOQ4cOiXovP6A2Lh07dkxr7srNzeX7779HURTDwANbYVRXr1ghUt3/
2Y78Yr1dh6yP5A0LC6smUs+fP89LL73Ef/7zH6ZOncro0aNNK1JdITExkczMTFq2bMkPP/zAgAED
yM/Pr/F75s2bR3R0NI8//riPRikQCLEqENSaxMREsrKyaNGiBSdPnqR///6GF/p27drxySef0KxZ
Mz+MUmCEJwIPnHnFqqIuODhYiFQP/G5HDw51rUN2RaReuHCBV155hdTUVCZNmsSDDz5o13wWqDzx
xBM0a9aMmTNnkpKSwtmzZ6s9cPsjDEYg0CHEqkBQW5o0aaItoSmKQtOmTe2W1FTat29Po0aNRL1X
gGAbeKCWFBgFHiQlJdGpUye7wIPTp0/zxRdfcOONN2qiVRVX/l7eri1mD12obXKXWkNbXl7uUKRe
unSJtWvXsm3bNsaNG8fDDz9MaGion47U85w5c4YRI0bw/fff25Uy+TsMRiDQIcSqQFATot5LoFJT
4EFERAQWi4XPP/+cIUOGsGTJEqKjo2sMPLBd3jbKmPd3o47ZRaozairhUJu/ZFkmNDSUy5cvI8uy
FjdcVlbGa6+9xr/+9S8eeugh/vSnP2luEwKBwOcIsSoQ1BZR7yU4fvw4ixYtYuPGjfTv359f//rX
FBYWuhV44Ki5y19esYEuUh2hKAqXL1/m8uXLBAcH28Wi7ty5kylTphATE0Pr1q05duwYv/nNb5g0
aRI9evSgSZMm/h6+QHAtI8SqQFBbzFbvlZGRoTkijBs3jpkzZ1bbZ9q0aaSnpxMZGcmGDRvo2bOn
x8dxraAoCrfeeit9+/blL3/5C61ataq2XQ08yM3N1eI1jQIPEhMTadasWTURa1QX6y2v2PouUsvL
y7X6YX1TVEVFBW+88Qbbtm3jhhtuICYmhm+++Ub7m0VFRTFkyBDWrl3rp6MQCK5phFgVCGqLmeq9
LBYLCQkJvPvuu8TFxXHzzTezefNmkpKStH3S0tJYtWoVaWlpHDhwgOnTp5Odne3xsVxLWCwWt7vB
bQMPVHeCvLw8fvrpJ8LCwujUqVO1wIOavGJrErGu2GzVZ5GqOjE4EqmVlZVs27aNNWvWcPfddzN9
+nQaNWpU7eccP36cn376ie7du/vyEDS2bt3K3Llzyc/P5+DBg/Tq1ctwP1ceWAWCAESIVYGgPvDx
xx8zb948MjIyALQZ3lmzZmn7TJw4kQEDBjBy5EjA3s1A4H8URbELPFBFrBp40KFDB7uZWH3ggbte
sZIkaRGiqpm/2VO0XMEVkWqxWHj77bdZvXo1ycnJPPbYY6Ze6s/Pz0eWZSZMmMDSpUsNxaorD6wC
QYBieFEKbH8VgeAa5Pjx47Rp00b7unXr1hw4cMDpPsXFxUKsmgRJkoiMjKRHjx706NFDe10fePDZ
Z5/xxhtv1Bh4YDszapQipYpYgKCgILv6TTOlSLmD3tM2Kiqqmki1Wq3s3r2bFStW0K9fP3bt2sV1
113npxG7TmJiotN9cnJy6NixI/Hx8QCMGjWKnTt3CrEqqLcIsSoQBBiuigv9qkkgipJrDUmSCAsL
o2vXrnTt2lV73SjwYPv27Q4DD+Lj48nIyGDlypWsW7eO2NhYO2utiooKLl++HBBRqLa4KlL37NnD
smXLuPnmm9mxY0e9e0hz5YFVIKhPCLEqEAQYcXFxFBUVaV8XFRXRunXrGvcpLi4mLi7OZ2MUeBZJ
kggJCSEhIYGEhAStNlofePDVV1+xZs0aDh06RExMDH369GHTpk0kJSVpgQdhYWEObbbUelazecUq
ikJFRQVlZWUEBQURGRlZLXjBarWSmZnJkiVL6Nq1K1u2bKnWCGcWHNnkzZ8/n6FDhzr9fjM+SAgE
3kSIVYEgwLjpppsoKCigsLCQVq1asWXLFjZv3my3z7Bhw1i1ahWjRo0iOzubxo0b17vZJQGaoGzf
vj3Hjh1jy5YtAGzcuJEhQ4Zw4sQJzSs2KyvL5cADIxHrD69YVaRevnxZK53Qi1RFUfjoo49YtGgR
HTp04LXXXuP666/3+Fg8yZ49e+r0/a48sAoE9QkhVgWCACM4OJhVq1Zxxx13YLFYGDt2LElJSaxZ
swaACRMmcNddd5GWlkbHjh2Jiopi/fr1Ph2js07lzMxM7rnnHtq3bw/A8OHDeeqpp3w6xvpGRUUF
c+fOZdiwYZrobNu2LW3btuXOO+/U9tMHHmzYsEELPGjcuLFms5WUlERCQgJRUVE1esVWVFR43CtW
L1IjIiIMReqBAwdISUkhLi6Of/7zn9r7qb7gqAHalQdWgaA+IdwABAKBR3GlUzkzM5Nly5aRmprq
x5EKbFEUhZ9++kmric3NzXU78MDIZgswrIs1ErF6kRoeHl6t9EBRFD799FNSUlJo0qQJzzzzDJ07
d/bdifIyO3bsYNq0aZw+fZpGjRrRs2dP0tPT7WzyANLT07UHwrFjx4pYVEF9QVhXCQQC7+OKtVZm
ZiZLly7l3//+t1/GKHAdfeCBKmJdCTwA17xiZVnWhKoqUvXWWoqi8OWXX7JgwQLCw8OZM2cOSUlJ
on5TIKhfCOsqgUDgfVzpVJYkif3799O9e3fi4uJYsmQJXbp08fVQBS4gSRKNGzfmtttu47bbbtNe
1wcevPvuu6xcuZIzZ84QGhrqNPBAdTg4deoUUVFR2u+yWq2UlZWRkpJCREQESUlJREZG8vrrryPL
Ms8++yy/+tWvhEgVCK4hhFgVCAQexRUR0atXL4qKioiMjCQ9PZ17772XI0eO+GB0Ak8hSRINGjSg
d+/e9O7dW3tdH3iwb98+1q5daxd40LlzZywWC1u3biUmJoZt27ZpM6lqTWzXrl05cOAAL730El9/
/TWlpaV06NCB5557ji5dutClSxduv/12WrZs6cezIBAIfIEQqwKBwKO40qncoEED7f8HDx7M5MmT
OXPmDE2bNvXZOAXeoabAg8uXL/P666+zePFizp49y29/+1u+//57hgwZYhd4EB0dzfvvv8+ZM2dY
tmwZt9xyC2VlZRw5ckQrRXjrrbeIiYnxm1h1NRY1Pj6ehg0bEhQUREhICDk5OT4eqUAQ+AixKhAI
PIorncolJSU0b94cSZLIyclBURSfCdVHHnmE3bt307x5c7788kvDfaZNm0Z6ejqRkZFs2LCBnj17
+mRs9RlJkhgzZgyff/45c+bMYeTIkQQFBRkGHmzbto0XX3yRfv36aTP1ERERdO/ene7du/v5SKro
1q0bO3bsYMKECTXuJ0kSmZmZ4kFMIKgDQqwKBAKP4oq11rZt23j55ZcJDg4mMjKSN99802fje/jh
h5k6dSoPPfSQ4fa0tDSOHj1KQUEBBw4cYNKkSWRnZ/tsfPWZuXPn0qlTJzsbKqPAg0CwMXMlFlXF
SSOzQCBwgnADEAgE1xyFhYUMHTrUcGZ14sSJDBgwgJEjRwJVoiQrK0uEKggMGTBgAEuXLnVYBtC+
fXsaNWpEUFAQEyZMYPz48T4eoUAQUAg3AIFAIHCGkZtBcXGxEKvXIHWNRQXYt28fsbGxnDp1iuTk
ZBITE+nXr5+nhyoQ1GuEWBUIBAId+hUnYZN0bVLXWFSA2NhYAGJiYvj9739PTk6OEKsCgZt4PsxZ
IBAIAhi9m0FxcTFxcXF+HJHA7DgqpystLeWXX34B4OLFi7zzzjt069bNl0MTCOoFQqwKBAKBDcOG
DWPjxo0AZGdn07hxY1ECIKjGjh07aNOmDdnZ2dx9990MHjwYgBMnTnD33XcDcPLkSfr160ePHj3o
06cPQ4YMYdCgQf4ctkAQkIgGK4FAcE0xevRosrKyOH36NC1atGDevHlUVFQAaDZEU6ZMISMjg6io
KNavX++wecYbOLPWyszM5J577qF9+/YADB8+PCC65wUCgcAFDGuuhFgVCAQCE/Hhhx8SHR3NQw89
5FCsLlu2jNTUVD+MTiAQCLyKoVgVZQACgUBgIvr160eTJk1q3Ef4dgoEgmsJIVYFAoEggJAkif37
99O9e3fuuusucnNz/T0kgUAg8CpCrAoEAkEA0atXL4qKivjvf//L1KlTuffee/09JFPz17/+laSk
JLp37859993HuXPnDPfLyMggMTGRTp06sXDhQh+PUiAQ1IQQqwKBQBBANGjQgMjISAAGDx5MRUUF
Z86c8fOozMugQYM4fPgw//3vf+ncuTMLFiyoto/FYtGa6nJzc9m8eTN5eXl+GK1AIDBCiFWBQCAI
IEpKSrSa1ZycHBRFoWnTpn4elXlJTk5GlqtudX369KG4uLjaPjk5OXTs2JH4+HhCQkIYNWoUO3fu
9PVQBQKBA4RYFQgEAhMxevRo+vbty9dff02bNm1Yt24da9asYc2aNQBs27aNbt260aNHD2bMmMGb
b77p8zEWFRUxYMAAbrjhBrp27cqLL75ouN+0adPo1KkT3bt357PPPvPxKKuzbt067rrrrmqvG0Xs
Hj9+3JdDEwgENSDiVgUCgcBEbN68ucbtjz76KI8++qiPRmNMSEgIy5cvp0ePHly4cIEbb7yR5ORk
kpKStH3S0tI4evQoBQUFHDhwgEmTJpGdne2V8SQnJ3Py5Mlqr8+fP5+hQ4cC8PzzzxMaGsoDDzxQ
bT8RpysQmBshVgUCgUDgFi1btqRly5YAREdHk5SUxIkTJ+zEampqKmPGjAGqlt/Pnj1LSUmJV9LA
9uzZU+P2DRs2kJaWxt69ew236yN2i4qKaN26tUfHKBAIao8oAxAIBAJBrSksLOSzzz6jT58+dq8b
La0b1Yt6m4yMDBYvXszOnTsJDw833Oemm26ioKCAwsJCysvL2bJlC8OGDfPxSAUCgSOEWBUIBAJB
rbhw4QL3338/K1asIDo6utp2fXiBP5bbp06dyoULF0hOTqZnz55MnjwZgBMnTnD33XcDEBwczKpV
q7jjjjvo0qULI0eOtJslFggE/kXErQoEAoHAbSoqKhgyZAiDBw9mxowZ1bZPnDiR/v37M2rUKAAS
ExPJysryShmAQCCoN4i4VYFAIBDUHUVRGDt2LF26dDEUqgDDhg1j48aNAGRnZ9O4cWMhVAUCQa1w
NrMqEAgEAoEdkiT9GvgA+IKrK3BPAm0BFEVZc2W/VcCdwEXgYUVRPvX9aAUCQaAjxKpAIBAIBAKB
wLSIMgCBQCAQCAQCgWkRYlUgEAgEAoFAYFqEWBUIBAKBQCAQmBYhVgUCgUAgEAgEpkWIVYFAIBAI
BAKBafl/CyJH4aoVOLIAAAAASUVORK5CYII=
)